{
 "cells": [
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {},
   "outputs": [],
   "source": [
    "import altair as alt\n",
    "import numpy as np\n",
    "import pandas as pd"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Parameters:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {},
   "outputs": [],
   "source": [
    "x_mean, y_mean = 4, 4\n",
    "sigma_X, sigma_Y = 3, 3\n",
    "sigma_D = 0.5\n",
    "dAverage = np.sqrt(x_mean**2 + y_mean**2)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "2D Gaussian function $f(x, y)$:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {},
   "outputs": [],
   "source": [
    "def f_xy(x, y):\n",
    "    return (\n",
    "        1\n",
    "        / (2 * np.pi * sigma_X * sigma_Y)\n",
    "        * np.exp(\n",
    "            -(\n",
    "                ((x - x_mean) ** 2) / (2 * sigma_X**2)\n",
    "                + ((y - y_mean) ** 2) / (2 * sigma_Y**2)\n",
    "            )\n",
    "        )\n",
    "    )"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Distance Gaussian $f_D(d, x, y)$:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {},
   "outputs": [],
   "source": [
    "def fD(d, x, y):\n",
    "    return (\n",
    "        1\n",
    "        / (np.sqrt(2 * np.pi) * sigma_D)\n",
    "        * np.exp(-((d - np.sqrt(x**2 + y**2)) ** 2) / (2 * sigma_D**2))\n",
    "    )"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Combined function $f(x, y, d)$:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {},
   "outputs": [],
   "source": [
    "def f_xy_d(x, y, d):\n",
    "    return fD(d, x, y) * f_xy(x, y)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Interactive plotting function: one panel for $f(x, y)$, the other for $f(x, y, d)$ with a circle of radius $d$."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {},
   "outputs": [],
   "source": [
    "def generate_common_components(font_size=12, domain=[-10, 10]):\n",
    "    axis_cfg = alt.Axis(\n",
    "        grid=False,\n",
    "        labelFont=\"Times\",\n",
    "        labelFontSize=font_size,\n",
    "        labelFontStyle=\"normal\",\n",
    "        titleFont=\"Times\",\n",
    "        titleFontSize=font_size,\n",
    "        titleFontStyle=\"italic\",\n",
    "    )\n",
    "\n",
    "    xs = np.linspace(domain[0], domain[1], 70)\n",
    "    X, Y = np.meshgrid(xs, xs)\n",
    "    step = xs[1] - xs[0]\n",
    "\n",
    "    df_grid = pd.DataFrame(\n",
    "        {\n",
    "            \"x\": X.ravel(),\n",
    "            \"y\": Y.ravel(),\n",
    "            \"x2\": (X + step).ravel(),\n",
    "            \"y2\": (Y + step).ravel(),\n",
    "            \"center_x\": (X + step / 2).ravel(),\n",
    "            \"center_y\": (Y + step / 2).ravel(),\n",
    "            \"value_uncond\": f_xy(X, Y).ravel(),\n",
    "        }\n",
    "    )\n",
    "\n",
    "    d_slider = alt.param(\n",
    "        \"d\",\n",
    "        bind=alt.binding_range(\n",
    "            min=float(dAverage - 2), max=float(dAverage + 2), step=0.1, name=\"𝑑\"\n",
    "        ),\n",
    "        value=float(dAverage),\n",
    "    )\n",
    "\n",
    "    encode_x = alt.X(\"x:Q\", title=\"x\", scale=alt.Scale(domain=domain), axis=axis_cfg)\n",
    "    encode_y = alt.Y(\"y:Q\", title=\"y\", scale=alt.Scale(domain=domain), axis=axis_cfg)\n",
    "\n",
    "    return {\n",
    "        \"axis_cfg\": axis_cfg,\n",
    "        \"df_grid\": df_grid,\n",
    "        \"d_slider\": d_slider,\n",
    "        \"encode_x\": encode_x,\n",
    "        \"encode_y\": encode_y,\n",
    "    }\n",
    "\n",
    "\n",
    "def plot_unconditional(components):\n",
    "    chart = (\n",
    "        alt.Chart(components[\"df_grid\"])\n",
    "        .mark_rect()\n",
    "        .encode(\n",
    "            x=components[\"encode_x\"],\n",
    "            x2=\"x2:Q\",\n",
    "            y=components[\"encode_y\"],\n",
    "            y2=\"y2:Q\",\n",
    "            color=alt.Color(\"value_uncond:Q\", legend=None),\n",
    "        )\n",
    "        .properties(width=300, height=300)\n",
    "    )\n",
    "    return chart\n",
    "\n",
    "\n",
    "def plot_conditional(components):\n",
    "    expr = (\n",
    "        \"datum.value_uncond / (sqrt(2 * PI) * {sd}) * \"\n",
    "        \"exp(- (pow(d - sqrt(pow(datum.center_x, 2) + pow(datum.center_y, 2)), 2)) / (2 * {sd} * {sd}))\"\n",
    "    ).format(sd=sigma_D)\n",
    "\n",
    "    density_chart = (\n",
    "        alt.Chart(components[\"df_grid\"])\n",
    "        .transform_calculate(value_cond=expr)\n",
    "        .mark_rect()\n",
    "        .encode(\n",
    "            x=components[\"encode_x\"],\n",
    "            x2=\"x2:Q\",\n",
    "            y=components[\"encode_y\"],\n",
    "            y2=\"y2:Q\",\n",
    "            color=alt.Color(\"value_cond:Q\", legend=None),\n",
    "        )\n",
    "        .properties(width=300, height=300)\n",
    "        .add_params(components[\"d_slider\"])\n",
    "    )\n",
    "\n",
    "    theta = np.linspace(0, 2 * np.pi, 100)\n",
    "    circle_df = pd.DataFrame({\"theta\": theta, \"x\": np.cos(theta), \"y\": np.sin(theta)})\n",
    "\n",
    "    circle = (\n",
    "        alt.Chart(circle_df)\n",
    "        .transform_calculate(\n",
    "            x_scaled=\"datum.x * d\",\n",
    "            y_scaled=\"datum.y * d\",\n",
    "        )\n",
    "        .mark_line(color=\"gray\", strokeWidth=1)\n",
    "        .encode(\n",
    "            x=alt.X(\n",
    "                \"x_scaled:Q\",\n",
    "                scale=alt.Scale(domain=[-10, 10]),\n",
    "                axis=components[\"axis_cfg\"],\n",
    "            ),\n",
    "            y=alt.Y(\n",
    "                \"y_scaled:Q\",\n",
    "                scale=alt.Scale(domain=[-10, 10]),\n",
    "                axis=components[\"axis_cfg\"],\n",
    "            ),\n",
    "            order=alt.Order(\"theta:Q\"),\n",
    "        )\n",
    "        .add_params(components[\"d_slider\"])\n",
    "    )\n",
    "\n",
    "    return density_chart + circle\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Create the interactive slider for $d$"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {},
   "outputs": [],
   "source": [
    "components = generate_common_components(font_size=12)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 11,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<style>\n",
       "  #altair-viz-f2387fe632604e8a98580dbd74f9d88f.vega-embed {\n",
       "    width: 100%;\n",
       "    display: flex;\n",
       "  }\n",
       "\n",
       "  #altair-viz-f2387fe632604e8a98580dbd74f9d88f.vega-embed details,\n",
       "  #altair-viz-f2387fe632604e8a98580dbd74f9d88f.vega-embed details summary {\n",
       "    position: relative;\n",
       "  }\n",
       "</style>\n",
       "<div id=\"altair-viz-f2387fe632604e8a98580dbd74f9d88f\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-f2387fe632604e8a98580dbd74f9d88f\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-f2387fe632604e8a98580dbd74f9d88f\");\n",
       "    }\n",
       "\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.20.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function maybeLoadScript(lib, version) {\n",
       "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
       "      return (VEGA_DEBUG[key] == version) ?\n",
       "        Promise.resolve(paths[lib]) :\n",
       "        new Promise(function(resolve, reject) {\n",
       "          var s = document.createElement('script');\n",
       "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "          s.async = true;\n",
       "          s.onload = () => {\n",
       "            VEGA_DEBUG[key] = version;\n",
       "            return resolve(paths[lib]);\n",
       "          };\n",
       "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "          s.src = paths[lib];\n",
       "        });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      let deps = [\"vega-embed\"];\n",
       "      require(deps, displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else {\n",
       "      maybeLoadScript(\"vega\", \"5\")\n",
       "        .then(() => maybeLoadScript(\"vega-lite\", \"5.20.1\"))\n",
       "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-14fe821a8b2c524d22cd359632b5b9ec\"}, \"mark\": {\"type\": \"rect\"}, \"encoding\": {\"color\": {\"field\": \"value_uncond\", \"legend\": null, \"type\": \"quantitative\"}, \"x\": {\"axis\": {\"grid\": false, \"labelFont\": \"Times\", \"labelFontSize\": 12, \"labelFontStyle\": \"normal\", \"titleFont\": \"Times\", \"titleFontSize\": 12, \"titleFontStyle\": \"italic\"}, \"field\": \"x\", \"scale\": {\"domain\": [-10, 10]}, \"title\": \"x\", \"type\": \"quantitative\"}, \"x2\": {\"field\": \"x2\"}, \"y\": {\"axis\": {\"grid\": false, \"labelFont\": \"Times\", \"labelFontSize\": 12, \"labelFontStyle\": \"normal\", \"titleFont\": \"Times\", \"titleFontSize\": 12, \"titleFontStyle\": \"italic\"}, \"field\": \"y\", \"scale\": {\"domain\": [-10, 10]}, \"title\": \"y\", \"type\": \"quantitative\"}, \"y2\": {\"field\": \"y2\"}}, \"height\": 300, \"width\": 300, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.20.1.json\", \"datasets\": {\"data-14fe821a8b2c524d22cd359632b5b9ec\": [{\"x\": -10.0, \"y\": -10.0, \"x2\": -9.710144927536232, \"y2\": -9.710144927536232, \"center_x\": -9.855072463768117, \"center_y\": -9.855072463768117, \"value_uncond\": 6.160399900836236e-12}, {\"x\": -9.710144927536232, \"y\": -10.0, \"x2\": -9.420289855072465, \"y2\": -9.710144927536232, \"center_x\": -9.565217391304348, \"center_y\": -9.855072463768117, \"value_uncond\": 9.624960816767312e-12}, {\"x\": -9.420289855072463, \"y\": -10.0, \"x2\": -9.130434782608695, \"y2\": -9.710144927536232, \"center_x\": -9.275362318840578, \"center_y\": -9.855072463768117, \"value_uncond\": 1.4898236004033224e-11}, {\"x\": -9.130434782608695, \"y\": -10.0, \"x2\": -8.840579710144928, \"y2\": -9.710144927536232, \"center_x\": -8.985507246376812, \"center_y\": -9.855072463768117, \"value_uncond\": 2.284633516259696e-11}, {\"x\": -8.840579710144928, \"y\": -10.0, \"x2\": -8.55072463768116, \"y2\": -9.710144927536232, \"center_x\": -8.695652173913043, \"center_y\": -9.855072463768117, \"value_uncond\": 3.470915591894953e-11}, {\"x\": -8.55072463768116, \"y\": -10.0, \"x2\": -8.260869565217392, \"y2\": -9.710144927536232, \"center_x\": -8.405797101449277, \"center_y\": -9.855072463768117, \"value_uncond\": 5.2241708969495986e-11}, {\"x\": -8.26086956521739, \"y\": -10.0, \"x2\": -7.971014492753623, \"y2\": -9.710144927536232, \"center_x\": -8.115942028985508, \"center_y\": -9.855072463768117, \"value_uncond\": 7.789983057737388e-11}, {\"x\": -7.971014492753623, \"y\": -10.0, \"x2\": -7.681159420289855, \"y2\": -9.710144927536232, \"center_x\": -7.826086956521739, \"center_y\": -9.855072463768117, \"value_uncond\": 1.150804271859119e-10}, {\"x\": -7.681159420289855, \"y\": -10.0, \"x2\": -7.391304347826088, \"y2\": -9.710144927536232, \"center_x\": -7.536231884057972, \"center_y\": -9.855072463768117, \"value_uncond\": 1.6842720127136773e-10}, {\"x\": -7.391304347826087, \"y\": -10.0, \"x2\": -7.101449275362319, \"y2\": -9.710144927536232, \"center_x\": -7.246376811594203, \"center_y\": -9.855072463768117, \"value_uncond\": 2.442130195215731e-10}, {\"x\": -7.101449275362318, \"y\": -10.0, \"x2\": -6.811594202898551, \"y2\": -9.710144927536232, \"center_x\": -6.956521739130435, \"center_y\": -9.855072463768117, \"value_uncond\": 3.508093898116566e-10}, {\"x\": -6.811594202898551, \"y\": -10.0, \"x2\": -6.521739130434783, \"y2\": -9.710144927536232, \"center_x\": -6.666666666666667, \"center_y\": -9.855072463768117, \"value_uncond\": 4.99251547394975e-10}, {\"x\": -6.521739130434782, \"y\": -10.0, \"x2\": -6.231884057971015, \"y2\": -9.710144927536232, \"center_x\": -6.3768115942028984, \"center_y\": -9.855072463768117, \"value_uncond\": 7.039040184716764e-10}, {\"x\": -6.231884057971014, \"y\": -10.0, \"x2\": -5.942028985507246, \"y2\": -9.710144927536232, \"center_x\": -6.08695652173913, \"center_y\": -9.855072463768117, \"value_uncond\": 9.832258407473207e-10}, {\"x\": -5.942028985507246, \"y\": -10.0, \"x2\": -5.6521739130434785, \"y2\": -9.710144927536232, \"center_x\": -5.797101449275362, \"center_y\": -9.855072463768117, \"value_uncond\": 1.360626540139841e-09}, {\"x\": -5.6521739130434785, \"y\": -10.0, \"x2\": -5.362318840579711, \"y2\": -9.710144927536232, \"center_x\": -5.507246376811595, \"center_y\": -9.855072463768117, \"value_uncond\": 1.8653932740416187e-09}, {\"x\": -5.36231884057971, \"y\": -10.0, \"x2\": -5.072463768115942, \"y2\": -9.710144927536232, \"center_x\": -5.217391304347826, \"center_y\": -9.855072463768117, \"value_uncond\": 2.5336562342392283e-09}, {\"x\": -5.0724637681159415, \"y\": -10.0, \"x2\": -4.782608695652174, \"y2\": -9.710144927536232, \"center_x\": -4.927536231884058, \"center_y\": -9.855072463768117, \"value_uncond\": 3.4093437159328184e-09}, {\"x\": -4.782608695652174, \"y\": -10.0, \"x2\": -4.492753623188406, \"y2\": -9.710144927536232, \"center_x\": -4.63768115942029, \"center_y\": -9.855072463768117, \"value_uncond\": 4.5450608224403395e-09}, {\"x\": -4.492753623188405, \"y\": -10.0, \"x2\": -4.202898550724638, \"y2\": -9.710144927536232, \"center_x\": -4.3478260869565215, \"center_y\": -9.855072463768117, \"value_uncond\": 6.002807632471971e-09}, {\"x\": -4.202898550724638, \"y\": -10.0, \"x2\": -3.91304347826087, \"y2\": -9.710144927536232, \"center_x\": -4.057971014492754, \"center_y\": -9.855072463768117, \"value_uncond\": 7.85443531273968e-09}, {\"x\": -3.913043478260869, \"y\": -10.0, \"x2\": -3.6231884057971016, \"y2\": -9.710144927536232, \"center_x\": -3.7681159420289854, \"center_y\": -9.855072463768117, \"value_uncond\": 1.0181724065953475e-08}, {\"x\": -3.6231884057971016, \"y\": -10.0, \"x2\": -3.333333333333334, \"y2\": -9.710144927536232, \"center_x\": -3.4782608695652177, \"center_y\": -9.855072463768117, \"value_uncond\": 1.3075957290817584e-08}, {\"x\": -3.333333333333333, \"y\": -10.0, \"x2\": -3.0434782608695654, \"y2\": -9.710144927536232, \"center_x\": -3.1884057971014492, \"center_y\": -9.855072463768117, \"value_uncond\": 1.663686445303529e-08}, {\"x\": -3.0434782608695645, \"y\": -10.0, \"x2\": -2.753623188405797, \"y2\": -9.710144927536232, \"center_x\": -2.8985507246376807, \"center_y\": -9.855072463768117, \"value_uncond\": 2.097081348614346e-08}, {\"x\": -2.753623188405797, \"y\": -10.0, \"x2\": -2.4637681159420293, \"y2\": -9.710144927536232, \"center_x\": -2.608695652173913, \"center_y\": -9.855072463768117, \"value_uncond\": 2.6188154329573736e-08}, {\"x\": -2.4637681159420284, \"y\": -10.0, \"x2\": -2.1739130434782608, \"y2\": -9.710144927536232, \"center_x\": -2.3188405797101446, \"center_y\": -9.855072463768117, \"value_uncond\": 3.239965010092863e-08}, {\"x\": -2.1739130434782608, \"y\": -10.0, \"x2\": -1.8840579710144931, \"y2\": -9.710144927536232, \"center_x\": -2.028985507246377, \"center_y\": -9.855072463768117, \"value_uncond\": 3.9711982012199266e-08}, {\"x\": -1.8840579710144922, \"y\": -10.0, \"x2\": -1.5942028985507246, \"y2\": -9.710144927536232, \"center_x\": -1.7391304347826084, \"center_y\": -9.855072463768117, \"value_uncond\": 4.822237773806992e-08}, {\"x\": -1.5942028985507246, \"y\": -10.0, \"x2\": -1.304347826086957, \"y2\": -9.710144927536232, \"center_x\": -1.4492753623188408, \"center_y\": -9.855072463768117, \"value_uncond\": 5.801248815659017e-08}, {\"x\": -1.304347826086957, \"y\": -10.0, \"x2\": -1.0144927536231894, \"y2\": -9.710144927536232, \"center_x\": -1.1594202898550732, \"center_y\": -9.855072463768117, \"value_uncond\": 6.914172005796482e-08}, {\"x\": -1.0144927536231876, \"y\": -10.0, \"x2\": -0.72463768115942, \"y2\": -9.710144927536232, \"center_x\": -0.8695652173913038, \"center_y\": -9.855072463768117, \"value_uncond\": 8.164031666641845e-08}, {\"x\": -0.72463768115942, \"y\": -10.0, \"x2\": -0.43478260869565233, \"y2\": -9.710144927536232, \"center_x\": -0.5797101449275361, \"center_y\": -9.855072463768117, \"value_uncond\": 9.550255627540823e-08}, {\"x\": -0.43478260869565233, \"y\": -10.0, \"x2\": -0.1449275362318847, \"y2\": -9.710144927536232, \"center_x\": -0.2898550724637685, \"center_y\": -9.855072463768117, \"value_uncond\": 1.1068050361167863e-07}, {\"x\": -0.14492753623188293, \"y\": -10.0, \"x2\": 0.1449275362318847, \"y2\": -9.710144927536232, \"center_x\": 8.881784197001252e-16, \"center_y\": -9.855072463768117, \"value_uncond\": 1.2707879011787393e-07}, {\"x\": 0.1449275362318847, \"y\": -10.0, \"x2\": 0.43478260869565233, \"y2\": -9.710144927536232, \"center_x\": 0.2898550724637685, \"center_y\": -9.855072463768117, \"value_uncond\": 1.445509102212839e-07}, {\"x\": 0.43478260869565233, \"y\": -10.0, \"x2\": 0.72463768115942, \"y2\": -9.710144927536232, \"center_x\": 0.5797101449275361, \"center_y\": -9.855072463768117, \"value_uncond\": 1.628974945214488e-07}, {\"x\": 0.72463768115942, \"y\": -10.0, \"x2\": 1.0144927536231876, \"y2\": -9.710144927536232, \"center_x\": 0.8695652173913038, \"center_y\": -9.855072463768117, \"value_uncond\": 1.8186695398019615e-07}, {\"x\": 1.0144927536231894, \"y\": -10.0, \"x2\": 1.304347826086957, \"y2\": -9.710144927536232, \"center_x\": 1.1594202898550732, \"center_y\": -9.855072463768117, \"value_uncond\": 2.0115878137617703e-07}, {\"x\": 1.304347826086957, \"y\": -10.0, \"x2\": 1.5942028985507246, \"y2\": -9.710144927536232, \"center_x\": 1.4492753623188408, \"center_y\": -9.855072463768117, \"value_uncond\": 2.2042965122937443e-07}, {\"x\": 1.5942028985507246, \"y\": -10.0, \"x2\": 1.8840579710144922, \"y2\": -9.710144927536232, \"center_x\": 1.7391304347826084, \"center_y\": -9.855072463768117, \"value_uncond\": 2.3930228500439113e-07}, {\"x\": 1.884057971014494, \"y\": -10.0, \"x2\": 2.1739130434782616, \"y2\": -9.710144927536232, \"center_x\": 2.028985507246378, \"center_y\": -9.855072463768117, \"value_uncond\": 2.573768564143178e-07}, {\"x\": 2.1739130434782616, \"y\": -10.0, \"x2\": 2.4637681159420293, \"y2\": -9.710144927536232, \"center_x\": 2.3188405797101455, \"center_y\": -9.855072463768117, \"value_uncond\": 2.742445168837601e-07}, {\"x\": 2.4637681159420293, \"y\": -10.0, \"x2\": 2.753623188405797, \"y2\": -9.710144927536232, \"center_x\": 2.608695652173913, \"center_y\": -9.855072463768117, \"value_uncond\": 2.8950244033097844e-07}, {\"x\": 2.753623188405797, \"y\": -10.0, \"x2\": 3.0434782608695645, \"y2\": -9.710144927536232, \"center_x\": 2.8985507246376807, \"center_y\": -9.855072463768117, \"value_uncond\": 3.027696362842212e-07}, {\"x\": 3.0434782608695663, \"y\": -10.0, \"x2\": 3.333333333333334, \"y2\": -9.710144927536232, \"center_x\": 3.18840579710145, \"center_y\": -9.855072463768117, \"value_uncond\": 3.137026763368097e-07}, {\"x\": 3.333333333333334, \"y\": -10.0, \"x2\": 3.6231884057971016, \"y2\": -9.710144927536232, \"center_x\": 3.4782608695652177, \"center_y\": -9.855072463768117, \"value_uncond\": 3.2201043320822097e-07}, {\"x\": 3.6231884057971016, \"y\": -10.0, \"x2\": 3.913043478260869, \"y2\": -9.710144927536232, \"center_x\": 3.7681159420289854, \"center_y\": -9.855072463768117, \"value_uncond\": 3.2746695161816275e-07}, {\"x\": 3.913043478260871, \"y\": -10.0, \"x2\": 4.202898550724639, \"y2\": -9.710144927536232, \"center_x\": 4.057971014492755, \"center_y\": -9.855072463768117, \"value_uncond\": 3.2992165741277494e-07}, {\"x\": 4.202898550724639, \"y\": -10.0, \"x2\": 4.492753623188406, \"y2\": -9.710144927536232, \"center_x\": 4.347826086956522, \"center_y\": -9.855072463768117, \"value_uncond\": 3.2930626127546e-07}, {\"x\": 4.492753623188406, \"y\": -10.0, \"x2\": 4.782608695652174, \"y2\": -9.710144927536232, \"center_x\": 4.63768115942029, \"center_y\": -9.855072463768117, \"value_uncond\": 3.256379152547972e-07}, {\"x\": 4.782608695652174, \"y\": -10.0, \"x2\": 5.0724637681159415, \"y2\": -9.710144927536232, \"center_x\": 4.927536231884058, \"center_y\": -9.855072463768117, \"value_uncond\": 3.1901841847480727e-07}, {\"x\": 5.072463768115943, \"y\": -10.0, \"x2\": 5.362318840579711, \"y2\": -9.710144927536232, \"center_x\": 5.217391304347827, \"center_y\": -9.855072463768117, \"value_uncond\": 3.096295233639719e-07}, {\"x\": 5.362318840579711, \"y\": -10.0, \"x2\": 5.6521739130434785, \"y2\": -9.710144927536232, \"center_x\": 5.507246376811595, \"center_y\": -9.855072463768117, \"value_uncond\": 2.977246444577404e-07}, {\"x\": 5.6521739130434785, \"y\": -10.0, \"x2\": 5.942028985507246, \"y2\": -9.710144927536232, \"center_x\": 5.797101449275362, \"center_y\": -9.855072463768117, \"value_uncond\": 2.8361749763298007e-07}, {\"x\": 5.942028985507246, \"y\": -10.0, \"x2\": 6.231884057971014, \"y2\": -9.710144927536232, \"center_x\": 6.08695652173913, \"center_y\": -9.855072463768117, \"value_uncond\": 2.6766838036410634e-07}, {\"x\": 6.2318840579710155, \"y\": -10.0, \"x2\": 6.521739130434783, \"y2\": -9.710144927536232, \"center_x\": 6.376811594202899, \"center_y\": -9.855072463768117, \"value_uncond\": 2.502689293738903e-07}, {\"x\": 6.521739130434785, \"y\": -10.0, \"x2\": 6.8115942028985526, \"y2\": -9.710144927536232, \"center_x\": 6.666666666666669, \"center_y\": -9.855072463768117, \"value_uncond\": 2.318262525705508e-07}, {\"x\": 6.811594202898551, \"y\": -10.0, \"x2\": 7.101449275362318, \"y2\": -9.710144927536232, \"center_x\": 6.956521739130435, \"center_y\": -9.855072463768117, \"value_uncond\": 2.1274732529638975e-07}, {\"x\": 7.10144927536232, \"y\": -10.0, \"x2\": 7.391304347826088, \"y2\": -9.710144927536232, \"center_x\": 7.246376811594204, \"center_y\": -9.855072463768117, \"value_uncond\": 1.9342447068386744e-07}, {\"x\": 7.391304347826086, \"y\": -10.0, \"x2\": 7.681159420289854, \"y2\": -9.710144927536232, \"center_x\": 7.53623188405797, \"center_y\": -9.855072463768117, \"value_uncond\": 1.7422261977549334e-07}, {\"x\": 7.681159420289855, \"y\": -10.0, \"x2\": 7.971014492753623, \"y2\": -9.710144927536232, \"center_x\": 7.826086956521739, \"center_y\": -9.855072463768117, \"value_uncond\": 1.5546888264731634e-07}, {\"x\": 7.971014492753625, \"y\": -10.0, \"x2\": 8.260869565217392, \"y2\": -9.710144927536232, \"center_x\": 8.115942028985508, \"center_y\": -9.855072463768117, \"value_uncond\": 1.3744477328023635e-07}, {\"x\": 8.26086956521739, \"y\": -10.0, \"x2\": 8.550724637681158, \"y2\": -9.710144927536232, \"center_x\": 8.405797101449274, \"center_y\": -9.855072463768117, \"value_uncond\": 1.203812353436658e-07}, {\"x\": 8.55072463768116, \"y\": -10.0, \"x2\": 8.840579710144928, \"y2\": -9.710144927536232, \"center_x\": 8.695652173913043, \"center_y\": -9.855072463768117, \"value_uncond\": 1.0445642947586815e-07}, {\"x\": 8.84057971014493, \"y\": -10.0, \"x2\": 9.130434782608697, \"y2\": -9.710144927536232, \"center_x\": 8.985507246376812, \"center_y\": -9.855072463768117, \"value_uncond\": 8.979607877804766e-08}, {\"x\": 9.130434782608695, \"y\": -10.0, \"x2\": 9.420289855072463, \"y2\": -9.710144927536232, \"center_x\": 9.275362318840578, \"center_y\": -9.855072463768117, \"value_uncond\": 7.647603836058899e-08}, {\"x\": 9.420289855072465, \"y\": -10.0, \"x2\": 9.710144927536232, \"y2\": -9.710144927536232, \"center_x\": 9.565217391304348, \"center_y\": -9.855072463768117, \"value_uncond\": 6.452666313083046e-08}, {\"x\": 9.710144927536234, \"y\": -10.0, \"x2\": 10.000000000000002, \"y2\": -9.710144927536232, \"center_x\": 9.855072463768117, \"center_y\": -9.855072463768117, \"value_uncond\": 5.3938497688053584e-08}, {\"x\": 10.0, \"y\": -10.0, \"x2\": 10.289855072463768, \"y2\": -9.710144927536232, \"center_x\": 10.144927536231883, \"center_y\": -9.855072463768117, \"value_uncond\": 4.466880147298297e-08}, {\"x\": -10.0, \"y\": -9.710144927536232, \"x2\": -9.710144927536232, \"y2\": -9.420289855072465, \"center_x\": -9.855072463768117, \"center_y\": -9.565217391304348, \"value_uncond\": 9.624960816767312e-12}, {\"x\": -9.710144927536232, \"y\": -9.710144927536232, \"x2\": -9.420289855072465, \"y2\": -9.420289855072465, \"center_x\": -9.565217391304348, \"center_y\": -9.565217391304348, \"value_uncond\": 1.503796380357231e-11}, {\"x\": -9.420289855072463, \"y\": -9.710144927536232, \"x2\": -9.130434782608695, \"y2\": -9.420289855072465, \"center_x\": -9.275362318840578, \"center_y\": -9.565217391304348, \"value_uncond\": 2.327688787838372e-11}, {\"x\": -9.130434782608695, \"y\": -9.710144927536232, \"x2\": -8.840579710144928, \"y2\": -9.420289855072465, \"center_x\": -8.985507246376812, \"center_y\": -9.565217391304348, \"value_uncond\": 3.56949360896001e-11}, {\"x\": -8.840579710144928, \"y\": -9.710144927536232, \"x2\": -8.55072463768116, \"y2\": -9.420289855072465, \"center_x\": -8.695652173913043, \"center_y\": -9.565217391304348, \"value_uncond\": 5.42293148302932e-11}, {\"x\": -8.55072463768116, \"y\": -9.710144927536232, \"x2\": -8.260869565217392, \"y2\": -9.420289855072465, \"center_x\": -8.405797101449277, \"center_y\": -9.565217391304348, \"value_uncond\": 8.162203914133939e-11}, {\"x\": -8.26086956521739, \"y\": -9.710144927536232, \"x2\": -7.971014492753623, \"y2\": -9.420289855072465, \"center_x\": -8.115942028985508, \"center_y\": -9.565217391304348, \"value_uncond\": 1.2171008846978545e-10}, {\"x\": -7.971014492753623, \"y\": -9.710144927536232, \"x2\": -7.681159420289855, \"y2\": -9.420289855072465, \"center_x\": -7.826086956521739, \"center_y\": -9.565217391304348, \"value_uncond\": 1.7980076298145616e-10}, {\"x\": -7.681159420289855, \"y\": -9.710144927536232, \"x2\": -7.391304347826088, \"y2\": -9.420289855072465, \"center_x\": -7.536231884057972, \"center_y\": -9.565217391304348, \"value_uncond\": 2.6314934725173203e-10}, {\"x\": -7.391304347826087, \"y\": -9.710144927536232, \"x2\": -7.101449275362319, \"y2\": -9.420289855072465, \"center_x\": -7.246376811594203, \"center_y\": -9.565217391304348, \"value_uncond\": 3.815565193292877e-10}, {\"x\": -7.101449275362318, \"y\": -9.710144927536232, \"x2\": -6.811594202898551, \"y2\": -9.420289855072465, \"center_x\": -6.956521739130435, \"center_y\": -9.565217391304348, \"value_uncond\": 5.481018579058321e-10}, {\"x\": -6.811594202898551, \"y\": -9.710144927536232, \"x2\": -6.521739130434783, \"y2\": -9.420289855072465, \"center_x\": -6.666666666666667, \"center_y\": -9.565217391304348, \"value_uncond\": 7.800267285789022e-10}, {\"x\": -6.521739130434782, \"y\": -9.710144927536232, \"x2\": -6.231884057971015, \"y2\": -9.420289855072465, \"center_x\": -6.3768115942028984, \"center_y\": -9.565217391304348, \"value_uncond\": 1.0997741551867875e-09}, {\"x\": -6.231884057971014, \"y\": -9.710144927536232, \"x2\": -5.942028985507246, \"y2\": -9.420289855072465, \"center_x\": -6.08695652173913, \"center_y\": -9.565217391304348, \"value_uncond\": 1.5361843944483886e-09}, {\"x\": -5.942028985507246, \"y\": -9.710144927536232, \"x2\": -5.6521739130434785, \"y2\": -9.420289855072465, \"center_x\": -5.797101449275362, \"center_y\": -9.565217391304348, \"value_uncond\": 2.125832307302315e-09}, {\"x\": -5.6521739130434785, \"y\": -9.710144927536232, \"x2\": -5.362318840579711, \"y2\": -9.420289855072465, \"center_x\": -5.507246376811595, \"center_y\": -9.565217391304348, \"value_uncond\": 2.9144759203172313e-09}, {\"x\": -5.36231884057971, \"y\": -9.710144927536232, \"x2\": -5.072463768115942, \"y2\": -9.420289855072465, \"center_x\": -5.217391304347826, \"center_y\": -9.565217391304348, \"value_uncond\": 3.958564763693418e-09}, {\"x\": -5.0724637681159415, \"y\": -9.710144927536232, \"x2\": -4.782608695652174, \"y2\": -9.420289855072465, \"center_x\": -4.927536231884058, \"center_y\": -9.565217391304348, \"value_uncond\": 5.326732063658852e-09}, {\"x\": -4.782608695652174, \"y\": -9.710144927536232, \"x2\": -4.492753623188406, \"y2\": -9.420289855072465, \"center_x\": -4.63768115942029, \"center_y\": -9.565217391304348, \"value_uncond\": 7.10116762385412e-09}, {\"x\": -4.492753623188405, \"y\": -9.710144927536232, \"x2\": -4.202898550724638, \"y2\": -9.420289855072465, \"center_x\": -4.3478260869565215, \"center_y\": -9.565217391304348, \"value_uncond\": 9.378739884287616e-09}, {\"x\": -4.202898550724638, \"y\": -9.710144927536232, \"x2\": -3.91304347826087, \"y2\": -9.420289855072465, \"center_x\": -4.057971014492754, \"center_y\": -9.565217391304348, \"value_uncond\": 1.2271708548123759e-08}, {\"x\": -3.913043478260869, \"y\": -9.710144927536232, \"x2\": -3.6231884057971016, \"y2\": -9.420289855072465, \"center_x\": -3.7681159420289854, \"center_y\": -9.565217391304348, \"value_uncond\": 1.5907846367024987e-08}, {\"x\": -3.6231884057971016, \"y\": -9.710144927536232, \"x2\": -3.333333333333334, \"y2\": -9.420289855072465, \"center_x\": -3.4782608695652177, \"center_y\": -9.565217391304348, \"value_uncond\": 2.0429773812047134e-08}, {\"x\": -3.333333333333333, \"y\": -9.710144927536232, \"x2\": -3.0434782608695654, \"y2\": -9.420289855072465, \"center_x\": -3.1884057971014492, \"center_y\": -9.565217391304348, \"value_uncond\": 2.5993307423532162e-08}, {\"x\": -3.0434782608695645, \"y\": -9.710144927536232, \"x2\": -2.753623188405797, \"y2\": -9.420289855072465, \"center_x\": -2.8985507246376807, \"center_y\": -9.565217391304348, \"value_uncond\": 3.276463563225292e-08}, {\"x\": -2.753623188405797, \"y\": -9.710144927536232, \"x2\": -2.4637681159420293, \"y2\": -9.420289855072465, \"center_x\": -2.608695652173913, \"center_y\": -9.565217391304348, \"value_uncond\": 4.0916168323973e-08}, {\"x\": -2.4637681159420284, \"y\": -9.710144927536232, \"x2\": -2.1739130434782608, \"y2\": -9.420289855072465, \"center_x\": -2.3188405797101446, \"center_y\": -9.565217391304348, \"value_uncond\": 5.0620960930811905e-08}, {\"x\": -2.1739130434782608, \"y\": -9.710144927536232, \"x2\": -1.8840579710144931, \"y2\": -9.420289855072465, \"center_x\": -2.028985507246377, \"center_y\": -9.565217391304348, \"value_uncond\": 6.204569134735891e-08}, {\"x\": -1.8840579710144922, \"y\": -9.710144927536232, \"x2\": -1.5942028985507246, \"y2\": -9.420289855072465, \"center_x\": -1.7391304347826084, \"center_y\": -9.565217391304348, \"value_uncond\": 7.53422673351565e-08}, {\"x\": -1.5942028985507246, \"y\": -9.710144927536232, \"x2\": -1.304347826086957, \"y2\": -9.420289855072465, \"center_x\": -1.4492753623188408, \"center_y\": -9.565217391304348, \"value_uncond\": 9.063825959002471e-08}, {\"x\": -1.304347826086957, \"y\": -9.710144927536232, \"x2\": -1.0144927536231894, \"y2\": -9.420289855072465, \"center_x\": -1.1594202898550732, \"center_y\": -9.565217391304348, \"value_uncond\": 1.080264848182127e-07}, {\"x\": -1.0144927536231876, \"y\": -9.710144927536232, \"x2\": -0.72463768115942, \"y2\": -9.420289855072465, \"center_x\": -0.8695652173913038, \"center_y\": -9.565217391304348, \"value_uncond\": 1.2755419479766016e-07}, {\"x\": -0.72463768115942, \"y\": -9.710144927536232, \"x2\": -0.43478260869565233, \"y2\": -9.420289855072465, \"center_x\": -0.5797101449275361, \"center_y\": -9.565217391304348, \"value_uncond\": 1.4921244997863546e-07}, {\"x\": -0.43478260869565233, \"y\": -9.710144927536232, \"x2\": -0.1449275362318847, \"y2\": -9.420289855072465, \"center_x\": -0.2898550724637685, \"center_y\": -9.565217391304348, \"value_uncond\": 1.7292635666361052e-07}, {\"x\": -0.14492753623188293, \"y\": -9.710144927536232, \"x2\": 0.1449275362318847, \"y2\": -9.420289855072465, \"center_x\": 8.881784197001252e-16, \"center_y\": -9.565217391304348, \"value_uncond\": 1.98546911761475e-07}, {\"x\": 0.1449275362318847, \"y\": -9.710144927536232, \"x2\": 0.43478260869565233, \"y2\": -9.420289855072465, \"center_x\": 0.2898550724637685, \"center_y\": -9.565217391304348, \"value_uncond\": 2.258452161066759e-07}, {\"x\": 0.43478260869565233, \"y\": -9.710144927536232, \"x2\": 0.72463768115942, \"y2\": -9.420289855072465, \"center_x\": 0.5797101449275361, \"center_y\": -9.565217391304348, \"value_uncond\": 2.545097765009833e-07}, {\"x\": 0.72463768115942, \"y\": -9.710144927536232, \"x2\": 1.0144927536231876, \"y2\": -9.420289855072465, \"center_x\": 0.8695652173913038, \"center_y\": -9.565217391304348, \"value_uncond\": 2.841475121909858e-07}, {\"x\": 1.0144927536231894, \"y\": -9.710144927536232, \"x2\": 1.304347826086957, \"y2\": -9.420289855072465, \"center_x\": 1.1594202898550732, \"center_y\": -9.565217391304348, \"value_uncond\": 3.1428891303493833e-07}, {\"x\": 1.304347826086957, \"y\": -9.710144927536232, \"x2\": 1.5942028985507246, \"y2\": -9.420289855072465, \"center_x\": 1.4492753623188408, \"center_y\": -9.565217391304348, \"value_uncond\": 3.4439756997730165e-07}, {\"x\": 1.5942028985507246, \"y\": -9.710144927536232, \"x2\": 1.8840579710144922, \"y2\": -9.420289855072465, \"center_x\": 1.7391304347826084, \"center_y\": -9.565217391304348, \"value_uncond\": 3.738840259732958e-07}, {\"x\": 1.884057971014494, \"y\": -9.710144927536232, \"x2\": 2.1739130434782616, \"y2\": -9.420289855072465, \"center_x\": 2.028985507246378, \"center_y\": -9.565217391304348, \"value_uncond\": 4.021235955468218e-07}, {\"x\": 2.1739130434782616, \"y\": -9.710144927536232, \"x2\": 2.4637681159420293, \"y2\": -9.420289855072465, \"center_x\": 2.3188405797101455, \"center_y\": -9.565217391304348, \"value_uncond\": 4.284774968685328e-07}, {\"x\": 2.4637681159420293, \"y\": -9.710144927536232, \"x2\": 2.753623188405797, \"y2\": -9.420289855072465, \"center_x\": 2.608695652173913, \"center_y\": -9.565217391304348, \"value_uncond\": 4.523163576062548e-07}, {\"x\": 2.753623188405797, \"y\": -9.710144927536232, \"x2\": 3.0434782608695645, \"y2\": -9.420289855072465, \"center_x\": 2.8985507246376807, \"center_y\": -9.565217391304348, \"value_uncond\": 4.7304492121476363e-07}, {\"x\": 3.0434782608695663, \"y\": -9.710144927536232, \"x2\": 3.333333333333334, \"y2\": -9.420289855072465, \"center_x\": 3.18840579710145, \"center_y\": -9.565217391304348, \"value_uncond\": 4.901266178267039e-07}, {\"x\": 3.333333333333334, \"y\": -9.710144927536232, \"x2\": 3.6231884057971016, \"y2\": -9.420289855072465, \"center_x\": 3.4782608695652177, \"center_y\": -9.565217391304348, \"value_uncond\": 5.031065924468107e-07}, {\"x\": 3.6231884057971016, \"y\": -9.710144927536232, \"x2\": 3.913043478260869, \"y2\": -9.420289855072465, \"center_x\": 3.7681159420289854, \"center_y\": -9.565217391304348, \"value_uncond\": 5.116318143053023e-07}, {\"x\": 3.913043478260871, \"y\": -9.710144927536232, \"x2\": 4.202898550724639, \"y2\": -9.420289855072465, \"center_x\": 4.057971014492755, \"center_y\": -9.565217391304348, \"value_uncond\": 5.154670275171308e-07}, {\"x\": 4.202898550724639, \"y\": -9.710144927536232, \"x2\": 4.492753623188406, \"y2\": -9.420289855072465, \"center_x\": 4.347826086956522, \"center_y\": -9.565217391304348, \"value_uncond\": 5.145055373860044e-07}, {\"x\": 4.492753623188406, \"y\": -9.710144927536232, \"x2\": 4.782608695652174, \"y2\": -9.420289855072465, \"center_x\": 4.63768115942029, \"center_y\": -9.565217391304348, \"value_uncond\": 5.087741421390123e-07}, {\"x\": 4.782608695652174, \"y\": -9.710144927536232, \"x2\": 5.0724637681159415, \"y2\": -9.420289855072465, \"center_x\": 4.927536231884058, \"center_y\": -9.565217391304348, \"value_uncond\": 4.984318919345294e-07}, {\"x\": 5.072463768115943, \"y\": -9.710144927536232, \"x2\": 5.362318840579711, \"y2\": -9.420289855072465, \"center_x\": 5.217391304347827, \"center_y\": -9.565217391304348, \"value_uncond\": 4.837627553509998e-07}, {\"x\": 5.362318840579711, \"y\": -9.710144927536232, \"x2\": 5.6521739130434785, \"y2\": -9.420289855072465, \"center_x\": 5.507246376811595, \"center_y\": -9.565217391304348, \"value_uncond\": 4.6516266528456056e-07}, {\"x\": 5.6521739130434785, \"y\": -9.710144927536232, \"x2\": 5.942028985507246, \"y2\": -9.420289855072465, \"center_x\": 5.797101449275362, \"center_y\": -9.565217391304348, \"value_uncond\": 4.4312176897744417e-07}, {\"x\": 5.942028985507246, \"y\": -9.710144927536232, \"x2\": 6.231884057971014, \"y2\": -9.420289855072465, \"center_x\": 6.08695652173913, \"center_y\": -9.565217391304348, \"value_uncond\": 4.182029923970312e-07}, {\"x\": 6.2318840579710155, \"y\": -9.710144927536232, \"x2\": 6.521739130434783, \"y2\": -9.420289855072465, \"center_x\": 6.376811594202899, \"center_y\": -9.565217391304348, \"value_uncond\": 3.9101822570820645e-07}, {\"x\": 6.521739130434785, \"y\": -9.710144927536232, \"x2\": 6.8115942028985526, \"y2\": -9.420289855072465, \"center_x\": 6.666666666666669, \"center_y\": -9.565217391304348, \"value_uncond\": 3.6220353113548075e-07}, {\"x\": 6.811594202898551, \"y\": -9.710144927536232, \"x2\": 7.101449275362318, \"y2\": -9.420289855072465, \"center_x\": 6.956521739130435, \"center_y\": -9.565217391304348, \"value_uncond\": 3.32394763783409e-07}, {\"x\": 7.10144927536232, \"y\": -9.710144927536232, \"x2\": 7.391304347826088, \"y2\": -9.420289855072465, \"center_x\": 7.246376811594204, \"center_y\": -9.565217391304348, \"value_uncond\": 3.022048862580275e-07}, {\"x\": 7.391304347826086, \"y\": -9.710144927536232, \"x2\": 7.681159420289854, \"y2\": -9.420289855072465, \"center_x\": 7.53623188405797, \"center_y\": -9.565217391304348, \"value_uncond\": 2.7220406397741216e-07}, {\"x\": 7.681159420289855, \"y\": -9.710144927536232, \"x2\": 7.971014492753623, \"y2\": -9.420289855072465, \"center_x\": 7.826086956521739, \"center_y\": -9.565217391304348, \"value_uncond\": 2.4290337117625886e-07}, {\"x\": 7.971014492753625, \"y\": -9.710144927536232, \"x2\": 8.260869565217392, \"y2\": -9.420289855072465, \"center_x\": 8.115942028985508, \"center_y\": -9.565217391304348, \"value_uncond\": 2.1474264310538734e-07}, {\"x\": 8.26086956521739, \"y\": -9.710144927536232, \"x2\": 8.550724637681158, \"y2\": -9.420289855072465, \"center_x\": 8.405797101449274, \"center_y\": -9.565217391304348, \"value_uncond\": 1.880827043548819e-07}, {\"x\": 8.55072463768116, \"y\": -9.710144927536232, \"x2\": 8.840579710144928, \"y2\": -9.420289855072465, \"center_x\": 8.695652173913043, \"center_y\": -9.565217391304348, \"value_uncond\": 1.6320191171812923e-07}, {\"x\": 8.84057971014493, \"y\": -9.710144927536232, \"x2\": 9.130434782608697, \"y2\": -9.420289855072465, \"center_x\": 8.985507246376812, \"center_y\": -9.565217391304348, \"value_uncond\": 1.402966939890929e-07}, {\"x\": 9.130434782608695, \"y\": -9.710144927536232, \"x2\": 9.420289855072463, \"y2\": -9.420289855072465, \"center_x\": 9.275362318840578, \"center_y\": -9.565217391304348, \"value_uncond\": 1.1948556660134085e-07}, {\"x\": 9.420289855072465, \"y\": -9.710144927536232, \"x2\": 9.710144927536232, \"y2\": -9.420289855072465, \"center_x\": 9.565217391304348, \"center_y\": -9.565217391304348, \"value_uncond\": 1.0081595582564033e-07}, {\"x\": 9.710144927536234, \"y\": -9.710144927536232, \"x2\": 10.000000000000002, \"y2\": -9.420289855072465, \"center_x\": 9.855072463768117, \"center_y\": -9.565217391304348, \"value_uncond\": 8.427308861756474e-08}, {\"x\": 10.0, \"y\": -9.710144927536232, \"x2\": 10.289855072463768, \"y2\": -9.420289855072465, \"center_x\": 10.144927536231883, \"center_y\": -9.565217391304348, \"value_uncond\": 6.979018746024219e-08}, {\"x\": -10.0, \"y\": -9.420289855072463, \"x2\": -9.710144927536232, \"y2\": -9.130434782608695, \"center_x\": -9.855072463768117, \"center_y\": -9.275362318840578, \"value_uncond\": 1.4898236004033224e-11}, {\"x\": -9.710144927536232, \"y\": -9.420289855072463, \"x2\": -9.420289855072465, \"y2\": -9.130434782608695, \"center_x\": -9.565217391304348, \"center_y\": -9.275362318840578, \"value_uncond\": 2.327688787838372e-11}, {\"x\": -9.420289855072463, \"y\": -9.420289855072463, \"x2\": -9.130434782608695, \"y2\": -9.130434782608695, \"center_x\": -9.275362318840578, \"center_y\": -9.275362318840578, \"value_uncond\": 3.6029712292174674e-11}, {\"x\": -9.130434782608695, \"y\": -9.420289855072463, \"x2\": -8.840579710144928, \"y2\": -9.130434782608695, \"center_x\": -8.985507246376812, \"center_y\": -9.275362318840578, \"value_uncond\": 5.52512983829845e-11}, {\"x\": -8.840579710144928, \"y\": -9.420289855072463, \"x2\": -8.55072463768116, \"y2\": -9.130434782608695, \"center_x\": -8.695652173913043, \"center_y\": -9.275362318840578, \"value_uncond\": 8.394019945216559e-11}, {\"x\": -8.55072463768116, \"y\": -9.420289855072463, \"x2\": -8.260869565217392, \"y2\": -9.130434782608695, \"center_x\": -8.405797101449277, \"center_y\": -9.275362318840578, \"value_uncond\": 1.2634071196837675e-10}, {\"x\": -8.26086956521739, \"y\": -9.420289855072463, \"x2\": -7.971014492753623, \"y2\": -9.130434782608695, \"center_x\": -8.115942028985508, \"center_y\": -9.275362318840578, \"value_uncond\": 1.883920004054249e-10}, {\"x\": -7.971014492753623, \"y\": -9.420289855072463, \"x2\": -7.681159420289855, \"y2\": -9.130434782608695, \"center_x\": -7.826086956521739, \"center_y\": -9.275362318840578, \"value_uncond\": 2.783091018860542e-10}, {\"x\": -7.681159420289855, \"y\": -9.420289855072463, \"x2\": -7.391304347826088, \"y2\": -9.130434782608695, \"center_x\": -7.536231884057972, \"center_y\": -9.275362318840578, \"value_uncond\": 4.0732228985637995e-10}, {\"x\": -7.391304347826087, \"y\": -9.420289855072463, \"x2\": -7.101449275362319, \"y2\": -9.130434782608695, \"center_x\": -7.246376811594203, \"center_y\": -9.275362318840578, \"value_uncond\": 5.906017886267534e-10}, {\"x\": -7.101449275362318, \"y\": -9.420289855072463, \"x2\": -6.811594202898551, \"y2\": -9.130434782608695, \"center_x\": -6.956521739130435, \"center_y\": -9.275362318840578, \"value_uncond\": 8.48393150765341e-10}, {\"x\": -6.811594202898551, \"y\": -9.420289855072463, \"x2\": -6.521739130434783, \"y2\": -9.130434782608695, \"center_x\": -6.666666666666667, \"center_y\": -9.275362318840578, \"value_uncond\": 1.207383854651945e-09}, {\"x\": -6.521739130434782, \"y\": -9.420289855072463, \"x2\": -6.231884057971015, \"y2\": -9.130434782608695, \"center_x\": -6.3768115942028984, \"center_y\": -9.275362318840578, \"value_uncond\": 1.7023128952967586e-09}, {\"x\": -6.231884057971014, \"y\": -9.420289855072463, \"x2\": -5.942028985507246, \"y2\": -9.130434782608695, \"center_x\": -6.08695652173913, \"center_y\": -9.275362318840578, \"value_uncond\": 2.3778213844086803e-09}, {\"x\": -5.942028985507246, \"y\": -9.420289855072463, \"x2\": -5.6521739130434785, \"y2\": -9.130434782608695, \"center_x\": -5.797101449275362, \"center_y\": -9.275362318840578, \"value_uncond\": 3.290522634026223e-09}, {\"x\": -5.6521739130434785, \"y\": -9.420289855072463, \"x2\": -5.362318840579711, \"y2\": -9.130434782608695, \"center_x\": -5.507246376811595, \"center_y\": -9.275362318840578, \"value_uncond\": 4.511244348477409e-09}, {\"x\": -5.36231884057971, \"y\": -9.420289855072463, \"x2\": -5.072463768115942, \"y2\": -9.130434782608695, \"center_x\": -5.217391304347826, \"center_y\": -9.275362318840578, \"value_uncond\": 6.127363343029421e-09}, {\"x\": -5.0724637681159415, \"y\": -9.420289855072463, \"x2\": -4.782608695652174, \"y2\": -9.130434782608695, \"center_x\": -4.927536231884058, \"center_y\": -9.275362318840578, \"value_uncond\": 8.245115271159551e-09}, {\"x\": -4.782608695652174, \"y\": -9.420289855072463, \"x2\": -4.492753623188406, \"y2\": -9.130434782608695, \"center_x\": -4.63768115942029, \"center_y\": -9.275362318840578, \"value_uncond\": 1.0991719673297463e-08}, {\"x\": -4.492753623188405, \"y\": -9.420289855072463, \"x2\": -4.202898550724638, \"y2\": -9.130434782608695, \"center_x\": -4.3478260869565215, \"center_y\": -9.275362318840578, \"value_uncond\": 1.451711678380478e-08}, {\"x\": -4.202898550724638, \"y\": -9.420289855072463, \"x2\": -3.91304347826087, \"y2\": -9.130434782608695, \"center_x\": -4.057971014492754, \"center_y\": -9.275362318840578, \"value_uncond\": 1.8995070588148614e-08}, {\"x\": -3.913043478260869, \"y\": -9.420289855072463, \"x2\": -3.6231884057971016, \"y2\": -9.130434782608695, \"center_x\": -3.7681159420289854, \"center_y\": -9.275362318840578, \"value_uncond\": 2.4623357331384997e-08}, {\"x\": -3.6231884057971016, \"y\": -9.420289855072463, \"x2\": -3.333333333333334, \"y2\": -9.130434782608695, \"center_x\": -3.4782608695652177, \"center_y\": -9.275362318840578, \"value_uncond\": 3.16227356718863e-08}, {\"x\": -3.333333333333333, \"y\": -9.420289855072463, \"x2\": -3.0434782608695654, \"y2\": -9.130434782608695, \"center_x\": -3.1884057971014492, \"center_y\": -9.275362318840578, \"value_uncond\": 4.0234390133469245e-08}, {\"x\": -3.0434782608695645, \"y\": -9.420289855072463, \"x2\": -2.753623188405797, \"y2\": -9.130434782608695, \"center_x\": -2.8985507246376807, \"center_y\": -9.275362318840578, \"value_uncond\": 5.071555962961394e-08}, {\"x\": -2.753623188405797, \"y\": -9.420289855072463, \"x2\": -2.4637681159420293, \"y2\": -9.130434782608695, \"center_x\": -2.608695652173913, \"center_y\": -9.275362318840578, \"value_uncond\": 6.333311310830191e-08}, {\"x\": -2.4637681159420284, \"y\": -9.420289855072463, \"x2\": -2.1739130434782608, \"y2\": -9.130434782608695, \"center_x\": -2.3188405797101446, \"center_y\": -9.275362318840578, \"value_uncond\": 7.835491874256564e-08}, {\"x\": -2.1739130434782608, \"y\": -9.420289855072463, \"x2\": -1.8840579710144931, \"y2\": -9.130434782608695, \"center_x\": -2.028985507246377, \"center_y\": -9.275362318840578, \"value_uncond\": 9.603897307467887e-08}, {\"x\": -1.8840579710144922, \"y\": -9.420289855072463, \"x2\": -1.5942028985507246, \"y2\": -9.130434782608695, \"center_x\": -1.7391304347826084, \"center_y\": -9.275362318840578, \"value_uncond\": 1.1662041032756351e-07}, {\"x\": -1.5942028985507246, \"y\": -9.420289855072463, \"x2\": -1.304347826086957, \"y2\": -9.130434782608695, \"center_x\": -1.4492753623188408, \"center_y\": -9.275362318840578, \"value_uncond\": 1.4029669398909313e-07}, {\"x\": -1.304347826086957, \"y\": -9.420289855072463, \"x2\": -1.0144927536231894, \"y2\": -9.130434782608695, \"center_x\": -1.1594202898550732, \"center_y\": -9.275362318840578, \"value_uncond\": 1.6721149271632956e-07}, {\"x\": -1.0144927536231876, \"y\": -9.420289855072463, \"x2\": -0.72463768115942, \"y2\": -9.130434782608695, \"center_x\": -0.8695652173913038, \"center_y\": -9.275362318840578, \"value_uncond\": 1.9743794635396995e-07}, {\"x\": -0.72463768115942, \"y\": -9.420289855072463, \"x2\": -0.43478260869565233, \"y2\": -9.130434782608695, \"center_x\": -0.5797101449275361, \"center_y\": -9.275362318840578, \"value_uncond\": 2.3096221759667814e-07}, {\"x\": -0.43478260869565233, \"y\": -9.420289855072463, \"x2\": -0.1449275362318847, \"y2\": -9.130434782608695, \"center_x\": -0.2898550724637685, \"center_y\": -9.275362318840578, \"value_uncond\": 2.6766838036410634e-07}, {\"x\": -0.14492753623188293, \"y\": -9.420289855072463, \"x2\": 0.1449275362318847, \"y2\": -9.130434782608695, \"center_x\": 8.881784197001252e-16, \"center_y\": -9.275362318840578, \"value_uncond\": 3.073257965000113e-07}, {\"x\": 0.1449275362318847, \"y\": -9.420289855072463, \"x2\": 0.43478260869565233, \"y2\": -9.130434782608695, \"center_x\": 0.2898550724637685, \"center_y\": -9.275362318840578, \"value_uncond\": 3.4958015871375006e-07}, {\"x\": 0.43478260869565233, \"y\": -9.420289855072463, \"x2\": 0.72463768115942, \"y2\": -9.130434782608695, \"center_x\": 0.5797101449275361, \"center_y\": -9.275362318840578, \"value_uncond\": 3.9394931447823936e-07}, {\"x\": 0.72463768115942, \"y\": -9.420289855072463, \"x2\": 1.0144927536231876, \"y2\": -9.130434782608695, \"center_x\": 0.8695652173913038, \"center_y\": -9.275362318840578, \"value_uncond\": 4.398248239312864e-07}, {\"x\": 1.0144927536231894, \"y\": -9.420289855072463, \"x2\": 1.304347826086957, \"y2\": -9.130434782608695, \"center_x\": 1.1594202898550732, \"center_y\": -9.275362318840578, \"value_uncond\": 4.864799440729798e-07}, {\"x\": 1.304347826086957, \"y\": -9.420289855072463, \"x2\": 1.5942028985507246, \"y2\": -9.130434782608695, \"center_x\": 1.4492753623188408, \"center_y\": -9.275362318840578, \"value_uncond\": 5.330843807487501e-07}, {\"x\": 1.5942028985507246, \"y\": -9.420289855072463, \"x2\": 1.8840579710144922, \"y2\": -9.130434782608695, \"center_x\": 1.7391304347826084, \"center_y\": -9.275362318840578, \"value_uncond\": 5.787257281488953e-07}, {\"x\": 1.884057971014494, \"y\": -9.420289855072463, \"x2\": 2.1739130434782616, \"y2\": -9.130434782608695, \"center_x\": 2.028985507246378, \"center_y\": -9.275362318840578, \"value_uncond\": 6.224370512563913e-07}, {\"x\": 2.1739130434782616, \"y\": -9.420289855072463, \"x2\": 2.4637681159420293, \"y2\": -9.130434782608695, \"center_x\": 2.3188405797101455, \"center_y\": -9.275362318840578, \"value_uncond\": 6.632295956617537e-07}, {\"x\": 2.4637681159420293, \"y\": -9.420289855072463, \"x2\": 2.753623188405797, \"y2\": -9.130434782608695, \"center_x\": 2.608695652173913, \"center_y\": -9.275362318840578, \"value_uncond\": 7.001291716807186e-07}, {\"x\": 2.753623188405797, \"y\": -9.420289855072463, \"x2\": 3.0434782608695645, \"y2\": -9.130434782608695, \"center_x\": 2.8985507246376807, \"center_y\": -9.275362318840578, \"value_uncond\": 7.322143966019667e-07}, {\"x\": 3.0434782608695663, \"y\": -9.420289855072463, \"x2\": 3.333333333333334, \"y2\": -9.130434782608695, \"center_x\": 3.18840579710145, \"center_y\": -9.275362318840578, \"value_uncond\": 7.586547273543421e-07}, {\"x\": 3.333333333333334, \"y\": -9.420289855072463, \"x2\": 3.6231884057971016, \"y2\": -9.130434782608695, \"center_x\": 3.4782608695652177, \"center_y\": -9.275362318840578, \"value_uncond\": 7.787461052724562e-07}, {\"x\": 3.6231884057971016, \"y\": -9.420289855072463, \"x2\": 3.913043478260869, \"y2\": -9.130434782608695, \"center_x\": 3.7681159420289854, \"center_y\": -9.275362318840578, \"value_uncond\": 7.919420828616108e-07}, {\"x\": 3.913043478260871, \"y\": -9.420289855072463, \"x2\": 4.202898550724639, \"y2\": -9.130434782608695, \"center_x\": 4.057971014492755, \"center_y\": -9.275362318840578, \"value_uncond\": 7.978785134241195e-07}, {\"x\": 4.202898550724639, \"y\": -9.420289855072463, \"x2\": 4.492753623188406, \"y2\": -9.130434782608695, \"center_x\": 4.347826086956522, \"center_y\": -9.275362318840578, \"value_uncond\": 7.963902469094011e-07}, {\"x\": 4.492753623188406, \"y\": -9.420289855072463, \"x2\": 4.782608695652174, \"y2\": -9.130434782608695, \"center_x\": 4.63768115942029, \"center_y\": -9.275362318840578, \"value_uncond\": 7.875187636225984e-07}, {\"x\": 4.782608695652174, \"y\": -9.420289855072463, \"x2\": 5.0724637681159415, \"y2\": -9.130434782608695, \"center_x\": 4.927536231884058, \"center_y\": -9.275362318840578, \"value_uncond\": 7.715102533239665e-07}, {\"x\": 5.072463768115943, \"y\": -9.420289855072463, \"x2\": 5.362318840579711, \"y2\": -9.130434782608695, \"center_x\": 5.217391304347827, \"center_y\": -9.275362318840578, \"value_uncond\": 7.488042638703676e-07}, {\"x\": 5.362318840579711, \"y\": -9.420289855072463, \"x2\": 5.6521739130434785, \"y2\": -9.130434782608695, \"center_x\": 5.507246376811595, \"center_y\": -9.275362318840578, \"value_uncond\": 7.200136498843506e-07}, {\"x\": 5.6521739130434785, \"y\": -9.420289855072463, \"x2\": 5.942028985507246, \"y2\": -9.130434782608695, \"center_x\": 5.797101449275362, \"center_y\": -9.275362318840578, \"value_uncond\": 6.858970980172719e-07}, {\"x\": 5.942028985507246, \"y\": -9.420289855072463, \"x2\": 6.231884057971014, \"y2\": -9.130434782608695, \"center_x\": 6.08695652173913, \"center_y\": -9.275362318840578, \"value_uncond\": 6.473259472880103e-07}, {\"x\": 6.2318840579710155, \"y\": -9.420289855072463, \"x2\": 6.521739130434783, \"y2\": -9.130434782608695, \"center_x\": 6.376811594202899, \"center_y\": -9.275362318840578, \"value_uncond\": 6.052473271715371e-07}, {\"x\": 6.521739130434785, \"y\": -9.420289855072463, \"x2\": 6.8115942028985526, \"y2\": -9.130434782608695, \"center_x\": 6.666666666666669, \"center_y\": -9.275362318840578, \"value_uncond\": 5.606457824690636e-07}, {\"x\": 6.811594202898551, \"y\": -9.420289855072463, \"x2\": 7.101449275362318, \"y2\": -9.130434782608695, \"center_x\": 6.956521739130435, \"center_y\": -9.275362318840578, \"value_uncond\": 5.145055373860044e-07}, {\"x\": 7.10144927536232, \"y\": -9.420289855072463, \"x2\": 7.391304347826088, \"y2\": -9.130434782608695, \"center_x\": 7.246376811594204, \"center_y\": -9.275362318840578, \"value_uncond\": 4.677753814021533e-07}, {\"x\": 7.391304347826086, \"y\": -9.420289855072463, \"x2\": 7.681159420289854, \"y2\": -9.130434782608695, \"center_x\": 7.53623188405797, \"center_y\": -9.275362318840578, \"value_uncond\": 4.213378593009689e-07}, {\"x\": 7.681159420289855, \"y\": -9.420289855072463, \"x2\": 7.971014492753623, \"y2\": -9.130434782608695, \"center_x\": 7.826086956521739, \"center_y\": -9.275362318840578, \"value_uncond\": 3.7598405010178783e-07}, {\"x\": 7.971014492753625, \"y\": -9.420289855072463, \"x2\": 8.260869565217392, \"y2\": -9.130434782608695, \"center_x\": 8.115942028985508, \"center_y\": -9.275362318840578, \"value_uncond\": 3.32394763783409e-07}, {\"x\": 8.26086956521739, \"y\": -9.420289855072463, \"x2\": 8.550724637681158, \"y2\": -9.130434782608695, \"center_x\": 8.405797101449274, \"center_y\": -9.275362318840578, \"value_uncond\": 2.911285116999536e-07}, {\"x\": 8.55072463768116, \"y\": -9.420289855072463, \"x2\": 8.840579710144928, \"y2\": -9.130434782608695, \"center_x\": 8.695652173913043, \"center_y\": -9.275362318840578, \"value_uncond\": 2.5261615536661616e-07}, {\"x\": 8.84057971014493, \"y\": -9.420289855072463, \"x2\": 9.130434782608697, \"y2\": -9.130434782608695, \"center_x\": 8.985507246376812, \"center_y\": -9.275362318840578, \"value_uncond\": 2.1716174199835867e-07}, {\"x\": 9.130434782608695, \"y\": -9.420289855072463, \"x2\": 9.420289855072463, \"y2\": -9.130434782608695, \"center_x\": 9.275362318840578, \"center_y\": -9.275362318840578, \"value_uncond\": 1.8494871866920357e-07}, {\"x\": 9.420289855072465, \"y\": -9.420289855072463, \"x2\": 9.710144927536232, \"y2\": -9.130434782608695, \"center_x\": 9.565217391304348, \"center_y\": -9.275362318840578, \"value_uncond\": 1.5605049531692952e-07}, {\"x\": 9.710144927536234, \"y\": -9.420289855072463, \"x2\": 10.000000000000002, \"y2\": -9.130434782608695, \"center_x\": 9.855072463768117, \"center_y\": -9.275362318840578, \"value_uncond\": 1.3044420511573268e-07}, {\"x\": 10.0, \"y\": -9.420289855072463, \"x2\": 10.289855072463768, \"y2\": -9.130434782608695, \"center_x\": 10.144927536231883, \"center_y\": -9.275362318840578, \"value_uncond\": 1.080264848182129e-07}, {\"x\": -10.0, \"y\": -9.130434782608695, \"x2\": -9.710144927536232, \"y2\": -8.840579710144928, \"center_x\": -9.855072463768117, \"center_y\": -8.985507246376812, \"value_uncond\": 2.284633516259696e-11}, {\"x\": -9.710144927536232, \"y\": -9.130434782608695, \"x2\": -9.420289855072465, \"y2\": -8.840579710144928, \"center_x\": -9.565217391304348, \"center_y\": -8.985507246376812, \"value_uncond\": 3.56949360896001e-11}, {\"x\": -9.420289855072463, \"y\": -9.130434782608695, \"x2\": -9.130434782608695, \"y2\": -8.840579710144928, \"center_x\": -9.275362318840578, \"center_y\": -8.985507246376812, \"value_uncond\": 5.52512983829845e-11}, {\"x\": -9.130434782608695, \"y\": -9.130434782608695, \"x2\": -8.840579710144928, \"y2\": -8.840579710144928, \"center_x\": -8.985507246376812, \"center_y\": -8.985507246376812, \"value_uncond\": 8.472745905519222e-11}, {\"x\": -8.840579710144928, \"y\": -9.130434782608695, \"x2\": -8.55072463768116, \"y2\": -8.840579710144928, \"center_x\": -8.695652173913043, \"center_y\": -8.985507246376812, \"value_uncond\": 1.2872167750465555e-10}, {\"x\": -8.55072463768116, \"y\": -9.130434782608695, \"x2\": -8.260869565217392, \"y2\": -8.840579710144928, \"center_x\": -8.405797101449277, \"center_y\": -8.985507246376812, \"value_uncond\": 1.9374255109995932e-10}, {\"x\": -8.26086956521739, \"y\": -9.130434782608695, \"x2\": -7.971014492753623, \"y2\": -8.840579710144928, \"center_x\": -8.115942028985508, \"center_y\": -8.985507246376812, \"value_uncond\": 2.888977448101407e-10}, {\"x\": -7.971014492753623, \"y\": -9.130434782608695, \"x2\": -7.681159420289855, \"y2\": -8.840579710144928, \"center_x\": -7.826086956521739, \"center_y\": -8.985507246376812, \"value_uncond\": 4.267849575459015e-10}, {\"x\": -7.681159420289855, \"y\": -9.130434782608695, \"x2\": -7.391304347826088, \"y2\": -8.840579710144928, \"center_x\": -7.536231884057972, \"center_y\": -8.985507246376812, \"value_uncond\": 6.246257309077444e-10}, {\"x\": -7.391304347826087, \"y\": -9.130434782608695, \"x2\": -7.101449275362319, \"y2\": -8.840579710144928, \"center_x\": -7.246376811594203, \"center_y\": -8.985507246376812, \"value_uncond\": 9.056834921223715e-10}, {\"x\": -7.101449275362318, \"y\": -9.130434782608695, \"x2\": -6.811594202898551, \"y2\": -8.840579710144928, \"center_x\": -6.956521739130435, \"center_y\": -8.985507246376812, \"value_uncond\": 1.3010046469118486e-09}, {\"x\": -6.811594202898551, \"y\": -9.130434782608695, \"x2\": -6.521739130434783, \"y2\": -8.840579710144928, \"center_x\": -6.666666666666667, \"center_y\": -8.985507246376812, \"value_uncond\": 1.85151424677519e-09}, {\"x\": -6.521739130434782, \"y\": -9.130434782608695, \"x2\": -6.231884057971015, \"y2\": -8.840579710144928, \"center_x\": -6.3768115942028984, \"center_y\": -8.985507246376812, \"value_uncond\": 2.6104842846516803e-09}, {\"x\": -6.231884057971014, \"y\": -9.130434782608695, \"x2\": -5.942028985507246, \"y2\": -8.840579710144928, \"center_x\": -6.08695652173913, \"center_y\": -8.985507246376812, \"value_uncond\": 3.6463715764929747e-09}, {\"x\": -5.942028985507246, \"y\": -9.130434782608695, \"x2\": -5.6521739130434785, \"y2\": -8.840579710144928, \"center_x\": -5.797101449275362, \"center_y\": -8.985507246376812, \"value_uncond\": 5.045992219261586e-09}, {\"x\": -5.6521739130434785, \"y\": -9.130434782608695, \"x2\": -5.362318840579711, \"y2\": -8.840579710144928, \"center_x\": -5.507246376811595, \"center_y\": -8.985507246376812, \"value_uncond\": 6.917959975784015e-09}, {\"x\": -5.36231884057971, \"y\": -9.130434782608695, \"x2\": -5.072463768115942, \"y2\": -8.840579710144928, \"center_x\": -5.217391304347826, \"center_y\": -8.985507246376812, \"value_uncond\": 9.396266548601021e-09}, {\"x\": -5.0724637681159415, \"y\": -9.130434782608695, \"x2\": -4.782608695652174, \"y2\": -8.840579710144928, \"center_x\": -4.927536231884058, \"center_y\": -8.985507246376812, \"value_uncond\": 1.2643823529722732e-08}, {\"x\": -4.782608695652174, \"y\": -9.130434782608695, \"x2\": -4.492753623188406, \"y2\": -8.840579710144928, \"center_x\": -4.63768115942029, \"center_y\": -8.985507246376812, \"value_uncond\": 1.68557211472205e-08}, {\"x\": -4.492753623188405, \"y\": -9.130434782608695, \"x2\": -4.202898550724638, \"y2\": -8.840579710144928, \"center_x\": -4.3478260869565215, \"center_y\": -8.985507246376812, \"value_uncond\": 2.2261891645935698e-08}, {\"x\": -4.202898550724638, \"y\": -9.130434782608695, \"x2\": -3.91304347826087, \"y2\": -8.840579710144928, \"center_x\": -4.057971014492754, \"center_y\": -8.985507246376812, \"value_uncond\": 2.912880081752954e-08}, {\"x\": -3.913043478260869, \"y\": -9.130434782608695, \"x2\": -3.6231884057971016, \"y2\": -8.840579710144928, \"center_x\": -3.7681159420289854, \"center_y\": -8.985507246376812, \"value_uncond\": 3.775973707685375e-08}, {\"x\": -3.6231884057971016, \"y\": -9.130434782608695, \"x2\": -3.333333333333334, \"y2\": -8.840579710144928, \"center_x\": -3.4782608695652177, \"center_y\": -8.985507246376812, \"value_uncond\": 4.8493232200278026e-08}, {\"x\": -3.333333333333333, \"y\": -9.130434782608695, \"x2\": -3.0434782608695654, \"y2\": -8.840579710144928, \"center_x\": -3.1884057971014492, \"center_y\": -8.985507246376812, \"value_uncond\": 6.169914087836146e-08}, {\"x\": -3.0434782608695645, \"y\": -9.130434782608695, \"x2\": -2.753623188405797, \"y2\": -8.840579710144928, \"center_x\": -2.8985507246376807, \"center_y\": -8.985507246376812, \"value_uncond\": 7.777193708994542e-08}, {\"x\": -2.753623188405797, \"y\": -9.130434782608695, \"x2\": -2.4637681159420293, \"y2\": -8.840579710144928, \"center_x\": -2.608695652173913, \"center_y\": -8.985507246376812, \"value_uncond\": 9.71208624008385e-08}, {\"x\": -2.4637681159420284, \"y\": -9.130434782608695, \"x2\": -2.1739130434782608, \"y2\": -8.840579710144928, \"center_x\": -2.3188405797101446, \"center_y\": -8.985507246376812, \"value_uncond\": 1.2015669068110387e-07}, {\"x\": -2.1739130434782608, \"y\": -9.130434782608695, \"x2\": -1.8840579710144931, \"y2\": -8.840579710144928, \"center_x\": -2.028985507246377, \"center_y\": -8.985507246376812, \"value_uncond\": 1.4727505772775686e-07}, {\"x\": -1.8840579710144922, \"y\": -9.130434782608695, \"x2\": -1.5942028985507246, \"y2\": -8.840579710144928, \"center_x\": -1.7391304347826084, \"center_y\": -8.985507246376812, \"value_uncond\": 1.7883654013950458e-07}, {\"x\": -1.5942028985507246, \"y\": -9.130434782608695, \"x2\": -1.304347826086957, \"y2\": -8.840579710144928, \"center_x\": -1.4492753623188408, \"center_y\": -8.985507246376812, \"value_uncond\": 2.1514394672036343e-07}, {\"x\": -1.304347826086957, \"y\": -9.130434782608695, \"x2\": -1.0144927536231894, \"y2\": -8.840579710144928, \"center_x\": -1.1594202898550732, \"center_y\": -8.985507246376812, \"value_uncond\": 2.564175922975858e-07}, {\"x\": -1.0144927536231876, \"y\": -9.130434782608695, \"x2\": -0.72463768115942, \"y2\": -8.840579710144928, \"center_x\": -0.8695652173913038, \"center_y\": -8.985507246376812, \"value_uncond\": 3.0276963628422175e-07}, {\"x\": -0.72463768115942, \"y\": -9.130434782608695, \"x2\": -0.43478260869565233, \"y2\": -8.840579710144928, \"center_x\": -0.5797101449275361, \"center_y\": -8.985507246376812, \"value_uncond\": 3.5417885927447224e-07}, {\"x\": -0.43478260869565233, \"y\": -9.130434782608695, \"x2\": -0.1449275362318847, \"y2\": -8.840579710144928, \"center_x\": -0.2898550724637685, \"center_y\": -8.985507246376812, \"value_uncond\": 4.1046748947810695e-07}, {\"x\": -0.14492753623188293, \"y\": -9.130434782608695, \"x2\": 0.1449275362318847, \"y2\": -8.840579710144928, \"center_x\": 8.881784197001252e-16, \"center_y\": -8.985507246376812, \"value_uncond\": 4.7128184498154966e-07}, {\"x\": 0.1449275362318847, \"y\": -9.130434782608695, \"x2\": 0.43478260869565233, \"y2\": -8.840579710144928, \"center_x\": 0.2898550724637685, \"center_y\": -8.985507246376812, \"value_uncond\": 5.360785981646451e-07}, {\"x\": 0.43478260869565233, \"y\": -9.130434782608695, \"x2\": 0.72463768115942, \"y2\": -8.840579710144928, \"center_x\": 0.5797101449275361, \"center_y\": -8.985507246376812, \"value_uncond\": 6.04118371678944e-07}, {\"x\": 0.72463768115942, \"y\": -9.130434782608695, \"x2\": 1.0144927536231876, \"y2\": -8.840579710144928, \"center_x\": 0.8695652173913038, \"center_y\": -8.985507246376812, \"value_uncond\": 6.744681274779165e-07}, {\"x\": 1.0144927536231894, \"y\": -9.130434782608695, \"x2\": 1.304347826086957, \"y2\": -8.840579710144928, \"center_x\": 1.1594202898550732, \"center_y\": -8.985507246376812, \"value_uncond\": 7.460134105248357e-07}, {\"x\": 1.304347826086957, \"y\": -9.130434782608695, \"x2\": 1.5942028985507246, \"y2\": -8.840579710144928, \"center_x\": 1.4492753623188408, \"center_y\": -8.985507246376812, \"value_uncond\": 8.17480970850127e-07}, {\"x\": 1.5942028985507246, \"y\": -9.130434782608695, \"x2\": 1.8840579710144922, \"y2\": -8.840579710144928, \"center_x\": 1.7391304347826084, \"center_y\": -8.985507246376812, \"value_uncond\": 8.874716408659564e-07}, {\"x\": 1.884057971014494, \"y\": -9.130434782608695, \"x2\": 2.1739130434782616, \"y2\": -8.840579710144928, \"center_x\": 2.028985507246378, \"center_y\": -8.985507246376812, \"value_uncond\": 9.54502632846757e-07}, {\"x\": 2.1739130434782616, \"y\": -9.130434782608695, \"x2\": 2.4637681159420293, \"y2\": -8.840579710144928, \"center_x\": 2.3188405797101455, \"center_y\": -8.985507246376812, \"value_uncond\": 1.0170576991893582e-06}, {\"x\": 2.4637681159420293, \"y\": -9.130434782608695, \"x2\": 2.753623188405797, \"y2\": -8.840579710144928, \"center_x\": 2.608695652173913, \"center_y\": -8.985507246376812, \"value_uncond\": 1.0736429271894232e-06}, {\"x\": 2.753623188405797, \"y\": -9.130434782608695, \"x2\": 3.0434782608695645, \"y2\": -8.840579710144928, \"center_x\": 2.8985507246376807, \"center_y\": -8.985507246376812, \"value_uncond\": 1.1228453832466169e-06}, {\"x\": 3.0434782608695663, \"y\": -9.130434782608695, \"x2\": 3.333333333333334, \"y2\": -8.840579710144928, \"center_x\": 3.18840579710145, \"center_y\": -8.985507246376812, \"value_uncond\": 1.1633914356796134e-06}, {\"x\": 3.333333333333334, \"y\": -9.130434782608695, \"x2\": 3.6231884057971016, \"y2\": -8.840579710144928, \"center_x\": 3.4782608695652177, \"center_y\": -8.985507246376812, \"value_uncond\": 1.1942014157115696e-06}, {\"x\": 3.6231884057971016, \"y\": -9.130434782608695, \"x2\": 3.913043478260869, \"y2\": -8.840579710144928, \"center_x\": 3.7681159420289854, \"center_y\": -8.985507246376812, \"value_uncond\": 1.2144373501348344e-06}, {\"x\": 3.913043478260871, \"y\": -9.130434782608695, \"x2\": 4.202898550724639, \"y2\": -8.840579710144928, \"center_x\": 4.057971014492755, \"center_y\": -8.985507246376812, \"value_uncond\": 1.2235408226710357e-06}, {\"x\": 4.202898550724639, \"y\": -9.130434782608695, \"x2\": 4.492753623188406, \"y2\": -8.840579710144928, \"center_x\": 4.347826086956522, \"center_y\": -8.985507246376812, \"value_uncond\": 1.2212585769342034e-06}, {\"x\": 4.492753623188406, \"y\": -9.130434782608695, \"x2\": 4.782608695652174, \"y2\": -8.840579710144928, \"center_x\": 4.63768115942029, \"center_y\": -8.985507246376812, \"value_uncond\": 1.2076542226667046e-06}, {\"x\": 4.782608695652174, \"y\": -9.130434782608695, \"x2\": 5.0724637681159415, \"y2\": -8.840579710144928, \"center_x\": 4.927536231884058, \"center_y\": -8.985507246376812, \"value_uncond\": 1.1831052900523056e-06}, {\"x\": 5.072463768115943, \"y\": -9.130434782608695, \"x2\": 5.362318840579711, \"y2\": -8.840579710144928, \"center_x\": 5.217391304347827, \"center_y\": -8.985507246376812, \"value_uncond\": 1.1482858224915232e-06}, {\"x\": 5.362318840579711, \"y\": -9.130434782608695, \"x2\": 5.6521739130434785, \"y2\": -8.840579710144928, \"center_x\": 5.507246376811595, \"center_y\": -8.985507246376812, \"value_uncond\": 1.1041356280333723e-06}, {\"x\": 5.6521739130434785, \"y\": -9.130434782608695, \"x2\": 5.942028985507246, \"y2\": -8.840579710144928, \"center_x\": 5.797101449275362, \"center_y\": -8.985507246376812, \"value_uncond\": 1.0518181470687534e-06}, {\"x\": 5.942028985507246, \"y\": -9.130434782608695, \"x2\": 6.231884057971014, \"y2\": -8.840579710144928, \"center_x\": 6.08695652173913, \"center_y\": -8.985507246376812, \"value_uncond\": 9.926695715642979e-07}, {\"x\": 6.2318840579710155, \"y\": -9.130434782608695, \"x2\": 6.521739130434783, \"y2\": -8.840579710144928, \"center_x\": 6.376811594202899, \"center_y\": -8.985507246376812, \"value_uncond\": 9.281423175927344e-07}, {\"x\": 6.521739130434785, \"y\": -9.130434782608695, \"x2\": 6.8115942028985526, \"y2\": -8.840579710144928, \"center_x\": 6.666666666666669, \"center_y\": -8.985507246376812, \"value_uncond\": 8.59746177353957e-07}, {\"x\": 6.811594202898551, \"y\": -9.130434782608695, \"x2\": 7.101449275362318, \"y2\": -8.840579710144928, \"center_x\": 6.956521739130435, \"center_y\": -8.985507246376812, \"value_uncond\": 7.889904514165666e-07}, {\"x\": 7.10144927536232, \"y\": -9.130434782608695, \"x2\": 7.391304347826088, \"y2\": -8.840579710144928, \"center_x\": 7.246376811594204, \"center_y\": -8.985507246376812, \"value_uncond\": 7.17330101458459e-07}, {\"x\": 7.391304347826086, \"y\": -9.130434782608695, \"x2\": 7.681159420289854, \"y2\": -8.840579710144928, \"center_x\": 7.53623188405797, \"center_y\": -8.985507246376812, \"value_uncond\": 6.461185034036994e-07}, {\"x\": 7.681159420289855, \"y\": -9.130434782608695, \"x2\": 7.971014492753623, \"y2\": -8.840579710144928, \"center_x\": 7.826086956521739, \"center_y\": -8.985507246376812, \"value_uncond\": 5.765687711008647e-07}, {\"x\": 7.971014492753625, \"y\": -9.130434782608695, \"x2\": 8.260869565217392, \"y2\": -8.840579710144928, \"center_x\": 8.115942028985508, \"center_y\": -8.985507246376812, \"value_uncond\": 5.097249216371772e-07}, {\"x\": 8.26086956521739, \"y\": -9.130434782608695, \"x2\": 8.550724637681158, \"y2\": -8.840579710144928, \"center_x\": 8.405797101449274, \"center_y\": -8.985507246376812, \"value_uncond\": 4.4644342805984316e-07}, {\"x\": 8.55072463768116, \"y\": -9.130434782608695, \"x2\": 8.840579710144928, \"y2\": -8.840579710144928, \"center_x\": 8.695652173913043, \"center_y\": -8.985507246376812, \"value_uncond\": 3.873850133284215e-07}, {\"x\": 8.84057971014493, \"y\": -9.130434782608695, \"x2\": 9.130434782608697, \"y2\": -8.840579710144928, \"center_x\": 8.985507246376812, \"center_y\": -8.985507246376812, \"value_uncond\": 3.330159316072577e-07}, {\"x\": 9.130434782608695, \"y\": -9.130434782608695, \"x2\": 9.420289855072463, \"y2\": -8.840579710144928, \"center_x\": 9.275362318840578, \"center_y\": -8.985507246376812, \"value_uncond\": 2.836174976329806e-07}, {\"x\": 9.420289855072465, \"y\": -9.130434782608695, \"x2\": 9.710144927536232, \"y2\": -8.840579710144928, \"center_x\": 9.565217391304348, \"center_y\": -8.985507246376812, \"value_uncond\": 2.3930228500439113e-07}, {\"x\": 9.710144927536234, \"y\": -9.130434782608695, \"x2\": 10.000000000000002, \"y2\": -8.840579710144928, \"center_x\": 9.855072463768117, \"center_y\": -8.985507246376812, \"value_uncond\": 2.0003522761257018e-07}, {\"x\": 10.0, \"y\": -9.130434782608695, \"x2\": 10.289855072463768, \"y2\": -8.840579710144928, \"center_x\": 10.144927536231883, \"center_y\": -8.985507246376812, \"value_uncond\": 1.6565781867906704e-07}, {\"x\": -10.0, \"y\": -8.840579710144928, \"x2\": -9.710144927536232, \"y2\": -8.55072463768116, \"center_x\": -9.855072463768117, \"center_y\": -8.695652173913043, \"value_uncond\": 3.470915591894953e-11}, {\"x\": -9.710144927536232, \"y\": -8.840579710144928, \"x2\": -9.420289855072465, \"y2\": -8.55072463768116, \"center_x\": -9.565217391304348, \"center_y\": -8.695652173913043, \"value_uncond\": 5.42293148302932e-11}, {\"x\": -9.420289855072463, \"y\": -8.840579710144928, \"x2\": -9.130434782608695, \"y2\": -8.55072463768116, \"center_x\": -9.275362318840578, \"center_y\": -8.695652173913043, \"value_uncond\": 8.394019945216559e-11}, {\"x\": -9.130434782608695, \"y\": -8.840579710144928, \"x2\": -8.840579710144928, \"y2\": -8.55072463768116, \"center_x\": -8.985507246376812, \"center_y\": -8.695652173913043, \"value_uncond\": 1.2872167750465555e-10}, {\"x\": -8.840579710144928, \"y\": -8.840579710144928, \"x2\": -8.55072463768116, \"y2\": -8.55072463768116, \"center_x\": -8.695652173913043, \"center_y\": -8.695652173913043, \"value_uncond\": 1.9555962664735687e-10}, {\"x\": -8.55072463768116, \"y\": -8.840579710144928, \"x2\": -8.260869565217392, \"y2\": -8.55072463768116, \"center_x\": -8.405797101449277, \"center_y\": -8.695652173913043, \"value_uncond\": 2.9434219389693743e-10}, {\"x\": -8.26086956521739, \"y\": -8.840579710144928, \"x2\": -7.971014492753623, \"y2\": -8.55072463768116, \"center_x\": -8.115942028985508, \"center_y\": -8.695652173913043, \"value_uncond\": 4.3890614393438853e-10}, {\"x\": -7.971014492753623, \"y\": -8.840579710144928, \"x2\": -7.681159420289855, \"y2\": -8.55072463768116, \"center_x\": -7.826086956521739, \"center_y\": -8.695652173913043, \"value_uncond\": 6.483904543068586e-10}, {\"x\": -7.681159420289855, \"y\": -8.840579710144928, \"x2\": -7.391304347826088, \"y2\": -8.55072463768116, \"center_x\": -7.536231884057972, \"center_y\": -8.695652173913043, \"value_uncond\": 9.4895884748109e-10}, {\"x\": -7.391304347826087, \"y\": -8.840579710144928, \"x2\": -7.101449275362319, \"y2\": -8.55072463768116, \"center_x\": -7.246376811594203, \"center_y\": -8.695652173913043, \"value_uncond\": 1.3759541439608688e-09}, {\"x\": -7.101449275362318, \"y\": -8.840579710144928, \"x2\": -6.811594202898551, \"y2\": -8.55072463768116, \"center_x\": -6.956521739130435, \"center_y\": -8.695652173913043, \"value_uncond\": 1.976543407052434e-09}, {\"x\": -6.811594202898551, \"y\": -8.840579710144928, \"x2\": -6.521739130434783, \"y2\": -8.55072463768116, \"center_x\": -6.666666666666667, \"center_y\": -8.695652173913043, \"value_uncond\": 2.8129017726522515e-09}, {\"x\": -6.521739130434782, \"y\": -8.840579710144928, \"x2\": -6.231884057971015, \"y2\": -8.55072463768116, \"center_x\": -6.3768115942028984, \"center_y\": -8.695652173913043, \"value_uncond\": 3.965962392440151e-09}, {\"x\": -6.231884057971014, \"y\": -8.840579710144928, \"x2\": -5.942028985507246, \"y2\": -8.55072463768116, \"center_x\": -6.08695652173913, \"center_y\": -8.695652173913043, \"value_uncond\": 5.539727868219475e-09}, {\"x\": -5.942028985507246, \"y\": -8.840579710144928, \"x2\": -5.6521739130434785, \"y2\": -8.55072463768116, \"center_x\": -5.797101449275362, \"center_y\": -8.695652173913043, \"value_uncond\": 7.666093027948395e-09}, {\"x\": -5.6521739130434785, \"y\": -8.840579710144928, \"x2\": -5.362318840579711, \"y2\": -8.55072463768116, \"center_x\": -5.507246376811595, \"center_y\": -8.695652173913043, \"value_uncond\": 1.05100686710422e-08}, {\"x\": -5.36231884057971, \"y\": -8.840579710144928, \"x2\": -5.072463768115942, \"y2\": -8.55072463768116, \"center_x\": -5.217391304347826, \"center_y\": -8.695652173913043, \"value_uncond\": 1.4275220877672309e-08}, {\"x\": -5.0724637681159415, \"y\": -8.840579710144928, \"x2\": -4.782608695652174, \"y2\": -8.55072463768116, \"center_x\": -4.927536231884058, \"center_y\": -8.695652173913043, \"value_uncond\": 1.9209052094416735e-08}, {\"x\": -4.782608695652174, \"y\": -8.840579710144928, \"x2\": -4.492753623188406, \"y2\": -8.55072463768116, \"center_x\": -4.63768115942029, \"center_y\": -8.695652173913043, \"value_uncond\": 2.560795196522492e-08}, {\"x\": -4.492753623188405, \"y\": -8.840579710144928, \"x2\": -4.202898550724638, \"y2\": -8.55072463768116, \"center_x\": -4.3478260869565215, \"center_y\": -8.695652173913043, \"value_uncond\": 3.382124365638135e-08}, {\"x\": -4.202898550724638, \"y\": -8.840579710144928, \"x2\": -3.91304347826087, \"y2\": -8.55072463768116, \"center_x\": -4.057971014492754, \"center_y\": -8.695652173913043, \"value_uncond\": 4.425375370325845e-08}, {\"x\": -3.913043478260869, \"y\": -8.840579710144928, \"x2\": -3.6231884057971016, \"y2\": -8.55072463768116, \"center_x\": -3.7681159420289854, \"center_y\": -8.695652173913043, \"value_uncond\": 5.736625118783737e-08}, {\"x\": -3.6231884057971016, \"y\": -8.840579710144928, \"x2\": -3.333333333333334, \"y2\": -8.55072463768116, \"center_x\": -3.4782608695652177, \"center_y\": -8.695652173913043, \"value_uncond\": 7.36730484550044e-08}, {\"x\": -3.333333333333333, \"y\": -8.840579710144928, \"x2\": -3.0434782608695654, \"y2\": -8.55072463768116, \"center_x\": -3.1884057971014492, \"center_y\": -8.695652173913043, \"value_uncond\": 9.373604499676155e-08}, {\"x\": -3.0434782608695645, \"y\": -8.840579710144928, \"x2\": -2.753623188405797, \"y2\": -8.55072463768116, \"center_x\": -2.8985507246376807, \"center_y\": -8.695652173913043, \"value_uncond\": 1.1815454300928705e-07}, {\"x\": -2.753623188405797, \"y\": -8.840579710144928, \"x2\": -2.4637681159420293, \"y2\": -8.55072463768116, \"center_x\": -2.608695652173913, \"center_y\": -8.695652173913043, \"value_uncond\": 1.475502802555563e-07}, {\"x\": -2.4637681159420284, \"y\": -8.840579710144928, \"x2\": -2.1739130434782608, \"y2\": -8.55072463768116, \"center_x\": -2.3188405797101446, \"center_y\": -8.695652173913043, \"value_uncond\": 1.8254732244247453e-07}, {\"x\": -2.1739130434782608, \"y\": -8.840579710144928, \"x2\": -1.8840579710144931, \"y2\": -8.55072463768116, \"center_x\": -2.028985507246377, \"center_y\": -8.695652173913043, \"value_uncond\": 2.2374673685142385e-07}, {\"x\": -1.8840579710144922, \"y\": -8.840579710144928, \"x2\": -1.5942028985507246, \"y2\": -8.55072463768116, \"center_x\": -1.7391304347826084, \"center_y\": -8.695652173913043, \"value_uncond\": 2.7169632728971814e-07}, {\"x\": -1.5942028985507246, \"y\": -8.840579710144928, \"x2\": -1.304347826086957, \"y2\": -8.55072463768116, \"center_x\": -1.4492753623188408, \"center_y\": -8.695652173913043, \"value_uncond\": 3.268561341934916e-07}, {\"x\": -1.304347826086957, \"y\": -8.840579710144928, \"x2\": -1.0144927536231894, \"y2\": -8.55072463768116, \"center_x\": -1.1594202898550732, \"center_y\": -8.695652173913043, \"value_uncond\": 3.895608695257747e-07}, {\"x\": -1.0144927536231876, \"y\": -8.840579710144928, \"x2\": -0.72463768115942, \"y2\": -8.55072463768116, \"center_x\": -0.8695652173913038, \"center_y\": -8.695652173913043, \"value_uncond\": 4.5998093079354775e-07}, {\"x\": -0.72463768115942, \"y\": -8.840579710144928, \"x2\": -0.43478260869565233, \"y2\": -8.55072463768116, \"center_x\": -0.5797101449275361, \"center_y\": -8.695652173913043, \"value_uncond\": 5.380840805434449e-07}, {\"x\": -0.43478260869565233, \"y\": -8.840579710144928, \"x2\": -0.1449275362318847, \"y2\": -8.55072463768116, \"center_x\": -0.2898550724637685, \"center_y\": -8.695652173913043, \"value_uncond\": 6.236002400630083e-07}, {\"x\": -0.14492753623188293, \"y\": -8.840579710144928, \"x2\": 0.1449275362318847, \"y2\": -8.55072463768116, \"center_x\": 8.881784197001252e-16, \"center_y\": -8.695652173913043, \"value_uncond\": 7.159920802534279e-07}, {\"x\": 0.1449275362318847, \"y\": -8.840579710144928, \"x2\": 0.43478260869565233, \"y2\": -8.55072463768116, \"center_x\": 0.2898550724637685, \"center_y\": -8.695652173913043, \"value_uncond\": 8.144341539281496e-07}, {\"x\": 0.43478260869565233, \"y\": -8.840579710144928, \"x2\": 0.72463768115942, \"y2\": -8.55072463768116, \"center_x\": 0.5797101449275361, \"center_y\": -8.695652173913043, \"value_uncond\": 9.178031665417845e-07}, {\"x\": 0.72463768115942, \"y\": -8.840579710144928, \"x2\": 1.0144927536231876, \"y2\": -8.55072463768116, \"center_x\": 0.8695652173913038, \"center_y\": -8.695652173913043, \"value_uncond\": 1.024681605709748e-06}, {\"x\": 1.0144927536231894, \"y\": -8.840579710144928, \"x2\": 1.304347826086957, \"y2\": -8.55072463768116, \"center_x\": 1.1594202898550732, \"center_y\": -8.695652173913043, \"value_uncond\": 1.1333763423870968e-06}, {\"x\": 1.304347826086957, \"y\": -8.840579710144928, \"x2\": 1.5942028985507246, \"y2\": -8.55072463768116, \"center_x\": 1.4492753623188408, \"center_y\": -8.695652173913043, \"value_uncond\": 1.241952999291727e-06}, {\"x\": 1.5942028985507246, \"y\": -8.840579710144928, \"x2\": 1.8840579710144922, \"y2\": -8.55072463768116, \"center_x\": 1.7391304347826084, \"center_y\": -8.695652173913043, \"value_uncond\": 1.3482858995648677e-06}, {\"x\": 1.884057971014494, \"y\": -8.840579710144928, \"x2\": 2.1739130434782616, \"y2\": -8.55072463768116, \"center_x\": 2.028985507246378, \"center_y\": -8.695652173913043, \"value_uncond\": 1.4501223269614357e-06}, {\"x\": 2.1739130434782616, \"y\": -8.840579710144928, \"x2\": 2.4637681159420293, \"y2\": -8.55072463768116, \"center_x\": 2.3188405797101455, \"center_y\": -8.695652173913043, \"value_uncond\": 1.5451587315205457e-06}, {\"x\": 2.4637681159420293, \"y\": -8.840579710144928, \"x2\": 2.753623188405797, \"y2\": -8.55072463768116, \"center_x\": 2.608695652173913, \"center_y\": -8.695652173913043, \"value_uncond\": 1.6311254954406947e-06}, {\"x\": 2.753623188405797, \"y\": -8.840579710144928, \"x2\": 3.0434782608695645, \"y2\": -8.55072463768116, \"center_x\": 2.8985507246376807, \"center_y\": -8.695652173913043, \"value_uncond\": 1.7058760279322381e-06}, {\"x\": 3.0434782608695663, \"y\": -8.840579710144928, \"x2\": 3.333333333333334, \"y2\": -8.55072463768116, \"center_x\": 3.18840579710145, \"center_y\": -8.695652173913043, \"value_uncond\": 1.7674753717998176e-06}, {\"x\": 3.333333333333334, \"y\": -8.840579710144928, \"x2\": 3.6231884057971016, \"y2\": -8.55072463768116, \"center_x\": 3.4782608695652177, \"center_y\": -8.695652173913043, \"value_uncond\": 1.814283246812509e-06}, {\"x\": 3.6231884057971016, \"y\": -8.840579710144928, \"x2\": 3.913043478260869, \"y2\": -8.55072463768116, \"center_x\": 3.7681159420289854, \"center_y\": -8.695652173913043, \"value_uncond\": 1.8450265672647379e-06}, {\"x\": 3.913043478260871, \"y\": -8.840579710144928, \"x2\": 4.202898550724639, \"y2\": -8.55072463768116, \"center_x\": 4.057971014492755, \"center_y\": -8.695652173913043, \"value_uncond\": 1.8588569626176071e-06}, {\"x\": 4.202898550724639, \"y\": -8.840579710144928, \"x2\": 4.492753623188406, \"y2\": -8.55072463768116, \"center_x\": 4.347826086956522, \"center_y\": -8.695652173913043, \"value_uncond\": 1.8553896746451031e-06}, {\"x\": 4.492753623188406, \"y\": -8.840579710144928, \"x2\": 4.782608695652174, \"y2\": -8.55072463768116, \"center_x\": 4.63768115942029, \"center_y\": -8.695652173913043, \"value_uncond\": 1.834721342061928e-06}, {\"x\": 4.782608695652174, \"y\": -8.840579710144928, \"x2\": 5.0724637681159415, \"y2\": -8.55072463768116, \"center_x\": 4.927536231884058, \"center_y\": -8.695652173913043, \"value_uncond\": 1.7974255253065148e-06}, {\"x\": 5.072463768115943, \"y\": -8.840579710144928, \"x2\": 5.362318840579711, \"y2\": -8.55072463768116, \"center_x\": 5.217391304347827, \"center_y\": -8.695652173913043, \"value_uncond\": 1.7445262607207185e-06}, {\"x\": 5.362318840579711, \"y\": -8.840579710144928, \"x2\": 5.6521739130434785, \"y2\": -8.55072463768116, \"center_x\": 5.507246376811595, \"center_y\": -8.695652173913043, \"value_uncond\": 1.6774513459742732e-06}, {\"x\": 5.6521739130434785, \"y\": -8.840579710144928, \"x2\": 5.942028985507246, \"y2\": -8.55072463768116, \"center_x\": 5.797101449275362, \"center_y\": -8.695652173913043, \"value_uncond\": 1.5979683308139013e-06}, {\"x\": 5.942028985507246, \"y\": -8.840579710144928, \"x2\": 6.231884057971014, \"y2\": -8.55072463768116, \"center_x\": 6.08695652173913, \"center_y\": -8.695652173913043, \"value_uncond\": 1.5081072167683986e-06}, {\"x\": 6.2318840579710155, \"y\": -8.840579710144928, \"x2\": 6.521739130434783, \"y2\": -8.55072463768116, \"center_x\": 6.376811594202899, \"center_y\": -8.695652173913043, \"value_uncond\": 1.4100745781337623e-06}, {\"x\": 6.521739130434785, \"y\": -8.840579710144928, \"x2\": 6.8115942028985526, \"y2\": -8.55072463768116, \"center_x\": 6.666666666666669, \"center_y\": -8.695652173913043, \"value_uncond\": 1.3061641575386623e-06}, {\"x\": 6.811594202898551, \"y\": -8.840579710144928, \"x2\": 7.101449275362318, \"y2\": -8.55072463768116, \"center_x\": 6.956521739130435, \"center_y\": -8.695652173913043, \"value_uncond\": 1.198668950703914e-06}, {\"x\": 7.10144927536232, \"y\": -8.840579710144928, \"x2\": 7.391304347826088, \"y2\": -8.55072463768116, \"center_x\": 7.246376811594204, \"center_y\": -8.695652173913043, \"value_uncond\": 1.089799399320701e-06}, {\"x\": 7.391304347826086, \"y\": -8.840579710144928, \"x2\": 7.681159420289854, \"y2\": -8.55072463768116, \"center_x\": 7.53623188405797, \"center_y\": -8.695652173913043, \"value_uncond\": 9.8161161154077e-07}, {\"x\": 7.681159420289855, \"y\": -8.840579710144928, \"x2\": 7.971014492753623, \"y2\": -8.55072463768116, \"center_x\": 7.826086956521739, \"center_y\": -8.695652173913043, \"value_uncond\": 8.759486032096825e-07}, {\"x\": 7.971014492753625, \"y\": -8.840579710144928, \"x2\": 8.260869565217392, \"y2\": -8.55072463768116, \"center_x\": 8.115942028985508, \"center_y\": -8.695652173913043, \"value_uncond\": 7.74396490945468e-07}, {\"x\": 8.26086956521739, \"y\": -8.840579710144928, \"x2\": 8.550724637681158, \"y2\": -8.55072463768116, \"center_x\": 8.405797101449274, \"center_y\": -8.695652173913043, \"value_uncond\": 6.782564662225695e-07}, {\"x\": 8.55072463768116, \"y\": -8.840579710144928, \"x2\": 8.840579710144928, \"y2\": -8.55072463768116, \"center_x\": 8.695652173913043, \"center_y\": -8.695652173913043, \"value_uncond\": 5.885323283838296e-07}, {\"x\": 8.84057971014493, \"y\": -8.840579710144928, \"x2\": 9.130434782608697, \"y2\": -8.55072463768116, \"center_x\": 8.985507246376812, \"center_y\": -8.695652173913043, \"value_uncond\": 5.059324312362338e-07}, {\"x\": 9.130434782608695, \"y\": -8.840579710144928, \"x2\": 9.420289855072463, \"y2\": -8.55072463768116, \"center_x\": 9.275362318840578, \"center_y\": -8.695652173913043, \"value_uncond\": 4.308841604846021e-07}, {\"x\": 9.420289855072465, \"y\": -8.840579710144928, \"x2\": 9.710144927536232, \"y2\": -8.55072463768116, \"center_x\": 9.565217391304348, \"center_y\": -8.695652173913043, \"value_uncond\": 3.6355854288509836e-07}, {\"x\": 9.710144927536234, \"y\": -8.840579710144928, \"x2\": 10.000000000000002, \"y2\": -8.55072463768116, \"center_x\": 9.855072463768117, \"center_y\": -8.695652173913043, \"value_uncond\": 3.039023044647501e-07}, {\"x\": 10.0, \"y\": -8.840579710144928, \"x2\": 10.289855072463768, \"y2\": -8.55072463768116, \"center_x\": 10.144927536231883, \"center_y\": -8.695652173913043, \"value_uncond\": 2.5167463476322513e-07}, {\"x\": -10.0, \"y\": -8.55072463768116, \"x2\": -9.710144927536232, \"y2\": -8.260869565217392, \"center_x\": -9.855072463768117, \"center_y\": -8.405797101449277, \"value_uncond\": 5.2241708969495986e-11}, {\"x\": -9.710144927536232, \"y\": -8.55072463768116, \"x2\": -9.420289855072465, \"y2\": -8.260869565217392, \"center_x\": -9.565217391304348, \"center_y\": -8.405797101449277, \"value_uncond\": 8.162203914133939e-11}, {\"x\": -9.420289855072463, \"y\": -8.55072463768116, \"x2\": -9.130434782608695, \"y2\": -8.260869565217392, \"center_x\": -9.275362318840578, \"center_y\": -8.405797101449277, \"value_uncond\": 1.2634071196837675e-10}, {\"x\": -9.130434782608695, \"y\": -8.55072463768116, \"x2\": -8.840579710144928, \"y2\": -8.260869565217392, \"center_x\": -8.985507246376812, \"center_y\": -8.405797101449277, \"value_uncond\": 1.9374255109995932e-10}, {\"x\": -8.840579710144928, \"y\": -8.55072463768116, \"x2\": -8.55072463768116, \"y2\": -8.260869565217392, \"center_x\": -8.695652173913043, \"center_y\": -8.405797101449277, \"value_uncond\": 2.9434219389693743e-10}, {\"x\": -8.55072463768116, \"y\": -8.55072463768116, \"x2\": -8.260869565217392, \"y2\": -8.260869565217392, \"center_x\": -8.405797101449277, \"center_y\": -8.405797101449277, \"value_uncond\": 4.430225634675171e-10}, {\"x\": -8.26086956521739, \"y\": -8.55072463768116, \"x2\": -7.971014492753623, \"y2\": -8.260869565217392, \"center_x\": -8.115942028985508, \"center_y\": -8.405797101449277, \"value_uncond\": 6.606097563964613e-10}, {\"x\": -7.971014492753623, \"y\": -8.55072463768116, \"x2\": -7.681159420289855, \"y2\": -8.260869565217392, \"center_x\": -7.826086956521739, \"center_y\": -8.405797101449277, \"value_uncond\": 9.75910376259108e-10}, {\"x\": -7.681159420289855, \"y\": -8.55072463768116, \"x2\": -7.391304347826088, \"y2\": -8.260869565217392, \"center_x\": -7.536231884057972, \"center_y\": -8.405797101449277, \"value_uncond\": 1.4283041641778947e-09}, {\"x\": -7.391304347826087, \"y\": -8.55072463768116, \"x2\": -7.101449275362319, \"y2\": -8.260869565217392, \"center_x\": -7.246376811594203, \"center_y\": -8.405797101449277, \"value_uncond\": 2.07098657518581e-09}, {\"x\": -7.101449275362318, \"y\": -8.55072463768116, \"x2\": -6.811594202898551, \"y2\": -8.260869565217392, \"center_x\": -6.956521739130435, \"center_y\": -8.405797101449277, \"value_uncond\": 2.974950058651102e-09}, {\"x\": -6.811594202898551, \"y\": -8.55072463768116, \"x2\": -6.521739130434783, \"y2\": -8.260869565217392, \"center_x\": -6.666666666666667, \"center_y\": -8.405797101449277, \"value_uncond\": 4.233776128403348e-09}, {\"x\": -6.521739130434782, \"y\": -8.55072463768116, \"x2\": -6.231884057971015, \"y2\": -8.260869565217392, \"center_x\": -6.3768115942028984, \"center_y\": -8.405797101449277, \"value_uncond\": 5.969279505777591e-09}, {\"x\": -6.231884057971014, \"y\": -8.55072463768116, \"x2\": -5.942028985507246, \"y2\": -8.260869565217392, \"center_x\": -6.08695652173913, \"center_y\": -8.405797101449277, \"value_uncond\": 8.33799737848785e-09}, {\"x\": -5.942028985507246, \"y\": -8.55072463768116, \"x2\": -5.6521739130434785, \"y2\": -8.260869565217392, \"center_x\": -5.797101449275362, \"center_y\": -8.405797101449277, \"value_uncond\": 1.153844829399938e-08}, {\"x\": -5.6521739130434785, \"y\": -8.55072463768116, \"x2\": -5.362318840579711, \"y2\": -8.260869565217392, \"center_x\": -5.507246376811595, \"center_y\": -8.405797101449277, \"value_uncond\": 1.5818994562821986e-08}, {\"x\": -5.36231884057971, \"y\": -8.55072463768116, \"x2\": -5.072463768115942, \"y2\": -8.260869565217392, \"center_x\": -5.217391304347826, \"center_y\": -8.405797101449277, \"value_uncond\": 2.1486029113127425e-08}, {\"x\": -5.0724637681159415, \"y\": -8.55072463768116, \"x2\": -4.782608695652174, \"y2\": -8.260869565217392, \"center_x\": -4.927536231884058, \"center_y\": -8.405797101449277, \"value_uncond\": 2.8912074711345388e-08}, {\"x\": -4.782608695652174, \"y\": -8.55072463768116, \"x2\": -4.492753623188406, \"y2\": -8.260869565217392, \"center_x\": -4.63768115942029, \"center_y\": -8.405797101449277, \"value_uncond\": 3.854323559455201e-08}, {\"x\": -4.492753623188405, \"y\": -8.55072463768116, \"x2\": -4.202898550724638, \"y2\": -8.260869565217392, \"center_x\": -4.3478260869565215, \"center_y\": -8.405797101449277, \"value_uncond\": 5.0905287705900384e-08}, {\"x\": -4.202898550724638, \"y\": -8.55072463768116, \"x2\": -3.91304347826087, \"y2\": -8.260869565217392, \"center_x\": -4.057971014492754, \"center_y\": -8.405797101449277, \"value_uncond\": 6.660754664192793e-08}, {\"x\": -3.913043478260869, \"y\": -8.55072463768116, \"x2\": -3.6231884057971016, \"y2\": -8.260869565217392, \"center_x\": -3.7681159420289854, \"center_y\": -8.405797101449277, \"value_uncond\": 8.634352867076865e-08}, {\"x\": -3.6231884057971016, \"y\": -8.55072463768116, \"x2\": -3.333333333333334, \"y2\": -8.260869565217392, \"center_x\": -3.4782608695652177, \"center_y\": -8.405797101449277, \"value_uncond\": 1.1088733950400234e-07}, {\"x\": -3.333333333333333, \"y\": -8.55072463768116, \"x2\": -3.0434782608695654, \"y2\": -8.260869565217392, \"center_x\": -3.1884057971014492, \"center_y\": -8.405797101449277, \"value_uncond\": 1.41084709582318e-07}, {\"x\": -3.0434782608695645, \"y\": -8.55072463768116, \"x2\": -2.753623188405797, \"y2\": -8.260869565217392, \"center_x\": -2.8985507246376807, \"center_y\": -8.405797101449277, \"value_uncond\": 1.7783766518923127e-07}, {\"x\": -2.753623188405797, \"y\": -8.55072463768116, \"x2\": -2.4637681159420293, \"y2\": -8.260869565217392, \"center_x\": -2.608695652173913, \"center_y\": -8.405797101449277, \"value_uncond\": 2.2208200099933804e-07}, {\"x\": -2.4637681159420284, \"y\": -8.55072463768116, \"x2\": -2.1739130434782608, \"y2\": -8.260869565217392, \"center_x\": -2.3188405797101446, \"center_y\": -8.405797101449277, \"value_uncond\": 2.747570155399246e-07}, {\"x\": -2.1739130434782608, \"y\": -8.55072463768116, \"x2\": -1.8840579710144931, \"y2\": -8.260869565217392, \"center_x\": -2.028985507246377, \"center_y\": -8.405797101449277, \"value_uncond\": 3.3676739177298414e-07}, {\"x\": -1.8840579710144922, \"y\": -8.55072463768116, \"x2\": -1.5942028985507246, \"y2\": -8.260869565217392, \"center_x\": -1.7391304347826084, \"center_y\": -8.405797101449277, \"value_uncond\": 4.089376443349696e-07}, {\"x\": -1.5942028985507246, \"y\": -8.55072463768116, \"x2\": -1.304347826086957, \"y2\": -8.260869565217392, \"center_x\": -1.4492753623188408, \"center_y\": -8.405797101449277, \"value_uncond\": 4.919601927890292e-07}, {\"x\": -1.304347826086957, \"y\": -8.55072463768116, \"x2\": -1.0144927536231894, \"y2\": -8.260869565217392, \"center_x\": -1.1594202898550732, \"center_y\": -8.405797101449277, \"value_uncond\": 5.863388213528535e-07}, {\"x\": -1.0144927536231876, \"y\": -8.55072463768116, \"x2\": -0.72463768115942, \"y2\": -8.260869565217392, \"center_x\": -0.8695652173913038, \"center_y\": -8.405797101449277, \"value_uncond\": 6.923300000192465e-07}, {\"x\": -0.72463768115942, \"y\": -8.55072463768116, \"x2\": -0.43478260869565233, \"y2\": -8.260869565217392, \"center_x\": -0.5797101449275361, \"center_y\": -8.405797101449277, \"value_uncond\": 8.098852073070005e-07}, {\"x\": -0.43478260869565233, \"y\": -8.55072463768116, \"x2\": -0.1449275362318847, \"y2\": -8.260869565217392, \"center_x\": -0.2898550724637685, \"center_y\": -8.405797101449277, \"value_uncond\": 9.385979402885297e-07}, {\"x\": -0.14492753623188293, \"y\": -8.55072463768116, \"x2\": 0.1449275362318847, \"y2\": -8.260869565217392, \"center_x\": 8.881784197001252e-16, \"center_y\": -8.405797101449277, \"value_uncond\": 1.077659450100381e-06}, {\"x\": 0.1449275362318847, \"y\": -8.55072463768116, \"x2\": 0.43478260869565233, \"y2\": -8.260869565217392, \"center_x\": 0.2898550724637685, \"center_y\": -8.405797101449277, \"value_uncond\": 1.2258273333896651e-06}, {\"x\": 0.43478260869565233, \"y\": -8.55072463768116, \"x2\": 0.72463768115942, \"y2\": -8.260869565217392, \"center_x\": 0.5797101449275361, \"center_y\": -8.405797101449277, \"value_uncond\": 1.3814108885194928e-06}, {\"x\": 0.72463768115942, \"y\": -8.55072463768116, \"x2\": 1.0144927536231876, \"y2\": -8.260869565217392, \"center_x\": 0.8695652173913038, \"center_y\": -8.405797101449277, \"value_uncond\": 1.5422765784592037e-06}, {\"x\": 1.0144927536231894, \"y\": -8.55072463768116, \"x2\": 1.304347826086957, \"y2\": -8.260869565217392, \"center_x\": 1.1594202898550732, \"center_y\": -8.405797101449277, \"value_uncond\": 1.705876027932241e-06}, {\"x\": 1.304347826086957, \"y\": -8.55072463768116, \"x2\": 1.5942028985507246, \"y2\": -8.260869565217392, \"center_x\": 1.4492753623188408, \"center_y\": -8.405797101449277, \"value_uncond\": 1.8692977522789205e-06}, {\"x\": 1.5942028985507246, \"y\": -8.55072463768116, \"x2\": 1.8840579710144922, \"y2\": -8.260869565217392, \"center_x\": 1.7391304347826084, \"center_y\": -8.405797101449277, \"value_uncond\": 2.0293423365645064e-06}, {\"x\": 1.884057971014494, \"y\": -8.55072463768116, \"x2\": 2.1739130434782616, \"y2\": -8.260869565217392, \"center_x\": 2.028985507246378, \"center_y\": -8.405797101449277, \"value_uncond\": 2.1826191553660887e-06}, {\"x\": 2.1739130434782616, \"y\": -8.55072463768116, \"x2\": 2.4637681159420293, \"y2\": -8.260869565217392, \"center_x\": 2.3188405797101455, \"center_y\": -8.405797101449277, \"value_uncond\": 2.325661072031476e-06}, {\"x\": 2.4637681159420293, \"y\": -8.55072463768116, \"x2\": 2.753623188405797, \"y2\": -8.260869565217392, \"center_x\": 2.608695652173913, \"center_y\": -8.405797101449277, \"value_uncond\": 2.455052022138501e-06}, {\"x\": 2.753623188405797, \"y\": -8.55072463768116, \"x2\": 3.0434782608695645, \"y2\": -8.260869565217392, \"center_x\": 2.8985507246376807, \"center_y\": -8.405797101449277, \"value_uncond\": 2.567561112617595e-06}, {\"x\": 3.0434782608695663, \"y\": -8.55072463768116, \"x2\": 3.333333333333334, \"y2\": -8.260869565217392, \"center_x\": 3.18840579710145, \"center_y\": -8.405797101449277, \"value_uncond\": 2.6602759859656123e-06}, {\"x\": 3.333333333333334, \"y\": -8.55072463768116, \"x2\": 3.6231884057971016, \"y2\": -8.260869565217392, \"center_x\": 3.4782608695652177, \"center_y\": -8.405797101449277, \"value_uncond\": 2.7307278111152564e-06}, {\"x\": 3.6231884057971016, \"y\": -8.55072463768116, \"x2\": 3.913043478260869, \"y2\": -8.260869565217392, \"center_x\": 3.7681159420289854, \"center_y\": -8.405797101449277, \"value_uncond\": 2.7770004316183796e-06}, {\"x\": 3.913043478260871, \"y\": -8.55072463768116, \"x2\": 4.202898550724639, \"y2\": -8.260869565217392, \"center_x\": 4.057971014492755, \"center_y\": -8.405797101449277, \"value_uncond\": 2.7978169415515185e-06}, {\"x\": 4.202898550724639, \"y\": -8.55072463768116, \"x2\": 4.492753623188406, \"y2\": -8.260869565217392, \"center_x\": 4.347826086956522, \"center_y\": -8.405797101449277, \"value_uncond\": 2.7925982306846808e-06}, {\"x\": 4.492753623188406, \"y\": -8.55072463768116, \"x2\": 4.782608695652174, \"y2\": -8.260869565217392, \"center_x\": 4.63768115942029, \"center_y\": -8.405797101449277, \"value_uncond\": 2.761489752615771e-06}, {\"x\": 4.782608695652174, \"y\": -8.55072463768116, \"x2\": 5.0724637681159415, \"y2\": -8.260869565217392, \"center_x\": 4.927536231884058, \"center_y\": -8.405797101449277, \"value_uncond\": 2.705354788997938e-06}, {\"x\": 5.072463768115943, \"y\": -8.55072463768116, \"x2\": 5.362318840579711, \"y2\": -8.260869565217392, \"center_x\": 5.217391304347827, \"center_y\": -8.405797101449277, \"value_uncond\": 2.625734645205194e-06}, {\"x\": 5.362318840579711, \"y\": -8.55072463768116, \"x2\": 5.6521739130434785, \"y2\": -8.260869565217392, \"center_x\": 5.507246376811595, \"center_y\": -8.405797101449277, \"value_uncond\": 2.52477833893488e-06}, {\"x\": 5.6521739130434785, \"y\": -8.55072463768116, \"x2\": 5.942028985507246, \"y2\": -8.260869565217392, \"center_x\": 5.797101449275362, \"center_y\": -8.405797101449277, \"value_uncond\": 2.4051462581167118e-06}, {\"x\": 5.942028985507246, \"y\": -8.55072463768116, \"x2\": 6.231884057971014, \"y2\": -8.260869565217392, \"center_x\": 6.08695652173913, \"center_y\": -8.405797101449277, \"value_uncond\": 2.2698938141044712e-06}, {\"x\": 6.2318840579710155, \"y\": -8.55072463768116, \"x2\": 6.521739130434783, \"y2\": -8.260869565217392, \"center_x\": 6.376811594202899, \"center_y\": -8.405797101449277, \"value_uncond\": 2.1223421827994186e-06}, {\"x\": 6.521739130434785, \"y\": -8.55072463768116, \"x2\": 6.8115942028985526, \"y2\": -8.260869565217392, \"center_x\": 6.666666666666669, \"center_y\": -8.405797101449277, \"value_uncond\": 1.965943739567227e-06}, {\"x\": 6.811594202898551, \"y\": -8.55072463768116, \"x2\": 7.101449275362318, \"y2\": -8.260869565217392, \"center_x\": 6.956521739130435, \"center_y\": -8.405797101449277, \"value_uncond\": 1.8041497355819331e-06}, {\"x\": 7.10144927536232, \"y\": -8.55072463768116, \"x2\": 7.391304347826088, \"y2\": -8.260869565217392, \"center_x\": 7.246376811594204, \"center_y\": -8.405797101449277, \"value_uncond\": 1.6402871676680804e-06}, {\"x\": 7.391304347826086, \"y\": -8.55072463768116, \"x2\": 7.681159420289854, \"y2\": -8.260869565217392, \"center_x\": 7.53623188405797, \"center_y\": -8.405797101449277, \"value_uncond\": 1.4774507409785143e-06}, {\"x\": 7.681159420289855, \"y\": -8.55072463768116, \"x2\": 7.971014492753623, \"y2\": -8.260869565217392, \"center_x\": 7.826086956521739, \"center_y\": -8.405797101449277, \"value_uncond\": 1.3184144295520983e-06}, {\"x\": 7.971014492753625, \"y\": -8.55072463768116, \"x2\": 8.260869565217392, \"y2\": -8.260869565217392, \"center_x\": 8.115942028985508, \"center_y\": -8.405797101449277, \"value_uncond\": 1.165565541306785e-06}, {\"x\": 8.26086956521739, \"y\": -8.55072463768116, \"x2\": 8.550724637681158, \"y2\": -8.260869565217392, \"center_x\": 8.405797101449274, \"center_y\": -8.405797101449277, \"value_uncond\": 1.020862535459508e-06}, {\"x\": 8.55072463768116, \"y\": -8.55072463768116, \"x2\": 8.840579710144928, \"y2\": -8.260869565217392, \"center_x\": 8.695652173913043, \"center_y\": -8.405797101449277, \"value_uncond\": 8.858162581182798e-07}, {\"x\": 8.84057971014493, \"y\": -8.55072463768116, \"x2\": 9.130434782608697, \"y2\": -8.260869565217392, \"center_x\": 8.985507246376812, \"center_y\": -8.405797101449277, \"value_uncond\": 7.614928721571976e-07}, {\"x\": 9.130434782608695, \"y\": -8.55072463768116, \"x2\": 9.420289855072463, \"y2\": -8.260869565217392, \"center_x\": 9.275362318840578, \"center_y\": -8.405797101449277, \"value_uncond\": 6.485356476016378e-07}, {\"x\": 9.420289855072465, \"y\": -8.55072463768116, \"x2\": 9.710144927536232, \"y2\": -8.260869565217392, \"center_x\": 9.565217391304348, \"center_y\": -8.405797101449277, \"value_uncond\": 5.472020015447292e-07}, {\"x\": 9.710144927536234, \"y\": -8.55072463768116, \"x2\": 10.000000000000002, \"y2\": -8.260869565217392, \"center_x\": 9.855072463768117, \"center_y\": -8.405797101449277, \"value_uncond\": 4.5741174985874186e-07}, {\"x\": 10.0, \"y\": -8.55072463768116, \"x2\": 10.289855072463768, \"y2\": -8.260869565217392, \"center_x\": 10.144927536231883, \"center_y\": -8.405797101449277, \"value_uncond\": 3.7880244207052163e-07}, {\"x\": -10.0, \"y\": -8.26086956521739, \"x2\": -9.710144927536232, \"y2\": -7.971014492753623, \"center_x\": -9.855072463768117, \"center_y\": -8.115942028985508, \"value_uncond\": 7.789983057737388e-11}, {\"x\": -9.710144927536232, \"y\": -8.26086956521739, \"x2\": -9.420289855072465, \"y2\": -7.971014492753623, \"center_x\": -9.565217391304348, \"center_y\": -8.115942028985508, \"value_uncond\": 1.2171008846978545e-10}, {\"x\": -9.420289855072463, \"y\": -8.26086956521739, \"x2\": -9.130434782608695, \"y2\": -7.971014492753623, \"center_x\": -9.275362318840578, \"center_y\": -8.115942028985508, \"value_uncond\": 1.883920004054249e-10}, {\"x\": -9.130434782608695, \"y\": -8.26086956521739, \"x2\": -8.840579710144928, \"y2\": -7.971014492753623, \"center_x\": -8.985507246376812, \"center_y\": -8.115942028985508, \"value_uncond\": 2.888977448101407e-10}, {\"x\": -8.840579710144928, \"y\": -8.26086956521739, \"x2\": -8.55072463768116, \"y2\": -7.971014492753623, \"center_x\": -8.695652173913043, \"center_y\": -8.115942028985508, \"value_uncond\": 4.3890614393438853e-10}, {\"x\": -8.55072463768116, \"y\": -8.26086956521739, \"x2\": -8.260869565217392, \"y2\": -7.971014492753623, \"center_x\": -8.405797101449277, \"center_y\": -8.115942028985508, \"value_uncond\": 6.606097563964613e-10}, {\"x\": -8.26086956521739, \"y\": -8.26086956521739, \"x2\": -7.971014492753623, \"y2\": -7.971014492753623, \"center_x\": -8.115942028985508, \"center_y\": -8.115942028985508, \"value_uncond\": 9.850632591497524e-10}, {\"x\": -7.971014492753623, \"y\": -8.26086956521739, \"x2\": -7.681159420289855, \"y2\": -7.971014492753623, \"center_x\": -7.826086956521739, \"center_y\": -8.115942028985508, \"value_uncond\": 1.4552214019965556e-09}, {\"x\": -7.681159420289855, \"y\": -8.26086956521739, \"x2\": -7.391304347826088, \"y2\": -7.971014492753623, \"center_x\": -7.536231884057972, \"center_y\": -8.115942028985508, \"value_uncond\": 2.129804989101398e-09}, {\"x\": -7.391304347826087, \"y\": -8.26086956521739, \"x2\": -7.101449275362319, \"y2\": -7.971014492753623, \"center_x\": -7.246376811594203, \"center_y\": -8.115942028985508, \"value_uncond\": 3.0881360222957336e-09}, {\"x\": -7.101449275362318, \"y\": -8.26086956521739, \"x2\": -6.811594202898551, \"y2\": -7.971014492753623, \"center_x\": -6.956521739130435, \"center_y\": -8.115942028985508, \"value_uncond\": 4.4360743573757856e-09}, {\"x\": -6.811594202898551, \"y\": -8.26086956521739, \"x2\": -6.521739130434783, \"y2\": -7.971014492753623, \"center_x\": -6.666666666666667, \"center_y\": -8.115942028985508, \"value_uncond\": 6.313163363352597e-09}, {\"x\": -6.521739130434782, \"y\": -8.26086956521739, \"x2\": -6.231884057971015, \"y2\": -7.971014492753623, \"center_x\": -6.3768115942028984, \"center_y\": -8.115942028985508, \"value_uncond\": 8.901046143811682e-09}, {\"x\": -6.231884057971014, \"y\": -8.26086956521739, \"x2\": -5.942028985507246, \"y2\": -7.971014492753623, \"center_x\": -6.08695652173913, \"center_y\": -8.115942028985508, \"value_uncond\": 1.2433141946371896e-08}, {\"x\": -5.942028985507246, \"y\": -8.26086956521739, \"x2\": -5.6521739130434785, \"y2\": -7.971014492753623, \"center_x\": -5.797101449275362, \"center_y\": -8.115942028985508, \"value_uncond\": 1.720547020682608e-08}, {\"x\": -5.6521739130434785, \"y\": -8.26086956521739, \"x2\": -5.362318840579711, \"y2\": -7.971014492753623, \"center_x\": -5.507246376811595, \"center_y\": -8.115942028985508, \"value_uncond\": 2.358837451255229e-08}, {\"x\": -5.36231884057971, \"y\": -8.26086956521739, \"x2\": -5.072463768115942, \"y2\": -7.971014492753623, \"center_x\": -5.217391304347826, \"center_y\": -8.115942028985508, \"value_uncond\": 3.203873036907085e-08}, {\"x\": -5.0724637681159415, \"y\": -8.26086956521739, \"x2\": -4.782608695652174, \"y2\": -7.971014492753623, \"center_x\": -4.927536231884058, \"center_y\": -8.115942028985508, \"value_uncond\": 4.311202229179132e-08}, {\"x\": -4.782608695652174, \"y\": -8.26086956521739, \"x2\": -4.492753623188406, \"y2\": -7.971014492753623, \"center_x\": -4.63768115942029, \"center_y\": -8.115942028985508, \"value_uncond\": 5.747345525148468e-08}, {\"x\": -4.492753623188405, \"y\": -8.26086956521739, \"x2\": -4.202898550724638, \"y2\": -7.971014492753623, \"center_x\": -4.3478260869565215, \"center_y\": -8.115942028985508, \"value_uncond\": 7.59070360829428e-08}, {\"x\": -4.202898550724638, \"y\": -8.26086956521739, \"x2\": -3.91304347826087, \"y2\": -7.971014492753623, \"center_x\": -4.057971014492754, \"center_y\": -8.115942028985508, \"value_uncond\": 9.932134114545186e-08}, {\"x\": -3.913043478260869, \"y\": -8.26086956521739, \"x2\": -3.6231884057971016, \"y2\": -7.971014492753623, \"center_x\": -3.7681159420289854, \"center_y\": -8.115942028985508, \"value_uncond\": 1.287505019951189e-07}, {\"x\": -3.6231884057971016, \"y\": -8.26086956521739, \"x2\": -3.333333333333334, \"y2\": -7.971014492753623, \"center_x\": -3.4782608695652177, \"center_y\": -8.115942028985508, \"value_uncond\": 1.6534882052923152e-07}, {\"x\": -3.333333333333333, \"y\": -8.26086956521739, \"x2\": -3.0434782608695654, \"y2\": -7.971014492753623, \"center_x\": -3.1884057971014492, \"center_y\": -8.115942028985508, \"value_uncond\": 2.1037740132004386e-07}, {\"x\": -3.0434782608695645, \"y\": -8.26086956521739, \"x2\": -2.753623188405797, \"y2\": -7.971014492753623, \"center_x\": -2.8985507246376807, \"center_y\": -8.115942028985508, \"value_uncond\": 2.651812940615314e-07}, {\"x\": -2.753623188405797, \"y\": -8.26086956521739, \"x2\": -2.4637681159420293, \"y2\": -7.971014492753623, \"center_x\": -2.608695652173913, \"center_y\": -8.115942028985508, \"value_uncond\": 3.3115590192951433e-07}, {\"x\": -2.4637681159420284, \"y\": -8.26086956521739, \"x2\": -2.1739130434782608, \"y2\": -7.971014492753623, \"center_x\": -2.3188405797101446, \"center_y\": -8.115942028985508, \"value_uncond\": 4.0970185284334017e-07}, {\"x\": -2.1739130434782608, \"y\": -8.26086956521739, \"x2\": -1.8840579710144931, \"y2\": -7.971014492753623, \"center_x\": -2.028985507246377, \"center_y\": -8.115942028985508, \"value_uncond\": 5.021681579830735e-07}, {\"x\": -1.8840579710144922, \"y\": -8.26086956521739, \"x2\": -1.5942028985507246, \"y2\": -7.971014492753623, \"center_x\": -1.7391304347826084, \"center_y\": -8.115942028985508, \"value_uncond\": 6.09784286134387e-07}, {\"x\": -1.5942028985507246, \"y\": -8.26086956521739, \"x2\": -1.304347826086957, \"y2\": -7.971014492753623, \"center_x\": -1.4492753623188408, \"center_y\": -8.115942028985508, \"value_uncond\": 7.33582733510017e-07}, {\"x\": -1.304347826086957, \"y\": -8.26086956521739, \"x2\": -1.0144927536231894, \"y2\": -7.971014492753623, \"center_x\": -1.1594202898550732, \"center_y\": -8.115942028985508, \"value_uncond\": 8.743147141490828e-07}, {\"x\": -1.0144927536231876, \"y\": -8.26086956521739, \"x2\": -0.72463768115942, \"y2\": -7.971014492753623, \"center_x\": -0.8695652173913038, \"center_y\": -8.115942028985508, \"value_uncond\": 1.032362661348308e-06}, {\"x\": -0.72463768115942, \"y\": -8.26086956521739, \"x2\": -0.43478260869565233, \"y2\": -7.971014492753623, \"center_x\": -0.5797101449275361, \"center_y\": -8.115942028985508, \"value_uncond\": 1.2076542226667024e-06}, {\"x\": -0.43478260869565233, \"y\": -8.26086956521739, \"x2\": -0.1449275362318847, \"y2\": -7.971014492753623, \"center_x\": -0.2898550724637685, \"center_y\": -8.115942028985508, \"value_uncond\": 1.3995832443276615e-06}, {\"x\": -0.14492753623188293, \"y\": -8.26086956521739, \"x2\": 0.1449275362318847, \"y2\": -7.971014492753623, \"center_x\": 8.881784197001252e-16, \"center_y\": -8.115942028985508, \"value_uncond\": 1.6069437665590913e-06}, {\"x\": 0.1449275362318847, \"y\": -8.26086956521739, \"x2\": 0.43478260869565233, \"y2\": -7.971014492753623, \"center_x\": 0.2898550724637685, \"center_y\": -8.115942028985508, \"value_uncond\": 1.8278831889654851e-06}, {\"x\": 0.43478260869565233, \"y\": -8.26086956521739, \"x2\": 0.72463768115942, \"y2\": -7.971014492753623, \"center_x\": 0.5797101449275361, \"center_y\": -8.115942028985508, \"value_uncond\": 2.0598804345440314e-06}, {\"x\": 0.72463768115942, \"y\": -8.26086956521739, \"x2\": 1.0144927536231876, \"y2\": -7.971014492753623, \"center_x\": 0.8695652173913038, \"center_y\": -8.115942028985508, \"value_uncond\": 2.2997540956322e-06}, {\"x\": 1.0144927536231894, \"y\": -8.26086956521739, \"x2\": 1.304347826086957, \"y2\": -7.971014492753623, \"center_x\": 1.1594202898550732, \"center_y\": -8.115942028985508, \"value_uncond\": 2.5437041816438e-06}, {\"x\": 1.304347826086957, \"y\": -8.26086956521739, \"x2\": 1.5942028985507246, \"y2\": -7.971014492753623, \"center_x\": 1.4492753623188408, \"center_y\": -8.115942028985508, \"value_uncond\": 2.7873892541727638e-06}, {\"x\": 1.5942028985507246, \"y\": -8.26086956521739, \"x2\": 1.8840579710144922, \"y2\": -7.971014492753623, \"center_x\": 1.7391304347826084, \"center_y\": -8.115942028985508, \"value_uncond\": 3.0260385297535673e-06}, {\"x\": 1.884057971014494, \"y\": -8.26086956521739, \"x2\": 2.1739130434782616, \"y2\": -7.971014492753623, \"center_x\": 2.028985507246378, \"center_y\": -8.115942028985508, \"value_uncond\": 3.2545961028424198e-06}, {\"x\": 2.1739130434782616, \"y\": -8.26086956521739, \"x2\": 2.4637681159420293, \"y2\": -7.971014492753623, \"center_x\": 2.3188405797101455, \"center_y\": -8.115942028985508, \"value_uncond\": 3.4678919787526597e-06}, {\"x\": 2.4637681159420293, \"y\": -8.26086956521739, \"x2\": 2.753623188405797, \"y2\": -7.971014492753623, \"center_x\": 2.608695652173913, \"center_y\": -8.115942028985508, \"value_uncond\": 3.660832318768493e-06}, {\"x\": 2.753623188405797, \"y\": -8.26086956521739, \"x2\": 3.0434782608695645, \"y2\": -7.971014492753623, \"center_x\": 2.8985507246376807, \"center_y\": -8.115942028985508, \"value_uncond\": 3.828599401040885e-06}, {\"x\": 3.0434782608695663, \"y\": -8.26086956521739, \"x2\": 3.333333333333334, \"y2\": -7.971014492753623, \"center_x\": 3.18840579710145, \"center_y\": -8.115942028985508, \"value_uncond\": 3.966850485629838e-06}, {\"x\": 3.333333333333334, \"y\": -8.26086956521739, \"x2\": 3.6231884057971016, \"y2\": -7.971014492753623, \"center_x\": 3.4782608695652177, \"center_y\": -8.115942028985508, \"value_uncond\": 4.071904193697249e-06}, {\"x\": 3.6231884057971016, \"y\": -8.26086956521739, \"x2\": 3.913043478260869, \"y2\": -7.971014492753623, \"center_x\": 3.7681159420289854, \"center_y\": -8.115942028985508, \"value_uncond\": 4.14090326299778e-06}, {\"x\": 3.913043478260871, \"y\": -8.26086956521739, \"x2\": 4.202898550724639, \"y2\": -7.971014492753623, \"center_x\": 4.057971014492755, \"center_y\": -8.115942028985508, \"value_uncond\": 4.171943644887863e-06}, {\"x\": 4.202898550724639, \"y\": -8.26086956521739, \"x2\": 4.492753623188406, \"y2\": -7.971014492753623, \"center_x\": 4.347826086956522, \"center_y\": -8.115942028985508, \"value_uncond\": 4.164161803512874e-06}, {\"x\": 4.492753623188406, \"y\": -8.26086956521739, \"x2\": 4.782608695652174, \"y2\": -7.971014492753623, \"center_x\": 4.63768115942029, \"center_y\": -8.115942028985508, \"value_uncond\": 4.117774630909027e-06}, {\"x\": 4.782608695652174, \"y\": -8.26086956521739, \"x2\": 5.0724637681159415, \"y2\": -7.971014492753623, \"center_x\": 4.927536231884058, \"center_y\": -8.115942028985508, \"value_uncond\": 4.034069403006746e-06}, {\"x\": 5.072463768115943, \"y\": -8.26086956521739, \"x2\": 5.362318840579711, \"y2\": -7.971014492753623, \"center_x\": 5.217391304347827, \"center_y\": -8.115942028985508, \"value_uncond\": 3.915344425697475e-06}, {\"x\": 5.362318840579711, \"y\": -8.26086956521739, \"x2\": 5.6521739130434785, \"y2\": -7.971014492753623, \"center_x\": 5.507246376811595, \"center_y\": -8.115942028985508, \"value_uncond\": 3.7648041905231814e-06}, {\"x\": 5.6521739130434785, \"y\": -8.26086956521739, \"x2\": 5.942028985507246, \"y2\": -7.971014492753623, \"center_x\": 5.797101449275362, \"center_y\": -8.115942028985508, \"value_uncond\": 3.586415714893573e-06}, {\"x\": 5.942028985507246, \"y\": -8.26086956521739, \"x2\": 6.231884057971014, \"y2\": -7.971014492753623, \"center_x\": 6.08695652173913, \"center_y\": -8.115942028985508, \"value_uncond\": 3.3847350524198137e-06}, {\"x\": 6.2318840579710155, \"y\": -8.26086956521739, \"x2\": 6.521739130434783, \"y2\": -7.971014492753623, \"center_x\": 6.376811594202899, \"center_y\": -8.115942028985508, \"value_uncond\": 3.1647145495149364e-06}, {\"x\": 6.521739130434785, \"y\": -8.26086956521739, \"x2\": 6.8115942028985526, \"y2\": -7.971014492753623, \"center_x\": 6.666666666666669, \"center_y\": -8.115942028985508, \"value_uncond\": 2.931502189684466e-06}, {\"x\": 6.811594202898551, \"y\": -8.26086956521739, \"x2\": 7.101449275362318, \"y2\": -7.971014492753623, \"center_x\": 6.956521739130435, \"center_y\": -8.115942028985508, \"value_uncond\": 2.6902442801040447e-06}, {\"x\": 7.10144927536232, \"y\": -8.26086956521739, \"x2\": 7.391304347826088, \"y2\": -7.971014492753623, \"center_x\": 7.246376811594204, \"center_y\": -8.115942028985508, \"value_uncond\": 2.445901847012585e-06}, {\"x\": 7.391304347826086, \"y\": -8.26086956521739, \"x2\": 7.681159420289854, \"y2\": -7.971014492753623, \"center_x\": 7.53623188405797, \"center_y\": -8.115942028985508, \"value_uncond\": 2.2030895366735617e-06}, {\"x\": 7.681159420289855, \"y\": -8.26086956521739, \"x2\": 7.971014492753623, \"y2\": -7.971014492753623, \"center_x\": 7.826086956521739, \"center_y\": -8.115942028985508, \"value_uncond\": 1.965943739567227e-06}, {\"x\": 7.971014492753625, \"y\": -8.26086956521739, \"x2\": 8.260869565217392, \"y2\": -7.971014492753623, \"center_x\": 8.115942028985508, \"center_y\": -8.115942028985508, \"value_uncond\": 1.7380242719019876e-06}, {\"x\": 8.26086956521739, \"y\": -8.26086956521739, \"x2\": 8.550724637681158, \"y2\": -7.971014492753623, \"center_x\": 8.405797101449274, \"center_y\": -8.115942028985508, \"value_uncond\": 1.5222514753780152e-06}, {\"x\": 8.55072463768116, \"y\": -8.26086956521739, \"x2\": 8.840579710144928, \"y2\": -7.971014492753623, \"center_x\": 8.695652173913043, \"center_y\": -8.115942028985508, \"value_uncond\": 1.3208782367818309e-06}, {\"x\": 8.84057971014493, \"y\": -8.26086956521739, \"x2\": 9.130434782608697, \"y2\": -7.971014492753623, \"center_x\": 8.985507246376812, \"center_y\": -8.115942028985508, \"value_uncond\": 1.1354943568473354e-06}, {\"x\": 9.130434782608695, \"y\": -8.26086956521739, \"x2\": 9.420289855072463, \"y2\": -7.971014492753623, \"center_x\": 9.275362318840578, \"center_y\": -8.115942028985508, \"value_uncond\": 9.670590428244664e-07}, {\"x\": 9.420289855072465, \"y\": -8.26086956521739, \"x2\": 9.710144927536232, \"y2\": -7.971014492753623, \"center_x\": 9.565217391304348, \"center_y\": -8.115942028985508, \"value_uncond\": 8.15956140271452e-07}, {\"x\": 9.710144927536234, \"y\": -8.26086956521739, \"x2\": 10.000000000000002, \"y2\": -7.971014492753623, \"center_x\": 9.855072463768117, \"center_y\": -8.115942028985508, \"value_uncond\": 6.820660832305835e-07}, {\"x\": 10.0, \"y\": -8.26086956521739, \"x2\": 10.289855072463768, \"y2\": -7.971014492753623, \"center_x\": 10.144927536231883, \"center_y\": -8.115942028985508, \"value_uncond\": 5.648484064106578e-07}, {\"x\": -10.0, \"y\": -7.971014492753623, \"x2\": -9.710144927536232, \"y2\": -7.681159420289855, \"center_x\": -9.855072463768117, \"center_y\": -7.826086956521739, \"value_uncond\": 1.150804271859119e-10}, {\"x\": -9.710144927536232, \"y\": -7.971014492753623, \"x2\": -9.420289855072465, \"y2\": -7.681159420289855, \"center_x\": -9.565217391304348, \"center_y\": -7.826086956521739, \"value_uncond\": 1.7980076298145616e-10}, {\"x\": -9.420289855072463, \"y\": -7.971014492753623, \"x2\": -9.130434782608695, \"y2\": -7.681159420289855, \"center_x\": -9.275362318840578, \"center_y\": -7.826086956521739, \"value_uncond\": 2.783091018860542e-10}, {\"x\": -9.130434782608695, \"y\": -7.971014492753623, \"x2\": -8.840579710144928, \"y2\": -7.681159420289855, \"center_x\": -8.985507246376812, \"center_y\": -7.826086956521739, \"value_uncond\": 4.267849575459015e-10}, {\"x\": -8.840579710144928, \"y\": -7.971014492753623, \"x2\": -8.55072463768116, \"y2\": -7.681159420289855, \"center_x\": -8.695652173913043, \"center_y\": -7.826086956521739, \"value_uncond\": 6.483904543068586e-10}, {\"x\": -8.55072463768116, \"y\": -7.971014492753623, \"x2\": -8.260869565217392, \"y2\": -7.681159420289855, \"center_x\": -8.405797101449277, \"center_y\": -7.826086956521739, \"value_uncond\": 9.75910376259108e-10}, {\"x\": -8.26086956521739, \"y\": -7.971014492753623, \"x2\": -7.971014492753623, \"y2\": -7.681159420289855, \"center_x\": -8.115942028985508, \"center_y\": -7.826086956521739, \"value_uncond\": 1.4552214019965556e-09}, {\"x\": -7.971014492753623, \"y\": -7.971014492753623, \"x2\": -7.681159420289855, \"y2\": -7.681159420289855, \"center_x\": -7.826086956521739, \"center_y\": -7.826086956521739, \"value_uncond\": 2.1497800361132766e-09}, {\"x\": -7.681159420289855, \"y\": -7.971014492753623, \"x2\": -7.391304347826088, \"y2\": -7.681159420289855, \"center_x\": -7.536231884057972, \"center_y\": -7.826086956521739, \"value_uncond\": 3.146333774436529e-09}, {\"x\": -7.391304347826087, \"y\": -7.971014492753623, \"x2\": -7.101449275362319, \"y2\": -7.681159420289855, \"center_x\": -7.246376811594203, \"center_y\": -7.826086956521739, \"value_uncond\": 4.5620639996259195e-09}, {\"x\": -7.101449275362318, \"y\": -7.971014492753623, \"x2\": -6.811594202898551, \"y2\": -7.681159420289855, \"center_x\": -6.956521739130435, \"center_y\": -7.826086956521739, \"value_uncond\": 6.553356127882929e-09}, {\"x\": -6.811594202898551, \"y\": -7.971014492753623, \"x2\": -6.521739130434783, \"y2\": -7.681159420289855, \"center_x\": -6.666666666666667, \"center_y\": -7.826086956521739, \"value_uncond\": 9.326355800317806e-09}, {\"x\": -6.521739130434782, \"y\": -7.971014492753623, \"x2\": -6.231884057971015, \"y2\": -7.681159420289855, \"center_x\": -6.3768115942028984, \"center_y\": -7.826086956521739, \"value_uncond\": 1.314940205953262e-08}, {\"x\": -6.231884057971014, \"y\": -7.971014492753623, \"x2\": -5.942028985507246, \"y2\": -7.681159420289855, \"center_x\": -6.08695652173913, \"center_y\": -7.826086956521739, \"value_uncond\": 1.836732218602715e-08}, {\"x\": -5.942028985507246, \"y\": -7.971014492753623, \"x2\": -5.6521739130434785, \"y2\": -7.681159420289855, \"center_x\": -5.797101449275362, \"center_y\": -7.826086956521739, \"value_uncond\": 2.5417421920698242e-08}, {\"x\": -5.6521739130434785, \"y\": -7.971014492753623, \"x2\": -5.362318840579711, \"y2\": -7.681159420289855, \"center_x\": -5.507246376811595, \"center_y\": -7.826086956521739, \"value_uncond\": 3.484680512661137e-08}, {\"x\": -5.36231884057971, \"y\": -7.971014492753623, \"x2\": -5.072463768115942, \"y2\": -7.681159420289855, \"center_x\": -5.217391304347826, \"center_y\": -7.826086956521739, \"value_uncond\": 4.7330408166995674e-08}, {\"x\": -5.0724637681159415, \"y\": -7.971014492753623, \"x2\": -4.782608695652174, \"y2\": -7.681159420289855, \"center_x\": -4.927536231884058, \"center_y\": -7.826086956521739, \"value_uncond\": 6.368884123900681e-08}, {\"x\": -4.782608695652174, \"y\": -7.971014492753623, \"x2\": -4.492753623188406, \"y2\": -7.681159420289855, \"center_x\": -4.63768115942029, \"center_y\": -7.826086956521739, \"value_uncond\": 8.490480317055164e-08}, {\"x\": -4.492753623188405, \"y\": -7.971014492753623, \"x2\": -4.202898550724638, \"y2\": -7.681159420289855, \"center_x\": -4.3478260869565215, \"center_y\": -7.826086956521739, \"value_uncond\": 1.1213649726959334e-07}, {\"x\": -4.202898550724638, \"y\": -7.971014492753623, \"x2\": -3.91304347826087, \"y2\": -7.681159420289855, \"center_x\": -4.057971014492754, \"center_y\": -7.826086956521739, \"value_uncond\": 1.467261518154846e-07}, {\"x\": -3.913043478260869, \"y\": -7.971014492753623, \"x2\": -3.6231884057971016, \"y2\": -7.681159420289855, \"center_x\": -3.7681159420289854, \"center_y\": -7.826086956521739, \"value_uncond\": 1.902014761801341e-07}, {\"x\": -3.6231884057971016, \"y\": -7.971014492753623, \"x2\": -3.333333333333334, \"y2\": -7.681159420289855, \"center_x\": -3.4782608695652177, \"center_y\": -7.826086956521739, \"value_uncond\": 2.442677058493814e-07}, {\"x\": -3.333333333333333, \"y\": -7.971014492753623, \"x2\": -3.0434782608695654, \"y2\": -7.681159420289855, \"center_x\": -3.1884057971014492, \"center_y\": -7.826086956521739, \"value_uncond\": 3.1078785454001425e-07}, {\"x\": -3.0434782608695645, \"y\": -7.971014492753623, \"x2\": -2.753623188405797, \"y2\": -7.681159420289855, \"center_x\": -2.8985507246376807, \"center_y\": -7.826086956521739, \"value_uncond\": 3.917489470275911e-07}, {\"x\": -2.753623188405797, \"y\": -7.971014492753623, \"x2\": -2.4637681159420293, \"y2\": -7.681159420289855, \"center_x\": -2.608695652173913, \"center_y\": -7.826086956521739, \"value_uncond\": 4.892123946448407e-07}, {\"x\": -2.4637681159420284, \"y\": -7.971014492753623, \"x2\": -2.1739130434782608, \"y2\": -7.681159420289855, \"center_x\": -2.3188405797101446, \"center_y\": -7.826086956521739, \"value_uncond\": 6.052473271715371e-07}, {\"x\": -2.1739130434782608, \"y\": -7.971014492753623, \"x2\": -1.8840579710144931, \"y2\": -7.681159420289855, \"center_x\": -2.028985507246377, \"center_y\": -7.826086956521739, \"value_uncond\": 7.418466216361657e-07}, {\"x\": -1.8840579710144922, \"y\": -7.971014492753623, \"x2\": -1.5942028985507246, \"y2\": -7.681159420289855, \"center_x\": -1.7391304347826084, \"center_y\": -7.826086956521739, \"value_uncond\": 9.008265566110717e-07}, {\"x\": -1.5942028985507246, \"y\": -7.971014492753623, \"x2\": -1.304347826086957, \"y2\": -7.681159420289855, \"center_x\": -1.4492753623188408, \"center_y\": -7.826086956521739, \"value_uncond\": 1.0837124255962345e-06}, {\"x\": -1.304347826086957, \"y\": -7.971014492753623, \"x2\": -1.0144927536231894, \"y2\": -7.681159420289855, \"center_x\": -1.1594202898550732, \"center_y\": -7.826086956521739, \"value_uncond\": 1.291613987520393e-06}, {\"x\": -1.0144927536231876, \"y\": -7.971014492753623, \"x2\": -0.72463768115942, \"y2\": -7.681159420289855, \"center_x\": -0.8695652173913038, \"center_y\": -7.826086956521739, \"value_uncond\": 1.5250962062201841e-06}, {\"x\": -0.72463768115942, \"y\": -7.971014492753623, \"x2\": -0.43478260869565233, \"y2\": -7.681159420289855, \"center_x\": -0.5797101449275361, \"center_y\": -7.826086956521739, \"value_uncond\": 1.7840521963563896e-06}, {\"x\": -0.43478260869565233, \"y\": -7.971014492753623, \"x2\": -0.1449275362318847, \"y2\": -7.681159420289855, \"center_x\": -0.2898550724637685, \"center_y\": -7.826086956521739, \"value_uncond\": 2.067586494677862e-06}, {\"x\": -0.14492753623188293, \"y\": -7.971014492753623, \"x2\": 0.1449275362318847, \"y2\": -7.681159420289855, \"center_x\": 8.881784197001252e-16, \"center_y\": -7.826086956521739, \"value_uncond\": 2.373917552178486e-06}, {\"x\": 0.1449275362318847, \"y\": -7.971014492753623, \"x2\": 0.43478260869565233, \"y2\": -7.681159420289855, \"center_x\": 0.2898550724637685, \"center_y\": -7.826086956521739, \"value_uncond\": 2.7003085458980758e-06}, {\"x\": 0.43478260869565233, \"y\": -7.971014492753623, \"x2\": 0.72463768115942, \"y2\": -7.681159420289855, \"center_x\": 0.5797101449275361, \"center_y\": -7.826086956521739, \"value_uncond\": 3.043035120901547e-06}, {\"x\": 0.72463768115942, \"y\": -7.971014492753623, \"x2\": 1.0144927536231876, \"y2\": -7.681159420289855, \"center_x\": 0.8695652173913038, \"center_y\": -7.826086956521739, \"value_uncond\": 3.3973974241835387e-06}, {\"x\": 1.0144927536231894, \"y\": -7.971014492753623, \"x2\": 1.304347826086957, \"y2\": -7.681159420289855, \"center_x\": 1.1594202898550732, \"center_y\": -7.826086956521739, \"value_uncond\": 3.757781778066953e-06}, {\"x\": 1.304347826086957, \"y\": -7.971014492753623, \"x2\": 1.5942028985507246, \"y2\": -7.681159420289855, \"center_x\": 1.4492753623188408, \"center_y\": -7.826086956521739, \"value_uncond\": 4.117774630909027e-06}, {\"x\": 1.5942028985507246, \"y\": -7.971014492753623, \"x2\": 1.8840579710144922, \"y2\": -7.681159420289855, \"center_x\": 1.7391304347826084, \"center_y\": -7.826086956521739, \"value_uncond\": 4.470328165080958e-06}, {\"x\": 1.884057971014494, \"y\": -7.971014492753623, \"x2\": 2.1739130434782616, \"y2\": -7.681159420289855, \"center_x\": 2.028985507246378, \"center_y\": -7.826086956521739, \"value_uncond\": 4.807973355740461e-06}, {\"x\": 2.1739130434782616, \"y\": -7.971014492753623, \"x2\": 2.4637681159420293, \"y2\": -7.681159420289855, \"center_x\": 2.3188405797101455, \"center_y\": -7.826086956521739, \"value_uncond\": 5.123072635608127e-06}, {\"x\": 2.4637681159420293, \"y\": -7.971014492753623, \"x2\": 2.753623188405797, \"y2\": -7.681159420289855, \"center_x\": 2.608695652173913, \"center_y\": -7.826086956521739, \"value_uncond\": 5.4081009416499825e-06}, {\"x\": 2.753623188405797, \"y\": -7.971014492753623, \"x2\": 3.0434782608695645, \"y2\": -7.681159420289855, \"center_x\": 2.8985507246376807, \"center_y\": -7.826086956521739, \"value_uncond\": 5.65594111476133e-06}, {\"x\": 3.0434782608695663, \"y\": -7.971014492753623, \"x2\": 3.333333333333334, \"y2\": -7.681159420289855, \"center_x\": 3.18840579710145, \"center_y\": -7.826086956521739, \"value_uncond\": 5.860177680559899e-06}, {\"x\": 3.333333333333334, \"y\": -7.971014492753623, \"x2\": 3.6231884057971016, \"y2\": -7.681159420289855, \"center_x\": 3.4782608695652177, \"center_y\": -7.826086956521739, \"value_uncond\": 6.015372184992783e-06}, {\"x\": 3.6231884057971016, \"y\": -7.971014492753623, \"x2\": 3.913043478260869, \"y2\": -7.681159420289855, \"center_x\": 3.7681159420289854, \"center_y\": -7.826086956521739, \"value_uncond\": 6.117303630949506e-06}, {\"x\": 3.913043478260871, \"y\": -7.971014492753623, \"x2\": 4.202898550724639, \"y2\": -7.681159420289855, \"center_x\": 4.057971014492755, \"center_y\": -7.826086956521739, \"value_uncond\": 6.1631591916285006e-06}, {\"x\": 4.202898550724639, \"y\": -7.971014492753623, \"x2\": 4.492753623188406, \"y2\": -7.681159420289855, \"center_x\": 4.347826086956522, \"center_y\": -7.826086956521739, \"value_uncond\": 6.1516631765141e-06}, {\"x\": 4.492753623188406, \"y\": -7.971014492753623, \"x2\": 4.782608695652174, \"y2\": -7.681159420289855, \"center_x\": 4.63768115942029, \"center_y\": -7.826086956521739, \"value_uncond\": 6.08313599744797e-06}, {\"x\": 4.782608695652174, \"y\": -7.971014492753623, \"x2\": 5.0724637681159415, \"y2\": -7.681159420289855, \"center_x\": 4.927536231884058, \"center_y\": -7.826086956521739, \"value_uncond\": 5.9594793307608665e-06}, {\"x\": 5.072463768115943, \"y\": -7.971014492753623, \"x2\": 5.362318840579711, \"y2\": -7.681159420289855, \"center_x\": 5.217391304347827, \"center_y\": -7.826086956521739, \"value_uncond\": 5.7840884344633715e-06}, {\"x\": 5.362318840579711, \"y\": -7.971014492753623, \"x2\": 5.6521739130434785, \"y2\": -7.681159420289855, \"center_x\": 5.507246376811595, \"center_y\": -7.826086956521739, \"value_uncond\": 5.561697263081826e-06}, {\"x\": 5.6521739130434785, \"y\": -7.971014492753623, \"x2\": 5.942028985507246, \"y2\": -7.681159420289855, \"center_x\": 5.797101449275362, \"center_y\": -7.826086956521739, \"value_uncond\": 5.2981662408916325e-06}, {\"x\": 5.942028985507246, \"y\": -7.971014492753623, \"x2\": 6.231884057971014, \"y2\": -7.681159420289855, \"center_x\": 6.08695652173913, \"center_y\": -7.826086956521739, \"value_uncond\": 5.0002259678435955e-06}, {\"x\": 6.2318840579710155, \"y\": -7.971014492753623, \"x2\": 6.521739130434783, \"y2\": -7.681159420289855, \"center_x\": 6.376811594202899, \"center_y\": -7.826086956521739, \"value_uncond\": 4.675192482195596e-06}, {\"x\": 6.521739130434785, \"y\": -7.971014492753623, \"x2\": 6.8115942028985526, \"y2\": -7.681159420289855, \"center_x\": 6.666666666666669, \"center_y\": -7.826086956521739, \"value_uncond\": 4.330670834389596e-06}, {\"x\": 6.811594202898551, \"y\": -7.971014492753623, \"x2\": 7.101449275362318, \"y2\": -7.681159420289855, \"center_x\": 6.956521739130435, \"center_y\": -7.826086956521739, \"value_uncond\": 3.974263598446794e-06}, {\"x\": 7.10144927536232, \"y\": -7.971014492753623, \"x2\": 7.391304347826088, \"y2\": -7.681159420289855, \"center_x\": 7.246376811594204, \"center_y\": -7.826086956521739, \"value_uncond\": 3.613299635221212e-06}, {\"x\": 7.391304347826086, \"y\": -7.971014492753623, \"x2\": 7.681159420289854, \"y2\": -7.681159420289855, \"center_x\": 7.53623188405797, \"center_y\": -7.826086956521739, \"value_uncond\": 3.2545961028424198e-06}, {\"x\": 7.681159420289855, \"y\": -7.971014492753623, \"x2\": 7.971014492753623, \"y2\": -7.681159420289855, \"center_x\": 7.826086956521739, \"center_y\": -7.826086956521739, \"value_uncond\": 2.9042636382649264e-06}, {\"x\": 7.971014492753625, \"y\": -7.971014492753623, \"x2\": 8.260869565217392, \"y2\": -7.681159420289855, \"center_x\": 8.115942028985508, \"center_y\": -7.826086956521739, \"value_uncond\": 2.567561112617595e-06}, {\"x\": 8.26086956521739, \"y\": -7.971014492753623, \"x2\": 8.550724637681158, \"y2\": -7.681159420289855, \"center_x\": 8.405797101449274, \"center_y\": -7.826086956521739, \"value_uncond\": 2.248802709485845e-06}, {\"x\": 8.55072463768116, \"y\": -7.971014492753623, \"x2\": 8.840579710144928, \"y2\": -7.681159420289855, \"center_x\": 8.695652173913043, \"center_y\": -7.826086956521739, \"value_uncond\": 1.9513165898152533e-06}, {\"x\": 8.84057971014493, \"y\": -7.971014492753623, \"x2\": 9.130434782608697, \"y2\": -7.681159420289855, \"center_x\": 8.985507246376812, \"center_y\": -7.826086956521739, \"value_uncond\": 1.6774513459742732e-06}, {\"x\": 9.130434782608695, \"y\": -7.971014492753623, \"x2\": 9.420289855072463, \"y2\": -7.681159420289855, \"center_x\": 9.275362318840578, \"center_y\": -7.826086956521739, \"value_uncond\": 1.4286240026119246e-06}, {\"x\": 9.420289855072465, \"y\": -7.971014492753623, \"x2\": 9.710144927536232, \"y2\": -7.681159420289855, \"center_x\": 9.565217391304348, \"center_y\": -7.826086956521739, \"value_uncond\": 1.2054016098807787e-06}, {\"x\": 9.710144927536234, \"y\": -7.971014492753623, \"x2\": 10.000000000000002, \"y2\": -7.681159420289855, \"center_x\": 9.855072463768117, \"center_y\": -7.826086956521739, \"value_uncond\": 1.0076075345149136e-06}, {\"x\": 10.0, \"y\": -7.971014492753623, \"x2\": 10.289855072463768, \"y2\": -7.681159420289855, \"center_x\": 10.144927536231883, \"center_y\": -7.826086956521739, \"value_uncond\": 8.344433540257313e-07}, {\"x\": -10.0, \"y\": -7.681159420289855, \"x2\": -9.710144927536232, \"y2\": -7.391304347826088, \"center_x\": -9.855072463768117, \"center_y\": -7.536231884057972, \"value_uncond\": 1.6842720127136773e-10}, {\"x\": -9.710144927536232, \"y\": -7.681159420289855, \"x2\": -9.420289855072465, \"y2\": -7.391304347826088, \"center_x\": -9.565217391304348, \"center_y\": -7.536231884057972, \"value_uncond\": 2.6314934725173203e-10}, {\"x\": -9.420289855072463, \"y\": -7.681159420289855, \"x2\": -9.130434782608695, \"y2\": -7.391304347826088, \"center_x\": -9.275362318840578, \"center_y\": -7.536231884057972, \"value_uncond\": 4.0732228985637995e-10}, {\"x\": -9.130434782608695, \"y\": -7.681159420289855, \"x2\": -8.840579710144928, \"y2\": -7.391304347826088, \"center_x\": -8.985507246376812, \"center_y\": -7.536231884057972, \"value_uncond\": 6.246257309077444e-10}, {\"x\": -8.840579710144928, \"y\": -7.681159420289855, \"x2\": -8.55072463768116, \"y2\": -7.391304347826088, \"center_x\": -8.695652173913043, \"center_y\": -7.536231884057972, \"value_uncond\": 9.4895884748109e-10}, {\"x\": -8.55072463768116, \"y\": -7.681159420289855, \"x2\": -8.260869565217392, \"y2\": -7.391304347826088, \"center_x\": -8.405797101449277, \"center_y\": -7.536231884057972, \"value_uncond\": 1.4283041641778947e-09}, {\"x\": -8.26086956521739, \"y\": -7.681159420289855, \"x2\": -7.971014492753623, \"y2\": -7.391304347826088, \"center_x\": -8.115942028985508, \"center_y\": -7.536231884057972, \"value_uncond\": 2.129804989101398e-09}, {\"x\": -7.971014492753623, \"y\": -7.681159420289855, \"x2\": -7.681159420289855, \"y2\": -7.391304347826088, \"center_x\": -7.826086956521739, \"center_y\": -7.536231884057972, \"value_uncond\": 3.146333774436529e-09}, {\"x\": -7.681159420289855, \"y\": -7.681159420289855, \"x2\": -7.391304347826088, \"y2\": -7.391304347826088, \"center_x\": -7.536231884057972, \"center_y\": -7.536231884057972, \"value_uncond\": 4.604850753967282e-09}, {\"x\": -7.391304347826087, \"y\": -7.681159420289855, \"x2\": -7.101449275362319, \"y2\": -7.391304347826088, \"center_x\": -7.246376811594203, \"center_y\": -7.536231884057972, \"value_uncond\": 6.6768580050241456e-09}, {\"x\": -7.101449275362318, \"y\": -7.681159420289855, \"x2\": -6.811594202898551, \"y2\": -7.391304347826088, \"center_x\": -6.956521739130435, \"center_y\": -7.536231884057972, \"value_uncond\": 9.591235091357127e-09}, {\"x\": -6.811594202898551, \"y\": -7.681159420289855, \"x2\": -6.521739130434783, \"y2\": -7.391304347826088, \"center_x\": -6.666666666666667, \"center_y\": -7.536231884057972, \"value_uncond\": 1.3649688690943727e-08}, {\"x\": -6.521739130434782, \"y\": -7.681159420289855, \"x2\": -6.231884057971015, \"y2\": -7.391304347826088, \"center_x\": -6.3768115942028984, \"center_y\": -7.536231884057972, \"value_uncond\": 1.924494930576833e-08}, {\"x\": -6.231884057971014, \"y\": -7.681159420289855, \"x2\": -5.942028985507246, \"y2\": -7.391304347826088, \"center_x\": -6.08695652173913, \"center_y\": -7.536231884057972, \"value_uncond\": 2.688169262392831e-08}, {\"x\": -5.942028985507246, \"y\": -7.681159420289855, \"x2\": -5.6521739130434785, \"y2\": -7.391304347826088, \"center_x\": -5.797101449275362, \"center_y\": -7.536231884057972, \"value_uncond\": 3.719994218235569e-08}, {\"x\": -5.6521739130434785, \"y\": -7.681159420289855, \"x2\": -5.362318840579711, \"y2\": -7.391304347826088, \"center_x\": -5.507246376811595, \"center_y\": -7.536231884057972, \"value_uncond\": 5.100041774473357e-08}, {\"x\": -5.36231884057971, \"y\": -7.681159420289855, \"x2\": -5.072463768115942, \"y2\": -7.391304347826088, \"center_x\": -5.217391304347826, \"center_y\": -7.536231884057972, \"value_uncond\": 6.92709297100564e-08}, {\"x\": -5.0724637681159415, \"y\": -7.681159420289855, \"x2\": -4.782608695652174, \"y2\": -7.391304347826088, \"center_x\": -4.927536231884058, \"center_y\": -7.536231884057972, \"value_uncond\": 9.321249098921986e-08}, {\"x\": -4.782608695652174, \"y\": -7.681159420289855, \"x2\": -4.492753623188406, \"y2\": -7.391304347826088, \"center_x\": -4.63768115942029, \"center_y\": -7.536231884057972, \"value_uncond\": 1.2426334105807845e-07}, {\"x\": -4.492753623188405, \"y\": -7.681159420289855, \"x2\": -4.202898550724638, \"y2\": -7.391304347826088, \"center_x\": -4.3478260869565215, \"center_y\": -7.536231884057972, \"value_uncond\": 1.641185808684942e-07}, {\"x\": -4.202898550724638, \"y\": -7.681159420289855, \"x2\": -3.91304347826087, \"y2\": -7.391304347826088, \"center_x\": -4.057971014492754, \"center_y\": -7.536231884057972, \"value_uncond\": 2.1474264310538774e-07}, {\"x\": -3.913043478260869, \"y\": -7.681159420289855, \"x2\": -3.6231884057971016, \"y2\": -7.391304347826088, \"center_x\": -3.7681159420289854, \"center_y\": -7.536231884057972, \"value_uncond\": 2.783714233085887e-07}, {\"x\": -3.6231884057971016, \"y\": -7.681159420289855, \"x2\": -3.333333333333334, \"y2\": -7.391304347826088, \"center_x\": -3.4782608695652177, \"center_y\": -7.536231884057972, \"value_uncond\": 3.575006372780089e-07}, {\"x\": -3.333333333333333, \"y\": -7.681159420289855, \"x2\": -3.0434782608695654, \"y2\": -7.391304347826088, \"center_x\": -3.1884057971014492, \"center_y\": -7.536231884057972, \"value_uncond\": 4.548569188463666e-07}, {\"x\": -3.0434782608695645, \"y\": -7.681159420289855, \"x2\": -2.753623188405797, \"y2\": -7.391304347826088, \"center_x\": -2.8985507246376807, \"center_y\": -7.536231884057972, \"value_uncond\": 5.733483995698952e-07}, {\"x\": -2.753623188405797, \"y\": -7.681159420289855, \"x2\": -2.4637681159420293, \"y2\": -7.391304347826088, \"center_x\": -2.608695652173913, \"center_y\": -7.536231884057972, \"value_uncond\": 7.159920802534279e-07}, {\"x\": -2.4637681159420284, \"y\": -7.681159420289855, \"x2\": -2.1739130434782608, \"y2\": -7.391304347826088, \"center_x\": -2.3188405797101446, \"center_y\": -7.536231884057972, \"value_uncond\": 8.858162581182814e-07}, {\"x\": -2.1739130434782608, \"y\": -7.681159420289855, \"x2\": -1.8840579710144931, \"y2\": -7.391304347826088, \"center_x\": -2.028985507246377, \"center_y\": -7.536231884057972, \"value_uncond\": 1.0857376298486197e-06}, {\"x\": -1.8840579710144922, \"y\": -7.681159420289855, \"x2\": -1.5942028985507246, \"y2\": -7.391304347826088, \"center_x\": -1.7391304347826084, \"center_y\": -7.536231884057972, \"value_uncond\": 1.3184144295521006e-06}, {\"x\": -1.5942028985507246, \"y\": -7.681159420289855, \"x2\": -1.304347826086957, \"y2\": -7.391304347826088, \"center_x\": -1.4492753623188408, \"center_y\": -7.536231884057972, \"value_uncond\": 1.586079016993117e-06}, {\"x\": -1.304347826086957, \"y\": -7.681159420289855, \"x2\": -1.0144927536231894, \"y2\": -7.391304347826088, \"center_x\": -1.1594202898550732, \"center_y\": -7.536231884057972, \"value_uncond\": 1.8903555918294522e-06}, {\"x\": -1.0144927536231876, \"y\": -7.681159420289855, \"x2\": -0.72463768115942, \"y2\": -7.391304347826088, \"center_x\": -0.8695652173913038, \"center_y\": -7.536231884057972, \"value_uncond\": 2.2320710129818836e-06}, {\"x\": -0.72463768115942, \"y\": -7.681159420289855, \"x2\": -0.43478260869565233, \"y2\": -7.391304347826088, \"center_x\": -0.5797101449275361, \"center_y\": -7.536231884057972, \"value_uncond\": 2.611068847258569e-06}, {\"x\": -0.43478260869565233, \"y\": -7.681159420289855, \"x2\": -0.1449275362318847, \"y2\": -7.391304347826088, \"center_x\": -0.2898550724637685, \"center_y\": -7.536231884057972, \"value_uncond\": 3.0260385297535673e-06}, {\"x\": -0.14492753623188293, \"y\": -7.681159420289855, \"x2\": 0.1449275362318847, \"y2\": -7.391304347826088, \"center_x\": 8.881784197001252e-16, \"center_y\": -7.536231884057972, \"value_uncond\": 3.4743726551907147e-06}, {\"x\": 0.1449275362318847, \"y\": -7.681159420289855, \"x2\": 0.43478260869565233, \"y2\": -7.391304347826088, \"center_x\": 0.2898550724637685, \"center_y\": -7.536231884057972, \"value_uncond\": 3.952065716788075e-06}, {\"x\": 0.43478260869565233, \"y\": -7.681159420289855, \"x2\": 0.72463768115942, \"y2\": -7.391304347826088, \"center_x\": 0.5797101449275361, \"center_y\": -7.536231884057972, \"value_uncond\": 4.453666894683446e-06}, {\"x\": 0.72463768115942, \"y\": -7.681159420289855, \"x2\": 1.0144927536231876, \"y2\": -7.391304347826088, \"center_x\": 0.8695652173913038, \"center_y\": -7.536231884057972, \"value_uncond\": 4.97229766828531e-06}, {\"x\": 1.0144927536231894, \"y\": -7.681159420289855, \"x2\": 1.304347826086957, \"y2\": -7.391304347826088, \"center_x\": 1.1594202898550732, \"center_y\": -7.536231884057972, \"value_uncond\": 5.499742079040889e-06}, {\"x\": 1.304347826086957, \"y\": -7.681159420289855, \"x2\": 1.5942028985507246, \"y2\": -7.391304347826088, \"center_x\": 1.4492753623188408, \"center_y\": -7.536231884057972, \"value_uncond\": 6.026613504221936e-06}, {\"x\": 1.5942028985507246, \"y\": -7.681159420289855, \"x2\": 1.8840579710144922, \"y2\": -7.391304347826088, \"center_x\": 1.7391304347826084, \"center_y\": -7.536231884057972, \"value_uncond\": 6.5425970342707065e-06}, {\"x\": 1.884057971014494, \"y\": -7.681159420289855, \"x2\": 2.1739130434782616, \"y2\": -7.391304347826088, \"center_x\": 2.028985507246378, \"center_y\": -7.536231884057972, \"value_uncond\": 7.036761297266066e-06}, {\"x\": 2.1739130434782616, \"y\": -7.681159420289855, \"x2\": 2.4637681159420293, \"y2\": -7.391304347826088, \"center_x\": 2.3188405797101455, \"center_y\": -7.536231884057972, \"value_uncond\": 7.497928249183951e-06}, {\"x\": 2.4637681159420293, \"y\": -7.681159420289855, \"x2\": 2.753623188405797, \"y2\": -7.391304347826088, \"center_x\": 2.608695652173913, \"center_y\": -7.536231884057972, \"value_uncond\": 7.915084502802953e-06}, {\"x\": 2.753623188405797, \"y\": -7.681159420289855, \"x2\": 3.0434782608695645, \"y2\": -7.391304347826088, \"center_x\": 2.8985507246376807, \"center_y\": -7.536231884057972, \"value_uncond\": 8.277813663099864e-06}, {\"x\": 3.0434782608695663, \"y\": -7.681159420289855, \"x2\": 3.333333333333334, \"y2\": -7.391304347826088, \"center_x\": 3.18840579710145, \"center_y\": -7.536231884057972, \"value_uncond\": 8.57672629330027e-06}, {\"x\": 3.333333333333334, \"y\": -7.681159420289855, \"x2\": 3.6231884057971016, \"y2\": -7.391304347826088, \"center_x\": 3.4782608695652177, \"center_y\": -7.536231884057972, \"value_uncond\": 8.803862885277813e-06}, {\"x\": 3.6231884057971016, \"y\": -7.681159420289855, \"x2\": 3.913043478260869, \"y2\": -7.391304347826088, \"center_x\": 3.7681159420289854, \"center_y\": -7.536231884057972, \"value_uncond\": 8.953045753154204e-06}, {\"x\": 3.913043478260871, \"y\": -7.681159420289855, \"x2\": 4.202898550724639, \"y2\": -7.391304347826088, \"center_x\": 4.057971014492755, \"center_y\": -7.536231884057972, \"value_uncond\": 9.020158153905162e-06}, {\"x\": 4.202898550724639, \"y\": -7.681159420289855, \"x2\": 4.492753623188406, \"y2\": -7.391304347826088, \"center_x\": 4.347826086956522, \"center_y\": -7.536231884057972, \"value_uncond\": 9.003333036907952e-06}, {\"x\": 4.492753623188406, \"y\": -7.681159420289855, \"x2\": 4.782608695652174, \"y2\": -7.391304347826088, \"center_x\": 4.63768115942029, \"center_y\": -7.536231884057972, \"value_uncond\": 8.90303934437165e-06}, {\"x\": 4.782608695652174, \"y\": -7.681159420289855, \"x2\": 5.0724637681159415, \"y2\": -7.391304347826088, \"center_x\": 4.927536231884058, \"center_y\": -7.536231884057972, \"value_uncond\": 8.72206029521493e-06}, {\"x\": 5.072463768115943, \"y\": -7.681159420289855, \"x2\": 5.362318840579711, \"y2\": -7.391304347826088, \"center_x\": 5.217391304347827, \"center_y\": -7.536231884057972, \"value_uncond\": 8.465365055944217e-06}, {\"x\": 5.362318840579711, \"y\": -7.681159420289855, \"x2\": 5.6521739130434785, \"y2\": -7.391304347826088, \"center_x\": 5.507246376811595, \"center_y\": -7.536231884057972, \"value_uncond\": 8.139882056800119e-06}, {\"x\": 5.6521739130434785, \"y\": -7.681159420289855, \"x2\": 5.942028985507246, \"y2\": -7.391304347826088, \"center_x\": 5.797101449275362, \"center_y\": -7.536231884057972, \"value_uncond\": 7.754188384982478e-06}, {\"x\": 5.942028985507246, \"y\": -7.681159420289855, \"x2\": 6.231884057971014, \"y2\": -7.391304347826088, \"center_x\": 6.08695652173913, \"center_y\": -7.536231884057972, \"value_uncond\": 7.318134682692684e-06}, {\"x\": 6.2318840579710155, \"y\": -7.681159420289855, \"x2\": 6.521739130434783, \"y2\": -7.391304347826088, \"center_x\": 6.376811594202899, \"center_y\": -7.536231884057972, \"value_uncond\": 6.842428416685089e-06}, {\"x\": 6.521739130434785, \"y\": -7.681159420289855, \"x2\": 6.8115942028985526, \"y2\": -7.391304347826088, \"center_x\": 6.666666666666669, \"center_y\": -7.536231884057972, \"value_uncond\": 6.338200040615343e-06}, {\"x\": 6.811594202898551, \"y\": -7.681159420289855, \"x2\": 7.101449275362318, \"y2\": -7.391304347826088, \"center_x\": 6.956521739130435, \"center_y\": -7.536231884057972, \"value_uncond\": 5.816576383746788e-06}, {\"x\": 7.10144927536232, \"y\": -7.681159420289855, \"x2\": 7.391304347826088, \"y2\": -7.391304347826088, \"center_x\": 7.246376811594204, \"center_y\": -7.536231884057972, \"value_uncond\": 5.288283679482755e-06}, {\"x\": 7.391304347826086, \"y\": -7.681159420289855, \"x2\": 7.681159420289854, \"y2\": -7.391304347826088, \"center_x\": 7.53623188405797, \"center_y\": -7.536231884057972, \"value_uncond\": 4.763299253181387e-06}, {\"x\": 7.681159420289855, \"y\": -7.681159420289855, \"x2\": 7.971014492753623, \"y2\": -7.391304347826088, \"center_x\": 7.826086956521739, \"center_y\": -7.536231884057972, \"value_uncond\": 4.250566393509563e-06}, {\"x\": 7.971014492753625, \"y\": -7.681159420289855, \"x2\": 8.260869565217392, \"y2\": -7.391304347826088, \"center_x\": 8.115942028985508, \"center_y\": -7.536231884057972, \"value_uncond\": 3.7577817780669465e-06}, {\"x\": 8.26086956521739, \"y\": -7.681159420289855, \"x2\": 8.550724637681158, \"y2\": -7.391304347826088, \"center_x\": 8.405797101449274, \"center_y\": -7.536231884057972, \"value_uncond\": 3.291259476802988e-06}, {\"x\": 8.55072463768116, \"y\": -7.681159420289855, \"x2\": 8.840579710144928, \"y2\": -7.391304347826088, \"center_x\": 8.695652173913043, \"center_y\": -7.536231884057972, \"value_uncond\": 2.8558704555904338e-06}, {\"x\": 8.84057971014493, \"y\": -7.681159420289855, \"x2\": 9.130434782608697, \"y2\": -7.391304347826088, \"center_x\": 8.985507246376812, \"center_y\": -7.536231884057972, \"value_uncond\": 2.455052022138501e-06}, {\"x\": 9.130434782608695, \"y\": -7.681159420289855, \"x2\": 9.420289855072463, \"y2\": -7.391304347826088, \"center_x\": 9.275362318840578, \"center_y\": -7.536231884057972, \"value_uncond\": 2.0908780781662027e-06}, {\"x\": 9.420289855072465, \"y\": -7.681159420289855, \"x2\": 9.710144927536232, \"y2\": -7.391304347826088, \"center_x\": 9.565217391304348, \"center_y\": -7.536231884057972, \"value_uncond\": 1.7641785360445216e-06}, {\"x\": 9.710144927536234, \"y\": -7.681159420289855, \"x2\": 10.000000000000002, \"y2\": -7.391304347826088, \"center_x\": 9.855072463768117, \"center_y\": -7.536231884057972, \"value_uncond\": 1.4746948822507115e-06}, {\"x\": 10.0, \"y\": -7.681159420289855, \"x2\": 10.289855072463768, \"y2\": -7.391304347826088, \"center_x\": 10.144927536231883, \"center_y\": -7.536231884057972, \"value_uncond\": 1.221258576934201e-06}, {\"x\": -10.0, \"y\": -7.391304347826087, \"x2\": -9.710144927536232, \"y2\": -7.101449275362319, \"center_x\": -9.855072463768117, \"center_y\": -7.246376811594203, \"value_uncond\": 2.442130195215731e-10}, {\"x\": -9.710144927536232, \"y\": -7.391304347826087, \"x2\": -9.420289855072465, \"y2\": -7.101449275362319, \"center_x\": -9.565217391304348, \"center_y\": -7.246376811594203, \"value_uncond\": 3.815565193292877e-10}, {\"x\": -9.420289855072463, \"y\": -7.391304347826087, \"x2\": -9.130434782608695, \"y2\": -7.101449275362319, \"center_x\": -9.275362318840578, \"center_y\": -7.246376811594203, \"value_uncond\": 5.906017886267534e-10}, {\"x\": -9.130434782608695, \"y\": -7.391304347826087, \"x2\": -8.840579710144928, \"y2\": -7.101449275362319, \"center_x\": -8.985507246376812, \"center_y\": -7.246376811594203, \"value_uncond\": 9.056834921223715e-10}, {\"x\": -8.840579710144928, \"y\": -7.391304347826087, \"x2\": -8.55072463768116, \"y2\": -7.101449275362319, \"center_x\": -8.695652173913043, \"center_y\": -7.246376811594203, \"value_uncond\": 1.3759541439608688e-09}, {\"x\": -8.55072463768116, \"y\": -7.391304347826087, \"x2\": -8.260869565217392, \"y2\": -7.101449275362319, \"center_x\": -8.405797101449277, \"center_y\": -7.246376811594203, \"value_uncond\": 2.07098657518581e-09}, {\"x\": -8.26086956521739, \"y\": -7.391304347826087, \"x2\": -7.971014492753623, \"y2\": -7.101449275362319, \"center_x\": -8.115942028985508, \"center_y\": -7.246376811594203, \"value_uncond\": 3.0881360222957336e-09}, {\"x\": -7.971014492753623, \"y\": -7.391304347826087, \"x2\": -7.681159420289855, \"y2\": -7.101449275362319, \"center_x\": -7.826086956521739, \"center_y\": -7.246376811594203, \"value_uncond\": 4.5620639996259195e-09}, {\"x\": -7.681159420289855, \"y\": -7.391304347826087, \"x2\": -7.391304347826088, \"y2\": -7.101449275362319, \"center_x\": -7.536231884057972, \"center_y\": -7.246376811594203, \"value_uncond\": 6.6768580050241456e-09}, {\"x\": -7.391304347826087, \"y\": -7.391304347826087, \"x2\": -7.101449275362319, \"y2\": -7.101449275362319, \"center_x\": -7.246376811594203, \"center_y\": -7.246376811594203, \"value_uncond\": 9.681189511049189e-09}, {\"x\": -7.101449275362318, \"y\": -7.391304347826087, \"x2\": -6.811594202898551, \"y2\": -7.101449275362319, \"center_x\": -6.956521739130435, \"center_y\": -7.246376811594203, \"value_uncond\": 1.3906925157698896e-08}, {\"x\": -6.811594202898551, \"y\": -7.391304347826087, \"x2\": -6.521739130434783, \"y2\": -7.101449275362319, \"center_x\": -6.666666666666667, \"center_y\": -7.246376811594203, \"value_uncond\": 1.9791528123619735e-08}, {\"x\": -6.521739130434782, \"y\": -7.391304347826087, \"x2\": -6.231884057971015, \"y2\": -7.101449275362319, \"center_x\": -6.3768115942028984, \"center_y\": -7.246376811594203, \"value_uncond\": 2.7904442661425693e-08}, {\"x\": -6.231884057971014, \"y\": -7.391304347826087, \"x2\": -5.942028985507246, \"y2\": -7.101449275362319, \"center_x\": -6.08695652173913, \"center_y\": -7.246376811594203, \"value_uncond\": 3.897742927499661e-08}, {\"x\": -5.942028985507246, \"y\": -7.391304347826087, \"x2\": -5.6521739130434785, \"y2\": -7.101449275362319, \"center_x\": -5.797101449275362, \"center_y\": -7.246376811594203, \"value_uncond\": 5.3938497688053776e-08}, {\"x\": -5.6521739130434785, \"y\": -7.391304347826087, \"x2\": -5.362318840579711, \"y2\": -7.101449275362319, \"center_x\": -5.507246376811595, \"center_y\": -7.246376811594203, \"value_uncond\": 7.394866102557714e-08}, {\"x\": -5.36231884057971, \"y\": -7.391304347826087, \"x2\": -5.072463768115942, \"y2\": -7.101449275362319, \"center_x\": -5.217391304347826, \"center_y\": -7.246376811594203, \"value_uncond\": 1.0044020669976769e-07}, {\"x\": -5.0724637681159415, \"y\": -7.391304347826087, \"x2\": -4.782608695652174, \"y2\": -7.101449275362319, \"center_x\": -4.927536231884058, \"center_y\": -7.246376811594203, \"value_uncond\": 1.3515455763542766e-07}, {\"x\": -4.782608695652174, \"y\": -7.391304347826087, \"x2\": -4.492753623188406, \"y2\": -7.101449275362319, \"center_x\": -4.63768115942029, \"center_y\": -7.246376811594203, \"value_uncond\": 1.8017710623082913e-07}, {\"x\": -4.492753623188405, \"y\": -7.391304347826087, \"x2\": -4.202898550724638, \"y2\": -7.101449275362319, \"center_x\": -4.3478260869565215, \"center_y\": -7.246376811594203, \"value_uncond\": 2.379656842300335e-07}, {\"x\": -4.202898550724638, \"y\": -7.391304347826087, \"x2\": -3.91304347826087, \"y2\": -7.101449275362319, \"center_x\": -4.057971014492754, \"center_y\": -7.246376811594203, \"value_uncond\": 3.113686441201083e-07}, {\"x\": -3.913043478260869, \"y\": -7.391304347826087, \"x2\": -3.6231884057971016, \"y2\": -7.101449275362319, \"center_x\": -3.7681159420289854, \"center_y\": -7.246376811594203, \"value_uncond\": 4.036279491765524e-07}, {\"x\": -3.6231884057971016, \"y\": -7.391304347826087, \"x2\": -3.333333333333334, \"y2\": -7.101449275362319, \"center_x\": -3.4782608695652177, \"center_y\": -7.246376811594203, \"value_uncond\": 5.183622921447384e-07}, {\"x\": -3.333333333333333, \"y\": -7.391304347826087, \"x2\": -3.0434782608695654, \"y2\": -7.101449275362319, \"center_x\": -3.1884057971014492, \"center_y\": -7.246376811594203, \"value_uncond\": 6.595251881124395e-07}, {\"x\": -3.0434782608695645, \"y\": -7.391304347826087, \"x2\": -2.753623188405797, \"y2\": -7.101449275362319, \"center_x\": -2.8985507246376807, \"center_y\": -7.246376811594203, \"value_uncond\": 8.31333316945809e-07}, {\"x\": -2.753623188405797, \"y\": -7.391304347826087, \"x2\": -2.4637681159420293, \"y2\": -7.101449275362319, \"center_x\": -2.608695652173913, \"center_y\": -7.246376811594203, \"value_uncond\": 1.0381612147701664e-06}, {\"x\": -2.4637681159420284, \"y\": -7.391304347826087, \"x2\": -2.1739130434782608, \"y2\": -7.101449275362319, \"center_x\": -2.3188405797101446, \"center_y\": -7.246376811594203, \"value_uncond\": 1.2843997970839784e-06}, {\"x\": -2.1739130434782608, \"y\": -7.391304347826087, \"x2\": -1.8840579710144931, \"y2\": -7.101449275362319, \"center_x\": -2.028985507246377, \"center_y\": -7.246376811594203, \"value_uncond\": 1.574278162862302e-06}, {\"x\": -1.8840579710144922, \"y\": -7.391304347826087, \"x2\": -1.5942028985507246, \"y2\": -7.101449275362319, \"center_x\": -1.7391304347826084, \"center_y\": -7.246376811594203, \"value_uncond\": 1.9116506501997293e-06}, {\"x\": -1.5942028985507246, \"y\": -7.391304347826087, \"x2\": -1.304347826086957, \"y2\": -7.101449275362319, \"center_x\": -1.4492753623188408, \"center_y\": -7.246376811594203, \"value_uncond\": 2.299754095632208e-06}, {\"x\": -1.304347826086957, \"y\": -7.391304347826087, \"x2\": -1.0144927536231894, \"y2\": -7.101449275362319, \"center_x\": -1.1594202898550732, \"center_y\": -7.246376811594203, \"value_uncond\": 2.740943526730923e-06}, {\"x\": -1.0144927536231876, \"y\": -7.391304347826087, \"x2\": -0.72463768115942, \"y2\": -7.101449275362319, \"center_x\": -0.8695652173913038, \"center_y\": -7.246376811594203, \"value_uncond\": 3.2364178574019272e-06}, {\"x\": -0.72463768115942, \"y\": -7.391304347826087, \"x2\": -0.43478260869565233, \"y2\": -7.101449275362319, \"center_x\": -0.5797101449275361, \"center_y\": -7.246376811594203, \"value_uncond\": 3.785950265482027e-06}, {\"x\": -0.43478260869565233, \"y\": -7.391304347826087, \"x2\": -0.1449275362318847, \"y2\": -7.101449275362319, \"center_x\": -0.2898550724637685, \"center_y\": -7.246376811594203, \"value_uncond\": 4.387640481830946e-06}, {\"x\": -0.14492753623188293, \"y\": -7.391304347826087, \"x2\": 0.1449275362318847, \"y2\": -7.101449275362319, \"center_x\": 8.881784197001252e-16, \"center_y\": -7.246376811594203, \"value_uncond\": 5.037707868221594e-06}, {\"x\": 0.1449275362318847, \"y\": -7.391304347826087, \"x2\": 0.43478260869565233, \"y2\": -7.101449275362319, \"center_x\": 0.2898550724637685, \"center_y\": -7.246376811594203, \"value_uncond\": 5.73034459255472e-06}, {\"x\": 0.43478260869565233, \"y\": -7.391304347826087, \"x2\": 0.72463768115942, \"y2\": -7.101449275362319, \"center_x\": 0.5797101449275361, \"center_y\": -7.246376811594203, \"value_uncond\": 6.4576471738761325e-06}, {\"x\": 0.72463768115942, \"y\": -7.391304347826087, \"x2\": 1.0144927536231876, \"y2\": -7.101449275362319, \"center_x\": 0.8695652173913038, \"center_y\": -7.246376811594203, \"value_uncond\": 7.209642019613979e-06}, {\"x\": 1.0144927536231894, \"y\": -7.391304347826087, \"x2\": 1.304347826086957, \"y2\": -7.101449275362319, \"center_x\": 1.1594202898550732, \"center_y\": -7.246376811594203, \"value_uncond\": 7.97441630315065e-06}, {\"x\": 1.304347826086957, \"y\": -7.391304347826087, \"x2\": 1.5942028985507246, \"y2\": -7.101449275362319, \"center_x\": 1.4492753623188408, \"center_y\": -7.246376811594203, \"value_uncond\": 8.738359779452854e-06}, {\"x\": 1.5942028985507246, \"y\": -7.391304347826087, \"x2\": 1.8840579710144922, \"y2\": -7.101449275362319, \"center_x\": 1.7391304347826084, \"center_y\": -7.246376811594203, \"value_uncond\": 9.486516222981147e-06}, {\"x\": 1.884057971014494, \"y\": -7.391304347826087, \"x2\": 2.1739130434782616, \"y2\": -7.101449275362319, \"center_x\": 2.028985507246378, \"center_y\": -7.246376811594203, \"value_uncond\": 1.0203035561275618e-05}, {\"x\": 2.1739130434782616, \"y\": -7.391304347826087, \"x2\": 2.4637681159420293, \"y2\": -7.101449275362319, \"center_x\": 2.3188405797101455, \"center_y\": -7.246376811594203, \"value_uncond\": 1.0871710056732976e-05}, {\"x\": 2.4637681159420293, \"y\": -7.391304347826087, \"x2\": 2.753623188405797, \"y2\": -7.101449275362319, \"center_x\": 2.608695652173913, \"center_y\": -7.246376811594203, \"value_uncond\": 1.1476570717835243e-05}, {\"x\": 2.753623188405797, \"y\": -7.391304347826087, \"x2\": 3.0434782608695645, \"y2\": -7.101449275362319, \"center_x\": 2.8985507246376807, \"center_y\": -7.246376811594203, \"value_uncond\": 1.2002514168987824e-05}, {\"x\": 3.0434782608695663, \"y\": -7.391304347826087, \"x2\": 3.333333333333334, \"y2\": -7.101449275362319, \"center_x\": 3.18840579710145, \"center_y\": -7.246376811594203, \"value_uncond\": 1.2435926084897789e-05}, {\"x\": 3.333333333333334, \"y\": -7.391304347826087, \"x2\": 3.6231884057971016, \"y2\": -7.101449275362319, \"center_x\": 3.4782608695652177, \"center_y\": -7.246376811594203, \"value_uncond\": 1.2765265482287069e-05}, {\"x\": 3.6231884057971016, \"y\": -7.391304347826087, \"x2\": 3.913043478260869, \"y2\": -7.101449275362319, \"center_x\": 3.7681159420289854, \"center_y\": -7.246376811594203, \"value_uncond\": 1.2981574952194378e-05}, {\"x\": 3.913043478260871, \"y\": -7.391304347826087, \"x2\": 4.202898550724639, \"y2\": -7.101449275362319, \"center_x\": 4.057971014492755, \"center_y\": -7.246376811594203, \"value_uncond\": 1.3078885374210632e-05}, {\"x\": 4.202898550724639, \"y\": -7.391304347826087, \"x2\": 4.492753623188406, \"y2\": -7.101449275362319, \"center_x\": 4.347826086956522, \"center_y\": -7.246376811594203, \"value_uncond\": 1.3054489596125642e-05}, {\"x\": 4.492753623188406, \"y\": -7.391304347826087, \"x2\": 4.782608695652174, \"y2\": -7.101449275362319, \"center_x\": 4.63768115942029, \"center_y\": -7.246376811594203, \"value_uncond\": 1.2909067566261262e-05}, {\"x\": 4.782608695652174, \"y\": -7.391304347826087, \"x2\": 5.0724637681159415, \"y2\": -7.101449275362319, \"center_x\": 4.927536231884058, \"center_y\": -7.246376811594203, \"value_uncond\": 1.2646654845922255e-05}, {\"x\": 5.072463768115943, \"y\": -7.391304347826087, \"x2\": 5.362318840579711, \"y2\": -7.101449275362319, \"center_x\": 5.217391304347827, \"center_y\": -7.246376811594203, \"value_uncond\": 1.227445653706292e-05}, {\"x\": 5.362318840579711, \"y\": -7.391304347826087, \"x2\": 5.6521739130434785, \"y2\": -7.101449275362319, \"center_x\": 5.507246376811595, \"center_y\": -7.246376811594203, \"value_uncond\": 1.1802518599343171e-05}, {\"x\": 5.6521739130434785, \"y\": -7.391304347826087, \"x2\": 5.942028985507246, \"y2\": -7.101449275362319, \"center_x\": 5.797101449275362, \"center_y\": -7.246376811594203, \"value_uncond\": 1.1243277482148635e-05}, {\"x\": 5.942028985507246, \"y\": -7.391304347826087, \"x2\": 6.231884057971014, \"y2\": -7.101449275362319, \"center_x\": 6.08695652173913, \"center_y\": -7.246376811594203, \"value_uncond\": 1.0611016241055063e-05}, {\"x\": 6.2318840579710155, \"y\": -7.391304347826087, \"x2\": 6.521739130434783, \"y2\": -7.101449275362319, \"center_x\": 6.376811594202899, \"center_y\": -7.246376811594203, \"value_uncond\": 9.921260294568306e-06}, {\"x\": 6.521739130434785, \"y\": -7.391304347826087, \"x2\": 6.8115942028985526, \"y2\": -7.101449275362319, \"center_x\": 6.666666666666669, \"center_y\": -7.246376811594203, \"value_uncond\": 9.190148376072125e-06}, {\"x\": 6.811594202898551, \"y\": -7.391304347826087, \"x2\": 7.101449275362318, \"y2\": -7.101449275362319, \"center_x\": 6.956521739130435, \"center_y\": -7.246376811594203, \"value_uncond\": 8.433813963719633e-06}, {\"x\": 7.10144927536232, \"y\": -7.391304347826087, \"x2\": 7.391304347826088, \"y2\": -7.101449275362319, \"center_x\": 7.246376811594204, \"center_y\": -7.246376811594203, \"value_uncond\": 7.66780968694211e-06}, {\"x\": 7.391304347826086, \"y\": -7.391304347826087, \"x2\": 7.681159420289854, \"y2\": -7.101449275362319, \"center_x\": 7.53623188405797, \"center_y\": -7.246376811594203, \"value_uncond\": 6.906602287062016e-06}, {\"x\": 7.681159420289855, \"y\": -7.391304347826087, \"x2\": 7.971014492753623, \"y2\": -7.101449275362319, \"center_x\": 7.826086956521739, \"center_y\": -7.246376811594203, \"value_uncond\": 6.163159191628511e-06}, {\"x\": 7.971014492753625, \"y\": -7.391304347826087, \"x2\": 8.260869565217392, \"y2\": -7.101449275362319, \"center_x\": 8.115942028985508, \"center_y\": -7.246376811594203, \"value_uncond\": 5.448640289677979e-06}, {\"x\": 8.26086956521739, \"y\": -7.391304347826087, \"x2\": 8.550724637681158, \"y2\": -7.101449275362319, \"center_x\": 8.405797101449274, \"center_y\": -7.246376811594203, \"value_uncond\": 4.772200741874412e-06}, {\"x\": 8.55072463768116, \"y\": -7.391304347826087, \"x2\": 8.840579710144928, \"y2\": -7.101449275362319, \"center_x\": 8.695652173913043, \"center_y\": -7.246376811594203, \"value_uncond\": 4.140903262997788e-06}, {\"x\": 8.84057971014493, \"y\": -7.391304347826087, \"x2\": 9.130434782608697, \"y2\": -7.101449275362319, \"center_x\": 8.985507246376812, \"center_y\": -7.246376811594203, \"value_uncond\": 3.559731818157989e-06}, {\"x\": 9.130434782608695, \"y\": -7.391304347826087, \"x2\": 9.420289855072463, \"y2\": -7.101449275362319, \"center_x\": 9.275362318840578, \"center_y\": -7.246376811594203, \"value_uncond\": 3.0316934857673573e-06}, {\"x\": 9.420289855072465, \"y\": -7.391304347826087, \"x2\": 9.710144927536232, \"y2\": -7.101449275362319, \"center_x\": 9.565217391304348, \"center_y\": -7.246376811594203, \"value_uncond\": 2.5579916071182954e-06}, {\"x\": 9.710144927536234, \"y\": -7.391304347826087, \"x2\": 10.000000000000002, \"y2\": -7.101449275362319, \"center_x\": 9.855072463768117, \"center_y\": -7.246376811594203, \"value_uncond\": 2.138251347460231e-06}, {\"x\": 10.0, \"y\": -7.391304347826087, \"x2\": 10.289855072463768, \"y2\": -7.101449275362319, \"center_x\": 10.144927536231883, \"center_y\": -7.246376811594203, \"value_uncond\": 1.770778368567611e-06}, {\"x\": -10.0, \"y\": -7.101449275362318, \"x2\": -9.710144927536232, \"y2\": -6.811594202898551, \"center_x\": -9.855072463768117, \"center_y\": -6.956521739130435, \"value_uncond\": 3.508093898116566e-10}, {\"x\": -9.710144927536232, \"y\": -7.101449275362318, \"x2\": -9.420289855072465, \"y2\": -6.811594202898551, \"center_x\": -9.565217391304348, \"center_y\": -6.956521739130435, \"value_uncond\": 5.481018579058321e-10}, {\"x\": -9.420289855072463, \"y\": -7.101449275362318, \"x2\": -9.130434782608695, \"y2\": -6.811594202898551, \"center_x\": -9.275362318840578, \"center_y\": -6.956521739130435, \"value_uncond\": 8.48393150765341e-10}, {\"x\": -9.130434782608695, \"y\": -7.101449275362318, \"x2\": -8.840579710144928, \"y2\": -6.811594202898551, \"center_x\": -8.985507246376812, \"center_y\": -6.956521739130435, \"value_uncond\": 1.3010046469118486e-09}, {\"x\": -8.840579710144928, \"y\": -7.101449275362318, \"x2\": -8.55072463768116, \"y2\": -6.811594202898551, \"center_x\": -8.695652173913043, \"center_y\": -6.956521739130435, \"value_uncond\": 1.976543407052434e-09}, {\"x\": -8.55072463768116, \"y\": -7.101449275362318, \"x2\": -8.260869565217392, \"y2\": -6.811594202898551, \"center_x\": -8.405797101449277, \"center_y\": -6.956521739130435, \"value_uncond\": 2.974950058651102e-09}, {\"x\": -8.26086956521739, \"y\": -7.101449275362318, \"x2\": -7.971014492753623, \"y2\": -6.811594202898551, \"center_x\": -8.115942028985508, \"center_y\": -6.956521739130435, \"value_uncond\": 4.4360743573757856e-09}, {\"x\": -7.971014492753623, \"y\": -7.101449275362318, \"x2\": -7.681159420289855, \"y2\": -6.811594202898551, \"center_x\": -7.826086956521739, \"center_y\": -6.956521739130435, \"value_uncond\": 6.553356127882929e-09}, {\"x\": -7.681159420289855, \"y\": -7.101449275362318, \"x2\": -7.391304347826088, \"y2\": -6.811594202898551, \"center_x\": -7.536231884057972, \"center_y\": -6.956521739130435, \"value_uncond\": 9.591235091357127e-09}, {\"x\": -7.391304347826087, \"y\": -7.101449275362318, \"x2\": -7.101449275362319, \"y2\": -6.811594202898551, \"center_x\": -7.246376811594203, \"center_y\": -6.956521739130435, \"value_uncond\": 1.3906925157698896e-08}, {\"x\": -7.101449275362318, \"y\": -7.101449275362318, \"x2\": -6.811594202898551, \"y2\": -6.811594202898551, \"center_x\": -6.956521739130435, \"center_y\": -6.956521739130435, \"value_uncond\": 1.99771492047653e-08}, {\"x\": -6.811594202898551, \"y\": -7.101449275362318, \"x2\": -6.521739130434783, \"y2\": -6.811594202898551, \"center_x\": -6.666666666666667, \"center_y\": -6.956521739130435, \"value_uncond\": 2.8430318408449762e-08}, {\"x\": -6.521739130434782, \"y\": -7.101449275362318, \"x2\": -6.231884057971015, \"y2\": -6.811594202898551, \"center_x\": -6.3768115942028984, \"center_y\": -6.956521739130435, \"value_uncond\": 4.008443334539075e-08}, {\"x\": -6.231884057971014, \"y\": -7.101449275362318, \"x2\": -5.942028985507246, \"y2\": -6.811594202898551, \"center_x\": -6.08695652173913, \"center_y\": -6.956521739130435, \"value_uncond\": 5.599066015061769e-08}, {\"x\": -5.942028985507246, \"y\": -7.101449275362318, \"x2\": -5.6521739130434785, \"y2\": -6.811594202898551, \"center_x\": -5.797101449275362, \"center_y\": -6.956521739130435, \"value_uncond\": 7.748207486387541e-08}, {\"x\": -5.6521739130434785, \"y\": -7.101449275362318, \"x2\": -5.362318840579711, \"y2\": -6.811594202898551, \"center_x\": -5.507246376811595, \"center_y\": -6.956521739130435, \"value_uncond\": 1.062264604180127e-07}, {\"x\": -5.36231884057971, \"y\": -7.101449275362318, \"x2\": -5.072463768115942, \"y2\": -6.811594202898551, \"center_x\": -5.217391304347826, \"center_y\": -6.956521739130435, \"value_uncond\": 1.442812823572233e-07}, {\"x\": -5.0724637681159415, \"y\": -7.101449275362318, \"x2\": -4.782608695652174, \"y2\": -6.811594202898551, \"center_x\": -4.927536231884058, \"center_y\": -6.956521739130435, \"value_uncond\": 1.9414807608224334e-07}, {\"x\": -4.782608695652174, \"y\": -7.101449275362318, \"x2\": -4.492753623188406, \"y2\": -6.811594202898551, \"center_x\": -4.63768115942029, \"center_y\": -6.956521739130435, \"value_uncond\": 2.588224854624657e-07}, {\"x\": -4.492753623188405, \"y\": -7.101449275362318, \"x2\": -4.202898550724638, \"y2\": -6.811594202898551, \"center_x\": -4.3478260869565215, \"center_y\": -6.956521739130435, \"value_uncond\": 3.418351595029395e-07}, {\"x\": -4.202898550724638, \"y\": -7.101449275362318, \"x2\": -3.91304347826087, \"y2\": -6.811594202898551, \"center_x\": -4.057971014492754, \"center_y\": -6.956521739130435, \"value_uncond\": 4.4727772607802706e-07}, {\"x\": -3.913043478260869, \"y\": -7.101449275362318, \"x2\": -3.6231884057971016, \"y2\": -6.811594202898551, \"center_x\": -3.7681159420289854, \"center_y\": -6.956521739130435, \"value_uncond\": 5.798072307485984e-07}, {\"x\": -3.6231884057971016, \"y\": -7.101449275362318, \"x2\": -3.333333333333334, \"y2\": -6.811594202898551, \"center_x\": -3.4782608695652177, \"center_y\": -6.956521739130435, \"value_uncond\": 7.446218869285287e-07}, {\"x\": -3.333333333333333, \"y\": -7.101449275362318, \"x2\": -3.0434782608695654, \"y2\": -6.811594202898551, \"center_x\": -3.1884057971014492, \"center_y\": -6.956521739130435, \"value_uncond\": 9.474008767444301e-07}, {\"x\": -3.0434782608695645, \"y\": -7.101449275362318, \"x2\": -2.753623188405797, \"y2\": -6.811594202898551, \"center_x\": -2.8985507246376807, \"center_y\": -6.956521739130435, \"value_uncond\": 1.1942014157115696e-06}, {\"x\": -2.753623188405797, \"y\": -7.101449275362318, \"x2\": -2.4637681159420293, \"y2\": -6.811594202898551, \"center_x\": -2.608695652173913, \"center_y\": -6.956521739130435, \"value_uncond\": 1.4913074781726702e-06}, {\"x\": -2.4637681159420284, \"y\": -7.101449275362318, \"x2\": -2.1739130434782608, \"y2\": -6.811594202898551, \"center_x\": -2.3188405797101446, \"center_y\": -6.956521739130435, \"value_uncond\": 1.8450265672647442e-06}, {\"x\": -2.1739130434782608, \"y\": -7.101449275362318, \"x2\": -1.8840579710144931, \"y2\": -6.811594202898551, \"center_x\": -2.028985507246377, \"center_y\": -6.956521739130435, \"value_uncond\": 2.261433738420133e-06}, {\"x\": -1.8840579710144922, \"y\": -7.101449275362318, \"x2\": -1.5942028985507246, \"y2\": -6.811594202898551, \"center_x\": -1.7391304347826084, \"center_y\": -6.956521739130435, \"value_uncond\": 2.746065707075796e-06}, {\"x\": -1.5942028985507246, \"y\": -7.101449275362318, \"x2\": -1.304347826086957, \"y2\": -6.811594202898551, \"center_x\": -1.4492753623188408, \"center_y\": -6.956521739130435, \"value_uncond\": 3.3035721542860862e-06}, {\"x\": -1.304347826086957, \"y\": -7.101449275362318, \"x2\": -1.0144927536231894, \"y2\": -6.811594202898551, \"center_x\": -1.1594202898550732, \"center_y\": -6.956521739130435, \"value_uncond\": 3.937336051961573e-06}, {\"x\": -1.0144927536231876, \"y\": -7.101449275362318, \"x2\": -0.72463768115942, \"y2\": -6.811594202898551, \"center_x\": -0.8695652173913038, \"center_y\": -6.956521739130435, \"value_uncond\": 4.649079627101635e-06}, {\"x\": -0.72463768115942, \"y\": -7.101449275362318, \"x2\": -0.43478260869565233, \"y2\": -6.811594202898551, \"center_x\": -0.5797101449275361, \"center_y\": -6.956521739130435, \"value_uncond\": 5.4384770520955155e-06}, {\"x\": -0.43478260869565233, \"y\": -7.101449275362318, \"x2\": -0.1449275362318847, \"y2\": -6.811594202898551, \"center_x\": -0.2898550724637685, \"center_y\": -6.956521739130435, \"value_uncond\": 6.302798610653378e-06}, {\"x\": -0.14492753623188293, \"y\": -7.101449275362318, \"x2\": 0.1449275362318847, \"y2\": -6.811594202898551, \"center_x\": 8.881784197001252e-16, \"center_y\": -6.956521739130435, \"value_uncond\": 7.236613456409447e-06}, {\"x\": 0.1449275362318847, \"y\": -7.101449275362318, \"x2\": 0.43478260869565233, \"y2\": -6.811594202898551, \"center_x\": 0.2898550724637685, \"center_y\": -6.956521739130435, \"value_uncond\": 8.23157870068867e-06}, {\"x\": 0.43478260869565233, \"y\": -7.101449275362318, \"x2\": 0.72463768115942, \"y2\": -6.811594202898551, \"center_x\": 0.5797101449275361, \"center_y\": -6.956521739130435, \"value_uncond\": 9.276341077656326e-06}, {\"x\": 0.72463768115942, \"y\": -7.101449275362318, \"x2\": 1.0144927536231876, \"y2\": -6.811594202898551, \"center_x\": 0.8695652173913038, \"center_y\": -6.956521739130435, \"value_uncond\": 1.0356573628286171e-05}, {\"x\": 1.0144927536231894, \"y\": -7.101449275362318, \"x2\": 1.304347826086957, \"y2\": -6.811594202898551, \"center_x\": 1.1594202898550732, \"center_y\": -6.956521739130435, \"value_uncond\": 1.1455163704592264e-05}, {\"x\": 1.304347826086957, \"y\": -7.101449275362318, \"x2\": 1.5942028985507246, \"y2\": -6.811594202898551, \"center_x\": 1.4492753623188408, \"center_y\": -6.956521739130435, \"value_uncond\": 1.2552560335194498e-05}, {\"x\": 1.5942028985507246, \"y\": -7.101449275362318, \"x2\": 1.8840579710144922, \"y2\": -6.811594202898551, \"center_x\": 1.7391304347826084, \"center_y\": -6.956521739130435, \"value_uncond\": 1.362727906211575e-05}, {\"x\": 1.884057971014494, \"y\": -7.101449275362318, \"x2\": 2.1739130434782616, \"y2\": -6.811594202898551, \"center_x\": 2.028985507246378, \"center_y\": -6.956521739130435, \"value_uncond\": 1.465655142584053e-05}, {\"x\": 2.1739130434782616, \"y\": -7.101449275362318, \"x2\": 2.4637681159420293, \"y2\": -6.811594202898551, \"center_x\": 2.3188405797101455, \"center_y\": -6.956521739130435, \"value_uncond\": 1.5617095184701392e-05}, {\"x\": 2.4637681159420293, \"y\": -7.101449275362318, \"x2\": 2.753623188405797, \"y2\": -6.811594202898551, \"center_x\": 2.608695652173913, \"center_y\": -6.956521739130435, \"value_uncond\": 1.6485971053228203e-05}, {\"x\": 2.753623188405797, \"y\": -7.101449275362318, \"x2\": 3.0434782608695645, \"y2\": -6.811594202898551, \"center_x\": 2.8985507246376807, \"center_y\": -6.956521739130435, \"value_uncond\": 1.7241483193963902e-05}, {\"x\": 3.0434782608695663, \"y\": -7.101449275362318, \"x2\": 3.333333333333334, \"y2\": -6.811594202898551, \"center_x\": 3.18840579710145, \"center_y\": -6.956521739130435, \"value_uncond\": 1.7864074774279074e-05}, {\"x\": 3.333333333333334, \"y\": -7.101449275362318, \"x2\": 3.6231884057971016, \"y2\": -6.811594202898551, \"center_x\": 3.4782608695652177, \"center_y\": -6.956521739130435, \"value_uncond\": 1.833716729516683e-05}, {\"x\": 3.6231884057971016, \"y\": -7.101449275362318, \"x2\": 3.913043478260869, \"y2\": -6.811594202898551, \"center_x\": 3.7681159420289854, \"center_y\": -6.956521739130435, \"value_uncond\": 1.8647893534485788e-05}, {\"x\": 3.913043478260871, \"y\": -7.101449275362318, \"x2\": 4.202898550724639, \"y2\": -6.811594202898551, \"center_x\": 4.057971014492755, \"center_y\": -6.956521739130435, \"value_uncond\": 1.878767891462938e-05}, {\"x\": 4.202898550724639, \"y\": -7.101449275362318, \"x2\": 4.492753623188406, \"y2\": -6.811594202898551, \"center_x\": 4.347826086956522, \"center_y\": -6.956521739130435, \"value_uncond\": 1.8752634640410333e-05}, {\"x\": 4.492753623188406, \"y\": -7.101449275362318, \"x2\": 4.782608695652174, \"y2\": -6.811594202898551, \"center_x\": 4.63768115942029, \"center_y\": -6.956521739130435, \"value_uncond\": 1.8543737450318508e-05}, {\"x\": 4.782608695652174, \"y\": -7.101449275362318, \"x2\": 5.0724637681159415, \"y2\": -6.811594202898551, \"center_x\": 4.927536231884058, \"center_y\": -6.956521739130435, \"value_uncond\": 1.8166784384993456e-05}, {\"x\": 5.072463768115943, \"y\": -7.101449275362318, \"x2\": 5.362318840579711, \"y2\": -6.811594202898551, \"center_x\": 5.217391304347827, \"center_y\": -6.956521739130435, \"value_uncond\": 1.7632125496308203e-05}, {\"x\": 5.362318840579711, \"y\": -7.101449275362318, \"x2\": 5.6521739130434785, \"y2\": -6.811594202898551, \"center_x\": 5.507246376811595, \"center_y\": -6.956521739130435, \"value_uncond\": 1.6954191697836777e-05}, {\"x\": 5.6521739130434785, \"y\": -7.101449275362318, \"x2\": 5.942028985507246, \"y2\": -6.811594202898551, \"center_x\": 5.797101449275362, \"center_y\": -6.956521739130435, \"value_uncond\": 1.6150847816069353e-05}, {\"x\": 5.942028985507246, \"y\": -7.101449275362318, \"x2\": 6.231884057971014, \"y2\": -6.811594202898551, \"center_x\": 6.08695652173913, \"center_y\": -6.956521739130435, \"value_uncond\": 1.524261130753217e-05}, {\"x\": 6.2318840579710155, \"y\": -7.101449275362318, \"x2\": 6.521739130434783, \"y2\": -6.811594202898551, \"center_x\": 6.376811594202899, \"center_y\": -6.956521739130435, \"value_uncond\": 1.4251784269809043e-05}, {\"x\": 6.521739130434785, \"y\": -7.101449275362318, \"x2\": 6.8115942028985526, \"y2\": -6.811594202898551, \"center_x\": 6.666666666666669, \"center_y\": -6.956521739130435, \"value_uncond\": 1.3201549820744305e-05}, {\"x\": 6.811594202898551, \"y\": -7.101449275362318, \"x2\": 7.101449275362318, \"y2\": -6.811594202898551, \"center_x\": 6.956521739130435, \"center_y\": -6.956521739130435, \"value_uncond\": 1.2115083529099698e-05}, {\"x\": 7.10144927536232, \"y\": -7.101449275362318, \"x2\": 7.391304347826088, \"y2\": -6.811594202898551, \"center_x\": 7.246376811594204, \"center_y\": -6.956521739130435, \"value_uncond\": 1.1014726580662296e-05}, {\"x\": 7.391304347826086, \"y\": -7.101449275362318, \"x2\": 7.681159420289854, \"y2\": -6.811594202898551, \"center_x\": 7.53623188405797, \"center_y\": -6.956521739130435, \"value_uncond\": 9.921260294568306e-06}, {\"x\": 7.681159420289855, \"y\": -7.101449275362318, \"x2\": 7.971014492753623, \"y2\": -6.811594202898551, \"center_x\": 7.826086956521739, \"center_y\": -6.956521739130435, \"value_uncond\": 8.853312241759115e-06}, {\"x\": 7.971014492753625, \"y\": -7.101449275362318, \"x2\": 8.260869565217392, \"y2\": -6.811594202898551, \"center_x\": 8.115942028985508, \"center_y\": -6.956521739130435, \"value_uncond\": 7.826913483440587e-06}, {\"x\": 8.26086956521739, \"y\": -7.101449275362318, \"x2\": 8.550724637681158, \"y2\": -6.811594202898551, \"center_x\": 8.405797101449274, \"center_y\": -6.956521739130435, \"value_uncond\": 6.855215309959383e-06}, {\"x\": 8.55072463768116, \"y\": -7.101449275362318, \"x2\": 8.840579710144928, \"y2\": -6.811594202898551, \"center_x\": 8.695652173913043, \"center_y\": -6.956521739130435, \"value_uncond\": 5.948363235535961e-06}, {\"x\": 8.84057971014493, \"y\": -7.101449275362318, \"x2\": 9.130434782608697, \"y2\": -6.811594202898551, \"center_x\": 8.985507246376812, \"center_y\": -6.956521739130435, \"value_uncond\": 5.113516672729353e-06}, {\"x\": 9.130434782608695, \"y\": -7.101449275362318, \"x2\": 9.420289855072463, \"y2\": -6.811594202898551, \"center_x\": 9.275362318840578, \"center_y\": -6.956521739130435, \"value_uncond\": 4.354995257507432e-06}, {\"x\": 9.420289855072465, \"y\": -7.101449275362318, \"x2\": 9.710144927536232, \"y2\": -6.811594202898551, \"center_x\": 9.565217391304348, \"center_y\": -6.956521739130435, \"value_uncond\": 3.674527576762701e-06}, {\"x\": 9.710144927536234, \"y\": -7.101449275362318, \"x2\": 10.000000000000002, \"y2\": -6.811594202898551, \"center_x\": 9.855072463768117, \"center_y\": -6.956521739130435, \"value_uncond\": 3.071575184386158e-06}, {\"x\": 10.0, \"y\": -7.101449275362318, \"x2\": 10.289855072463768, \"y2\": -6.811594202898551, \"center_x\": 10.144927536231883, \"center_y\": -6.956521739130435, \"value_uncond\": 2.5437041816438e-06}, {\"x\": -10.0, \"y\": -6.811594202898551, \"x2\": -9.710144927536232, \"y2\": -6.521739130434783, \"center_x\": -9.855072463768117, \"center_y\": -6.666666666666667, \"value_uncond\": 4.99251547394975e-10}, {\"x\": -9.710144927536232, \"y\": -6.811594202898551, \"x2\": -9.420289855072465, \"y2\": -6.521739130434783, \"center_x\": -9.565217391304348, \"center_y\": -6.666666666666667, \"value_uncond\": 7.800267285789022e-10}, {\"x\": -9.420289855072463, \"y\": -6.811594202898551, \"x2\": -9.130434782608695, \"y2\": -6.521739130434783, \"center_x\": -9.275362318840578, \"center_y\": -6.666666666666667, \"value_uncond\": 1.207383854651945e-09}, {\"x\": -9.130434782608695, \"y\": -6.811594202898551, \"x2\": -8.840579710144928, \"y2\": -6.521739130434783, \"center_x\": -8.985507246376812, \"center_y\": -6.666666666666667, \"value_uncond\": 1.85151424677519e-09}, {\"x\": -8.840579710144928, \"y\": -6.811594202898551, \"x2\": -8.55072463768116, \"y2\": -6.521739130434783, \"center_x\": -8.695652173913043, \"center_y\": -6.666666666666667, \"value_uncond\": 2.8129017726522515e-09}, {\"x\": -8.55072463768116, \"y\": -6.811594202898551, \"x2\": -8.260869565217392, \"y2\": -6.521739130434783, \"center_x\": -8.405797101449277, \"center_y\": -6.666666666666667, \"value_uncond\": 4.233776128403348e-09}, {\"x\": -8.26086956521739, \"y\": -6.811594202898551, \"x2\": -7.971014492753623, \"y2\": -6.521739130434783, \"center_x\": -8.115942028985508, \"center_y\": -6.666666666666667, \"value_uncond\": 6.313163363352597e-09}, {\"x\": -7.971014492753623, \"y\": -6.811594202898551, \"x2\": -7.681159420289855, \"y2\": -6.521739130434783, \"center_x\": -7.826086956521739, \"center_y\": -6.666666666666667, \"value_uncond\": 9.326355800317806e-09}, {\"x\": -7.681159420289855, \"y\": -6.811594202898551, \"x2\": -7.391304347826088, \"y2\": -6.521739130434783, \"center_x\": -7.536231884057972, \"center_y\": -6.666666666666667, \"value_uncond\": 1.3649688690943727e-08}, {\"x\": -7.391304347826087, \"y\": -6.811594202898551, \"x2\": -7.101449275362319, \"y2\": -6.521739130434783, \"center_x\": -7.246376811594203, \"center_y\": -6.666666666666667, \"value_uncond\": 1.9791528123619735e-08}, {\"x\": -7.101449275362318, \"y\": -6.811594202898551, \"x2\": -6.811594202898551, \"y2\": -6.521739130434783, \"center_x\": -6.956521739130435, \"center_y\": -6.666666666666667, \"value_uncond\": 2.8430318408449762e-08}, {\"x\": -6.811594202898551, \"y\": -6.811594202898551, \"x2\": -6.521739130434783, \"y2\": -6.521739130434783, \"center_x\": -6.666666666666667, \"center_y\": -6.666666666666667, \"value_uncond\": 4.046037783073838e-08}, {\"x\": -6.521739130434782, \"y\": -6.811594202898551, \"x2\": -6.231884057971015, \"y2\": -6.521739130434783, \"center_x\": -6.3768115942028984, \"center_y\": -6.666666666666667, \"value_uncond\": 5.7045837298942615e-08}, {\"x\": -6.231884057971014, \"y\": -6.811594202898551, \"x2\": -5.942028985507246, \"y2\": -6.521739130434783, \"center_x\": -6.08695652173913, \"center_y\": -6.666666666666667, \"value_uncond\": 7.968265540118451e-08}, {\"x\": -5.942028985507246, \"y\": -6.811594202898551, \"x2\": -5.6521739130434785, \"y2\": -6.521739130434783, \"center_x\": -5.797101449275362, \"center_y\": -6.666666666666667, \"value_uncond\": 1.1026798852770564e-07}, {\"x\": -5.6521739130434785, \"y\": -6.811594202898551, \"x2\": -5.362318840579711, \"y2\": -6.521739130434783, \"center_x\": -5.507246376811595, \"center_y\": -6.666666666666667, \"value_uncond\": 1.5117532847811418e-07}, {\"x\": -5.36231884057971, \"y\": -6.811594202898551, \"x2\": -5.072463768115942, \"y2\": -6.521739130434783, \"center_x\": -5.217391304347826, \"center_y\": -6.666666666666667, \"value_uncond\": 2.053327407104132e-07}, {\"x\": -5.0724637681159415, \"y\": -6.811594202898551, \"x2\": -4.782608695652174, \"y2\": -6.521739130434783, \"center_x\": -4.927536231884058, \"center_y\": -6.666666666666667, \"value_uncond\": 2.763002651093713e-07}, {\"x\": -4.782608695652174, \"y\": -6.811594202898551, \"x2\": -4.492753623188406, \"y2\": -6.521739130434783, \"center_x\": -4.63768115942029, \"center_y\": -6.666666666666667, \"value_uncond\": 3.6834112803287286e-07}, {\"x\": -4.492753623188405, \"y\": -6.811594202898551, \"x2\": -4.202898550724638, \"y2\": -6.521739130434783, \"center_x\": -4.3478260869565215, \"center_y\": -6.666666666666667, \"value_uncond\": 4.86479944072979e-07}, {\"x\": -4.202898550724638, \"y\": -6.811594202898551, \"x2\": -3.91304347826087, \"y2\": -6.521739130434783, \"center_x\": -4.057971014492754, \"center_y\": -6.666666666666667, \"value_uncond\": 6.365396803650244e-07}, {\"x\": -3.913043478260869, \"y\": -6.811594202898551, \"x2\": -3.6231884057971016, \"y2\": -6.521739130434783, \"center_x\": -3.7681159420289854, \"center_y\": -6.666666666666667, \"value_uncond\": 8.25147973654423e-07}, {\"x\": -3.6231884057971016, \"y\": -6.811594202898551, \"x2\": -3.333333333333334, \"y2\": -6.521739130434783, \"center_x\": -3.4782608695652177, \"center_y\": -6.666666666666667, \"value_uncond\": 1.0597026193421523e-06}, {\"x\": -3.333333333333333, \"y\": -6.811594202898551, \"x2\": -3.0434782608695654, \"y2\": -6.521739130434783, \"center_x\": -3.1884057971014492, \"center_y\": -6.666666666666667, \"value_uncond\": 1.3482858995648702e-06}, {\"x\": -3.0434782608695645, \"y\": -6.811594202898551, \"x2\": -2.753623188405797, \"y2\": -6.521739130434783, \"center_x\": -2.8985507246376807, \"center_y\": -6.666666666666667, \"value_uncond\": 1.6995180916205377e-06}, {\"x\": -2.753623188405797, \"y\": -6.811594202898551, \"x2\": -2.4637681159420293, \"y2\": -6.521739130434783, \"center_x\": -2.608695652173913, \"center_y\": -6.666666666666667, \"value_uncond\": 2.1223421827994224e-06}, {\"x\": -2.4637681159420284, \"y\": -6.811594202898551, \"x2\": -2.1739130434782608, \"y2\": -6.521739130434783, \"center_x\": -2.3188405797101446, \"center_y\": -6.666666666666667, \"value_uncond\": 2.6257346452051987e-06}, {\"x\": -2.1739130434782608, \"y\": -6.811594202898551, \"x2\": -1.8840579710144931, \"y2\": -6.521739130434783, \"center_x\": -2.028985507246377, \"center_y\": -6.666666666666667, \"value_uncond\": 3.2183411448696105e-06}, {\"x\": -1.8840579710144922, \"y\": -6.811594202898551, \"x2\": -1.5942028985507246, \"y2\": -6.521739130434783, \"center_x\": -1.7391304347826084, \"center_y\": -6.666666666666667, \"value_uncond\": 3.9080412136115375e-06}, {\"x\": -1.5942028985507246, \"y\": -6.811594202898551, \"x2\": -1.304347826086957, \"y2\": -6.521739130434783, \"center_x\": -1.4492753623188408, \"center_y\": -6.666666666666667, \"value_uncond\": 4.701452007438475e-06}, {\"x\": -1.304347826086957, \"y\": -6.811594202898551, \"x2\": -1.0144927536231894, \"y2\": -6.521739130434783, \"center_x\": -1.1594202898550732, \"center_y\": -6.666666666666667, \"value_uncond\": 5.603387975479224e-06}, {\"x\": -1.0144927536231876, \"y\": -6.811594202898551, \"x2\": -0.72463768115942, \"y2\": -6.521739130434783, \"center_x\": -0.8695652173913038, \"center_y\": -6.666666666666667, \"value_uncond\": 6.616300091166552e-06}, {\"x\": -0.72463768115942, \"y\": -6.811594202898551, \"x2\": -0.43478260869565233, \"y2\": -6.521739130434783, \"center_x\": -0.5797101449275361, \"center_y\": -6.666666666666667, \"value_uncond\": 7.739724655570018e-06}, {\"x\": -0.43478260869565233, \"y\": -6.811594202898551, \"x2\": -0.1449275362318847, \"y2\": -6.521739130434783, \"center_x\": -0.2898550724637685, \"center_y\": -6.666666666666667, \"value_uncond\": 8.969776895016973e-06}, {\"x\": -0.14492753623188293, \"y\": -6.811594202898551, \"x2\": 0.1449275362318847, \"y2\": -6.521739130434783, \"center_x\": 8.881784197001252e-16, \"center_y\": -6.666666666666667, \"value_uncond\": 1.0298727944401408e-05}, {\"x\": 0.1449275362318847, \"y\": -6.811594202898551, \"x2\": 0.43478260869565233, \"y2\": -6.521739130434783, \"center_x\": 0.2898550724637685, \"center_y\": -6.666666666666667, \"value_uncond\": 1.1714704689143955e-05}, {\"x\": 0.43478260869565233, \"y\": -6.811594202898551, \"x2\": 0.72463768115942, \"y2\": -6.521739130434783, \"center_x\": 0.5797101449275361, \"center_y\": -6.666666666666667, \"value_uncond\": 1.3201549820744305e-05}, {\"x\": 0.72463768115942, \"y\": -6.811594202898551, \"x2\": 1.0144927536231876, \"y2\": -6.521739130434783, \"center_x\": 0.8695652173913038, \"center_y\": -6.666666666666667, \"value_uncond\": 1.4738874043274142e-05}, {\"x\": 1.0144927536231894, \"y\": -6.811594202898551, \"x2\": 1.304347826086957, \"y2\": -6.521739130434783, \"center_x\": 1.1594202898550732, \"center_y\": -6.666666666666667, \"value_uncond\": 1.6302323630079804e-05}, {\"x\": 1.304347826086957, \"y\": -6.811594202898551, \"x2\": 1.5942028985507246, \"y2\": -6.521739130434783, \"center_x\": 1.4492753623188408, \"center_y\": -6.666666666666667, \"value_uncond\": 1.7864074774279058e-05}, {\"x\": 1.5942028985507246, \"y\": -6.811594202898551, \"x2\": 1.8840579710144922, \"y2\": -6.521739130434783, \"center_x\": 1.7391304347826084, \"center_y\": -6.666666666666667, \"value_uncond\": 1.9393552043168186e-05}, {\"x\": 1.884057971014494, \"y\": -6.811594202898551, \"x2\": 2.1739130434782616, \"y2\": -6.521739130434783, \"center_x\": 2.028985507246378, \"center_y\": -6.666666666666667, \"value_uncond\": 2.0858352687633163e-05}, {\"x\": 2.1739130434782616, \"y\": -6.811594202898551, \"x2\": 2.4637681159420293, \"y2\": -6.521739130434783, \"center_x\": 2.3188405797101455, \"center_y\": -6.666666666666667, \"value_uncond\": 2.2225342773643506e-05}, {\"x\": 2.4637681159420293, \"y\": -6.811594202898551, \"x2\": 2.753623188405797, \"y2\": -6.521739130434783, \"center_x\": 2.608695652173913, \"center_y\": -6.666666666666667, \"value_uncond\": 2.346187644250868e-05}, {\"x\": 2.753623188405797, \"y\": -6.811594202898551, \"x2\": 3.0434782608695645, \"y2\": -6.521739130434783, \"center_x\": 2.8985507246376807, \"center_y\": -6.666666666666667, \"value_uncond\": 2.4537077438526764e-05}, {\"x\": 3.0434782608695663, \"y\": -6.811594202898551, \"x2\": 3.333333333333334, \"y2\": -6.521739130434783, \"center_x\": 3.18840579710145, \"center_y\": -6.666666666666667, \"value_uncond\": 2.542311361342594e-05}, {\"x\": 3.333333333333334, \"y\": -6.811594202898551, \"x2\": 3.6231884057971016, \"y2\": -6.521739130434783, \"center_x\": 3.4782608695652177, \"center_y\": -6.666666666666667, \"value_uncond\": 2.6096391410354376e-05}, {\"x\": 3.6231884057971016, \"y\": -6.811594202898551, \"x2\": 3.913043478260869, \"y2\": -6.521739130434783, \"center_x\": 3.7681159420289854, \"center_y\": -6.666666666666667, \"value_uncond\": 2.6538598946131853e-05}, {\"x\": 3.913043478260871, \"y\": -6.811594202898551, \"x2\": 4.202898550724639, \"y2\": -6.521739130434783, \"center_x\": 4.057971014492755, \"center_y\": -6.666666666666667, \"value_uncond\": 2.673753337994889e-05}, {\"x\": 4.202898550724639, \"y\": -6.811594202898551, \"x2\": 4.492753623188406, \"y2\": -6.521739130434783, \"center_x\": 4.347826086956522, \"center_y\": -6.666666666666667, \"value_uncond\": 2.6687660404369222e-05}, {\"x\": 4.492753623188406, \"y\": -6.811594202898551, \"x2\": 4.782608695652174, \"y2\": -6.521739130434783, \"center_x\": 4.63768115942029, \"center_y\": -6.666666666666667, \"value_uncond\": 2.639037005687939e-05}, {\"x\": 4.782608695652174, \"y\": -6.811594202898551, \"x2\": 5.0724637681159415, \"y2\": -6.521739130434783, \"center_x\": 4.927536231884058, \"center_y\": -6.666666666666667, \"value_uncond\": 2.585391234900603e-05}, {\"x\": 5.072463768115943, \"y\": -6.811594202898551, \"x2\": 5.362318840579711, \"y2\": -6.521739130434783, \"center_x\": 5.217391304347827, \"center_y\": -6.666666666666667, \"value_uncond\": 2.5093016873409156e-05}, {\"x\": 5.362318840579711, \"y\": -6.811594202898551, \"x2\": 5.6521739130434785, \"y2\": -6.521739130434783, \"center_x\": 5.507246376811595, \"center_y\": -6.666666666666667, \"value_uncond\": 2.4128220868091493e-05}, {\"x\": 5.6521739130434785, \"y\": -6.811594202898551, \"x2\": 5.942028985507246, \"y2\": -6.521739130434783, \"center_x\": 5.797101449275362, \"center_y\": -6.666666666666667, \"value_uncond\": 2.2984948516464874e-05}, {\"x\": 5.942028985507246, \"y\": -6.811594202898551, \"x2\": 6.231884057971014, \"y2\": -6.521739130434783, \"center_x\": 6.08695652173913, \"center_y\": -6.666666666666667, \"value_uncond\": 2.1692399070934804e-05}, {\"x\": 6.2318840579710155, \"y\": -6.811594202898551, \"x2\": 6.521739130434783, \"y2\": -6.521739130434783, \"center_x\": 6.376811594202899, \"center_y\": -6.666666666666667, \"value_uncond\": 2.0282311581402006e-05}, {\"x\": 6.521739130434785, \"y\": -6.811594202898551, \"x2\": 6.8115942028985526, \"y2\": -6.521739130434783, \"center_x\": 6.666666666666669, \"center_y\": -6.666666666666667, \"value_uncond\": 1.8787678914629364e-05}, {\"x\": 6.811594202898551, \"y\": -6.811594202898551, \"x2\": 7.101449275362318, \"y2\": -6.521739130434783, \"center_x\": 6.956521739130435, \"center_y\": -6.666666666666667, \"value_uncond\": 1.7241483193963888e-05}, {\"x\": 7.10144927536232, \"y\": -6.811594202898551, \"x2\": 7.391304347826088, \"y2\": -6.521739130434783, \"center_x\": 7.246376811594204, \"center_y\": -6.666666666666667, \"value_uncond\": 1.56755190973668e-05}, {\"x\": 7.391304347826086, \"y\": -6.811594202898551, \"x2\": 7.681159420289854, \"y2\": -6.521739130434783, \"center_x\": 7.53623188405797, \"center_y\": -6.666666666666667, \"value_uncond\": 1.4119361391184097e-05}, {\"x\": 7.681159420289855, \"y\": -6.811594202898551, \"x2\": 7.971014492753623, \"y2\": -6.521739130434783, \"center_x\": 7.826086956521739, \"center_y\": -6.666666666666667, \"value_uncond\": 1.2599519752427816e-05}, {\"x\": 7.971014492753625, \"y\": -6.811594202898551, \"x2\": 8.260869565217392, \"y2\": -6.521739130434783, \"center_x\": 8.115942028985508, \"center_y\": -6.666666666666667, \"value_uncond\": 1.1138808656268394e-05}, {\"x\": 8.26086956521739, \"y\": -6.811594202898551, \"x2\": 8.550724637681158, \"y2\": -6.521739130434783, \"center_x\": 8.405797101449274, \"center_y\": -6.666666666666667, \"value_uncond\": 9.755944255256153e-06}, {\"x\": 8.55072463768116, \"y\": -6.811594202898551, \"x2\": 8.840579710144928, \"y2\": -6.521739130434783, \"center_x\": 8.695652173913043, \"center_y\": -6.666666666666667, \"value_uncond\": 8.465365055944217e-06}, {\"x\": 8.84057971014493, \"y\": -6.811594202898551, \"x2\": 9.130434782608697, \"y2\": -6.521739130434783, \"center_x\": 8.985507246376812, \"center_y\": -6.666666666666667, \"value_uncond\": 7.277259918443921e-06}, {\"x\": 9.130434782608695, \"y\": -6.811594202898551, \"x2\": 9.420289855072463, \"y2\": -6.521739130434783, \"center_x\": 9.275362318840578, \"center_y\": -6.666666666666667, \"value_uncond\": 6.197776297765796e-06}, {\"x\": 9.420289855072465, \"y\": -6.811594202898551, \"x2\": 9.710144927536232, \"y2\": -6.521739130434783, \"center_x\": 9.565217391304348, \"center_y\": -6.666666666666667, \"value_uncond\": 5.229374218373128e-06}, {\"x\": 9.710144927536234, \"y\": -6.811594202898551, \"x2\": 10.000000000000002, \"y2\": -6.521739130434783, \"center_x\": 9.855072463768117, \"center_y\": -6.666666666666667, \"value_uncond\": 4.371287395038365e-06}, {\"x\": 10.0, \"y\": -6.811594202898551, \"x2\": 10.289855072463768, \"y2\": -6.521739130434783, \"center_x\": 10.144927536231883, \"center_y\": -6.666666666666667, \"value_uncond\": 3.6200520444522546e-06}, {\"x\": -10.0, \"y\": -6.521739130434782, \"x2\": -9.710144927536232, \"y2\": -6.231884057971015, \"center_x\": -9.855072463768117, \"center_y\": -6.3768115942028984, \"value_uncond\": 7.039040184716764e-10}, {\"x\": -9.710144927536232, \"y\": -6.521739130434782, \"x2\": -9.420289855072465, \"y2\": -6.231884057971015, \"center_x\": -9.565217391304348, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.0997741551867875e-09}, {\"x\": -9.420289855072463, \"y\": -6.521739130434782, \"x2\": -9.130434782608695, \"y2\": -6.231884057971015, \"center_x\": -9.275362318840578, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.7023128952967586e-09}, {\"x\": -9.130434782608695, \"y\": -6.521739130434782, \"x2\": -8.840579710144928, \"y2\": -6.231884057971015, \"center_x\": -8.985507246376812, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.6104842846516803e-09}, {\"x\": -8.840579710144928, \"y\": -6.521739130434782, \"x2\": -8.55072463768116, \"y2\": -6.231884057971015, \"center_x\": -8.695652173913043, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.965962392440151e-09}, {\"x\": -8.55072463768116, \"y\": -6.521739130434782, \"x2\": -8.260869565217392, \"y2\": -6.231884057971015, \"center_x\": -8.405797101449277, \"center_y\": -6.3768115942028984, \"value_uncond\": 5.969279505777591e-09}, {\"x\": -8.26086956521739, \"y\": -6.521739130434782, \"x2\": -7.971014492753623, \"y2\": -6.231884057971015, \"center_x\": -8.115942028985508, \"center_y\": -6.3768115942028984, \"value_uncond\": 8.901046143811682e-09}, {\"x\": -7.971014492753623, \"y\": -6.521739130434782, \"x2\": -7.681159420289855, \"y2\": -6.231884057971015, \"center_x\": -7.826086956521739, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.314940205953262e-08}, {\"x\": -7.681159420289855, \"y\": -6.521739130434782, \"x2\": -7.391304347826088, \"y2\": -6.231884057971015, \"center_x\": -7.536231884057972, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.924494930576833e-08}, {\"x\": -7.391304347826087, \"y\": -6.521739130434782, \"x2\": -7.101449275362319, \"y2\": -6.231884057971015, \"center_x\": -7.246376811594203, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.7904442661425693e-08}, {\"x\": -7.101449275362318, \"y\": -6.521739130434782, \"x2\": -6.811594202898551, \"y2\": -6.231884057971015, \"center_x\": -6.956521739130435, \"center_y\": -6.3768115942028984, \"value_uncond\": 4.008443334539075e-08}, {\"x\": -6.811594202898551, \"y\": -6.521739130434782, \"x2\": -6.521739130434783, \"y2\": -6.231884057971015, \"center_x\": -6.666666666666667, \"center_y\": -6.3768115942028984, \"value_uncond\": 5.7045837298942615e-08}, {\"x\": -6.521739130434782, \"y\": -6.521739130434782, \"x2\": -6.231884057971015, \"y2\": -6.231884057971015, \"center_x\": -6.3768115942028984, \"center_y\": -6.3768115942028984, \"value_uncond\": 8.042998428613649e-08}, {\"x\": -6.231884057971014, \"y\": -6.521739130434782, \"x2\": -5.942028985507246, \"y2\": -6.231884057971015, \"center_x\": -6.08695652173913, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.1234605407244484e-07}, {\"x\": -5.942028985507246, \"y\": -6.521739130434782, \"x2\": -5.6521739130434785, \"y2\": -6.231884057971015, \"center_x\": -5.797101449275362, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.5546888264731687e-07}, {\"x\": -5.6521739130434785, \"y\": -6.521739130434782, \"x2\": -5.362318840579711, \"y2\": -6.231884057971015, \"center_x\": -5.507246376811595, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.131449001305415e-07}, {\"x\": -5.36231884057971, \"y\": -6.521739130434782, \"x2\": -5.072463768115942, \"y2\": -6.231884057971015, \"center_x\": -5.217391304347826, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.895024403309789e-07}, {\"x\": -5.0724637681159415, \"y\": -6.521739130434782, \"x2\": -4.782608695652174, \"y2\": -6.231884057971015, \"center_x\": -4.927536231884058, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.8956086952577673e-07}, {\"x\": -4.782608695652174, \"y\": -6.521739130434782, \"x2\": -4.492753623188406, \"y2\": -6.231884057971015, \"center_x\": -4.63768115942029, \"center_y\": -6.3768115942028984, \"value_uncond\": 5.193309896456e-07}, {\"x\": -4.492753623188405, \"y\": -6.521739130434782, \"x2\": -4.202898550724638, \"y2\": -6.231884057971015, \"center_x\": -4.3478260869565215, \"center_y\": -6.3768115942028984, \"value_uncond\": 6.85897098017273e-07}, {\"x\": -4.202898550724638, \"y\": -6.521739130434782, \"x2\": -3.91304347826087, \"y2\": -6.231884057971015, \"center_x\": -4.057971014492754, \"center_y\": -6.3768115942028984, \"value_uncond\": 8.974691040289142e-07}, {\"x\": -3.913043478260869, \"y\": -6.521739130434782, \"x2\": -3.6231884057971016, \"y2\": -6.231884057971015, \"center_x\": -3.7681159420289854, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.1633914356796153e-06}, {\"x\": -3.6231884057971016, \"y\": -6.521739130434782, \"x2\": -3.333333333333334, \"y2\": -6.231884057971015, \"center_x\": -3.4782608695652177, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.4940943819444437e-06}, {\"x\": -3.333333333333333, \"y\": -6.521739130434782, \"x2\": -3.0434782608695654, \"y2\": -6.231884057971015, \"center_x\": -3.1884057971014492, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.9009733023452697e-06}, {\"x\": -3.0434782608695645, \"y\": -6.521739130434782, \"x2\": -2.753623188405797, \"y2\": -6.231884057971015, \"center_x\": -2.8985507246376807, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.3961820857624293e-06}, {\"x\": -2.753623188405797, \"y\": -6.521739130434782, \"x2\": -2.4637681159420293, \"y2\": -6.231884057971015, \"center_x\": -2.608695652173913, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.9923296158811253e-06}, {\"x\": -2.4637681159420284, \"y\": -6.521739130434782, \"x2\": -2.1739130434782608, \"y2\": -6.231884057971015, \"center_x\": -2.3188405797101446, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.7020719872461713e-06}, {\"x\": -2.1739130434782608, \"y\": -6.521739130434782, \"x2\": -1.8840579710144931, \"y2\": -6.231884057971015, \"center_x\": -2.028985507246377, \"center_y\": -6.3768115942028984, \"value_uncond\": 4.537598884784661e-06}, {\"x\": -1.8840579710144922, \"y\": -6.521739130434782, \"x2\": -1.5942028985507246, \"y2\": -6.231884057971015, \"center_x\": -1.7391304347826084, \"center_y\": -6.3768115942028984, \"value_uncond\": 5.510019806584133e-06}, {\"x\": -1.5942028985507246, \"y\": -6.521739130434782, \"x2\": -1.304347826086957, \"y2\": -6.231884057971015, \"center_x\": -1.4492753623188408, \"center_y\": -6.3768115942028984, \"value_uncond\": 6.628664403656853e-06}, {\"x\": -1.304347826086957, \"y\": -6.521739130434782, \"x2\": -1.0144927536231894, \"y2\": -6.231884057971015, \"center_x\": -1.1594202898550732, \"center_y\": -6.3768115942028984, \"value_uncond\": 7.900320657144142e-06}, {\"x\": -1.0144927536231876, \"y\": -6.521739130434782, \"x2\": -0.72463768115942, \"y2\": -6.231884057971015, \"center_x\": -0.8695652173913038, \"center_y\": -6.3768115942028984, \"value_uncond\": 9.328444239957765e-06}, {\"x\": -0.72463768115942, \"y\": -6.521739130434782, \"x2\": -0.43478260869565233, \"y2\": -6.231884057971015, \"center_x\": -0.5797101449275361, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.091238137437345e-05}, {\"x\": -0.43478260869565233, \"y\": -6.521739130434782, \"x2\": -0.1449275362318847, \"y2\": -6.231884057971015, \"center_x\": -0.2898550724637685, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.2646654845922255e-05}, {\"x\": -0.14492753623188293, \"y\": -6.521739130434782, \"x2\": 0.1449275362318847, \"y2\": -6.231884057971015, \"center_x\": 8.881784197001252e-16, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.4520367584310195e-05}, {\"x\": 0.1449275362318847, \"y\": -6.521739130434782, \"x2\": 0.43478260869565233, \"y2\": -6.231884057971015, \"center_x\": 0.2898550724637685, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.6516779465029294e-05}, {\"x\": 0.43478260869565233, \"y\": -6.521739130434782, \"x2\": 0.72463768115942, \"y2\": -6.231884057971015, \"center_x\": 0.5797101449275361, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.8613109999084778e-05}, {\"x\": 0.72463768115942, \"y\": -6.521739130434782, \"x2\": 1.0144927536231876, \"y2\": -6.231884057971015, \"center_x\": 0.8695652173913038, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.078061193989797e-05}, {\"x\": 1.0144927536231894, \"y\": -6.521739130434782, \"x2\": 1.304347826086957, \"y2\": -6.231884057971015, \"center_x\": 1.1594202898550732, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.2984948516464915e-05}, {\"x\": 1.304347826086957, \"y\": -6.521739130434782, \"x2\": 1.5942028985507246, \"y2\": -6.231884057971015, \"center_x\": 1.4492753623188408, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.5186890427292652e-05}, {\"x\": 1.5942028985507246, \"y\": -6.521739130434782, \"x2\": 1.8840579710144922, \"y2\": -6.231884057971015, \"center_x\": 1.7391304347826084, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.7343328802596077e-05}, {\"x\": 1.884057971014494, \"y\": -6.521739130434782, \"x2\": 2.1739130434782616, \"y2\": -6.231884057971015, \"center_x\": 2.028985507246378, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.9408578405283986e-05}, {\"x\": 2.1739130434782616, \"y\": -6.521739130434782, \"x2\": 2.4637681159420293, \"y2\": -6.231884057971015, \"center_x\": 2.3188405797101455, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.133592308708699e-05}, {\"x\": 2.4637681159420293, \"y\": -6.521739130434782, \"x2\": 2.753623188405797, \"y2\": -6.231884057971015, \"center_x\": 2.608695652173913, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.3079334846211935e-05}, {\"x\": 2.753623188405797, \"y\": -6.521739130434782, \"x2\": 3.0434782608695645, \"y2\": -6.231884057971015, \"center_x\": 2.8985507246376807, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.459528067694787e-05}, {\"x\": 3.0434782608695663, \"y\": -6.521739130434782, \"x2\": 3.333333333333334, \"y2\": -6.231884057971015, \"center_x\": 3.18840579710145, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.5844519517121926e-05}, {\"x\": 3.333333333333334, \"y\": -6.521739130434782, \"x2\": 3.6231884057971016, \"y2\": -6.231884057971015, \"center_x\": 3.4782608695652177, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.679378637323594e-05}, {\"x\": 3.6231884057971016, \"y\": -6.521739130434782, \"x2\": 3.913043478260869, \"y2\": -6.231884057971015, \"center_x\": 3.7681159420289854, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.741726298148362e-05}, {\"x\": 3.913043478260871, \"y\": -6.521739130434782, \"x2\": 4.202898550724639, \"y2\": -6.231884057971015, \"center_x\": 4.057971014492755, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.769774433022827e-05}, {\"x\": 4.202898550724639, \"y\": -6.521739130434782, \"x2\": 4.492753623188406, \"y2\": -6.231884057971015, \"center_x\": 4.347826086956522, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.762742749674654e-05}, {\"x\": 4.492753623188406, \"y\": -6.521739130434782, \"x2\": 4.782608695652174, \"y2\": -6.231884057971015, \"center_x\": 4.63768115942029, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.72082723206778e-05}, {\"x\": 4.782608695652174, \"y\": -6.521739130434782, \"x2\": 5.0724637681159415, \"y2\": -6.231884057971015, \"center_x\": 4.927536231884058, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.6451910646322456e-05}, {\"x\": 5.072463768115943, \"y\": -6.521739130434782, \"x2\": 5.362318840579711, \"y2\": -6.231884057971015, \"center_x\": 5.217391304347827, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.537910999962595e-05}, {\"x\": 5.362318840579711, \"y\": -6.521739130434782, \"x2\": 5.6521739130434785, \"y2\": -6.231884057971015, \"center_x\": 5.507246376811595, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.4018826213442224e-05}, {\"x\": 5.6521739130434785, \"y\": -6.521739130434782, \"x2\": 5.942028985507246, \"y2\": -6.231884057971015, \"center_x\": 5.797101449275362, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.2406905315616995e-05}, {\"x\": 5.942028985507246, \"y\": -6.521739130434782, \"x2\": 6.231884057971014, \"y2\": -6.231884057971015, \"center_x\": 6.08695652173913, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.0584515873802894e-05}, {\"x\": 6.2318840579710155, \"y\": -6.521739130434782, \"x2\": 6.521739130434783, \"y2\": -6.231884057971015, \"center_x\": 6.376811594202899, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.8596407363257766e-05}, {\"x\": 6.521739130434785, \"y\": -6.521739130434782, \"x2\": 6.8115942028985526, \"y2\": -6.231884057971015, \"center_x\": 6.666666666666669, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.6489097038893434e-05}, {\"x\": 6.811594202898551, \"y\": -6.521739130434782, \"x2\": 7.101449275362318, \"y2\": -6.231884057971015, \"center_x\": 6.956521739130435, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.4309087008280366e-05}, {\"x\": 7.10144927536232, \"y\": -6.521739130434782, \"x2\": 7.391304347826088, \"y2\": -6.231884057971015, \"center_x\": 7.246376811594204, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.21012051777109e-05}, {\"x\": 7.391304347826086, \"y\": -6.521739130434782, \"x2\": 7.681159420289854, \"y2\": -6.231884057971015, \"center_x\": 7.53623188405797, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.9907149558908627e-05}, {\"x\": 7.681159420289855, \"y\": -6.521739130434782, \"x2\": 7.971014492753623, \"y2\": -6.231884057971015, \"center_x\": 7.826086956521739, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.7764296637283633e-05}, {\"x\": 7.971014492753625, \"y\": -6.521739130434782, \"x2\": 8.260869565217392, \"y2\": -6.231884057971015, \"center_x\": 8.115942028985508, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.5704812964618436e-05}, {\"x\": 8.26086956521739, \"y\": -6.521739130434782, \"x2\": 8.550724637681158, \"y2\": -6.231884057971015, \"center_x\": 8.405797101449274, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.375508679160399e-05}, {\"x\": 8.55072463768116, \"y\": -6.521739130434782, \"x2\": 8.840579710144928, \"y2\": -6.231884057971015, \"center_x\": 8.695652173913043, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.1935475236483604e-05}, {\"x\": 8.84057971014493, \"y\": -6.521739130434782, \"x2\": 9.130434782608697, \"y2\": -6.231884057971015, \"center_x\": 8.985507246376812, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.0260343762145541e-05}, {\"x\": 9.130434782608695, \"y\": -6.521739130434782, \"x2\": 9.420289855072463, \"y2\": -6.231884057971015, \"center_x\": 9.275362318840578, \"center_y\": -6.3768115942028984, \"value_uncond\": 8.738359779452863e-06}, {\"x\": 9.420289855072465, \"y\": -6.521739130434782, \"x2\": 9.710144927536232, \"y2\": -6.231884057971015, \"center_x\": 9.565217391304348, \"center_y\": -6.3768115942028984, \"value_uncond\": 7.372991722533171e-06}, {\"x\": 9.710144927536234, \"y\": -6.521739130434782, \"x2\": 10.000000000000002, \"y2\": -6.231884057971015, \"center_x\": 9.855072463768117, \"center_y\": -6.3768115942028984, \"value_uncond\": 6.1631591916285065e-06}, {\"x\": 10.0, \"y\": -6.521739130434782, \"x2\": 10.289855072463768, \"y2\": -6.231884057971015, \"center_x\": 10.144927536231883, \"center_y\": -6.3768115942028984, \"value_uncond\": 5.103978534393217e-06}, {\"x\": -10.0, \"y\": -6.231884057971014, \"x2\": -9.710144927536232, \"y2\": -5.942028985507246, \"center_x\": -9.855072463768117, \"center_y\": -6.08695652173913, \"value_uncond\": 9.832258407473207e-10}, {\"x\": -9.710144927536232, \"y\": -6.231884057971014, \"x2\": -9.420289855072465, \"y2\": -5.942028985507246, \"center_x\": -9.565217391304348, \"center_y\": -6.08695652173913, \"value_uncond\": 1.5361843944483886e-09}, {\"x\": -9.420289855072463, \"y\": -6.231884057971014, \"x2\": -9.130434782608695, \"y2\": -5.942028985507246, \"center_x\": -9.275362318840578, \"center_y\": -6.08695652173913, \"value_uncond\": 2.3778213844086803e-09}, {\"x\": -9.130434782608695, \"y\": -6.231884057971014, \"x2\": -8.840579710144928, \"y2\": -5.942028985507246, \"center_x\": -8.985507246376812, \"center_y\": -6.08695652173913, \"value_uncond\": 3.6463715764929747e-09}, {\"x\": -8.840579710144928, \"y\": -6.231884057971014, \"x2\": -8.55072463768116, \"y2\": -5.942028985507246, \"center_x\": -8.695652173913043, \"center_y\": -6.08695652173913, \"value_uncond\": 5.539727868219475e-09}, {\"x\": -8.55072463768116, \"y\": -6.231884057971014, \"x2\": -8.260869565217392, \"y2\": -5.942028985507246, \"center_x\": -8.405797101449277, \"center_y\": -6.08695652173913, \"value_uncond\": 8.33799737848785e-09}, {\"x\": -8.26086956521739, \"y\": -6.231884057971014, \"x2\": -7.971014492753623, \"y2\": -5.942028985507246, \"center_x\": -8.115942028985508, \"center_y\": -6.08695652173913, \"value_uncond\": 1.2433141946371896e-08}, {\"x\": -7.971014492753623, \"y\": -6.231884057971014, \"x2\": -7.681159420289855, \"y2\": -5.942028985507246, \"center_x\": -7.826086956521739, \"center_y\": -6.08695652173913, \"value_uncond\": 1.836732218602715e-08}, {\"x\": -7.681159420289855, \"y\": -6.231884057971014, \"x2\": -7.391304347826088, \"y2\": -5.942028985507246, \"center_x\": -7.536231884057972, \"center_y\": -6.08695652173913, \"value_uncond\": 2.688169262392831e-08}, {\"x\": -7.391304347826087, \"y\": -6.231884057971014, \"x2\": -7.101449275362319, \"y2\": -5.942028985507246, \"center_x\": -7.246376811594203, \"center_y\": -6.08695652173913, \"value_uncond\": 3.897742927499661e-08}, {\"x\": -7.101449275362318, \"y\": -6.231884057971014, \"x2\": -6.811594202898551, \"y2\": -5.942028985507246, \"center_x\": -6.956521739130435, \"center_y\": -6.08695652173913, \"value_uncond\": 5.599066015061769e-08}, {\"x\": -6.811594202898551, \"y\": -6.231884057971014, \"x2\": -6.521739130434783, \"y2\": -5.942028985507246, \"center_x\": -6.666666666666667, \"center_y\": -6.08695652173913, \"value_uncond\": 7.968265540118451e-08}, {\"x\": -6.521739130434782, \"y\": -6.231884057971014, \"x2\": -6.231884057971015, \"y2\": -5.942028985507246, \"center_x\": -6.3768115942028984, \"center_y\": -6.08695652173913, \"value_uncond\": 1.1234605407244484e-07}, {\"x\": -6.231884057971014, \"y\": -6.231884057971014, \"x2\": -5.942028985507246, \"y2\": -5.942028985507246, \"center_x\": -6.08695652173913, \"center_y\": -6.08695652173913, \"value_uncond\": 1.5692699653833282e-07}, {\"x\": -5.942028985507246, \"y\": -6.231884057971014, \"x2\": -5.6521739130434785, \"y2\": -5.942028985507246, \"center_x\": -5.797101449275362, \"center_y\": -6.08695652173913, \"value_uncond\": 2.1716174199835867e-07}, {\"x\": -5.6521739130434785, \"y\": -6.231884057971014, \"x2\": -5.362318840579711, \"y2\": -5.942028985507246, \"center_x\": -5.507246376811595, \"center_y\": -6.08695652173913, \"value_uncond\": 2.977246444577404e-07}, {\"x\": -5.36231884057971, \"y\": -6.231884057971014, \"x2\": -5.072463768115942, \"y2\": -5.942028985507246, \"center_x\": -5.217391304347826, \"center_y\": -6.08695652173913, \"value_uncond\": 4.0438223511048235e-07}, {\"x\": -5.0724637681159415, \"y\": -6.231884057971014, \"x2\": -4.782608695652174, \"y2\": -5.942028985507246, \"center_x\": -4.927536231884058, \"center_y\": -6.08695652173913, \"value_uncond\": 5.441456553883133e-07}, {\"x\": -4.782608695652174, \"y\": -6.231884057971014, \"x2\": -4.492753623188406, \"y2\": -5.942028985507246, \"center_x\": -4.63768115942029, \"center_y\": -6.08695652173913, \"value_uncond\": 7.254109019424205e-07}, {\"x\": -4.492753623188405, \"y\": -6.231884057971014, \"x2\": -4.202898550724638, \"y2\": -5.942028985507246, \"center_x\": -4.3478260869565215, \"center_y\": -6.08695652173913, \"value_uncond\": 9.580734491734053e-07}, {\"x\": -4.202898550724638, \"y\": -6.231884057971014, \"x2\": -3.91304347826087, \"y2\": -5.942028985507246, \"center_x\": -4.057971014492754, \"center_y\": -6.08695652173913, \"value_uncond\": 1.2536010467300358e-06}, {\"x\": -3.913043478260869, \"y\": -6.231884057971014, \"x2\": -3.6231884057971016, \"y2\": -5.942028985507246, \"center_x\": -3.7681159420289854, \"center_y\": -6.08695652173913, \"value_uncond\": 1.625046160338616e-06}, {\"x\": -3.6231884057971016, \"y\": -6.231884057971014, \"x2\": -3.333333333333334, \"y2\": -5.942028985507246, \"center_x\": -3.4782608695652177, \"center_y\": -6.08695652173913, \"value_uncond\": 2.0869780059399955e-06}, {\"x\": -3.333333333333333, \"y\": -6.231884057971014, \"x2\": -3.0434782608695654, \"y2\": -5.942028985507246, \"center_x\": -3.1884057971014492, \"center_y\": -6.08695652173913, \"value_uncond\": 2.6553138274374587e-06}, {\"x\": -3.0434782608695645, \"y\": -6.231884057971014, \"x2\": -2.753623188405797, \"y2\": -5.942028985507246, \"center_x\": -2.8985507246376807, \"center_y\": -6.08695652173913, \"value_uncond\": 3.3470303962360863e-06}, {\"x\": -2.753623188405797, \"y\": -6.231884057971014, \"x2\": -2.4637681159420293, \"y2\": -5.942028985507246, \"center_x\": -2.608695652173913, \"center_y\": -6.08695652173913, \"value_uncond\": 4.179740028698538e-06}, {\"x\": -2.4637681159420284, \"y\": -6.231884057971014, \"x2\": -2.1739130434782608, \"y2\": -5.942028985507246, \"center_x\": -2.3188405797101446, \"center_y\": -6.08695652173913, \"value_uncond\": 5.171120986168483e-06}, {\"x\": -2.1739130434782608, \"y\": -6.231884057971014, \"x2\": -1.8840579710144931, \"y2\": -5.942028985507246, \"center_x\": -2.028985507246377, \"center_y\": -6.08695652173913, \"value_uncond\": 6.338200040615355e-06}, {\"x\": -1.8840579710144922, \"y\": -6.231884057971014, \"x2\": -1.5942028985507246, \"y2\": -5.942028985507246, \"center_x\": -1.7391304347826084, \"center_y\": -6.08695652173913, \"value_uncond\": 7.696495139530241e-06}, {\"x\": -1.5942028985507246, \"y\": -6.231884057971014, \"x2\": -1.304347826086957, \"y2\": -5.942028985507246, \"center_x\": -1.4492753623188408, \"center_y\": -6.08695652173913, \"value_uncond\": 9.259038107877462e-06}, {\"x\": -1.304347826086957, \"y\": -6.231884057971014, \"x2\": -1.0144927536231894, \"y2\": -5.942028985507246, \"center_x\": -1.1594202898550732, \"center_y\": -6.08695652173913, \"value_uncond\": 1.1035310520260253e-05}, {\"x\": -1.0144927536231876, \"y\": -6.231884057971014, \"x2\": -0.72463768115942, \"y2\": -5.942028985507246, \"center_x\": -0.8695652173913038, \"center_y\": -6.08695652173913, \"value_uncond\": 1.3030139322987851e-05}, {\"x\": -0.72463768115942, \"y\": -6.231884057971014, \"x2\": -0.43478260869565233, \"y2\": -5.942028985507246, \"center_x\": -0.5797101449275361, \"center_y\": -6.08695652173913, \"value_uncond\": 1.5242611307532183e-05}, {\"x\": -0.43478260869565233, \"y\": -6.231884057971014, \"x2\": -0.1449275362318847, \"y2\": -5.942028985507246, \"center_x\": -0.2898550724637685, \"center_y\": -6.08695652173913, \"value_uncond\": 1.7665075801841584e-05}, {\"x\": -0.14492753623188293, \"y\": -6.231884057971014, \"x2\": 0.1449275362318847, \"y2\": -5.942028985507246, \"center_x\": 8.881784197001252e-16, \"center_y\": -6.08695652173913, \"value_uncond\": 2.0282311581402023e-05}, {\"x\": 0.1449275362318847, \"y\": -6.231884057971014, \"x2\": 0.43478260869565233, \"y2\": -5.942028985507246, \"center_x\": 0.2898550724637685, \"center_y\": -6.08695652173913, \"value_uncond\": 2.307093573808732e-05}, {\"x\": 0.43478260869565233, \"y\": -6.231884057971014, \"x2\": 0.72463768115942, \"y2\": -5.942028985507246, \"center_x\": 0.5797101449275361, \"center_y\": -6.08695652173913, \"value_uncond\": 2.5999128073608017e-05}, {\"x\": 0.72463768115942, \"y\": -6.231884057971014, \"x2\": 1.0144927536231876, \"y2\": -5.942028985507246, \"center_x\": 0.8695652173913038, \"center_y\": -6.08695652173913, \"value_uncond\": 2.9026733914962152e-05}, {\"x\": 1.0144927536231894, \"y\": -6.231884057971014, \"x2\": 1.304347826086957, \"y2\": -5.942028985507246, \"center_x\": 1.1594202898550732, \"center_y\": -6.08695652173913, \"value_uncond\": 3.210579104052153e-05}, {\"x\": 1.304347826086957, \"y\": -6.231884057971014, \"x2\": 1.5942028985507246, \"y2\": -5.942028985507246, \"center_x\": 1.4492753623188408, \"center_y\": -6.08695652173913, \"value_uncond\": 3.518150325374492e-05}, {\"x\": 1.5942028985507246, \"y\": -6.231884057971014, \"x2\": 1.8840579710144922, \"y2\": -5.942028985507246, \"center_x\": 1.7391304347826084, \"center_y\": -6.08695652173913, \"value_uncond\": 3.819365530706185e-05}, {\"x\": 1.884057971014494, \"y\": -6.231884057971014, \"x2\": 2.1739130434782616, \"y2\": -5.942028985507246, \"center_x\": 2.028985507246378, \"center_y\": -6.08695652173913, \"value_uncond\": 4.107843323653689e-05}, {\"x\": 2.1739130434782616, \"y\": -6.231884057971014, \"x2\": 2.4637681159420293, \"y2\": -5.942028985507246, \"center_x\": 2.3188405797101455, \"center_y\": -6.08695652173913, \"value_uncond\": 4.377058308288967e-05}, {\"x\": 2.4637681159420293, \"y\": -6.231884057971014, \"x2\": 2.753623188405797, \"y2\": -5.942028985507246, \"center_x\": 2.608695652173913, \"center_y\": -6.08695652173913, \"value_uncond\": 4.62058121022611e-05}, {\"x\": 2.753623188405797, \"y\": -6.231884057971014, \"x2\": 3.0434782608695645, \"y2\": -5.942028985507246, \"center_x\": 2.8985507246376807, \"center_y\": -6.08695652173913, \"value_uncond\": 4.832331260636244e-05}, {\"x\": 3.0434782608695663, \"y\": -6.231884057971014, \"x2\": 3.333333333333334, \"y2\": -5.942028985507246, \"center_x\": 3.18840579710145, \"center_y\": -6.08695652173913, \"value_uncond\": 5.006827197112243e-05}, {\"x\": 3.333333333333334, \"y\": -6.231884057971014, \"x2\": 3.6231884057971016, \"y2\": -5.942028985507246, \"center_x\": 3.4782608695652177, \"center_y\": -6.08695652173913, \"value_uncond\": 5.1394225053082035e-05}, {\"x\": 3.6231884057971016, \"y\": -6.231884057971014, \"x2\": 3.913043478260869, \"y2\": -5.942028985507246, \"center_x\": 3.7681159420289854, \"center_y\": -6.08695652173913, \"value_uncond\": 5.2265108435253366e-05}, {\"x\": 3.913043478260871, \"y\": -6.231884057971014, \"x2\": 4.202898550724639, \"y2\": -5.942028985507246, \"center_x\": 4.057971014492755, \"center_y\": -6.08695652173913, \"value_uncond\": 5.265688984677617e-05}, {\"x\": 4.202898550724639, \"y\": -6.231884057971014, \"x2\": 4.492753623188406, \"y2\": -5.942028985507246, \"center_x\": 4.347826086956522, \"center_y\": -6.08695652173913, \"value_uncond\": 5.2558670024322436e-05}, {\"x\": 4.492753623188406, \"y\": -6.231884057971014, \"x2\": 4.782608695652174, \"y2\": -5.942028985507246, \"center_x\": 4.63768115942029, \"center_y\": -6.08695652173913, \"value_uncond\": 5.197318650728187e-05}, {\"x\": 4.782608695652174, \"y\": -6.231884057971014, \"x2\": 5.0724637681159415, \"y2\": -5.942028985507246, \"center_x\": 4.927536231884058, \"center_y\": -6.08695652173913, \"value_uncond\": 5.0916686865765747e-05}, {\"x\": 5.072463768115943, \"y\": -6.231884057971014, \"x2\": 5.362318840579711, \"y2\": -5.942028985507246, \"center_x\": 5.217391304347827, \"center_y\": -6.08695652173913, \"value_uncond\": 4.941817955493573e-05}, {\"x\": 5.362318840579711, \"y\": -6.231884057971014, \"x2\": 5.6521739130434785, \"y2\": -5.942028985507246, \"center_x\": 5.507246376811595, \"center_y\": -6.08695652173913, \"value_uncond\": 4.7518110604868697e-05}, {\"x\": 5.6521739130434785, \"y\": -6.231884057971014, \"x2\": 5.942028985507246, \"y2\": -5.942028985507246, \"center_x\": 5.797101449275362, \"center_y\": -6.08695652173913, \"value_uncond\": 4.52665503943964e-05}, {\"x\": 5.942028985507246, \"y\": -6.231884057971014, \"x2\": 6.231884057971014, \"y2\": -5.942028985507246, \"center_x\": 6.08695652173913, \"center_y\": -6.08695652173913, \"value_uncond\": 4.272100392204194e-05}, {\"x\": 6.2318840579710155, \"y\": -6.231884057971014, \"x2\": 6.521739130434783, \"y2\": -5.942028985507246, \"center_x\": 6.376811594202899, \"center_y\": -6.08695652173913, \"value_uncond\": 3.9943978062718354e-05}, {\"x\": 6.521739130434785, \"y\": -6.231884057971014, \"x2\": 6.8115942028985526, \"y2\": -5.942028985507246, \"center_x\": 6.666666666666669, \"center_y\": -6.08695652173913, \"value_uncond\": 3.70004489578735e-05}, {\"x\": 6.811594202898551, \"y\": -6.231884057971014, \"x2\": 7.101449275362318, \"y2\": -5.942028985507246, \"center_x\": 6.956521739130435, \"center_y\": -6.08695652173913, \"value_uncond\": 3.3955371590875396e-05}, {\"x\": 7.10144927536232, \"y\": -6.231884057971014, \"x2\": 7.391304347826088, \"y2\": -5.942028985507246, \"center_x\": 7.246376811594204, \"center_y\": -6.08695652173913, \"value_uncond\": 3.0871362390521965e-05}, {\"x\": 7.391304347826086, \"y\": -6.231884057971014, \"x2\": 7.681159420289854, \"y2\": -5.942028985507246, \"center_x\": 7.53623188405797, \"center_y\": -6.08695652173913, \"value_uncond\": 2.780666589237285e-05}, {\"x\": 7.681159420289855, \"y\": -6.231884057971014, \"x2\": 7.971014492753623, \"y2\": -5.942028985507246, \"center_x\": 7.826086956521739, \"center_y\": -6.08695652173913, \"value_uncond\": 2.4813490246015368e-05}, {\"x\": 7.971014492753625, \"y\": -6.231884057971014, \"x2\": 8.260869565217392, \"y2\": -5.942028985507246, \"center_x\": 8.115942028985508, \"center_y\": -6.08695652173913, \"value_uncond\": 2.1936766271689755e-05}, {\"x\": 8.26086956521739, \"y\": -6.231884057971014, \"x2\": 8.550724637681158, \"y2\": -5.942028985507246, \"center_x\": 8.405797101449274, \"center_y\": -6.08695652173913, \"value_uncond\": 1.921335355435446e-05}, {\"x\": 8.55072463768116, \"y\": -6.231884057971014, \"x2\": 8.840579710144928, \"y2\": -5.942028985507246, \"center_x\": 8.695652173913043, \"center_y\": -6.08695652173913, \"value_uncond\": 1.6671687284283626e-05}, {\"x\": 8.84057971014493, \"y\": -6.231884057971014, \"x2\": 9.130434782608697, \"y2\": -5.942028985507246, \"center_x\": 8.985507246376812, \"center_y\": -6.08695652173913, \"value_uncond\": 1.4331833399382685e-05}, {\"x\": 9.130434782608695, \"y\": -6.231884057971014, \"x2\": 9.420289855072463, \"y2\": -5.942028985507246, \"center_x\": 9.275362318840578, \"center_y\": -6.08695652173913, \"value_uncond\": 1.2205898695619978e-05}, {\"x\": 9.420289855072465, \"y\": -6.231884057971014, \"x2\": 9.710144927536232, \"y2\": -5.942028985507246, \"center_x\": 9.565217391304348, \"center_y\": -6.08695652173913, \"value_uncond\": 1.0298727944401408e-05}, {\"x\": 9.710144927536234, \"y\": -6.231884057971014, \"x2\": 10.000000000000002, \"y2\": -5.942028985507246, \"center_x\": 9.855072463768117, \"center_y\": -6.08695652173913, \"value_uncond\": 8.608812023840343e-06}, {\"x\": 10.0, \"y\": -6.231884057971014, \"x2\": 10.289855072463768, \"y2\": -5.942028985507246, \"center_x\": 10.144927536231883, \"center_y\": -6.08695652173913, \"value_uncond\": 7.1293293601746525e-06}, {\"x\": -10.0, \"y\": -5.942028985507246, \"x2\": -9.710144927536232, \"y2\": -5.6521739130434785, \"center_x\": -9.855072463768117, \"center_y\": -5.797101449275362, \"value_uncond\": 1.360626540139841e-09}, {\"x\": -9.710144927536232, \"y\": -5.942028985507246, \"x2\": -9.420289855072465, \"y2\": -5.6521739130434785, \"center_x\": -9.565217391304348, \"center_y\": -5.797101449275362, \"value_uncond\": 2.125832307302315e-09}, {\"x\": -9.420289855072463, \"y\": -5.942028985507246, \"x2\": -9.130434782608695, \"y2\": -5.6521739130434785, \"center_x\": -9.275362318840578, \"center_y\": -5.797101449275362, \"value_uncond\": 3.290522634026223e-09}, {\"x\": -9.130434782608695, \"y\": -5.942028985507246, \"x2\": -8.840579710144928, \"y2\": -5.6521739130434785, \"center_x\": -8.985507246376812, \"center_y\": -5.797101449275362, \"value_uncond\": 5.045992219261586e-09}, {\"x\": -8.840579710144928, \"y\": -5.942028985507246, \"x2\": -8.55072463768116, \"y2\": -5.6521739130434785, \"center_x\": -8.695652173913043, \"center_y\": -5.797101449275362, \"value_uncond\": 7.666093027948395e-09}, {\"x\": -8.55072463768116, \"y\": -5.942028985507246, \"x2\": -8.260869565217392, \"y2\": -5.6521739130434785, \"center_x\": -8.405797101449277, \"center_y\": -5.797101449275362, \"value_uncond\": 1.153844829399938e-08}, {\"x\": -8.26086956521739, \"y\": -5.942028985507246, \"x2\": -7.971014492753623, \"y2\": -5.6521739130434785, \"center_x\": -8.115942028985508, \"center_y\": -5.797101449275362, \"value_uncond\": 1.720547020682608e-08}, {\"x\": -7.971014492753623, \"y\": -5.942028985507246, \"x2\": -7.681159420289855, \"y2\": -5.6521739130434785, \"center_x\": -7.826086956521739, \"center_y\": -5.797101449275362, \"value_uncond\": 2.5417421920698242e-08}, {\"x\": -7.681159420289855, \"y\": -5.942028985507246, \"x2\": -7.391304347826088, \"y2\": -5.6521739130434785, \"center_x\": -7.536231884057972, \"center_y\": -5.797101449275362, \"value_uncond\": 3.719994218235569e-08}, {\"x\": -7.391304347826087, \"y\": -5.942028985507246, \"x2\": -7.101449275362319, \"y2\": -5.6521739130434785, \"center_x\": -7.246376811594203, \"center_y\": -5.797101449275362, \"value_uncond\": 5.3938497688053776e-08}, {\"x\": -7.101449275362318, \"y\": -5.942028985507246, \"x2\": -6.811594202898551, \"y2\": -5.6521739130434785, \"center_x\": -6.956521739130435, \"center_y\": -5.797101449275362, \"value_uncond\": 7.748207486387541e-08}, {\"x\": -6.811594202898551, \"y\": -5.942028985507246, \"x2\": -6.521739130434783, \"y2\": -5.6521739130434785, \"center_x\": -6.666666666666667, \"center_y\": -5.797101449275362, \"value_uncond\": 1.1026798852770564e-07}, {\"x\": -6.521739130434782, \"y\": -5.942028985507246, \"x2\": -6.231884057971015, \"y2\": -5.6521739130434785, \"center_x\": -6.3768115942028984, \"center_y\": -5.797101449275362, \"value_uncond\": 1.5546888264731687e-07}, {\"x\": -6.231884057971014, \"y\": -5.942028985507246, \"x2\": -5.942028985507246, \"y2\": -5.6521739130434785, \"center_x\": -6.08695652173913, \"center_y\": -5.797101449275362, \"value_uncond\": 2.1716174199835867e-07}, {\"x\": -5.942028985507246, \"y\": -5.942028985507246, \"x2\": -5.6521739130434785, \"y2\": -5.6521739130434785, \"center_x\": -5.797101449275362, \"center_y\": -5.797101449275362, \"value_uncond\": 3.0051694882366615e-07}, {\"x\": -5.6521739130434785, \"y\": -5.942028985507246, \"x2\": -5.362318840579711, \"y2\": -5.6521739130434785, \"center_x\": -5.507246376811595, \"center_y\": -5.797101449275362, \"value_uncond\": 4.1200305780714903e-07}, {\"x\": -5.36231884057971, \"y\": -5.942028985507246, \"x2\": -5.072463768115942, \"y2\": -5.6521739130434785, \"center_x\": -5.217391304347826, \"center_y\": -5.797101449275362, \"value_uncond\": 5.596000213279511e-07}, {\"x\": -5.0724637681159415, \"y\": -5.942028985507246, \"x2\": -4.782608695652174, \"y2\": -5.6521739130434785, \"center_x\": -4.927536231884058, \"center_y\": -5.797101449275362, \"value_uncond\": 7.530101323012316e-07}, {\"x\": -4.782608695652174, \"y\": -5.942028985507246, \"x2\": -4.492753623188406, \"y2\": -5.6521739130434785, \"center_x\": -4.63768115942029, \"center_y\": -5.797101449275362, \"value_uncond\": 1.0038521006927966e-06}, {\"x\": -4.492753623188405, \"y\": -5.942028985507246, \"x2\": -4.202898550724638, \"y2\": -5.6521739130434785, \"center_x\": -4.3478260869565215, \"center_y\": -5.797101449275362, \"value_uncond\": 1.325819672678501e-06}, {\"x\": -4.202898550724638, \"y\": -5.942028985507246, \"x2\": -3.91304347826087, \"y2\": -5.6521739130434785, \"center_x\": -4.057971014492754, \"center_y\": -5.797101449275362, \"value_uncond\": 1.7347823706825448e-06}, {\"x\": -3.913043478260869, \"y\": -5.942028985507246, \"x2\": -3.6231884057971016, \"y2\": -5.6521739130434785, \"center_x\": -3.7681159420289854, \"center_y\": -5.797101449275362, \"value_uncond\": 2.248802709485845e-06}, {\"x\": -3.6231884057971016, \"y\": -5.942028985507246, \"x2\": -3.333333333333334, \"y2\": -5.6521739130434785, \"center_x\": -3.4782608695652177, \"center_y\": -5.797101449275362, \"value_uncond\": 2.8880421423950747e-06}, {\"x\": -3.333333333333333, \"y\": -5.942028985507246, \"x2\": -3.0434782608695654, \"y2\": -5.6521739130434785, \"center_x\": -3.1884057971014492, \"center_y\": -5.797101449275362, \"value_uncond\": 3.674527576762701e-06}, {\"x\": -3.0434782608695645, \"y\": -5.942028985507246, \"x2\": -2.753623188405797, \"y2\": -5.6521739130434785, \"center_x\": -2.8985507246376807, \"center_y\": -5.797101449275362, \"value_uncond\": 4.631752135717058e-06}, {\"x\": -2.753623188405797, \"y\": -5.942028985507246, \"x2\": -2.4637681159420293, \"y2\": -5.6521739130434785, \"center_x\": -2.608695652173913, \"center_y\": -5.797101449275362, \"value_uncond\": 5.7840884344633715e-06}, {\"x\": -2.4637681159420284, \"y\": -5.942028985507246, \"x2\": -2.1739130434782608, \"y2\": -5.6521739130434785, \"center_x\": -2.3188405797101446, \"center_y\": -5.797101449275362, \"value_uncond\": 7.15600034546198e-06}, {\"x\": -2.1739130434782608, \"y\": -5.942028985507246, \"x2\": -1.8840579710144931, \"y2\": -5.6521739130434785, \"center_x\": -2.028985507246377, \"center_y\": -5.797101449275362, \"value_uncond\": 8.771050184586184e-06}, {\"x\": -1.8840579710144922, \"y\": -5.942028985507246, \"x2\": -1.5942028985507246, \"y2\": -5.6521739130434785, \"center_x\": -1.7391304347826084, \"center_y\": -5.797101449275362, \"value_uncond\": 1.0650712297128669e-05}, {\"x\": -1.5942028985507246, \"y\": -5.942028985507246, \"x2\": -1.304347826086957, \"y2\": -5.6521739130434785, \"center_x\": -1.4492753623188408, \"center_y\": -5.797101449275362, \"value_uncond\": 1.2813020634373129e-05}, {\"x\": -1.304347826086957, \"y\": -5.942028985507246, \"x2\": -1.0144927536231894, \"y2\": -5.6521739130434785, \"center_x\": -1.1594202898550732, \"center_y\": -5.797101449275362, \"value_uncond\": 1.5271096171697562e-05}, {\"x\": -1.0144927536231876, \"y\": -5.942028985507246, \"x2\": -0.72463768115942, \"y2\": -5.6521739130434785, \"center_x\": -0.8695652173913038, \"center_y\": -5.797101449275362, \"value_uncond\": 1.8031618627010143e-05}, {\"x\": -0.72463768115942, \"y\": -5.942028985507246, \"x2\": -0.43478260869565233, \"y2\": -5.6521739130434785, \"center_x\": -0.5797101449275361, \"center_y\": -5.797101449275362, \"value_uncond\": 2.1093324266478302e-05}, {\"x\": -0.43478260869565233, \"y\": -5.942028985507246, \"x2\": -0.1449275362318847, \"y2\": -5.6521739130434785, \"center_x\": -0.2898550724637685, \"center_y\": -5.797101449275362, \"value_uncond\": 2.4445625789593858e-05}, {\"x\": -0.14492753623188293, \"y\": -5.942028985507246, \"x2\": 0.1449275362318847, \"y2\": -5.6521739130434785, \"center_x\": 8.881784197001252e-16, \"center_y\": -5.797101449275362, \"value_uncond\": 2.80674594679753e-05}, {\"x\": 0.1449275362318847, \"y\": -5.942028985507246, \"x2\": 0.43478260869565233, \"y2\": -5.6521739130434785, \"center_x\": 0.2898550724637685, \"center_y\": -5.797101449275362, \"value_uncond\": 3.192646711486255e-05}, {\"x\": 0.43478260869565233, \"y\": -5.942028985507246, \"x2\": 0.72463768115942, \"y2\": -5.6521739130434785, \"center_x\": 0.5797101449275361, \"center_y\": -5.797101449275362, \"value_uncond\": 3.5978614689945916e-05}, {\"x\": 0.72463768115942, \"y\": -5.942028985507246, \"x2\": 1.0144927536231876, \"y2\": -5.6521739130434785, \"center_x\": 0.8695652173913038, \"center_y\": -5.797101449275362, \"value_uncond\": 4.0168334579425016e-05}, {\"x\": 1.0144927536231894, \"y\": -5.942028985507246, \"x2\": 1.304347826086957, \"y2\": -5.6521739130434785, \"center_x\": 1.1594202898550732, \"center_y\": -5.797101449275362, \"value_uncond\": 4.442925477702533e-05}, {\"x\": 1.304347826086957, \"y\": -5.942028985507246, \"x2\": 1.5942028985507246, \"y2\": -5.6521739130434785, \"center_x\": 1.4492753623188408, \"center_y\": -5.797101449275362, \"value_uncond\": 4.8685546153544873e-05}, {\"x\": 1.5942028985507246, \"y\": -5.942028985507246, \"x2\": 1.8840579710144922, \"y2\": -5.6521739130434785, \"center_x\": 1.7391304347826084, \"center_y\": -5.797101449275362, \"value_uncond\": 5.285388048410381e-05}, {\"x\": 1.884057971014494, \"y\": -5.942028985507246, \"x2\": 2.1739130434782616, \"y2\": -5.6521739130434785, \"center_x\": 2.028985507246378, \"center_y\": -5.797101449275362, \"value_uncond\": 5.684594949875671e-05}, {\"x\": 2.1739130434782616, \"y\": -5.942028985507246, \"x2\": 2.4637681159420293, \"y2\": -5.6521739130434785, \"center_x\": 2.3188405797101455, \"center_y\": -5.797101449275362, \"value_uncond\": 6.057145220543583e-05}, {\"x\": 2.4637681159420293, \"y\": -5.942028985507246, \"x2\": 2.753623188405797, \"y2\": -5.6521739130434785, \"center_x\": 2.608695652173913, \"center_y\": -5.797101449275362, \"value_uncond\": 6.394141777973059e-05}, {\"x\": 2.753623188405797, \"y\": -5.942028985507246, \"x2\": 3.0434782608695645, \"y2\": -5.6521739130434785, \"center_x\": 2.8985507246376807, \"center_y\": -5.797101449275362, \"value_uncond\": 6.687169815402376e-05}, {\"x\": 3.0434782608695663, \"y\": -5.942028985507246, \"x2\": 3.333333333333334, \"y2\": -5.6521739130434785, \"center_x\": 3.18840579710145, \"center_y\": -5.797101449275362, \"value_uncond\": 6.928644146605207e-05}, {\"x\": 3.333333333333334, \"y\": -5.942028985507246, \"x2\": 3.6231884057971016, \"y2\": -5.6521739130434785, \"center_x\": 3.4782608695652177, \"center_y\": -5.797101449275362, \"value_uncond\": 7.112134742511759e-05}, {\"x\": 3.6231884057971016, \"y\": -5.942028985507246, \"x2\": 3.913043478260869, \"y2\": -5.6521739130434785, \"center_x\": 3.7681159420289854, \"center_y\": -5.797101449275362, \"value_uncond\": 7.232651005819936e-05}, {\"x\": 3.913043478260871, \"y\": -5.942028985507246, \"x2\": 4.202898550724639, \"y2\": -5.6521739130434785, \"center_x\": 4.057971014492755, \"center_y\": -5.797101449275362, \"value_uncond\": 7.28686725648786e-05}, {\"x\": 4.202898550724639, \"y\": -5.942028985507246, \"x2\": 4.492753623188406, \"y2\": -5.6521739130434785, \"center_x\": 4.347826086956522, \"center_y\": -5.797101449275362, \"value_uncond\": 7.273275211643228e-05}, {\"x\": 4.492753623188406, \"y\": -5.942028985507246, \"x2\": 4.782608695652174, \"y2\": -5.6521739130434785, \"center_x\": 4.63768115942029, \"center_y\": -5.797101449275362, \"value_uncond\": 7.192253702740012e-05}, {\"x\": 4.782608695652174, \"y\": -5.942028985507246, \"x2\": 5.0724637681159415, \"y2\": -5.6521739130434785, \"center_x\": 4.927536231884058, \"center_y\": -5.797101449275362, \"value_uncond\": 7.046051132351661e-05}, {\"x\": 5.072463768115943, \"y\": -5.942028985507246, \"x2\": 5.362318840579711, \"y2\": -5.6521739130434785, \"center_x\": 5.217391304347827, \"center_y\": -5.797101449275362, \"value_uncond\": 6.838681804450433e-05}, {\"x\": 5.362318840579711, \"y\": -5.942028985507246, \"x2\": 5.6521739130434785, \"y2\": -5.6521739130434785, \"center_x\": 5.507246376811595, \"center_y\": -5.797101449275362, \"value_uncond\": 6.575742799552855e-05}, {\"x\": 5.6521739130434785, \"y\": -5.942028985507246, \"x2\": 5.942028985507246, \"y2\": -5.6521739130434785, \"center_x\": 5.797101449275362, \"center_y\": -5.797101449275362, \"value_uncond\": 6.26416305336118e-05}, {\"x\": 5.942028985507246, \"y\": -5.942028985507246, \"x2\": 6.231884057971014, \"y2\": -5.6521739130434785, \"center_x\": 6.08695652173913, \"center_y\": -5.797101449275362, \"value_uncond\": 5.911900333454195e-05}, {\"x\": 6.2318840579710155, \"y\": -5.942028985507246, \"x2\": 6.521739130434783, \"y2\": -5.6521739130434785, \"center_x\": 6.376811594202899, \"center_y\": -5.797101449275362, \"value_uncond\": 5.5276045867132e-05}, {\"x\": 6.521739130434785, \"y\": -5.942028985507246, \"x2\": 6.8115942028985526, \"y2\": -5.6521739130434785, \"center_x\": 6.666666666666669, \"center_y\": -5.797101449275362, \"value_uncond\": 5.12026746682202e-05}, {\"x\": 6.811594202898551, \"y\": -5.942028985507246, \"x2\": 7.101449275362318, \"y2\": -5.6521739130434785, \"center_x\": 6.956521739130435, \"center_y\": -5.797101449275362, \"value_uncond\": 4.698877699526274e-05}, {\"x\": 7.10144927536232, \"y\": -5.942028985507246, \"x2\": 7.391304347826088, \"y2\": -5.6521739130434785, \"center_x\": 7.246376811594204, \"center_y\": -5.797101449275362, \"value_uncond\": 4.27210039220419e-05}, {\"x\": 7.391304347826086, \"y\": -5.942028985507246, \"x2\": 7.681159420289854, \"y2\": -5.6521739130434785, \"center_x\": 7.53623188405797, \"center_y\": -5.797101449275362, \"value_uncond\": 3.8479956524746164e-05}, {\"x\": 7.681159420289855, \"y\": -5.942028985507246, \"x2\": 7.971014492753623, \"y2\": -5.6521739130434785, \"center_x\": 7.826086956521739, \"center_y\": -5.797101449275362, \"value_uncond\": 3.43378824915426e-05}, {\"x\": 7.971014492753625, \"y\": -5.942028985507246, \"x2\": 8.260869565217392, \"y2\": -5.6521739130434785, \"center_x\": 8.115942028985508, \"center_y\": -5.797101449275362, \"value_uncond\": 3.035695885638976e-05}, {\"x\": 8.26086956521739, \"y\": -5.942028985507246, \"x2\": 8.550724637681158, \"y2\": -5.6521739130434785, \"center_x\": 8.405797101449274, \"center_y\": -5.797101449275362, \"value_uncond\": 2.658819336082033e-05}, {\"x\": 8.55072463768116, \"y\": -5.942028985507246, \"x2\": 8.840579710144928, \"y2\": -5.6521739130434785, \"center_x\": 8.695652173913043, \"center_y\": -5.797101449275362, \"value_uncond\": 2.3070935738087277e-05}, {\"x\": 8.84057971014493, \"y\": -5.942028985507246, \"x2\": 9.130434782608697, \"y2\": -5.6521739130434785, \"center_x\": 8.985507246376812, \"center_y\": -5.797101449275362, \"value_uncond\": 1.9832954021266523e-05}, {\"x\": 9.130434782608695, \"y\": -5.942028985507246, \"x2\": 9.420289855072463, \"y2\": -5.6521739130434785, \"center_x\": 9.275362318840578, \"center_y\": -5.797101449275362, \"value_uncond\": 1.6891002070181413e-05}, {\"x\": 9.420289855072465, \"y\": -5.942028985507246, \"x2\": 9.710144927536232, \"y2\": -5.6521739130434785, \"center_x\": 9.565217391304348, \"center_y\": -5.797101449275362, \"value_uncond\": 1.425178426980903e-05}, {\"x\": 9.710144927536234, \"y\": -5.942028985507246, \"x2\": 10.000000000000002, \"y2\": -5.6521739130434785, \"center_x\": 9.855072463768117, \"center_y\": -5.797101449275362, \"value_uncond\": 1.191321223800342e-05}, {\"x\": 10.0, \"y\": -5.942028985507246, \"x2\": 10.289855072463768, \"y2\": -5.6521739130434785, \"center_x\": 10.144927536231883, \"center_y\": -5.797101449275362, \"value_uncond\": 9.865846013036942e-06}, {\"x\": -10.0, \"y\": -5.6521739130434785, \"x2\": -9.710144927536232, \"y2\": -5.362318840579711, \"center_x\": -9.855072463768117, \"center_y\": -5.507246376811595, \"value_uncond\": 1.8653932740416187e-09}, {\"x\": -9.710144927536232, \"y\": -5.6521739130434785, \"x2\": -9.420289855072465, \"y2\": -5.362318840579711, \"center_x\": -9.565217391304348, \"center_y\": -5.507246376811595, \"value_uncond\": 2.9144759203172313e-09}, {\"x\": -9.420289855072463, \"y\": -5.6521739130434785, \"x2\": -9.130434782608695, \"y2\": -5.362318840579711, \"center_x\": -9.275362318840578, \"center_y\": -5.507246376811595, \"value_uncond\": 4.511244348477409e-09}, {\"x\": -9.130434782608695, \"y\": -5.6521739130434785, \"x2\": -8.840579710144928, \"y2\": -5.362318840579711, \"center_x\": -8.985507246376812, \"center_y\": -5.507246376811595, \"value_uncond\": 6.917959975784015e-09}, {\"x\": -8.840579710144928, \"y\": -5.6521739130434785, \"x2\": -8.55072463768116, \"y2\": -5.362318840579711, \"center_x\": -8.695652173913043, \"center_y\": -5.507246376811595, \"value_uncond\": 1.05100686710422e-08}, {\"x\": -8.55072463768116, \"y\": -5.6521739130434785, \"x2\": -8.260869565217392, \"y2\": -5.362318840579711, \"center_x\": -8.405797101449277, \"center_y\": -5.507246376811595, \"value_uncond\": 1.5818994562821986e-08}, {\"x\": -8.26086956521739, \"y\": -5.6521739130434785, \"x2\": -7.971014492753623, \"y2\": -5.362318840579711, \"center_x\": -8.115942028985508, \"center_y\": -5.507246376811595, \"value_uncond\": 2.358837451255229e-08}, {\"x\": -7.971014492753623, \"y\": -5.6521739130434785, \"x2\": -7.681159420289855, \"y2\": -5.362318840579711, \"center_x\": -7.826086956521739, \"center_y\": -5.507246376811595, \"value_uncond\": 3.484680512661137e-08}, {\"x\": -7.681159420289855, \"y\": -5.6521739130434785, \"x2\": -7.391304347826088, \"y2\": -5.362318840579711, \"center_x\": -7.536231884057972, \"center_y\": -5.507246376811595, \"value_uncond\": 5.100041774473357e-08}, {\"x\": -7.391304347826087, \"y\": -5.6521739130434785, \"x2\": -7.101449275362319, \"y2\": -5.362318840579711, \"center_x\": -7.246376811594203, \"center_y\": -5.507246376811595, \"value_uncond\": 7.394866102557714e-08}, {\"x\": -7.101449275362318, \"y\": -5.6521739130434785, \"x2\": -6.811594202898551, \"y2\": -5.362318840579711, \"center_x\": -6.956521739130435, \"center_y\": -5.507246376811595, \"value_uncond\": 1.062264604180127e-07}, {\"x\": -6.811594202898551, \"y\": -5.6521739130434785, \"x2\": -6.521739130434783, \"y2\": -5.362318840579711, \"center_x\": -6.666666666666667, \"center_y\": -5.507246376811595, \"value_uncond\": 1.5117532847811418e-07}, {\"x\": -6.521739130434782, \"y\": -5.6521739130434785, \"x2\": -6.231884057971015, \"y2\": -5.362318840579711, \"center_x\": -6.3768115942028984, \"center_y\": -5.507246376811595, \"value_uncond\": 2.131449001305415e-07}, {\"x\": -6.231884057971014, \"y\": -5.6521739130434785, \"x2\": -5.942028985507246, \"y2\": -5.362318840579711, \"center_x\": -6.08695652173913, \"center_y\": -5.507246376811595, \"value_uncond\": 2.977246444577404e-07}, {\"x\": -5.942028985507246, \"y\": -5.6521739130434785, \"x2\": -5.6521739130434785, \"y2\": -5.362318840579711, \"center_x\": -5.797101449275362, \"center_y\": -5.507246376811595, \"value_uncond\": 4.1200305780714903e-07}, {\"x\": -5.6521739130434785, \"y\": -5.6521739130434785, \"x2\": -5.362318840579711, \"y2\": -5.362318840579711, \"center_x\": -5.507246376811595, \"center_y\": -5.507246376811595, \"value_uncond\": 5.648484064106578e-07}, {\"x\": -5.36231884057971, \"y\": -5.6521739130434785, \"x2\": -5.072463768115942, \"y2\": -5.362318840579711, \"center_x\": -5.217391304347826, \"center_y\": -5.507246376811595, \"value_uncond\": 7.672010541786288e-07}, {\"x\": -5.0724637681159415, \"y\": -5.6521739130434785, \"x2\": -4.782608695652174, \"y2\": -5.362318840579711, \"center_x\": -4.927536231884058, \"center_y\": -5.507246376811595, \"value_uncond\": 1.032362661348308e-06}, {\"x\": -4.782608695652174, \"y\": -5.6521739130434785, \"x2\": -4.492753623188406, \"y2\": -5.362318840579711, \"center_x\": -4.63768115942029, \"center_y\": -5.507246376811595, \"value_uncond\": 1.3762622597178169e-06}, {\"x\": -4.492753623188405, \"y\": -5.6521739130434785, \"x2\": -4.202898550724638, \"y2\": -5.362318840579711, \"center_x\": -4.3478260869565215, \"center_y\": -5.507246376811595, \"value_uncond\": 1.81767371651618e-06}, {\"x\": -4.202898550724638, \"y\": -5.6521739130434785, \"x2\": -3.91304347826087, \"y2\": -5.362318840579711, \"center_x\": -4.057971014492754, \"center_y\": -5.507246376811595, \"value_uncond\": 2.3783538470920915e-06}, {\"x\": -3.913043478260869, \"y\": -5.6521739130434785, \"x2\": -3.6231884057971016, \"y2\": -5.362318840579711, \"center_x\": -3.7681159420289854, \"center_y\": -5.507246376811595, \"value_uncond\": 3.0830660178731517e-06}, {\"x\": -3.6231884057971016, \"y\": -5.6521739130434785, \"x2\": -3.333333333333334, \"y2\": -5.362318840579711, \"center_x\": -3.4782608695652177, \"center_y\": -5.507246376811595, \"value_uncond\": 3.959451200341003e-06}, {\"x\": -3.333333333333333, \"y\": -5.6521739130434785, \"x2\": -3.0434782608695654, \"y2\": -5.362318840579711, \"center_x\": -3.1884057971014492, \"center_y\": -5.507246376811595, \"value_uncond\": 5.037707868221586e-06}, {\"x\": -3.0434782608695645, \"y\": -5.6521739130434785, \"x2\": -2.753623188405797, \"y2\": -5.362318840579711, \"center_x\": -2.8985507246376807, \"center_y\": -5.507246376811595, \"value_uncond\": 6.350044649361683e-06}, {\"x\": -2.753623188405797, \"y\": -5.6521739130434785, \"x2\": -2.4637681159420293, \"y2\": -5.362318840579711, \"center_x\": -2.608695652173913, \"center_y\": -5.507246376811595, \"value_uncond\": 7.92987593862528e-06}, {\"x\": -2.4637681159420284, \"y\": -5.6521739130434785, \"x2\": -2.1739130434782608, \"y2\": -5.362318840579711, \"center_x\": -2.3188405797101446, \"center_y\": -5.507246376811595, \"value_uncond\": 9.810741242848559e-06}, {\"x\": -2.1739130434782608, \"y\": -5.6521739130434785, \"x2\": -1.8840579710144931, \"y2\": -5.362318840579711, \"center_x\": -2.028985507246377, \"center_y\": -5.507246376811595, \"value_uncond\": 1.2024944051824084e-05}, {\"x\": -1.8840579710144922, \"y\": -5.6521739130434785, \"x2\": -1.5942028985507246, \"y2\": -5.362318840579711, \"center_x\": -1.7391304347826084, \"center_y\": -5.507246376811595, \"value_uncond\": 1.4601925287135904e-05}, {\"x\": -1.5942028985507246, \"y\": -5.6521739130434785, \"x2\": -1.304347826086957, \"y2\": -5.362318840579711, \"center_x\": -1.4492753623188408, \"center_y\": -5.507246376811595, \"value_uncond\": 1.7566409155196697e-05}, {\"x\": -1.304347826086957, \"y\": -5.6521739130434785, \"x2\": -1.0144927536231894, \"y2\": -5.362318840579711, \"center_x\": -1.1594202898550732, \"center_y\": -5.507246376811595, \"value_uncond\": 2.0936384265295586e-05}, {\"x\": -1.0144927536231876, \"y\": -5.6521739130434785, \"x2\": -0.72463768115942, \"y2\": -5.362318840579711, \"center_x\": -0.8695652173913038, \"center_y\": -5.507246376811595, \"value_uncond\": 2.4721008384454473e-05}, {\"x\": -0.72463768115942, \"y\": -5.6521739130434785, \"x2\": -0.43478260869565233, \"y2\": -5.362318840579711, \"center_x\": -0.5797101449275361, \"center_y\": -5.507246376811595, \"value_uncond\": 2.8918548957470345e-05}, {\"x\": -0.43478260869565233, \"y\": -5.6521739130434785, \"x2\": -0.1449275362318847, \"y2\": -5.362318840579711, \"center_x\": -0.2898550724637685, \"center_y\": -5.507246376811595, \"value_uncond\": 3.3514490995420406e-05}, {\"x\": -0.14492753623188293, \"y\": -5.6521739130434785, \"x2\": 0.1449275362318847, \"y2\": -5.362318840579711, \"center_x\": 8.881784197001252e-16, \"center_y\": -5.507246376811595, \"value_uncond\": 3.8479956524746164e-05}, {\"x\": 0.1449275362318847, \"y\": -5.6521739130434785, \"x2\": 0.43478260869565233, \"y2\": -5.362318840579711, \"center_x\": 0.2898550724637685, \"center_y\": -5.507246376811595, \"value_uncond\": 4.37705830828896e-05}, {\"x\": 0.43478260869565233, \"y\": -5.6521739130434785, \"x2\": 0.72463768115942, \"y2\": -5.362318840579711, \"center_x\": 0.5797101449275361, \"center_y\": -5.507246376811595, \"value_uncond\": 4.932600083272101e-05}, {\"x\": 0.72463768115942, \"y\": -5.6521739130434785, \"x2\": 1.0144927536231876, \"y2\": -5.362318840579711, \"center_x\": 0.8695652173913038, \"center_y\": -5.507246376811595, \"value_uncond\": 5.507002762581109e-05}, {\"x\": 1.0144927536231894, \"y\": -5.6521739130434785, \"x2\": 1.304347826086957, \"y2\": -5.362318840579711, \"center_x\": 1.1594202898550732, \"center_y\": -5.507246376811595, \"value_uncond\": 6.09116686958249e-05}, {\"x\": 1.304347826086957, \"y\": -5.6521739130434785, \"x2\": 1.5942028985507246, \"y2\": -5.362318840579711, \"center_x\": 1.4492753623188408, \"center_y\": -5.507246376811595, \"value_uncond\": 6.674696373961032e-05}, {\"x\": 1.5942028985507246, \"y\": -5.6521739130434785, \"x2\": 1.8840579710144922, \"y2\": -5.362318840579711, \"center_x\": 1.7391304347826084, \"center_y\": -5.507246376811595, \"value_uncond\": 7.246167133555524e-05}, {\"x\": 1.884057971014494, \"y\": -5.6521739130434785, \"x2\": 2.1739130434782616, \"y2\": -5.362318840579711, \"center_x\": 2.028985507246378, \"center_y\": -5.507246376811595, \"value_uncond\": 7.793472251437328e-05}, {\"x\": 2.1739130434782616, \"y\": -5.6521739130434785, \"x2\": 2.4637681159420293, \"y2\": -5.362318840579711, \"center_x\": 2.3188405797101455, \"center_y\": -5.507246376811595, \"value_uncond\": 8.304231632240589e-05}, {\"x\": 2.4637681159420293, \"y\": -5.6521739130434785, \"x2\": 2.753623188405797, \"y2\": -5.362318840579711, \"center_x\": 2.608695652173913, \"center_y\": -5.507246376811595, \"value_uncond\": 8.766247544071558e-05}, {\"x\": 2.753623188405797, \"y\": -5.6521739130434785, \"x2\": 3.0434782608695645, \"y2\": -5.362318840579711, \"center_x\": 2.8985507246376807, \"center_y\": -5.507246376811595, \"value_uncond\": 9.167983445879034e-05}, {\"x\": 3.0434782608695663, \"y\": -5.6521739130434785, \"x2\": 3.333333333333334, \"y2\": -5.362318840579711, \"center_x\": 3.18840579710145, \"center_y\": -5.507246376811595, \"value_uncond\": 9.499040190688058e-05}, {\"x\": 3.333333333333334, \"y\": -5.6521739130434785, \"x2\": 3.6231884057971016, \"y2\": -5.362318840579711, \"center_x\": 3.4782608695652177, \"center_y\": -5.507246376811595, \"value_uncond\": 9.75060233015565e-05}, {\"x\": 3.6231884057971016, \"y\": -5.6521739130434785, \"x2\": 3.913043478260869, \"y2\": -5.362318840579711, \"center_x\": 3.7681159420289854, \"center_y\": -5.507246376811595, \"value_uncond\": 9.91582784969064e-05}, {\"x\": 3.913043478260871, \"y\": -5.6521739130434785, \"x2\": 4.202898550724639, \"y2\": -5.362318840579711, \"center_x\": 4.057971014492755, \"center_y\": -5.507246376811595, \"value_uncond\": 9.990157304802774e-05}, {\"x\": 4.202898550724639, \"y\": -5.6521739130434785, \"x2\": 4.492753623188406, \"y2\": -5.362318840579711, \"center_x\": 4.347826086956522, \"center_y\": -5.507246376811595, \"value_uncond\": 9.971522868176951e-05}, {\"x\": 4.492753623188406, \"y\": -5.6521739130434785, \"x2\": 4.782608695652174, \"y2\": -5.362318840579711, \"center_x\": 4.63768115942029, \"center_y\": -5.507246376811595, \"value_uncond\": 9.860443910577588e-05}, {\"x\": 4.782608695652174, \"y\": -5.6521739130434785, \"x2\": 5.0724637681159415, \"y2\": -5.362318840579711, \"center_x\": 4.927536231884058, \"center_y\": -5.507246376811595, \"value_uncond\": 9.66000294944361e-05}, {\"x\": 5.072463768115943, \"y\": -5.6521739130434785, \"x2\": 5.362318840579711, \"y2\": -5.362318840579711, \"center_x\": 5.217391304347827, \"center_y\": -5.507246376811595, \"value_uncond\": 9.37570351966053e-05}, {\"x\": 5.362318840579711, \"y\": -5.6521739130434785, \"x2\": 5.6521739130434785, \"y2\": -5.362318840579711, \"center_x\": 5.507246376811595, \"center_y\": -5.507246376811595, \"value_uncond\": 9.01521911284547e-05}, {\"x\": 5.6521739130434785, \"y\": -5.6521739130434785, \"x2\": 5.942028985507246, \"y2\": -5.362318840579711, \"center_x\": 5.797101449275362, \"center_y\": -5.507246376811595, \"value_uncond\": 8.588049168906403e-05}, {\"x\": 5.942028985507246, \"y\": -5.6521739130434785, \"x2\": 6.231884057971014, \"y2\": -5.362318840579711, \"center_x\": 6.08695652173913, \"center_y\": -5.507246376811595, \"value_uncond\": 8.105103636811636e-05}, {\"x\": 6.2318840579710155, \"y\": -5.6521739130434785, \"x2\": 6.521739130434783, \"y2\": -5.362318840579711, \"center_x\": 6.376811594202899, \"center_y\": -5.507246376811595, \"value_uncond\": 7.578241430272746e-05}, {\"x\": 6.521739130434785, \"y\": -5.6521739130434785, \"x2\": 6.8115942028985526, \"y2\": -5.362318840579711, \"center_x\": 6.666666666666669, \"center_y\": -5.507246376811595, \"value_uncond\": 7.019789936570147e-05}, {\"x\": 6.811594202898551, \"y\": -5.6521739130434785, \"x2\": 7.101449275362318, \"y2\": -5.362318840579711, \"center_x\": 6.956521739130435, \"center_y\": -5.507246376811595, \"value_uncond\": 6.44207252883631e-05}, {\"x\": 7.10144927536232, \"y\": -5.6521739130434785, \"x2\": 7.391304347826088, \"y2\": -5.362318840579711, \"center_x\": 7.246376811594204, \"center_y\": -5.507246376811595, \"value_uncond\": 5.856968905537602e-05}, {\"x\": 7.391304347826086, \"y\": -5.6521739130434785, \"x2\": 7.681159420289854, \"y2\": -5.362318840579711, \"center_x\": 7.53623188405797, \"center_y\": -5.507246376811595, \"value_uncond\": 5.275529321903279e-05}, {\"x\": 7.681159420289855, \"y\": -5.6521739130434785, \"x2\": 7.971014492753623, \"y2\": -5.362318840579711, \"center_x\": 7.826086956521739, \"center_y\": -5.507246376811595, \"value_uncond\": 4.707658799450714e-05}, {\"x\": 7.971014492753625, \"y\": -5.6521739130434785, \"x2\": 8.260869565217392, \"y2\": -5.362318840579711, \"center_x\": 8.115942028985508, \"center_y\": -5.507246376811595, \"value_uncond\": 4.161881692036346e-05}, {\"x\": 8.26086956521739, \"y\": -5.6521739130434785, \"x2\": 8.550724637681158, \"y2\": -5.362318840579711, \"center_x\": 8.405797101449274, \"center_y\": -5.507246376811595, \"value_uncond\": 3.645191064632239e-05}, {\"x\": 8.55072463768116, \"y\": -5.6521739130434785, \"x2\": 8.840579710144928, \"y2\": -5.362318840579711, \"center_x\": 8.695652173913043, \"center_y\": -5.507246376811595, \"value_uncond\": 3.1629816913060714e-05}, {\"x\": 8.84057971014493, \"y\": -5.6521739130434785, \"x2\": 9.130434782608697, \"y2\": -5.362318840579711, \"center_x\": 8.985507246376812, \"center_y\": -5.507246376811595, \"value_uncond\": 2.719060516917808e-05}, {\"x\": 9.130434782608695, \"y\": -5.6521739130434785, \"x2\": 9.420289855072463, \"y2\": -5.362318840579711, \"center_x\": 9.275362318840578, \"center_y\": -5.507246376811595, \"value_uncond\": 2.315724463988563e-05}, {\"x\": 9.420289855072465, \"y\": -5.6521739130434785, \"x2\": 9.710144927536232, \"y2\": -5.362318840579711, \"center_x\": 9.565217391304348, \"center_y\": -5.507246376811595, \"value_uncond\": 1.9538926910290582e-05}, {\"x\": 9.710144927536234, \"y\": -5.6521739130434785, \"x2\": 10.000000000000002, \"y2\": -5.362318840579711, \"center_x\": 9.855072463768117, \"center_y\": -5.507246376811595, \"value_uncond\": 1.6332788847936102e-05}, {\"x\": 10.0, \"y\": -5.6521739130434785, \"x2\": 10.289855072463768, \"y2\": -5.362318840579711, \"center_x\": 10.144927536231883, \"center_y\": -5.507246376811595, \"value_uncond\": 1.3525888443685628e-05}, {\"x\": -10.0, \"y\": -5.36231884057971, \"x2\": -9.710144927536232, \"y2\": -5.072463768115942, \"center_x\": -9.855072463768117, \"center_y\": -5.217391304347826, \"value_uncond\": 2.5336562342392283e-09}, {\"x\": -9.710144927536232, \"y\": -5.36231884057971, \"x2\": -9.420289855072465, \"y2\": -5.072463768115942, \"center_x\": -9.565217391304348, \"center_y\": -5.217391304347826, \"value_uncond\": 3.958564763693418e-09}, {\"x\": -9.420289855072463, \"y\": -5.36231884057971, \"x2\": -9.130434782608695, \"y2\": -5.072463768115942, \"center_x\": -9.275362318840578, \"center_y\": -5.217391304347826, \"value_uncond\": 6.127363343029421e-09}, {\"x\": -9.130434782608695, \"y\": -5.36231884057971, \"x2\": -8.840579710144928, \"y2\": -5.072463768115942, \"center_x\": -8.985507246376812, \"center_y\": -5.217391304347826, \"value_uncond\": 9.396266548601021e-09}, {\"x\": -8.840579710144928, \"y\": -5.36231884057971, \"x2\": -8.55072463768116, \"y2\": -5.072463768115942, \"center_x\": -8.695652173913043, \"center_y\": -5.217391304347826, \"value_uncond\": 1.4275220877672309e-08}, {\"x\": -8.55072463768116, \"y\": -5.36231884057971, \"x2\": -8.260869565217392, \"y2\": -5.072463768115942, \"center_x\": -8.405797101449277, \"center_y\": -5.217391304347826, \"value_uncond\": 2.1486029113127425e-08}, {\"x\": -8.26086956521739, \"y\": -5.36231884057971, \"x2\": -7.971014492753623, \"y2\": -5.072463768115942, \"center_x\": -8.115942028985508, \"center_y\": -5.217391304347826, \"value_uncond\": 3.203873036907085e-08}, {\"x\": -7.971014492753623, \"y\": -5.36231884057971, \"x2\": -7.681159420289855, \"y2\": -5.072463768115942, \"center_x\": -7.826086956521739, \"center_y\": -5.217391304347826, \"value_uncond\": 4.7330408166995674e-08}, {\"x\": -7.681159420289855, \"y\": -5.36231884057971, \"x2\": -7.391304347826088, \"y2\": -5.072463768115942, \"center_x\": -7.536231884057972, \"center_y\": -5.217391304347826, \"value_uncond\": 6.92709297100564e-08}, {\"x\": -7.391304347826087, \"y\": -5.36231884057971, \"x2\": -7.101449275362319, \"y2\": -5.072463768115942, \"center_x\": -7.246376811594203, \"center_y\": -5.217391304347826, \"value_uncond\": 1.0044020669976769e-07}, {\"x\": -7.101449275362318, \"y\": -5.36231884057971, \"x2\": -6.811594202898551, \"y2\": -5.072463768115942, \"center_x\": -6.956521739130435, \"center_y\": -5.217391304347826, \"value_uncond\": 1.442812823572233e-07}, {\"x\": -6.811594202898551, \"y\": -5.36231884057971, \"x2\": -6.521739130434783, \"y2\": -5.072463768115942, \"center_x\": -6.666666666666667, \"center_y\": -5.217391304347826, \"value_uncond\": 2.053327407104132e-07}, {\"x\": -6.521739130434782, \"y\": -5.36231884057971, \"x2\": -6.231884057971015, \"y2\": -5.072463768115942, \"center_x\": -6.3768115942028984, \"center_y\": -5.217391304347826, \"value_uncond\": 2.895024403309789e-07}, {\"x\": -6.231884057971014, \"y\": -5.36231884057971, \"x2\": -5.942028985507246, \"y2\": -5.072463768115942, \"center_x\": -6.08695652173913, \"center_y\": -5.217391304347826, \"value_uncond\": 4.0438223511048235e-07}, {\"x\": -5.942028985507246, \"y\": -5.36231884057971, \"x2\": -5.6521739130434785, \"y2\": -5.072463768115942, \"center_x\": -5.797101449275362, \"center_y\": -5.217391304347826, \"value_uncond\": 5.596000213279511e-07}, {\"x\": -5.6521739130434785, \"y\": -5.36231884057971, \"x2\": -5.362318840579711, \"y2\": -5.072463768115942, \"center_x\": -5.507246376811595, \"center_y\": -5.217391304347826, \"value_uncond\": 7.672010541786288e-07}, {\"x\": -5.36231884057971, \"y\": -5.36231884057971, \"x2\": -5.072463768115942, \"y2\": -5.072463768115942, \"center_x\": -5.217391304347826, \"center_y\": -5.217391304347826, \"value_uncond\": 1.0420449997780032e-06}, {\"x\": -5.0724637681159415, \"y\": -5.36231884057971, \"x2\": -4.782608695652174, \"y2\": -5.072463768115942, \"center_x\": -4.927536231884058, \"center_y\": -5.217391304347826, \"value_uncond\": 1.4021987370275998e-06}, {\"x\": -4.782608695652174, \"y\": -5.36231884057971, \"x2\": -4.492753623188406, \"y2\": -5.072463768115942, \"center_x\": -4.63768115942029, \"center_y\": -5.217391304347826, \"value_uncond\": 1.8692977522789173e-06}, {\"x\": -4.492753623188405, \"y\": -5.36231884057971, \"x2\": -4.202898550724638, \"y2\": -5.072463768115942, \"center_x\": -4.3478260869565215, \"center_y\": -5.217391304347826, \"value_uncond\": 2.4688415079817903e-06}, {\"x\": -4.202898550724638, \"y\": -5.36231884057971, \"x2\": -3.91304347826087, \"y2\": -5.072463768115942, \"center_x\": -4.057971014492754, \"center_y\": -5.217391304347826, \"value_uncond\": 3.230381033194009e-06}, {\"x\": -3.913043478260869, \"y\": -5.36231884057971, \"x2\": -3.6231884057971016, \"y2\": -5.072463768115942, \"center_x\": -3.7681159420289854, \"center_y\": -5.217391304347826, \"value_uncond\": 4.187550982121279e-06}, {\"x\": -3.6231884057971016, \"y\": -5.36231884057971, \"x2\": -3.333333333333334, \"y2\": -5.072463768115942, \"center_x\": -3.4782608695652177, \"center_y\": -5.217391304347826, \"value_uncond\": 5.377894494159164e-06}, {\"x\": -3.333333333333333, \"y\": -5.36231884057971, \"x2\": -3.0434782608695654, \"y2\": -5.072463768115942, \"center_x\": -3.1884057971014492, \"center_y\": -5.217391304347826, \"value_uncond\": 6.842428416685089e-06}, {\"x\": -3.0434782608695645, \"y\": -5.36231884057971, \"x2\": -2.753623188405797, \"y2\": -5.072463768115942, \"center_x\": -2.8985507246376807, \"center_y\": -5.217391304347826, \"value_uncond\": 8.624899873630453e-06}, {\"x\": -2.753623188405797, \"y\": -5.36231884057971, \"x2\": -2.4637681159420293, \"y2\": -5.072463768115942, \"center_x\": -2.608695652173913, \"center_y\": -5.217391304347826, \"value_uncond\": 1.077069371281184e-05}, {\"x\": -2.4637681159420284, \"y\": -5.36231884057971, \"x2\": -2.1739130434782608, \"y2\": -5.072463768115942, \"center_x\": -2.3188405797101446, \"center_y\": -5.217391304347826, \"value_uncond\": 1.3325364714431008e-05}, {\"x\": -2.1739130434782608, \"y\": -5.36231884057971, \"x2\": -1.8840579710144931, \"y2\": -5.072463768115942, \"center_x\": -2.028985507246377, \"center_y\": -5.217391304347826, \"value_uncond\": 1.6332788847936102e-05}, {\"x\": -1.8840579710144922, \"y\": -5.36231884057971, \"x2\": -1.5942028985507246, \"y2\": -5.072463768115942, \"center_x\": -1.7391304347826084, \"center_y\": -5.217391304347826, \"value_uncond\": 1.9832954021266523e-05}, {\"x\": -1.5942028985507246, \"y\": -5.36231884057971, \"x2\": -1.304347826086957, \"y2\": -5.072463768115942, \"center_x\": -1.4492753623188408, \"center_y\": -5.217391304347826, \"value_uncond\": 2.38594416998354e-05}, {\"x\": -1.304347826086957, \"y\": -5.36231884057971, \"x2\": -1.0144927536231894, \"y2\": -5.072463768115942, \"center_x\": -1.1594202898550732, \"center_y\": -5.217391304347826, \"value_uncond\": 2.8436684775465024e-05}, {\"x\": -1.0144927536231876, \"y\": -5.36231884057971, \"x2\": -0.72463768115942, \"y2\": -5.072463768115942, \"center_x\": -0.8695652173913038, \"center_y\": -5.217391304347826, \"value_uncond\": 3.3577121715597955e-05}, {\"x\": -0.72463768115942, \"y\": -5.36231884057971, \"x2\": -0.43478260869565233, \"y2\": -5.072463768115942, \"center_x\": -0.5797101449275361, \"center_y\": -5.217391304347826, \"value_uncond\": 3.927839929030012e-05}, {\"x\": -0.43478260869565233, \"y\": -5.36231884057971, \"x2\": -0.1449275362318847, \"y2\": -5.072463768115942, \"center_x\": -0.2898550724637685, \"center_y\": -5.217391304347826, \"value_uncond\": 4.5520802626206266e-05}, {\"x\": -0.14492753623188293, \"y\": -5.36231884057971, \"x2\": 0.1449275362318847, \"y2\": -5.072463768115942, \"center_x\": 8.881784197001252e-16, \"center_y\": -5.217391304347826, \"value_uncond\": 5.226510843525332e-05}, {\"x\": 0.1449275362318847, \"y\": -5.36231884057971, \"x2\": 0.43478260869565233, \"y2\": -5.072463768115942, \"center_x\": 0.2898550724637685, \"center_y\": -5.217391304347826, \"value_uncond\": 5.9451061739903565e-05}, {\"x\": 0.43478260869565233, \"y\": -5.36231884057971, \"x2\": 0.72463768115942, \"y2\": -5.072463768115942, \"center_x\": 0.5797101449275361, \"center_y\": -5.217391304347826, \"value_uncond\": 6.699666566779119e-05}, {\"x\": 0.72463768115942, \"y\": -5.36231884057971, \"x2\": 1.0144927536231876, \"y2\": -5.072463768115942, \"center_x\": 0.8695652173913038, \"center_y\": -5.217391304347826, \"value_uncond\": 7.47984463949287e-05}, {\"x\": 1.0144927536231894, \"y\": -5.36231884057971, \"x2\": 1.304347826086957, \"y2\": -5.072463768115942, \"center_x\": 1.1594202898550732, \"center_y\": -5.217391304347826, \"value_uncond\": 8.273281097165984e-05}, {\"x\": 1.304347826086957, \"y\": -5.36231884057971, \"x2\": 1.5942028985507246, \"y2\": -5.072463768115942, \"center_x\": 1.4492753623188408, \"center_y\": -5.217391304347826, \"value_uncond\": 9.065855610650711e-05}, {\"x\": 1.5942028985507246, \"y\": -5.36231884057971, \"x2\": 1.8840579710144922, \"y2\": -5.072463768115942, \"center_x\": 1.7391304347826084, \"center_y\": -5.217391304347826, \"value_uncond\": 9.8420514256999e-05}, {\"x\": 1.884057971014494, \"y\": -5.36231884057971, \"x2\": 2.1739130434782616, \"y2\": -5.072463768115942, \"center_x\": 2.028985507246378, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00010585424441593667}, {\"x\": 2.1739130434782616, \"y\": -5.36231884057971, \"x2\": 2.4637681159420293, \"y2\": -5.072463768115942, \"center_x\": 2.3188405797101455, \"center_y\": -5.217391304347826, \"value_uncond\": 0.0001127915948791156}, {\"x\": 2.4637681159420293, \"y\": -5.36231884057971, \"x2\": 2.753623188405797, \"y2\": -5.072463768115942, \"center_x\": 2.608695652173913, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00011906689088032833}, {\"x\": 2.753623188405797, \"y\": -5.36231884057971, \"x2\": 3.0434782608695645, \"y2\": -5.072463768115942, \"center_x\": 2.8985507246376807, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00012452343822772443}, {\"x\": 3.0434782608695663, \"y\": -5.36231884057971, \"x2\": 3.333333333333334, \"y2\": -5.072463768115942, \"center_x\": 3.18840579710145, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00012901999129803215}, {\"x\": 3.333333333333334, \"y\": -5.36231884057971, \"x2\": 3.6231884057971016, \"y2\": -5.072463768115942, \"center_x\": 3.4782608695652177, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00013243681493426023}, {\"x\": 3.6231884057971016, \"y\": -5.36231884057971, \"x2\": 3.913043478260869, \"y2\": -5.072463768115942, \"center_x\": 3.7681159420289854, \"center_y\": -5.217391304347826, \"value_uncond\": 0.0001346809779933359}, {\"x\": 3.913043478260871, \"y\": -5.36231884057971, \"x2\": 4.202898550724639, \"y2\": -5.072463768115942, \"center_x\": 4.057971014492755, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00013569055216706725}, {\"x\": 4.202898550724639, \"y\": -5.36231884057971, \"x2\": 4.492753623188406, \"y2\": -5.072463768115942, \"center_x\": 4.347826086956522, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00013543745134813776}, {\"x\": 4.492753623188406, \"y\": -5.36231884057971, \"x2\": 4.782608695652174, \"y2\": -5.072463768115942, \"center_x\": 4.63768115942029, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00013392872985047388}, {\"x\": 4.782608695652174, \"y\": -5.36231884057971, \"x2\": 5.0724637681159415, \"y2\": -5.072463768115942, \"center_x\": 4.927536231884058, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00013120625573286498}, {\"x\": 5.072463768115943, \"y\": -5.36231884057971, \"x2\": 5.362318840579711, \"y2\": -5.072463768115942, \"center_x\": 5.217391304347827, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00012734478033952931}, {\"x\": 5.362318840579711, \"y\": -5.36231884057971, \"x2\": 5.6521739130434785, \"y2\": -5.072463768115942, \"center_x\": 5.507246376811595, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00012244852828703783}, {\"x\": 5.6521739130434785, \"y\": -5.36231884057971, \"x2\": 5.942028985507246, \"y2\": -5.072463768115942, \"center_x\": 5.797101449275362, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00011664652499581822}, {\"x\": 5.942028985507246, \"y\": -5.36231884057971, \"x2\": 6.231884057971014, \"y2\": -5.072463768115942, \"center_x\": 6.08695652173913, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00011008695401838697}, {\"x\": 6.2318840579710155, \"y\": -5.36231884057971, \"x2\": 6.521739130434783, \"y2\": -5.072463768115942, \"center_x\": 6.376811594202899, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00010293088814874822}, {\"x\": 6.521739130434785, \"y\": -5.36231884057971, \"x2\": 6.8115942028985526, \"y2\": -5.072463768115942, \"center_x\": 6.666666666666669, \"center_y\": -5.217391304347826, \"value_uncond\": 9.534576318754272e-05}, {\"x\": 6.811594202898551, \"y\": -5.36231884057971, \"x2\": 7.101449275362318, \"y2\": -5.072463768115942, \"center_x\": 6.956521739130435, \"center_y\": -5.217391304347826, \"value_uncond\": 8.74989604135519e-05}, {\"x\": 7.10144927536232, \"y\": -5.36231884057971, \"x2\": 7.391304347826088, \"y2\": -5.072463768115942, \"center_x\": 7.246376811594204, \"center_y\": -5.217391304347826, \"value_uncond\": 7.955183492813184e-05}, {\"x\": 7.391304347826086, \"y\": -5.36231884057971, \"x2\": 7.681159420289854, \"y2\": -5.072463768115942, \"center_x\": 7.53623188405797, \"center_y\": -5.217391304347826, \"value_uncond\": 7.165447598292267e-05}, {\"x\": 7.681159420289855, \"y\": -5.36231884057971, \"x2\": 7.971014492753623, \"y2\": -5.072463768115942, \"center_x\": 7.826086956521739, \"center_y\": -5.217391304347826, \"value_uncond\": 6.394141777973048e-05}, {\"x\": 7.971014492753625, \"y\": -5.36231884057971, \"x2\": 8.260869565217392, \"y2\": -5.072463768115942, \"center_x\": 8.115942028985508, \"center_y\": -5.217391304347826, \"value_uncond\": 5.652844170681143e-05}, {\"x\": 8.26086956521739, \"y\": -5.36231884057971, \"x2\": 8.550724637681158, \"y2\": -5.072463768115942, \"center_x\": 8.405797101449274, \"center_y\": -5.217391304347826, \"value_uncond\": 4.9510530537554236e-05}, {\"x\": 8.55072463768116, \"y\": -5.36231884057971, \"x2\": 8.840579710144928, \"y2\": -5.072463768115942, \"center_x\": 8.695652173913043, \"center_y\": -5.217391304347826, \"value_uncond\": 4.296095838063664e-05}, {\"x\": 8.84057971014493, \"y\": -5.36231884057971, \"x2\": 9.130434782608697, \"y2\": -5.072463768115942, \"center_x\": 8.985507246376812, \"center_y\": -5.217391304347826, \"value_uncond\": 3.6931432775225205e-05}, {\"x\": 9.130434782608695, \"y\": -5.36231884057971, \"x2\": 9.420289855072463, \"y2\": -5.072463768115942, \"center_x\": 9.275362318840578, \"center_y\": -5.217391304347826, \"value_uncond\": 3.1453151496856975e-05}, {\"x\": 9.420289855072465, \"y\": -5.36231884057971, \"x2\": 9.710144927536232, \"y2\": -5.072463768115942, \"center_x\": 9.565217391304348, \"center_y\": -5.217391304347826, \"value_uncond\": 2.6538598946131802e-05}, {\"x\": 9.710144927536234, \"y\": -5.36231884057971, \"x2\": 10.000000000000002, \"y2\": -5.072463768115942, \"center_x\": 9.855072463768117, \"center_y\": -5.217391304347826, \"value_uncond\": 2.2183886295154995e-05}, {\"x\": 10.0, \"y\": -5.36231884057971, \"x2\": 10.289855072463768, \"y2\": -5.072463768115942, \"center_x\": 10.144927536231883, \"center_y\": -5.217391304347826, \"value_uncond\": 1.837143515839854e-05}, {\"x\": -10.0, \"y\": -5.0724637681159415, \"x2\": -9.710144927536232, \"y2\": -4.782608695652174, \"center_x\": -9.855072463768117, \"center_y\": -4.927536231884058, \"value_uncond\": 3.4093437159328184e-09}, {\"x\": -9.710144927536232, \"y\": -5.0724637681159415, \"x2\": -9.420289855072465, \"y2\": -4.782608695652174, \"center_x\": -9.565217391304348, \"center_y\": -4.927536231884058, \"value_uncond\": 5.326732063658852e-09}, {\"x\": -9.420289855072463, \"y\": -5.0724637681159415, \"x2\": -9.130434782608695, \"y2\": -4.782608695652174, \"center_x\": -9.275362318840578, \"center_y\": -4.927536231884058, \"value_uncond\": 8.245115271159551e-09}, {\"x\": -9.130434782608695, \"y\": -5.0724637681159415, \"x2\": -8.840579710144928, \"y2\": -4.782608695652174, \"center_x\": -8.985507246376812, \"center_y\": -4.927536231884058, \"value_uncond\": 1.2643823529722732e-08}, {\"x\": -8.840579710144928, \"y\": -5.0724637681159415, \"x2\": -8.55072463768116, \"y2\": -4.782608695652174, \"center_x\": -8.695652173913043, \"center_y\": -4.927536231884058, \"value_uncond\": 1.9209052094416735e-08}, {\"x\": -8.55072463768116, \"y\": -5.0724637681159415, \"x2\": -8.260869565217392, \"y2\": -4.782608695652174, \"center_x\": -8.405797101449277, \"center_y\": -4.927536231884058, \"value_uncond\": 2.8912074711345388e-08}, {\"x\": -8.26086956521739, \"y\": -5.0724637681159415, \"x2\": -7.971014492753623, \"y2\": -4.782608695652174, \"center_x\": -8.115942028985508, \"center_y\": -4.927536231884058, \"value_uncond\": 4.311202229179132e-08}, {\"x\": -7.971014492753623, \"y\": -5.0724637681159415, \"x2\": -7.681159420289855, \"y2\": -4.782608695652174, \"center_x\": -7.826086956521739, \"center_y\": -4.927536231884058, \"value_uncond\": 6.368884123900681e-08}, {\"x\": -7.681159420289855, \"y\": -5.0724637681159415, \"x2\": -7.391304347826088, \"y2\": -4.782608695652174, \"center_x\": -7.536231884057972, \"center_y\": -4.927536231884058, \"value_uncond\": 9.321249098921986e-08}, {\"x\": -7.391304347826087, \"y\": -5.0724637681159415, \"x2\": -7.101449275362319, \"y2\": -4.782608695652174, \"center_x\": -7.246376811594203, \"center_y\": -4.927536231884058, \"value_uncond\": 1.3515455763542766e-07}, {\"x\": -7.101449275362318, \"y\": -5.0724637681159415, \"x2\": -6.811594202898551, \"y2\": -4.782608695652174, \"center_x\": -6.956521739130435, \"center_y\": -4.927536231884058, \"value_uncond\": 1.9414807608224334e-07}, {\"x\": -6.811594202898551, \"y\": -5.0724637681159415, \"x2\": -6.521739130434783, \"y2\": -4.782608695652174, \"center_x\": -6.666666666666667, \"center_y\": -4.927536231884058, \"value_uncond\": 2.763002651093713e-07}, {\"x\": -6.521739130434782, \"y\": -5.0724637681159415, \"x2\": -6.231884057971015, \"y2\": -4.782608695652174, \"center_x\": -6.3768115942028984, \"center_y\": -4.927536231884058, \"value_uncond\": 3.8956086952577673e-07}, {\"x\": -6.231884057971014, \"y\": -5.0724637681159415, \"x2\": -5.942028985507246, \"y2\": -4.782608695652174, \"center_x\": -6.08695652173913, \"center_y\": -4.927536231884058, \"value_uncond\": 5.441456553883133e-07}, {\"x\": -5.942028985507246, \"y\": -5.0724637681159415, \"x2\": -5.6521739130434785, \"y2\": -4.782608695652174, \"center_x\": -5.797101449275362, \"center_y\": -4.927536231884058, \"value_uncond\": 7.530101323012316e-07}, {\"x\": -5.6521739130434785, \"y\": -5.0724637681159415, \"x2\": -5.362318840579711, \"y2\": -4.782608695652174, \"center_x\": -5.507246376811595, \"center_y\": -4.927536231884058, \"value_uncond\": 1.032362661348308e-06}, {\"x\": -5.36231884057971, \"y\": -5.0724637681159415, \"x2\": -5.072463768115942, \"y2\": -4.782608695652174, \"center_x\": -5.217391304347826, \"center_y\": -4.927536231884058, \"value_uncond\": 1.4021987370275998e-06}, {\"x\": -5.0724637681159415, \"y\": -5.0724637681159415, \"x2\": -4.782608695652174, \"y2\": -4.782608695652174, \"center_x\": -4.927536231884058, \"center_y\": -4.927536231884058, \"value_uncond\": 1.886829550106441e-06}, {\"x\": -4.782608695652174, \"y\": -5.0724637681159415, \"x2\": -4.492753623188406, \"y2\": -4.782608695652174, \"center_x\": -4.63768115942029, \"center_y\": -4.927536231884058, \"value_uncond\": 2.5153682882528417e-06}, {\"x\": -4.492753623188405, \"y\": -5.0724637681159415, \"x2\": -4.202898550724638, \"y2\": -4.782608695652174, \"center_x\": -4.3478260869565215, \"center_y\": -4.927536231884058, \"value_uncond\": 3.3221275906039403e-06}, {\"x\": -4.202898550724638, \"y\": -5.0724637681159415, \"x2\": -3.91304347826087, \"y2\": -4.782608695652174, \"center_x\": -4.057971014492754, \"center_y\": -4.927536231884058, \"value_uncond\": 4.346871973693597e-06}, {\"x\": -3.913043478260869, \"y\": -5.0724637681159415, \"x2\": -3.6231884057971016, \"y2\": -4.782608695652174, \"center_x\": -3.7681159420289854, \"center_y\": -4.927536231884058, \"value_uncond\": 5.634860970130909e-06}, {\"x\": -3.6231884057971016, \"y\": -5.0724637681159415, \"x2\": -3.333333333333334, \"y2\": -4.782608695652174, \"center_x\": -3.4782608695652177, \"center_y\": -4.927536231884058, \"value_uncond\": 7.2366134564094345e-06}, {\"x\": -3.333333333333333, \"y\": -5.0724637681159415, \"x2\": -3.0434782608695654, \"y2\": -4.782608695652174, \"center_x\": -3.1884057971014492, \"center_y\": -4.927536231884058, \"value_uncond\": 9.207322607105823e-06}, {\"x\": -3.0434782608695645, \"y\": -5.0724637681159415, \"x2\": -2.753623188405797, \"y2\": -4.782608695652174, \"center_x\": -2.8985507246376807, \"center_y\": -4.927536231884058, \"value_uncond\": 1.1605855517151936e-05}, {\"x\": -2.753623188405797, \"y\": -5.0724637681159415, \"x2\": -2.4637681159420293, \"y2\": -4.782608695652174, \"center_x\": -2.608695652173913, \"center_y\": -4.927536231884058, \"value_uncond\": 1.4493283038864286e-05}, {\"x\": -2.4637681159420284, \"y\": -5.0724637681159415, \"x2\": -2.1739130434782608, \"y2\": -4.782608695652174, \"center_x\": -2.3188405797101446, \"center_y\": -4.927536231884058, \"value_uncond\": 1.7930904689325227e-05}, {\"x\": -2.1739130434782608, \"y\": -5.0724637681159415, \"x2\": -1.8840579710144931, \"y2\": -4.782608695652174, \"center_x\": -2.028985507246377, \"center_y\": -4.927536231884058, \"value_uncond\": 2.197776094083601e-05}, {\"x\": -1.8840579710144922, \"y\": -5.0724637681159415, \"x2\": -1.5942028985507246, \"y2\": -4.782608695652174, \"center_x\": -1.7391304347826084, \"center_y\": -4.927536231884058, \"value_uncond\": 2.6687660404369246e-05}, {\"x\": -1.5942028985507246, \"y\": -5.0724637681159415, \"x2\": -1.304347826086957, \"y2\": -4.782608695652174, \"center_x\": -1.4492753623188408, \"center_y\": -4.927536231884058, \"value_uncond\": 3.21057910405215e-05}, {\"x\": -1.304347826086957, \"y\": -5.0724637681159415, \"x2\": -1.0144927536231894, \"y2\": -4.782608695652174, \"center_x\": -1.1594202898550732, \"center_y\": -4.927536231884058, \"value_uncond\": 3.826503028746719e-05}, {\"x\": -1.0144927536231876, \"y\": -5.0724637681159415, \"x2\": -0.72463768115942, \"y2\": -4.782608695652174, \"center_x\": -0.8695652173913038, \"center_y\": -4.927536231884058, \"value_uncond\": 4.51821156213635e-05}, {\"x\": -0.72463768115942, \"y\": -5.0724637681159415, \"x2\": -0.43478260869565233, \"y2\": -4.782608695652174, \"center_x\": -0.5797101449275361, \"center_y\": -4.927536231884058, \"value_uncond\": 5.285388048410386e-05}, {\"x\": -0.43478260869565233, \"y\": -5.0724637681159415, \"x2\": -0.1449275362318847, \"y2\": -4.782608695652174, \"center_x\": -0.2898550724637685, \"center_y\": -4.927536231884058, \"value_uncond\": 6.125379610721919e-05}, {\"x\": -0.14492753623188293, \"y\": -5.0724637681159415, \"x2\": 0.1449275362318847, \"y2\": -4.782608695652174, \"center_x\": 8.881784197001252e-16, \"center_y\": -4.927536231884058, \"value_uncond\": 7.032908276910843e-05}, {\"x\": 0.1449275362318847, \"y\": -5.0724637681159415, \"x2\": 0.43478260869565233, \"y2\": -4.782608695652174, \"center_x\": 0.2898550724637685, \"center_y\": -4.927536231884058, \"value_uncond\": 7.999866004289843e-05}, {\"x\": 0.43478260869565233, \"y\": -5.0724637681159415, \"x2\": 0.72463768115942, \"y2\": -4.782608695652174, \"center_x\": 0.5797101449275361, \"center_y\": -4.927536231884058, \"value_uncond\": 9.015219112845478e-05}, {\"x\": 0.72463768115942, \"y\": -5.0724637681159415, \"x2\": 1.0144927536231876, \"y2\": -4.782608695652174, \"center_x\": 0.8695652173913038, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00010065043936580447}, {\"x\": 1.0144927536231894, \"y\": -5.0724637681159415, \"x2\": 1.304347826086957, \"y2\": -4.782608695652174, \"center_x\": 1.1594202898550732, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00011132709535568892}, {\"x\": 1.304347826086957, \"y\": -5.0724637681159415, \"x2\": 1.5942028985507246, \"y2\": -4.782608695652174, \"center_x\": 1.4492753623188408, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00012199215283444759}, {\"x\": 1.5942028985507246, \"y\": -5.0724637681159415, \"x2\": 1.8840579710144922, \"y2\": -4.782608695652174, \"center_x\": 1.7391304347826084, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00013243681493426047}, {\"x\": 1.884057971014494, \"y\": -5.0724637681159415, \"x2\": 2.1739130434782616, \"y2\": -4.782608695652174, \"center_x\": 2.028985507246378, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00014243980620861715}, {\"x\": 2.1739130434782616, \"y\": -5.0724637681159415, \"x2\": 2.4637681159420293, \"y2\": -4.782608695652174, \"center_x\": 2.3188405797101455, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00015177485801526626}, {\"x\": 2.4637681159420293, \"y\": -5.0724637681159415, \"x2\": 2.753623188405797, \"y2\": -4.782608695652174, \"center_x\": 2.608695652173913, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00016021903473436135}, {\"x\": 2.753623188405797, \"y\": -5.0724637681159415, \"x2\": 3.0434782608695645, \"y2\": -4.782608695652174, \"center_x\": 2.8985507246376807, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00016756148520500328}, {\"x\": 3.0434782608695663, \"y\": -5.0724637681159415, \"x2\": 3.333333333333334, \"y2\": -4.782608695652174, \"center_x\": 3.18840579710145, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00017361214620093563}, {\"x\": 3.333333333333334, \"y\": -5.0724637681159415, \"x2\": 3.6231884057971016, \"y2\": -4.782608695652174, \"center_x\": 3.4782608695652177, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00017820989945380452}, {\"x\": 3.6231884057971016, \"y\": -5.0724637681159415, \"x2\": 3.913043478260869, \"y2\": -4.782608695652174, \"center_x\": 3.7681159420289854, \"center_y\": -4.927536231884058, \"value_uncond\": 0.0001812296947676252}, {\"x\": 3.913043478260871, \"y\": -5.0724637681159415, \"x2\": 4.202898550724639, \"y2\": -4.782608695652174, \"center_x\": 4.057971014492755, \"center_y\": -4.927536231884058, \"value_uncond\": 0.0001825882000448861}, {\"x\": 4.202898550724639, \"y\": -5.0724637681159415, \"x2\": 4.492753623188406, \"y2\": -4.782608695652174, \"center_x\": 4.347826086956522, \"center_y\": -4.927536231884058, \"value_uncond\": 0.0001822476220000616}, {\"x\": 4.492753623188406, \"y\": -5.0724637681159415, \"x2\": 4.782608695652174, \"y2\": -4.782608695652174, \"center_x\": 4.63768115942029, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00018021745307357436}, {\"x\": 4.782608695652174, \"y\": -5.0724637681159415, \"x2\": 5.0724637681159415, \"y2\": -4.782608695652174, \"center_x\": 4.927536231884058, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00017655403184885295}, {\"x\": 5.072463768115943, \"y\": -5.0724637681159415, \"x2\": 5.362318840579711, \"y2\": -4.782608695652174, \"center_x\": 5.217391304347827, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00017135794538353534}, {\"x\": 5.362318840579711, \"y\": -5.0724637681159415, \"x2\": 5.6521739130434785, \"y2\": -4.782608695652174, \"center_x\": 5.507246376811595, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00016476944062065562}, {\"x\": 5.6521739130434785, \"y\": -5.0724637681159415, \"x2\": 5.942028985507246, \"y2\": -4.782608695652174, \"center_x\": 5.797101449275362, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00015696213701197142}, {\"x\": 5.942028985507246, \"y\": -5.0724637681159415, \"x2\": 6.231884057971014, \"y2\": -4.782608695652174, \"center_x\": 6.08695652173913, \"center_y\": -4.927536231884058, \"value_uncond\": 0.0001481354336143672}, {\"x\": 6.2318840579710155, \"y\": -5.0724637681159415, \"x2\": 6.521739130434783, \"y2\": -4.782608695652174, \"center_x\": 6.376811594202899, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00013850607353238278}, {\"x\": 6.521739130434785, \"y\": -5.0724637681159415, \"x2\": 6.8115942028985526, \"y2\": -4.782608695652174, \"center_x\": 6.666666666666669, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00012829936207264282}, {\"x\": 6.811594202898551, \"y\": -5.0724637681159415, \"x2\": 7.101449275362318, \"y2\": -4.782608695652174, \"center_x\": 6.956521739130435, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00011774053117595541}, {\"x\": 7.10144927536232, \"y\": -5.0724637681159415, \"x2\": 7.391304347826088, \"y2\": -4.782608695652174, \"center_x\": 7.246376811594204, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00010704670382586031}, {\"x\": 7.391304347826086, \"y\": -5.0724637681159415, \"x2\": 7.681159420289854, \"y2\": -4.782608695652174, \"center_x\": 7.53623188405797, \"center_y\": -4.927536231884058, \"value_uncond\": 9.641984343001844e-05}, {\"x\": 7.681159420289855, \"y\": -5.0724637681159415, \"x2\": 7.971014492753623, \"y2\": -4.782608695652174, \"center_x\": 7.826086956521739, \"center_y\": -4.927536231884058, \"value_uncond\": 8.604098217792227e-05}, {\"x\": 7.971014492753625, \"y\": -5.0724637681159415, \"x2\": 8.260869565217392, \"y2\": -4.782608695652174, \"center_x\": 8.115942028985508, \"center_y\": -4.927536231884058, \"value_uncond\": 7.606591805950384e-05}, {\"x\": 8.26086956521739, \"y\": -5.0724637681159415, \"x2\": 8.550724637681158, \"y2\": -4.782608695652174, \"center_x\": 8.405797101449274, \"center_y\": -4.927536231884058, \"value_uncond\": 6.662246198975567e-05}, {\"x\": 8.55072463768116, \"y\": -5.0724637681159415, \"x2\": 8.840579710144928, \"y2\": -4.782608695652174, \"center_x\": 8.695652173913043, \"center_y\": -4.927536231884058, \"value_uncond\": 5.780921322558761e-05}, {\"x\": 8.84057971014493, \"y\": -5.0724637681159415, \"x2\": 9.130434782608697, \"y2\": -4.782608695652174, \"center_x\": 8.985507246376812, \"center_y\": -4.927536231884058, \"value_uncond\": 4.9695750572262035e-05}, {\"x\": 9.130434782608695, \"y\": -5.0724637681159415, \"x2\": 9.420289855072463, \"y2\": -4.782608695652174, \"center_x\": 9.275362318840578, \"center_y\": -4.927536231884058, \"value_uncond\": 4.2324054444699044e-05}, {\"x\": 9.420289855072465, \"y\": -5.0724637681159415, \"x2\": 9.710144927536232, \"y2\": -4.782608695652174, \"center_x\": 9.565217391304348, \"center_y\": -4.927536231884058, \"value_uncond\": 3.5710924127725504e-05}, {\"x\": 9.710144927536234, \"y\": -5.0724637681159415, \"x2\": 10.000000000000002, \"y2\": -4.782608695652174, \"center_x\": 9.855072463768117, \"center_y\": -4.927536231884058, \"value_uncond\": 2.9851126728746904e-05}, {\"x\": 10.0, \"y\": -5.0724637681159415, \"x2\": 10.289855072463768, \"y2\": -4.782608695652174, \"center_x\": 10.144927536231883, \"center_y\": -4.927536231884058, \"value_uncond\": 2.4721008384454473e-05}, {\"x\": -10.0, \"y\": -4.782608695652174, \"x2\": -9.710144927536232, \"y2\": -4.492753623188406, \"center_x\": -9.855072463768117, \"center_y\": -4.63768115942029, \"value_uncond\": 4.5450608224403395e-09}, {\"x\": -9.710144927536232, \"y\": -4.782608695652174, \"x2\": -9.420289855072465, \"y2\": -4.492753623188406, \"center_x\": -9.565217391304348, \"center_y\": -4.63768115942029, \"value_uncond\": 7.10116762385412e-09}, {\"x\": -9.420289855072463, \"y\": -4.782608695652174, \"x2\": -9.130434782608695, \"y2\": -4.492753623188406, \"center_x\": -9.275362318840578, \"center_y\": -4.63768115942029, \"value_uncond\": 1.0991719673297463e-08}, {\"x\": -9.130434782608695, \"y\": -4.782608695652174, \"x2\": -8.840579710144928, \"y2\": -4.492753623188406, \"center_x\": -8.985507246376812, \"center_y\": -4.63768115942029, \"value_uncond\": 1.68557211472205e-08}, {\"x\": -8.840579710144928, \"y\": -4.782608695652174, \"x2\": -8.55072463768116, \"y2\": -4.492753623188406, \"center_x\": -8.695652173913043, \"center_y\": -4.63768115942029, \"value_uncond\": 2.560795196522492e-08}, {\"x\": -8.55072463768116, \"y\": -4.782608695652174, \"x2\": -8.260869565217392, \"y2\": -4.492753623188406, \"center_x\": -8.405797101449277, \"center_y\": -4.63768115942029, \"value_uncond\": 3.854323559455201e-08}, {\"x\": -8.26086956521739, \"y\": -4.782608695652174, \"x2\": -7.971014492753623, \"y2\": -4.492753623188406, \"center_x\": -8.115942028985508, \"center_y\": -4.63768115942029, \"value_uncond\": 5.747345525148468e-08}, {\"x\": -7.971014492753623, \"y\": -4.782608695652174, \"x2\": -7.681159420289855, \"y2\": -4.492753623188406, \"center_x\": -7.826086956521739, \"center_y\": -4.63768115942029, \"value_uncond\": 8.490480317055164e-08}, {\"x\": -7.681159420289855, \"y\": -4.782608695652174, \"x2\": -7.391304347826088, \"y2\": -4.492753623188406, \"center_x\": -7.536231884057972, \"center_y\": -4.63768115942029, \"value_uncond\": 1.2426334105807845e-07}, {\"x\": -7.391304347826087, \"y\": -4.782608695652174, \"x2\": -7.101449275362319, \"y2\": -4.492753623188406, \"center_x\": -7.246376811594203, \"center_y\": -4.63768115942029, \"value_uncond\": 1.8017710623082913e-07}, {\"x\": -7.101449275362318, \"y\": -4.782608695652174, \"x2\": -6.811594202898551, \"y2\": -4.492753623188406, \"center_x\": -6.956521739130435, \"center_y\": -4.63768115942029, \"value_uncond\": 2.588224854624657e-07}, {\"x\": -6.811594202898551, \"y\": -4.782608695652174, \"x2\": -6.521739130434783, \"y2\": -4.492753623188406, \"center_x\": -6.666666666666667, \"center_y\": -4.63768115942029, \"value_uncond\": 3.6834112803287286e-07}, {\"x\": -6.521739130434782, \"y\": -4.782608695652174, \"x2\": -6.231884057971015, \"y2\": -4.492753623188406, \"center_x\": -6.3768115942028984, \"center_y\": -4.63768115942029, \"value_uncond\": 5.193309896456e-07}, {\"x\": -6.231884057971014, \"y\": -4.782608695652174, \"x2\": -5.942028985507246, \"y2\": -4.492753623188406, \"center_x\": -6.08695652173913, \"center_y\": -4.63768115942029, \"value_uncond\": 7.254109019424205e-07}, {\"x\": -5.942028985507246, \"y\": -4.782608695652174, \"x2\": -5.6521739130434785, \"y2\": -4.492753623188406, \"center_x\": -5.797101449275362, \"center_y\": -4.63768115942029, \"value_uncond\": 1.0038521006927966e-06}, {\"x\": -5.6521739130434785, \"y\": -4.782608695652174, \"x2\": -5.362318840579711, \"y2\": -4.492753623188406, \"center_x\": -5.507246376811595, \"center_y\": -4.63768115942029, \"value_uncond\": 1.3762622597178169e-06}, {\"x\": -5.36231884057971, \"y\": -4.782608695652174, \"x2\": -5.072463768115942, \"y2\": -4.492753623188406, \"center_x\": -5.217391304347826, \"center_y\": -4.63768115942029, \"value_uncond\": 1.8692977522789173e-06}, {\"x\": -5.0724637681159415, \"y\": -4.782608695652174, \"x2\": -4.782608695652174, \"y2\": -4.492753623188406, \"center_x\": -4.927536231884058, \"center_y\": -4.63768115942029, \"value_uncond\": 2.5153682882528417e-06}, {\"x\": -4.782608695652174, \"y\": -4.782608695652174, \"x2\": -4.492753623188406, \"y2\": -4.492753623188406, \"center_x\": -4.63768115942029, \"center_y\": -4.63768115942029, \"value_uncond\": 3.3532852107341146e-06}, {\"x\": -4.492753623188405, \"y\": -4.782608695652174, \"x2\": -4.202898550724638, \"y2\": -4.492753623188406, \"center_x\": -4.3478260869565215, \"center_y\": -4.63768115942029, \"value_uncond\": 4.428791350264565e-06}, {\"x\": -4.202898550724638, \"y\": -4.782608695652174, \"x2\": -3.91304347826087, \"y2\": -4.492753623188406, \"center_x\": -4.057971014492754, \"center_y\": -4.63768115942029, \"value_uncond\": 5.794897538628808e-06}, {\"x\": -3.913043478260869, \"y\": -4.782608695652174, \"x2\": -3.6231884057971016, \"y2\": -4.492753623188406, \"center_x\": -3.7681159420289854, \"center_y\": -4.63768115942029, \"value_uncond\": 7.511940117845491e-06}, {\"x\": -3.6231884057971016, \"y\": -4.782608695652174, \"x2\": -3.333333333333334, \"y2\": -4.492753623188406, \"center_x\": -3.4782608695652177, \"center_y\": -4.63768115942029, \"value_uncond\": 9.647266761096261e-06}, {\"x\": -3.333333333333333, \"y\": -4.782608695652174, \"x2\": -3.0434782608695654, \"y2\": -4.492753623188406, \"center_x\": -3.1884057971014492, \"center_y\": -4.63768115942029, \"value_uncond\": 1.227445653706291e-05}, {\"x\": -3.0434782608695645, \"y\": -4.782608695652174, \"x2\": -2.753623188405797, \"y2\": -4.492753623188406, \"center_x\": -2.8985507246376807, \"center_y\": -4.63768115942029, \"value_uncond\": 1.547198628738956e-05}, {\"x\": -2.753623188405797, \"y\": -4.782608695652174, \"x2\": -2.4637681159420293, \"y2\": -4.492753623188406, \"center_x\": -2.608695652173913, \"center_y\": -4.63768115942029, \"value_uncond\": 1.9321270724520628e-05}, {\"x\": -2.4637681159420284, \"y\": -4.782608695652174, \"x2\": -2.1739130434782608, \"y2\": -4.492753623188406, \"center_x\": -2.3188405797101446, \"center_y\": -4.63768115942029, \"value_uncond\": 2.3904029398240288e-05}, {\"x\": -2.1739130434782608, \"y\": -4.782608695652174, \"x2\": -1.8840579710144931, \"y2\": -4.492753623188406, \"center_x\": -2.028985507246377, \"center_y\": -4.63768115942029, \"value_uncond\": 2.929897028285477e-05}, {\"x\": -1.8840579710144922, \"y\": -4.782608695652174, \"x2\": -1.5942028985507246, \"y2\": -4.492753623188406, \"center_x\": -1.7391304347826084, \"center_y\": -4.63768115942029, \"value_uncond\": 3.557782665902412e-05}, {\"x\": -1.5942028985507246, \"y\": -4.782608695652174, \"x2\": -1.304347826086957, \"y2\": -4.492753623188406, \"center_x\": -1.4492753623188408, \"center_y\": -4.63768115942029, \"value_uncond\": 4.28008394547585e-05}, {\"x\": -1.304347826086957, \"y\": -4.782608695652174, \"x2\": -1.0144927536231894, \"y2\": -4.492753623188406, \"center_x\": -1.1594202898550732, \"center_y\": -4.63768115942029, \"value_uncond\": 5.1011838206953956e-05}, {\"x\": -1.0144927536231876, \"y\": -4.782608695652174, \"x2\": -0.72463768115942, \"y2\": -4.492753623188406, \"center_x\": -0.8695652173913038, \"center_y\": -4.63768115942029, \"value_uncond\": 6.0233135962779376e-05}, {\"x\": -0.72463768115942, \"y\": -4.782608695652174, \"x2\": -0.43478260869565233, \"y2\": -4.492753623188406, \"center_x\": -0.5797101449275361, \"center_y\": -4.63768115942029, \"value_uncond\": 7.046051132351661e-05}, {\"x\": -0.43478260869565233, \"y\": -4.782608695652174, \"x2\": -0.1449275362318847, \"y2\": -4.492753623188406, \"center_x\": -0.2898550724637685, \"center_y\": -4.63768115942029, \"value_uncond\": 8.165859828436157e-05}, {\"x\": -0.14492753623188293, \"y\": -4.782608695652174, \"x2\": 0.1449275362318847, \"y2\": -4.492753623188406, \"center_x\": 8.881784197001252e-16, \"center_y\": -4.63768115942029, \"value_uncond\": 9.37570351966054e-05}, {\"x\": 0.1449275362318847, \"y\": -4.782608695652174, \"x2\": 0.43478260869565233, \"y2\": -4.492753623188406, \"center_x\": 0.2898550724637685, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00010664773220414889}, {\"x\": 0.43478260869565233, \"y\": -4.782608695652174, \"x2\": 0.72463768115942, \"y2\": -4.492753623188406, \"center_x\": 0.5797101449275361, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00012018359722436608}, {\"x\": 0.72463768115942, \"y\": -4.782608695652174, \"x2\": 1.0144927536231876, \"y2\": -4.492753623188406, \"center_x\": 0.8695652173913038, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00013417901122291513}, {\"x\": 1.0144927536231894, \"y\": -4.782608695652174, \"x2\": 1.304347826086957, \"y2\": -4.492753623188406, \"center_x\": 1.1594202898550732, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00014841226398282928}, {\"x\": 1.304347826086957, \"y\": -4.782608695652174, \"x2\": 1.5942028985507246, \"y2\": -4.492753623188406, \"center_x\": 1.4492753623188408, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00016263005454740363}, {\"x\": 1.5942028985507246, \"y\": -4.782608695652174, \"x2\": 1.8840579710144922, \"y2\": -4.492753623188406, \"center_x\": 1.7391304347826084, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00017655403184885278}, {\"x\": 1.884057971014494, \"y\": -4.782608695652174, \"x2\": 2.1739130434782616, \"y2\": -4.492753623188406, \"center_x\": 2.028985507246378, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00018988920938927623}, {\"x\": 2.1739130434782616, \"y\": -4.782608695652174, \"x2\": 2.4637681159420293, \"y2\": -4.492753623188406, \"center_x\": 2.3188405797101455, \"center_y\": -4.63768115942029, \"value_uncond\": 0.0002023339441467523}, {\"x\": 2.4637681159420293, \"y\": -4.782608695652174, \"x2\": 2.753623188405797, \"y2\": -4.492753623188406, \"center_x\": 2.608695652173913, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00021359103641479342}, {\"x\": 2.753623188405797, \"y\": -4.782608695652174, \"x2\": 3.0434782608695645, \"y2\": -4.492753623188406, \"center_x\": 2.8985507246376807, \"center_y\": -4.63768115942029, \"value_uncond\": 0.0002233793965085168}, {\"x\": 3.0434782608695663, \"y\": -4.782608695652174, \"x2\": 3.333333333333334, \"y2\": -4.492753623188406, \"center_x\": 3.18840579710145, \"center_y\": -4.63768115942029, \"value_uncond\": 0.0002314456475332996}, {\"x\": 3.333333333333334, \"y\": -4.782608695652174, \"x2\": 3.6231884057971016, \"y2\": -4.492753623188406, \"center_x\": 3.4782608695652177, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00023757499966732003}, {\"x\": 3.6231884057971016, \"y\": -4.782608695652174, \"x2\": 3.913043478260869, \"y2\": -4.492753623188406, \"center_x\": 3.7681159420289854, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00024160074612066055}, {\"x\": 3.913043478260871, \"y\": -4.782608695652174, \"x2\": 4.202898550724639, \"y2\": -4.492753623188406, \"center_x\": 4.057971014492755, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00024341179529235364}, {\"x\": 4.202898550724639, \"y\": -4.782608695652174, \"x2\": 4.492753623188406, \"y2\": -4.492753623188406, \"center_x\": 4.347826086956522, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00024295776423608866}, {\"x\": 4.492753623188406, \"y\": -4.782608695652174, \"x2\": 4.782608695652174, \"y2\": -4.492753623188406, \"center_x\": 4.63768115942029, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00024025130750437475}, {\"x\": 4.782608695652174, \"y\": -4.782608695652174, \"x2\": 5.0724637681159415, \"y2\": -4.492753623188406, \"center_x\": 4.927536231884058, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00023536753113217578}, {\"x\": 5.072463768115943, \"y\": -4.782608695652174, \"x2\": 5.362318840579711, \"y2\": -4.492753623188406, \"center_x\": 5.217391304347827, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00022844052963533022}, {\"x\": 5.362318840579711, \"y\": -4.782608695652174, \"x2\": 5.6521739130434785, \"y2\": -4.492753623188406, \"center_x\": 5.507246376811595, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00021965726887570545}, {\"x\": 5.6521739130434785, \"y\": -4.782608695652174, \"x2\": 5.942028985507246, \"y2\": -4.492753623188406, \"center_x\": 5.797101449275362, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00020924920424001095}, {\"x\": 5.942028985507246, \"y\": -4.782608695652174, \"x2\": 6.231884057971014, \"y2\": -4.492753623188406, \"center_x\": 6.08695652173913, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00019748215839588857}, {\"x\": 6.2318840579710155, \"y\": -4.782608695652174, \"x2\": 6.521739130434783, \"y2\": -4.492753623188406, \"center_x\": 6.376811594202899, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00018464507569012695}, {\"x\": 6.521739130434785, \"y\": -4.782608695652174, \"x2\": 6.8115942028985526, \"y2\": -4.492753623188406, \"center_x\": 6.666666666666669, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00017103831490363806}, {\"x\": 6.811594202898551, \"y\": -4.782608695652174, \"x2\": 7.101449275362318, \"y2\": -4.492753623188406, \"center_x\": 6.956521739130435, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00015696213701197131}, {\"x\": 7.10144927536232, \"y\": -4.782608695652174, \"x2\": 7.391304347826088, \"y2\": -4.492753623188406, \"center_x\": 7.246376811594204, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00014270599278582075}, {\"x\": 7.391304347826086, \"y\": -4.782608695652174, \"x2\": 7.681159420289854, \"y2\": -4.492753623188406, \"center_x\": 7.53623188405797, \"center_y\": -4.63768115942029, \"value_uncond\": 0.0001285391234775238}, {\"x\": 7.681159420289855, \"y\": -4.782608695652174, \"x2\": 7.971014492753623, \"y2\": -4.492753623188406, \"center_x\": 7.826086956521739, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00011470286653516983}, {\"x\": 7.971014492753625, \"y\": -4.782608695652174, \"x2\": 8.260869565217392, \"y2\": -4.492753623188406, \"center_x\": 8.115942028985508, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00010140491921642922}, {\"x\": 8.26086956521739, \"y\": -4.782608695652174, \"x2\": 8.550724637681158, \"y2\": -4.492753623188406, \"center_x\": 8.405797101449274, \"center_y\": -4.63768115942029, \"value_uncond\": 8.881566867813159e-05}, {\"x\": 8.55072463768116, \"y\": -4.782608695652174, \"x2\": 8.840579710144928, \"y2\": -4.492753623188406, \"center_x\": 8.695652173913043, \"center_y\": -4.63768115942029, \"value_uncond\": 7.706655946123317e-05}, {\"x\": 8.84057971014493, \"y\": -4.782608695652174, \"x2\": 9.130434782608697, \"y2\": -4.492753623188406, \"center_x\": 8.985507246376812, \"center_y\": -4.63768115942029, \"value_uncond\": 6.625034839174487e-05}, {\"x\": 9.130434782608695, \"y\": -4.782608695652174, \"x2\": 9.420289855072463, \"y2\": -4.492753623188406, \"center_x\": 9.275362318840578, \"center_y\": -4.63768115942029, \"value_uncond\": 5.642300035765128e-05}, {\"x\": 9.420289855072465, \"y\": -4.782608695652174, \"x2\": 9.710144927536232, \"y2\": -4.492753623188406, \"center_x\": 9.565217391304348, \"center_y\": -4.63768115942029, \"value_uncond\": 4.760691080443206e-05}, {\"x\": 9.710144927536234, \"y\": -4.782608695652174, \"x2\": 10.000000000000002, \"y2\": -4.492753623188406, \"center_x\": 9.855072463768117, \"center_y\": -4.63768115942029, \"value_uncond\": 3.979510366364091e-05}, {\"x\": 10.0, \"y\": -4.782608695652174, \"x2\": 10.289855072463768, \"y2\": -4.492753623188406, \"center_x\": 10.144927536231883, \"center_y\": -4.63768115942029, \"value_uncond\": 3.29560455211132e-05}, {\"x\": -10.0, \"y\": -4.492753623188405, \"x2\": -9.710144927536232, \"y2\": -4.202898550724638, \"center_x\": -9.855072463768117, \"center_y\": -4.3478260869565215, \"value_uncond\": 6.002807632471971e-09}, {\"x\": -9.710144927536232, \"y\": -4.492753623188405, \"x2\": -9.420289855072465, \"y2\": -4.202898550724638, \"center_x\": -9.565217391304348, \"center_y\": -4.3478260869565215, \"value_uncond\": 9.378739884287616e-09}, {\"x\": -9.420289855072463, \"y\": -4.492753623188405, \"x2\": -9.130434782608695, \"y2\": -4.202898550724638, \"center_x\": -9.275362318840578, \"center_y\": -4.3478260869565215, \"value_uncond\": 1.451711678380478e-08}, {\"x\": -9.130434782608695, \"y\": -4.492753623188405, \"x2\": -8.840579710144928, \"y2\": -4.202898550724638, \"center_x\": -8.985507246376812, \"center_y\": -4.3478260869565215, \"value_uncond\": 2.2261891645935698e-08}, {\"x\": -8.840579710144928, \"y\": -4.492753623188405, \"x2\": -8.55072463768116, \"y2\": -4.202898550724638, \"center_x\": -8.695652173913043, \"center_y\": -4.3478260869565215, \"value_uncond\": 3.382124365638135e-08}, {\"x\": -8.55072463768116, \"y\": -4.492753623188405, \"x2\": -8.260869565217392, \"y2\": -4.202898550724638, \"center_x\": -8.405797101449277, \"center_y\": -4.3478260869565215, \"value_uncond\": 5.0905287705900384e-08}, {\"x\": -8.26086956521739, \"y\": -4.492753623188405, \"x2\": -7.971014492753623, \"y2\": -4.202898550724638, \"center_x\": -8.115942028985508, \"center_y\": -4.3478260869565215, \"value_uncond\": 7.59070360829428e-08}, {\"x\": -7.971014492753623, \"y\": -4.492753623188405, \"x2\": -7.681159420289855, \"y2\": -4.202898550724638, \"center_x\": -7.826086956521739, \"center_y\": -4.3478260869565215, \"value_uncond\": 1.1213649726959334e-07}, {\"x\": -7.681159420289855, \"y\": -4.492753623188405, \"x2\": -7.391304347826088, \"y2\": -4.202898550724638, \"center_x\": -7.536231884057972, \"center_y\": -4.3478260869565215, \"value_uncond\": 1.641185808684942e-07}, {\"x\": -7.391304347826087, \"y\": -4.492753623188405, \"x2\": -7.101449275362319, \"y2\": -4.202898550724638, \"center_x\": -7.246376811594203, \"center_y\": -4.3478260869565215, \"value_uncond\": 2.379656842300335e-07}, {\"x\": -7.101449275362318, \"y\": -4.492753623188405, \"x2\": -6.811594202898551, \"y2\": -4.202898550724638, \"center_x\": -6.956521739130435, \"center_y\": -4.3478260869565215, \"value_uncond\": 3.418351595029395e-07}, {\"x\": -6.811594202898551, \"y\": -4.492753623188405, \"x2\": -6.521739130434783, \"y2\": -4.202898550724638, \"center_x\": -6.666666666666667, \"center_y\": -4.3478260869565215, \"value_uncond\": 4.86479944072979e-07}, {\"x\": -6.521739130434782, \"y\": -4.492753623188405, \"x2\": -6.231884057971015, \"y2\": -4.202898550724638, \"center_x\": -6.3768115942028984, \"center_y\": -4.3478260869565215, \"value_uncond\": 6.85897098017273e-07}, {\"x\": -6.231884057971014, \"y\": -4.492753623188405, \"x2\": -5.942028985507246, \"y2\": -4.202898550724638, \"center_x\": -6.08695652173913, \"center_y\": -4.3478260869565215, \"value_uncond\": 9.580734491734053e-07}, {\"x\": -5.942028985507246, \"y\": -4.492753623188405, \"x2\": -5.6521739130434785, \"y2\": -4.202898550724638, \"center_x\": -5.797101449275362, \"center_y\": -4.3478260869565215, \"value_uncond\": 1.325819672678501e-06}, {\"x\": -5.6521739130434785, \"y\": -4.492753623188405, \"x2\": -5.362318840579711, \"y2\": -4.202898550724638, \"center_x\": -5.507246376811595, \"center_y\": -4.3478260869565215, \"value_uncond\": 1.81767371651618e-06}, {\"x\": -5.36231884057971, \"y\": -4.492753623188405, \"x2\": -5.072463768115942, \"y2\": -4.202898550724638, \"center_x\": -5.217391304347826, \"center_y\": -4.3478260869565215, \"value_uncond\": 2.4688415079817903e-06}, {\"x\": -5.0724637681159415, \"y\": -4.492753623188405, \"x2\": -4.782608695652174, \"y2\": -4.202898550724638, \"center_x\": -4.927536231884058, \"center_y\": -4.3478260869565215, \"value_uncond\": 3.3221275906039403e-06}, {\"x\": -4.782608695652174, \"y\": -4.492753623188405, \"x2\": -4.492753623188406, \"y2\": -4.202898550724638, \"center_x\": -4.63768115942029, \"center_y\": -4.3478260869565215, \"value_uncond\": 4.428791350264565e-06}, {\"x\": -4.492753623188405, \"y\": -4.492753623188405, \"x2\": -4.202898550724638, \"y2\": -4.202898550724638, \"center_x\": -4.3478260869565215, \"center_y\": -4.3478260869565215, \"value_uncond\": 5.8492468106773934e-06}, {\"x\": -4.202898550724638, \"y\": -4.492753623188405, \"x2\": -3.91304347826087, \"y2\": -4.202898550724638, \"center_x\": -4.057971014492754, \"center_y\": -4.3478260869565215, \"value_uncond\": 7.653507077953004e-06}, {\"x\": -3.913043478260869, \"y\": -4.492753623188405, \"x2\": -3.6231884057971016, \"y2\": -4.202898550724638, \"center_x\": -3.7681159420289854, \"center_y\": -4.3478260869565215, \"value_uncond\": 9.921260294568287e-06}, {\"x\": -3.6231884057971016, \"y\": -4.492753623188405, \"x2\": -3.333333333333334, \"y2\": -4.202898550724638, \"center_x\": -3.4782608695652177, \"center_y\": -4.3478260869565215, \"value_uncond\": 1.2741454692988741e-05}, {\"x\": -3.333333333333333, \"y\": -4.492753623188405, \"x2\": -3.0434782608695654, \"y2\": -4.202898550724638, \"center_x\": -3.1884057971014492, \"center_y\": -4.3478260869565215, \"value_uncond\": 1.621126850961822e-05}, {\"x\": -3.0434782608695645, \"y\": -4.492753623188405, \"x2\": -2.753623188405797, \"y2\": -4.202898550724638, \"center_x\": -2.8985507246376807, \"center_y\": -4.3478260869565215, \"value_uncond\": 2.0434348626731224e-05}, {\"x\": -2.753623188405797, \"y\": -4.492753623188405, \"x2\": -2.4637681159420293, \"y2\": -4.202898550724638, \"center_x\": -2.608695652173913, \"center_y\": -4.3478260869565215, \"value_uncond\": 2.551822206681418e-05}, {\"x\": -2.4637681159420284, \"y\": -4.492753623188405, \"x2\": -2.1739130434782608, \"y2\": -4.202898550724638, \"center_x\": -2.3188405797101446, \"center_y\": -4.3478260869565215, \"value_uncond\": 3.157081846080717e-05}, {\"x\": -2.1739130434782608, \"y\": -4.492753623188405, \"x2\": -1.8840579710144931, \"y2\": -4.202898550724638, \"center_x\": -2.028985507246377, \"center_y\": -4.3478260869565215, \"value_uncond\": 3.869608995530632e-05}, {\"x\": -1.8840579710144922, \"y\": -4.492753623188405, \"x2\": -1.5942028985507246, \"y2\": -4.202898550724638, \"center_x\": -1.7391304347826084, \"center_y\": -4.3478260869565215, \"value_uncond\": 4.698877699526274e-05}, {\"x\": -1.5942028985507246, \"y\": -4.492753623188405, \"x2\": -1.304347826086957, \"y2\": -4.202898550724638, \"center_x\": -1.4492753623188408, \"center_y\": -4.3478260869565215, \"value_uncond\": 5.652844170681153e-05}, {\"x\": -1.304347826086957, \"y\": -4.492753623188405, \"x2\": -1.0144927536231894, \"y2\": -4.202898550724638, \"center_x\": -1.1594202898550732, \"center_y\": -4.3478260869565215, \"value_uncond\": 6.737297116537058e-05}, {\"x\": -1.0144927536231876, \"y\": -4.492753623188405, \"x2\": -0.72463768115942, \"y2\": -4.202898550724638, \"center_x\": -0.8695652173913038, \"center_y\": -4.3478260869565215, \"value_uncond\": 7.955183492813199e-05}, {\"x\": -0.72463768115942, \"y\": -4.492753623188405, \"x2\": -0.43478260869565233, \"y2\": -4.202898550724638, \"center_x\": -0.5797101449275361, \"center_y\": -4.3478260869565215, \"value_uncond\": 9.305945765838754e-05}, {\"x\": -0.43478260869565233, \"y\": -4.492753623188405, \"x2\": -0.1449275362318847, \"y2\": -4.202898550724638, \"center_x\": -0.2898550724637685, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00010784913033906096}, {\"x\": -0.14492753623188293, \"y\": -4.492753623188405, \"x2\": 0.1449275362318847, \"y2\": -4.202898550724638, \"center_x\": 8.881784197001252e-16, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0001238279240835204}, {\"x\": 0.1449275362318847, \"y\": -4.492753623188405, \"x2\": 0.43478260869565233, \"y2\": -4.202898550724638, \"center_x\": 0.2898550724637685, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0001408530811513238}, {\"x\": 0.43478260869565233, \"y\": -4.492753623188405, \"x2\": 0.72463768115942, \"y2\": -4.202898550724638, \"center_x\": 0.5797101449275361, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00015873033231027375}, {\"x\": 0.72463768115942, \"y\": -4.492753623188405, \"x2\": 1.0144927536231876, \"y2\": -4.202898550724638, \"center_x\": 0.8695652173913038, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00017721452454710887}, {\"x\": 1.0144927536231894, \"y\": -4.492753623188405, \"x2\": 1.304347826086957, \"y2\": -4.202898550724638, \"center_x\": 1.1594202898550732, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0001960128380658796}, {\"x\": 1.304347826086957, \"y\": -4.492753623188405, \"x2\": 1.5942028985507246, \"y2\": -4.202898550724638, \"center_x\": 1.4492753623188408, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0002147907301672421}, {\"x\": 1.5942028985507246, \"y\": -4.492753623188405, \"x2\": 1.8840579710144922, \"y2\": -4.202898550724638, \"center_x\": 1.7391304347826084, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00023318057366654825}, {\"x\": 1.884057971014494, \"y\": -4.492753623188405, \"x2\": 2.1739130434782616, \"y2\": -4.202898550724638, \"center_x\": 2.028985507246378, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0002507927704329367}, {\"x\": 2.1739130434782616, \"y\": -4.492753623188405, \"x2\": 2.4637681159420293, \"y2\": -4.202898550724638, \"center_x\": 2.3188405797101455, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0002672289308507321}, {\"x\": 2.4637681159420293, \"y\": -4.492753623188405, \"x2\": 2.753623188405797, \"y2\": -4.202898550724638, \"center_x\": 2.608695652173913, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0002820965337334932}, {\"x\": 2.753623188405797, \"y\": -4.492753623188405, \"x2\": 3.0434782608695645, \"y2\": -4.202898550724638, \"center_x\": 2.8985507246376807, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.000295024334917117}, {\"x\": 3.0434782608695663, \"y\": -4.492753623188405, \"x2\": 3.333333333333334, \"y2\": -4.202898550724638, \"center_x\": 3.18840579710145, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00030567769140861566}, {\"x\": 3.333333333333334, \"y\": -4.492753623188405, \"x2\": 3.6231884057971016, \"y2\": -4.202898550724638, \"center_x\": 3.4782608695652177, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0003137729233999119}, {\"x\": 3.6231884057971016, \"y\": -4.492753623188405, \"x2\": 3.913043478260869, \"y2\": -4.202898550724638, \"center_x\": 3.7681159420289854, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00031908985588565455}, {\"x\": 3.913043478260871, \"y\": -4.492753623188405, \"x2\": 4.202898550724639, \"y2\": -4.202898550724638, \"center_x\": 4.057971014492755, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0003214817666246586}, {\"x\": 4.202898550724639, \"y\": -4.492753623188405, \"x2\": 4.492753623188406, \"y2\": -4.202898550724638, \"center_x\": 4.347826086956522, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0003208821132434606}, {\"x\": 4.492753623188406, \"y\": -4.492753623188405, \"x2\": 4.782608695652174, \"y2\": -4.202898550724638, \"center_x\": 4.63768115942029, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00031730760901551403}, {\"x\": 4.782608695652174, \"y\": -4.492753623188405, \"x2\": 5.0724637681159415, \"y2\": -4.202898550724638, \"center_x\": 4.927536231884058, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0003108574488905761}, {\"x\": 5.072463768115943, \"y\": -4.492753623188405, \"x2\": 5.362318840579711, \"y2\": -4.202898550724638, \"center_x\": 5.217391304347827, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00030170873579742915}, {\"x\": 5.362318840579711, \"y\": -4.492753623188405, \"x2\": 5.6521739130434785, \"y2\": -4.202898550724638, \"center_x\": 5.507246376811595, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0002901084015476537}, {\"x\": 5.6521739130434785, \"y\": -4.492753623188405, \"x2\": 5.942028985507246, \"y2\": -4.202898550724638, \"center_x\": 5.797101449275362, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0002763621366955009}, {\"x\": 5.942028985507246, \"y\": -4.492753623188405, \"x2\": 6.231884057971014, \"y2\": -4.202898550724638, \"center_x\": 6.08695652173913, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00026082102176564175}, {\"x\": 6.2318840579710155, \"y\": -4.492753623188405, \"x2\": 6.521739130434783, \"y2\": -4.202898550724638, \"center_x\": 6.376811594202899, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00024386667482613364}, {\"x\": 6.521739130434785, \"y\": -4.492753623188405, \"x2\": 6.8115942028985526, \"y2\": -4.202898550724638, \"center_x\": 6.666666666666669, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00022589578935435225}, {\"x\": 6.811594202898551, \"y\": -4.492753623188405, \"x2\": 7.101449275362318, \"y2\": -4.202898550724638, \"center_x\": 6.956521739130435, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00020730492965299356}, {\"x\": 7.10144927536232, \"y\": -4.492753623188405, \"x2\": 7.391304347826088, \"y2\": -4.202898550724638, \"center_x\": 7.246376811594204, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00018847638264041263}, {\"x\": 7.391304347826086, \"y\": -4.492753623188405, \"x2\": 7.681159420289854, \"y2\": -4.202898550724638, \"center_x\": 7.53623188405797, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0001697657438757553}, {\"x\": 7.681159420289855, \"y\": -4.492753623188405, \"x2\": 7.971014492753623, \"y2\": -4.202898550724638, \"center_x\": 7.826086956521739, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00015149175546875064}, {\"x\": 7.971014492753625, \"y\": -4.492753623188405, \"x2\": 8.260869565217392, \"y2\": -4.202898550724638, \"center_x\": 8.115942028985508, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00013392872985047388}, {\"x\": 8.26086956521739, \"y\": -4.492753623188405, \"x2\": 8.550724637681158, \"y2\": -4.202898550724638, \"center_x\": 8.405797101449274, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00011730170280492166}, {\"x\": 8.55072463768116, \"y\": -4.492753623188405, \"x2\": 8.840579710144928, \"y2\": -4.202898550724638, \"center_x\": 8.695652173913043, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00010178427735403919}, {\"x\": 8.84057971014493, \"y\": -4.492753623188405, \"x2\": 9.130434782608697, \"y2\": -4.202898550724638, \"center_x\": 8.985507246376812, \"center_y\": -4.3478260869565215, \"value_uncond\": 8.74989604135519e-05}, {\"x\": 9.130434782608695, \"y\": -4.492753623188405, \"x2\": 9.420289855072463, \"y2\": -4.202898550724638, \"center_x\": 9.275362318840578, \"center_y\": -4.3478260869565215, \"value_uncond\": 7.451966660635891e-05}, {\"x\": 9.420289855072465, \"y\": -4.492753623188405, \"x2\": 9.710144927536232, \"y2\": -4.202898550724638, \"center_x\": 9.565217391304348, \"center_y\": -4.3478260869565215, \"value_uncond\": 6.287597431574483e-05}, {\"x\": 9.710144927536234, \"y\": -4.492753623188405, \"x2\": 10.000000000000002, \"y2\": -4.202898550724638, \"center_x\": 9.855072463768117, \"center_y\": -4.3478260869565215, \"value_uncond\": 5.25586700243223e-05}, {\"x\": 10.0, \"y\": -4.492753623188405, \"x2\": 10.289855072463768, \"y2\": -4.202898550724638, \"center_x\": 10.144927536231883, \"center_y\": -4.3478260869565215, \"value_uncond\": 4.3526106540421027e-05}, {\"x\": -10.0, \"y\": -4.202898550724638, \"x2\": -9.710144927536232, \"y2\": -3.91304347826087, \"center_x\": -9.855072463768117, \"center_y\": -4.057971014492754, \"value_uncond\": 7.85443531273968e-09}, {\"x\": -9.710144927536232, \"y\": -4.202898550724638, \"x2\": -9.420289855072465, \"y2\": -3.91304347826087, \"center_x\": -9.565217391304348, \"center_y\": -4.057971014492754, \"value_uncond\": 1.2271708548123759e-08}, {\"x\": -9.420289855072463, \"y\": -4.202898550724638, \"x2\": -9.130434782608695, \"y2\": -3.91304347826087, \"center_x\": -9.275362318840578, \"center_y\": -4.057971014492754, \"value_uncond\": 1.8995070588148614e-08}, {\"x\": -9.130434782608695, \"y\": -4.202898550724638, \"x2\": -8.840579710144928, \"y2\": -3.91304347826087, \"center_x\": -8.985507246376812, \"center_y\": -4.057971014492754, \"value_uncond\": 2.912880081752954e-08}, {\"x\": -8.840579710144928, \"y\": -4.202898550724638, \"x2\": -8.55072463768116, \"y2\": -3.91304347826087, \"center_x\": -8.695652173913043, \"center_y\": -4.057971014492754, \"value_uncond\": 4.425375370325845e-08}, {\"x\": -8.55072463768116, \"y\": -4.202898550724638, \"x2\": -8.260869565217392, \"y2\": -3.91304347826087, \"center_x\": -8.405797101449277, \"center_y\": -4.057971014492754, \"value_uncond\": 6.660754664192793e-08}, {\"x\": -8.26086956521739, \"y\": -4.202898550724638, \"x2\": -7.971014492753623, \"y2\": -3.91304347826087, \"center_x\": -8.115942028985508, \"center_y\": -4.057971014492754, \"value_uncond\": 9.932134114545186e-08}, {\"x\": -7.971014492753623, \"y\": -4.202898550724638, \"x2\": -7.681159420289855, \"y2\": -3.91304347826087, \"center_x\": -7.826086956521739, \"center_y\": -4.057971014492754, \"value_uncond\": 1.467261518154846e-07}, {\"x\": -7.681159420289855, \"y\": -4.202898550724638, \"x2\": -7.391304347826088, \"y2\": -3.91304347826087, \"center_x\": -7.536231884057972, \"center_y\": -4.057971014492754, \"value_uncond\": 2.1474264310538774e-07}, {\"x\": -7.391304347826087, \"y\": -4.202898550724638, \"x2\": -7.101449275362319, \"y2\": -3.91304347826087, \"center_x\": -7.246376811594203, \"center_y\": -4.057971014492754, \"value_uncond\": 3.113686441201083e-07}, {\"x\": -7.101449275362318, \"y\": -4.202898550724638, \"x2\": -6.811594202898551, \"y2\": -3.91304347826087, \"center_x\": -6.956521739130435, \"center_y\": -4.057971014492754, \"value_uncond\": 4.4727772607802706e-07}, {\"x\": -6.811594202898551, \"y\": -4.202898550724638, \"x2\": -6.521739130434783, \"y2\": -3.91304347826087, \"center_x\": -6.666666666666667, \"center_y\": -4.057971014492754, \"value_uncond\": 6.365396803650244e-07}, {\"x\": -6.521739130434782, \"y\": -4.202898550724638, \"x2\": -6.231884057971015, \"y2\": -3.91304347826087, \"center_x\": -6.3768115942028984, \"center_y\": -4.057971014492754, \"value_uncond\": 8.974691040289142e-07}, {\"x\": -6.231884057971014, \"y\": -4.202898550724638, \"x2\": -5.942028985507246, \"y2\": -3.91304347826087, \"center_x\": -6.08695652173913, \"center_y\": -4.057971014492754, \"value_uncond\": 1.2536010467300358e-06}, {\"x\": -5.942028985507246, \"y\": -4.202898550724638, \"x2\": -5.6521739130434785, \"y2\": -3.91304347826087, \"center_x\": -5.797101449275362, \"center_y\": -4.057971014492754, \"value_uncond\": 1.7347823706825448e-06}, {\"x\": -5.6521739130434785, \"y\": -4.202898550724638, \"x2\": -5.362318840579711, \"y2\": -3.91304347826087, \"center_x\": -5.507246376811595, \"center_y\": -4.057971014492754, \"value_uncond\": 2.3783538470920915e-06}, {\"x\": -5.36231884057971, \"y\": -4.202898550724638, \"x2\": -5.072463768115942, \"y2\": -3.91304347826087, \"center_x\": -5.217391304347826, \"center_y\": -4.057971014492754, \"value_uncond\": 3.230381033194009e-06}, {\"x\": -5.0724637681159415, \"y\": -4.202898550724638, \"x2\": -4.782608695652174, \"y2\": -3.91304347826087, \"center_x\": -4.927536231884058, \"center_y\": -4.057971014492754, \"value_uncond\": 4.346871973693597e-06}, {\"x\": -4.782608695652174, \"y\": -4.202898550724638, \"x2\": -4.492753623188406, \"y2\": -3.91304347826087, \"center_x\": -4.63768115942029, \"center_y\": -4.057971014492754, \"value_uncond\": 5.794897538628808e-06}, {\"x\": -4.492753623188405, \"y\": -4.202898550724638, \"x2\": -4.202898550724638, \"y2\": -3.91304347826087, \"center_x\": -4.3478260869565215, \"center_y\": -4.057971014492754, \"value_uncond\": 7.653507077953004e-06}, {\"x\": -4.202898550724638, \"y\": -4.202898550724638, \"x2\": -3.91304347826087, \"y2\": -3.91304347826087, \"center_x\": -4.057971014492754, \"center_y\": -4.057971014492754, \"value_uncond\": 1.0014309959591713e-05}, {\"x\": -3.913043478260869, \"y\": -4.202898550724638, \"x2\": -3.6231884057971016, \"y2\": -3.91304347826087, \"center_x\": -3.7681159420289854, \"center_y\": -4.057971014492754, \"value_uncond\": 1.2981574952194378e-05}, {\"x\": -3.6231884057971016, \"y\": -4.202898550724638, \"x2\": -3.333333333333334, \"y2\": -3.91304347826087, \"center_x\": -3.4782608695652177, \"center_y\": -4.057971014492754, \"value_uncond\": 1.667168728428361e-05}, {\"x\": -3.333333333333333, \"y\": -4.202898550724638, \"x2\": -3.0434782608695654, \"y2\": -3.91304347826087, \"center_x\": -3.1884057971014492, \"center_y\": -4.057971014492754, \"value_uncond\": 2.1211800817580984e-05}, {\"x\": -3.0434782608695645, \"y\": -4.202898550724638, \"x2\": -2.753623188405797, \"y2\": -3.91304347826087, \"center_x\": -2.8985507246376807, \"center_y\": -4.057971014492754, \"value_uncond\": 2.6737533379948934e-05}, {\"x\": -2.753623188405797, \"y\": -4.202898550724638, \"x2\": -2.4637681159420293, \"y2\": -3.91304347826087, \"center_x\": -2.608695652173913, \"center_y\": -4.057971014492754, \"value_uncond\": 3.33895798085704e-05}, {\"x\": -2.4637681159420284, \"y\": -4.202898550724638, \"x2\": -2.1739130434782608, \"y2\": -3.91304347826087, \"center_x\": -2.3188405797101446, \"center_y\": -4.057971014492754, \"value_uncond\": 4.130916173779552e-05}, {\"x\": -2.1739130434782608, \"y\": -4.202898550724638, \"x2\": -1.8840579710144931, \"y2\": -3.91304347826087, \"center_x\": -2.028985507246377, \"center_y\": -4.057971014492754, \"value_uncond\": 5.063229642172422e-05}, {\"x\": -1.8840579710144922, \"y\": -4.202898550724638, \"x2\": -1.5942028985507246, \"y2\": -3.91304347826087, \"center_x\": -1.7391304347826084, \"center_y\": -4.057971014492754, \"value_uncond\": 6.148294796880874e-05}, {\"x\": -1.5942028985507246, \"y\": -4.202898550724638, \"x2\": -1.304347826086957, \"y2\": -3.91304347826087, \"center_x\": -1.4492753623188408, \"center_y\": -4.057971014492754, \"value_uncond\": 7.396522026032139e-05}, {\"x\": -1.304347826086957, \"y\": -4.202898550724638, \"x2\": -1.0144927536231894, \"y2\": -3.91304347826087, \"center_x\": -1.1594202898550732, \"center_y\": -4.057971014492754, \"value_uncond\": 8.815485623475879e-05}, {\"x\": -1.0144927536231876, \"y\": -4.202898550724638, \"x2\": -0.72463768115942, \"y2\": -3.91304347826087, \"center_x\": -0.8695652173913038, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0001040904156369658}, {\"x\": -0.72463768115942, \"y\": -4.202898550724638, \"x2\": -0.43478260869565233, \"y2\": -3.91304347826087, \"center_x\": -0.5797101449275361, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00012176460336035191}, {\"x\": -0.43478260869565233, \"y\": -4.202898550724638, \"x2\": -0.1449275362318847, \"y2\": -3.91304347826087, \"center_x\": -0.2898550724637685, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0001411163025116883}, {\"x\": -0.14492753623188293, \"y\": -4.202898550724638, \"x2\": 0.1449275362318847, \"y2\": -3.91304347826087, \"center_x\": 8.881784197001252e-16, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00016202391933461542}, {\"x\": 0.1449275362318847, \"y\": -4.202898550724638, \"x2\": 0.43478260869565233, \"y2\": -3.91304347826087, \"center_x\": 0.2898550724637685, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00018430066099712087}, {\"x\": 0.43478260869565233, \"y\": -4.202898550724638, \"x2\": 0.72463768115942, \"y2\": -3.91304347826087, \"center_x\": 0.5797101449275361, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00020769233392663476}, {\"x\": 0.72463768115942, \"y\": -4.202898550724638, \"x2\": 1.0144927536231876, \"y2\": -3.91304347826087, \"center_x\": 0.8695652173913038, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00023187816514453103}, {\"x\": 1.0144927536231894, \"y\": -4.202898550724638, \"x2\": 1.304347826086957, \"y2\": -3.91304347826087, \"center_x\": 1.1594202898550732, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0002564750115807015}, {\"x\": 1.304347826086957, \"y\": -4.202898550724638, \"x2\": 1.5942028985507246, \"y2\": -3.91304347826087, \"center_x\": 1.4492753623188408, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0002810451374034776}, {\"x\": 1.5942028985507246, \"y\": -4.202898550724638, \"x2\": 1.8840579710144922, \"y2\": -3.91304347826087, \"center_x\": 1.7391304347826084, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00030510751704652234}, {\"x\": 1.884057971014494, \"y\": -4.202898550724638, \"x2\": 2.1739130434782616, \"y2\": -3.91304347826087, \"center_x\": 2.028985507246378, \"center_y\": -4.057971014492754, \"value_uncond\": 0.000328152376833221}, {\"x\": 2.1739130434782616, \"y\": -4.202898550724638, \"x2\": 2.4637681159420293, \"y2\": -3.91304347826087, \"center_x\": 2.3188405797101455, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00034965843977834024}, {\"x\": 2.4637681159420293, \"y\": -4.202898550724638, \"x2\": 2.753623188405797, \"y2\": -3.91304347826087, \"center_x\": 2.608695652173913, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0003691121075031647}, {\"x\": 2.753623188405797, \"y\": -4.202898550724638, \"x2\": 3.0434782608695645, \"y2\": -3.91304347826087, \"center_x\": 2.8985507246376807, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0003860276217674322}, {\"x\": 3.0434782608695663, \"y\": -4.202898550724638, \"x2\": 3.333333333333334, \"y2\": -3.91304347826087, \"center_x\": 3.18840579710145, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0003999671155092253}, {\"x\": 3.333333333333334, \"y\": -4.202898550724638, \"x2\": 3.6231884057971016, \"y2\": -3.91304347826087, \"center_x\": 3.4782608695652177, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0004105594049694614}, {\"x\": 3.6231884057971016, \"y\": -4.202898550724638, \"x2\": 3.913043478260869, \"y2\": -3.91304347826087, \"center_x\": 3.7681159420289854, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00041751639990056063}, {\"x\": 3.913043478260871, \"y\": -4.202898550724638, \"x2\": 4.202898550724639, \"y2\": -3.91304347826087, \"center_x\": 4.057971014492755, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0004206461200787862}, {\"x\": 4.202898550724639, \"y\": -4.202898550724638, \"x2\": 4.492753623188406, \"y2\": -3.91304347826087, \"center_x\": 4.347826086956522, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0004198614974519994}, {\"x\": 4.492753623188406, \"y\": -4.202898550724638, \"x2\": 4.782608695652174, \"y2\": -3.91304347826087, \"center_x\": 4.63768115942029, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0004151844006745436}, {\"x\": 4.782608695652174, \"y\": -4.202898550724638, \"x2\": 5.0724637681159415, \"y2\": -3.91304347826087, \"center_x\": 4.927536231884058, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00040674462239744533}, {\"x\": 5.072463768115943, \"y\": -4.202898550724638, \"x2\": 5.362318840579711, \"y2\": -3.91304347826087, \"center_x\": 5.217391304347827, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0003947738947672235}, {\"x\": 5.362318840579711, \"y\": -4.202898550724638, \"x2\": 5.6521739130434785, \"y2\": -3.91304347826087, \"center_x\": 5.507246376811595, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0003795953182494388}, {\"x\": 5.6521739130434785, \"y\": -4.202898550724638, \"x2\": 5.942028985507246, \"y2\": -3.91304347826087, \"center_x\": 5.797101449275362, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00036160887679011775}, {\"x\": 5.942028985507246, \"y\": -4.202898550724638, \"x2\": 6.231884057971014, \"y2\": -3.91304347826087, \"center_x\": 6.08695652173913, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0003412739453083699}, {\"x\": 6.2318840579710155, \"y\": -4.202898550724638, \"x2\": 6.521739130434783, \"y2\": -3.91304347826087, \"center_x\": 6.376811594202899, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0003190898558856549}, {\"x\": 6.521739130434785, \"y\": -4.202898550724638, \"x2\": 6.8115942028985526, \"y2\": -3.91304347826087, \"center_x\": 6.666666666666669, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00029557566617762447}, {\"x\": 6.811594202898551, \"y\": -4.202898550724638, \"x2\": 7.101449275362318, \"y2\": -3.91304347826087, \"center_x\": 6.956521739130435, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0002712502648199919}, {\"x\": 7.10144927536232, \"y\": -4.202898550724638, \"x2\": 7.391304347826088, \"y2\": -3.91304347826087, \"center_x\": 7.246376811594204, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0002466138590582607}, {\"x\": 7.391304347826086, \"y\": -4.202898550724638, \"x2\": 7.681159420289854, \"y2\": -3.91304347826087, \"center_x\": 7.53623188405797, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00022213173155478084}, {\"x\": 7.681159420289855, \"y\": -4.202898550724638, \"x2\": 7.971014492753623, \"y2\": -3.91304347826087, \"center_x\": 7.826086956521739, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0001982209436974218}, {\"x\": 7.971014492753625, \"y\": -4.202898550724638, \"x2\": 8.260869565217392, \"y2\": -3.91304347826087, \"center_x\": 8.115942028985508, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00017524042240459845}, {\"x\": 8.26086956521739, \"y\": -4.202898550724638, \"x2\": 8.550724637681158, \"y2\": -3.91304347826087, \"center_x\": 8.405797101449274, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00015348461805964338}, {\"x\": 8.55072463768116, \"y\": -4.202898550724638, \"x2\": 8.840579710144928, \"y2\": -3.91304347826087, \"center_x\": 8.695652173913043, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0001331806833200212}, {\"x\": 8.84057971014493, \"y\": -4.202898550724638, \"x2\": 9.130434782608697, \"y2\": -3.91304347826087, \"center_x\": 8.985507246376812, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00011448891361810995}, {\"x\": 9.130434782608695, \"y\": -4.202898550724638, \"x2\": 9.420289855072463, \"y2\": -3.91304347826087, \"center_x\": 9.275362318840578, \"center_y\": -4.057971014492754, \"value_uncond\": 9.750602330155659e-05}, {\"x\": 9.420289855072465, \"y\": -4.202898550724638, \"x2\": 9.710144927536232, \"y2\": -3.91304347826087, \"center_x\": 9.565217391304348, \"center_y\": -4.057971014492754, \"value_uncond\": 8.227071450982501e-05}, {\"x\": 9.710144927536234, \"y\": -4.202898550724638, \"x2\": 10.000000000000002, \"y2\": -3.91304347826087, \"center_x\": 9.855072463768117, \"center_y\": -4.057971014492754, \"value_uncond\": 6.877093172144017e-05}, {\"x\": 10.0, \"y\": -4.202898550724638, \"x2\": 10.289855072463768, \"y2\": -3.91304347826087, \"center_x\": 10.144927536231883, \"center_y\": -4.057971014492754, \"value_uncond\": 5.695218124062533e-05}, {\"x\": -10.0, \"y\": -3.913043478260869, \"x2\": -9.710144927536232, \"y2\": -3.6231884057971016, \"center_x\": -9.855072463768117, \"center_y\": -3.7681159420289854, \"value_uncond\": 1.0181724065953475e-08}, {\"x\": -9.710144927536232, \"y\": -3.913043478260869, \"x2\": -9.420289855072465, \"y2\": -3.6231884057971016, \"center_x\": -9.565217391304348, \"center_y\": -3.7681159420289854, \"value_uncond\": 1.5907846367024987e-08}, {\"x\": -9.420289855072463, \"y\": -3.913043478260869, \"x2\": -9.130434782608695, \"y2\": -3.6231884057971016, \"center_x\": -9.275362318840578, \"center_y\": -3.7681159420289854, \"value_uncond\": 2.4623357331384997e-08}, {\"x\": -9.130434782608695, \"y\": -3.913043478260869, \"x2\": -8.840579710144928, \"y2\": -3.6231884057971016, \"center_x\": -8.985507246376812, \"center_y\": -3.7681159420289854, \"value_uncond\": 3.775973707685375e-08}, {\"x\": -8.840579710144928, \"y\": -3.913043478260869, \"x2\": -8.55072463768116, \"y2\": -3.6231884057971016, \"center_x\": -8.695652173913043, \"center_y\": -3.7681159420289854, \"value_uncond\": 5.736625118783737e-08}, {\"x\": -8.55072463768116, \"y\": -3.913043478260869, \"x2\": -8.260869565217392, \"y2\": -3.6231884057971016, \"center_x\": -8.405797101449277, \"center_y\": -3.7681159420289854, \"value_uncond\": 8.634352867076865e-08}, {\"x\": -8.26086956521739, \"y\": -3.913043478260869, \"x2\": -7.971014492753623, \"y2\": -3.6231884057971016, \"center_x\": -8.115942028985508, \"center_y\": -3.7681159420289854, \"value_uncond\": 1.287505019951189e-07}, {\"x\": -7.971014492753623, \"y\": -3.913043478260869, \"x2\": -7.681159420289855, \"y2\": -3.6231884057971016, \"center_x\": -7.826086956521739, \"center_y\": -3.7681159420289854, \"value_uncond\": 1.902014761801341e-07}, {\"x\": -7.681159420289855, \"y\": -3.913043478260869, \"x2\": -7.391304347826088, \"y2\": -3.6231884057971016, \"center_x\": -7.536231884057972, \"center_y\": -3.7681159420289854, \"value_uncond\": 2.783714233085887e-07}, {\"x\": -7.391304347826087, \"y\": -3.913043478260869, \"x2\": -7.101449275362319, \"y2\": -3.6231884057971016, \"center_x\": -7.246376811594203, \"center_y\": -3.7681159420289854, \"value_uncond\": 4.036279491765524e-07}, {\"x\": -7.101449275362318, \"y\": -3.913043478260869, \"x2\": -6.811594202898551, \"y2\": -3.6231884057971016, \"center_x\": -6.956521739130435, \"center_y\": -3.7681159420289854, \"value_uncond\": 5.798072307485984e-07}, {\"x\": -6.811594202898551, \"y\": -3.913043478260869, \"x2\": -6.521739130434783, \"y2\": -3.6231884057971016, \"center_x\": -6.666666666666667, \"center_y\": -3.7681159420289854, \"value_uncond\": 8.25147973654423e-07}, {\"x\": -6.521739130434782, \"y\": -3.913043478260869, \"x2\": -6.231884057971015, \"y2\": -3.6231884057971016, \"center_x\": -6.3768115942028984, \"center_y\": -3.7681159420289854, \"value_uncond\": 1.1633914356796153e-06}, {\"x\": -6.231884057971014, \"y\": -3.913043478260869, \"x2\": -5.942028985507246, \"y2\": -3.6231884057971016, \"center_x\": -6.08695652173913, \"center_y\": -3.7681159420289854, \"value_uncond\": 1.625046160338616e-06}, {\"x\": -5.942028985507246, \"y\": -3.913043478260869, \"x2\": -5.6521739130434785, \"y2\": -3.6231884057971016, \"center_x\": -5.797101449275362, \"center_y\": -3.7681159420289854, \"value_uncond\": 2.248802709485845e-06}, {\"x\": -5.6521739130434785, \"y\": -3.913043478260869, \"x2\": -5.362318840579711, \"y2\": -3.6231884057971016, \"center_x\": -5.507246376811595, \"center_y\": -3.7681159420289854, \"value_uncond\": 3.0830660178731517e-06}, {\"x\": -5.36231884057971, \"y\": -3.913043478260869, \"x2\": -5.072463768115942, \"y2\": -3.6231884057971016, \"center_x\": -5.217391304347826, \"center_y\": -3.7681159420289854, \"value_uncond\": 4.187550982121279e-06}, {\"x\": -5.0724637681159415, \"y\": -3.913043478260869, \"x2\": -4.782608695652174, \"y2\": -3.6231884057971016, \"center_x\": -4.927536231884058, \"center_y\": -3.7681159420289854, \"value_uncond\": 5.634860970130909e-06}, {\"x\": -4.782608695652174, \"y\": -3.913043478260869, \"x2\": -4.492753623188406, \"y2\": -3.6231884057971016, \"center_x\": -4.63768115942029, \"center_y\": -3.7681159420289854, \"value_uncond\": 7.511940117845491e-06}, {\"x\": -4.492753623188405, \"y\": -3.913043478260869, \"x2\": -4.202898550724638, \"y2\": -3.6231884057971016, \"center_x\": -4.3478260869565215, \"center_y\": -3.7681159420289854, \"value_uncond\": 9.921260294568287e-06}, {\"x\": -4.202898550724638, \"y\": -3.913043478260869, \"x2\": -3.91304347826087, \"y2\": -3.6231884057971016, \"center_x\": -4.057971014492754, \"center_y\": -3.7681159420289854, \"value_uncond\": 1.2981574952194378e-05}, {\"x\": -3.913043478260869, \"y\": -3.913043478260869, \"x2\": -3.6231884057971016, \"y2\": -3.6231884057971016, \"center_x\": -3.7681159420289854, \"center_y\": -3.7681159420289854, \"value_uncond\": 1.6828047955319243e-05}, {\"x\": -3.6231884057971016, \"y\": -3.913043478260869, \"x2\": -3.333333333333334, \"y2\": -3.6231884057971016, \"center_x\": -3.4782608695652177, \"center_y\": -3.7681159420289854, \"value_uncond\": 2.1611549765661293e-05}, {\"x\": -3.333333333333333, \"y\": -3.913043478260869, \"x2\": -3.0434782608695654, \"y2\": -3.6231884057971016, \"center_x\": -3.1884057971014492, \"center_y\": -3.7681159420289854, \"value_uncond\": 2.7496910250985696e-05}, {\"x\": -3.0434782608695645, \"y\": -3.913043478260869, \"x2\": -2.753623188405797, \"y2\": -3.6231884057971016, \"center_x\": -2.8985507246376807, \"center_y\": -3.7681159420289854, \"value_uncond\": 3.4659931139454876e-05}, {\"x\": -2.753623188405797, \"y\": -3.913043478260869, \"x2\": -2.4637681159420293, \"y2\": -3.6231884057971016, \"center_x\": -2.608695652173913, \"center_y\": -3.7681159420289854, \"value_uncond\": 4.328299549906327e-05}, {\"x\": -2.4637681159420284, \"y\": -3.913043478260869, \"x2\": -2.1739130434782608, \"y2\": -3.6231884057971016, \"center_x\": -2.3188405797101446, \"center_y\": -3.7681159420289854, \"value_uncond\": 5.354916928628562e-05}, {\"x\": -2.1739130434782608, \"y\": -3.913043478260869, \"x2\": -1.8840579710144931, \"y2\": -3.6231884057971016, \"center_x\": -2.028985507246377, \"center_y\": -3.7681159420289854, \"value_uncond\": 6.563477200651124e-05}, {\"x\": -1.8840579710144922, \"y\": -3.913043478260869, \"x2\": -1.5942028985507246, \"y2\": -3.6231884057971016, \"center_x\": -1.7391304347826084, \"center_y\": -3.7681159420289854, \"value_uncond\": 7.97004986423945e-05}, {\"x\": -1.5942028985507246, \"y\": -3.913043478260869, \"x2\": -1.304347826086957, \"y2\": -3.6231884057971016, \"center_x\": -1.4492753623188408, \"center_y\": -3.7681159420289854, \"value_uncond\": 9.588129931461353e-05}, {\"x\": -1.304347826086957, \"y\": -3.913043478260869, \"x2\": -1.0144927536231894, \"y2\": -3.6231884057971016, \"center_x\": -1.1594202898550732, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0001142753597830617}, {\"x\": -1.0144927536231876, \"y\": -3.913043478260869, \"x2\": -0.72463768115942, \"y2\": -3.6231884057971016, \"center_x\": -0.8695652173913038, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0001349326651410567}, {\"x\": -0.72463768115942, \"y\": -3.913043478260869, \"x2\": -0.43478260869565233, \"y2\": -3.6231884057971016, \"center_x\": -0.5797101449275361, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0001578437587237487}, {\"x\": -0.43478260869565233, \"y\": -3.913043478260869, \"x2\": -0.1449275362318847, \"y2\": -3.6231884057971016, \"center_x\": -0.2898550724637685, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00018292941455016692}, {\"x\": -0.14492753623188293, \"y\": -3.913043478260869, \"x2\": 0.1449275362318847, \"y2\": -3.6231884057971016, \"center_x\": 8.881784197001252e-16, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00021003201033098035}, {\"x\": 0.1449275362318847, \"y\": -3.913043478260869, \"x2\": 0.43478260869565233, \"y2\": -3.6231884057971016, \"center_x\": 0.2898550724637685, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00023890940605263985}, {\"x\": 0.43478260869565233, \"y\": -3.913043478260869, \"x2\": 0.72463768115942, \"y2\": -3.6231884057971016, \"center_x\": 0.5797101449275361, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0002692320899536763}, {\"x\": 0.72463768115942, \"y\": -3.913043478260869, \"x2\": 1.0144927536231876, \"y2\": -3.6231884057971016, \"center_x\": 0.8695652173913038, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00030058424322266115}, {\"x\": 1.0144927536231894, \"y\": -3.913043478260869, \"x2\": 1.304347826086957, \"y2\": -3.6231884057971016, \"center_x\": 1.1594202898550732, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0003324691965431773}, {\"x\": 1.304347826086957, \"y\": -3.913043478260869, \"x2\": 1.5942028985507246, \"y2\": -3.6231884057971016, \"center_x\": 1.4492753623188408, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00036431951186597375}, {\"x\": 1.5942028985507246, \"y\": -3.913043478260869, \"x2\": 1.8840579710144922, \"y2\": -3.6231884057971016, \"center_x\": 1.7391304347826084, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00039551163455088756}, {\"x\": 1.884057971014494, \"y\": -3.913043478260869, \"x2\": 2.1739130434782616, \"y2\": -3.6231884057971016, \"center_x\": 2.028985507246378, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00042538474371077597}, {\"x\": 2.1739130434782616, \"y\": -3.913043478260869, \"x2\": 2.4637681159420293, \"y2\": -3.6231884057971016, \"center_x\": 2.3188405797101455, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00045326310669087074}, {\"x\": 2.4637681159420293, \"y\": -3.913043478260869, \"x2\": 2.753623188405797, \"y2\": -3.6231884057971016, \"center_x\": 2.608695652173913, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0004784809446331656}, {\"x\": 2.753623188405797, \"y\": -3.913043478260869, \"x2\": 3.0434782608695645, \"y2\": -3.6231884057971016, \"center_x\": 2.8985507246376807, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0005004085679204973}, {\"x\": 3.0434782608695663, \"y\": -3.913043478260869, \"x2\": 3.333333333333334, \"y2\": -3.6231884057971016, \"center_x\": 3.18840579710145, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0005184783683895163}, {\"x\": 3.333333333333334, \"y\": -3.913043478260869, \"x2\": 3.6231884057971016, \"y2\": -3.6231884057971016, \"center_x\": 3.4782608695652177, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0005322091796084853}, {\"x\": 3.6231884057971016, \"y\": -3.913043478260869, \"x2\": 3.913043478260869, \"y2\": -3.6231884057971016, \"center_x\": 3.7681159420289854, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0005412275494716628}, {\"x\": 3.913043478260871, \"y\": -3.913043478260869, \"x2\": 4.202898550724639, \"y2\": -3.6231884057971016, \"center_x\": 4.057971014492755, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0005452846135366828}, {\"x\": 4.202898550724639, \"y\": -3.913043478260869, \"x2\": 4.492753623188406, \"y2\": -3.6231884057971016, \"center_x\": 4.347826086956522, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0005442675052706195}, {\"x\": 4.492753623188406, \"y\": -3.913043478260869, \"x2\": 4.782608695652174, \"y2\": -3.6231884057971016, \"center_x\": 4.63768115942029, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.000538204573064586}, {\"x\": 4.782608695652174, \"y\": -3.913043478260869, \"x2\": 5.0724637681159415, \"y2\": -3.6231884057971016, \"center_x\": 4.927536231884058, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0005272640674554986}, {\"x\": 5.072463768115943, \"y\": -3.913043478260869, \"x2\": 5.362318840579711, \"y2\": -3.6231884057971016, \"center_x\": 5.217391304347827, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0005117463834022716}, {\"x\": 5.362318840579711, \"y\": -3.913043478260869, \"x2\": 5.6521739130434785, \"y2\": -3.6231884057971016, \"center_x\": 5.507246376811595, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0004920703568434459}, {\"x\": 5.6521739130434785, \"y\": -3.913043478260869, \"x2\": 5.942028985507246, \"y2\": -3.6231884057971016, \"center_x\": 5.797101449275362, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0004687544879648525}, {\"x\": 5.942028985507246, \"y\": -3.913043478260869, \"x2\": 6.231884057971014, \"y2\": -3.6231884057971016, \"center_x\": 6.08695652173913, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00044239426561870794}, {\"x\": 6.2318840579710155, \"y\": -3.913043478260869, \"x2\": 6.521739130434783, \"y2\": -3.6231884057971016, \"center_x\": 6.376811594202899, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0004136369752263406}, {\"x\": 6.521739130434785, \"y\": -3.913043478260869, \"x2\": 6.8115942028985526, \"y2\": -3.6231884057971016, \"center_x\": 6.666666666666669, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00038315547252005096}, {\"x\": 6.811594202898551, \"y\": -3.913043478260869, \"x2\": 7.101449275362318, \"y2\": -3.6231884057971016, \"center_x\": 6.956521739130435, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.000351622394131174}, {\"x\": 7.10144927536232, \"y\": -3.913043478260869, \"x2\": 7.391304347826088, \"y2\": -3.6231884057971016, \"center_x\": 7.246376811594204, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00031968615995836775}, {\"x\": 7.391304347826086, \"y\": -3.913043478260869, \"x2\": 7.681159420289854, \"y2\": -3.6231884057971016, \"center_x\": 7.53623188405797, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0002879499170761312}, {\"x\": 7.681159420289855, \"y\": -3.913043478260869, \"x2\": 7.971014492753623, \"y2\": -3.6231884057971016, \"center_x\": 7.826086956521739, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00025695430320070645}, {\"x\": 7.971014492753625, \"y\": -3.913043478260869, \"x2\": 8.260869565217392, \"y2\": -3.6231884057971016, \"center_x\": 8.115942028985508, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00022716459619073407}, {\"x\": 8.26086956521739, \"y\": -3.913043478260869, \"x2\": 8.550724637681158, \"y2\": -3.6231884057971016, \"center_x\": 8.405797101449274, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00019896249281177862}, {\"x\": 8.55072463768116, \"y\": -3.913043478260869, \"x2\": 8.840579710144928, \"y2\": -3.6231884057971016, \"center_x\": 8.695652173913043, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00017264245161968284}, {\"x\": 8.84057971014493, \"y\": -3.913043478260869, \"x2\": 9.130434782608697, \"y2\": -3.6231884057971016, \"center_x\": 8.985507246376812, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00014841226398282917}, {\"x\": 9.130434782608695, \"y\": -3.913043478260869, \"x2\": 9.420289855072463, \"y2\": -3.6231884057971016, \"center_x\": 9.275362318840578, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00012639730095104576}, {\"x\": 9.420289855072465, \"y\": -3.913043478260869, \"x2\": 9.710144927536232, \"y2\": -3.6231884057971016, \"center_x\": 9.565217391304348, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00010664773220414889}, {\"x\": 9.710144927536234, \"y\": -3.913043478260869, \"x2\": 10.000000000000002, \"y2\": -3.6231884057971016, \"center_x\": 9.855072463768117, \"center_y\": -3.7681159420289854, \"value_uncond\": 8.914793013961349e-05}, {\"x\": 10.0, \"y\": -3.913043478260869, \"x2\": 10.289855072463768, \"y2\": -3.6231884057971016, \"center_x\": 10.144927536231883, \"center_y\": -3.7681159420289854, \"value_uncond\": 7.382725444382787e-05}, {\"x\": -10.0, \"y\": -3.6231884057971016, \"x2\": -9.710144927536232, \"y2\": -3.333333333333334, \"center_x\": -9.855072463768117, \"center_y\": -3.4782608695652177, \"value_uncond\": 1.3075957290817584e-08}, {\"x\": -9.710144927536232, \"y\": -3.6231884057971016, \"x2\": -9.420289855072465, \"y2\": -3.333333333333334, \"center_x\": -9.565217391304348, \"center_y\": -3.4782608695652177, \"value_uncond\": 2.0429773812047134e-08}, {\"x\": -9.420289855072463, \"y\": -3.6231884057971016, \"x2\": -9.130434782608695, \"y2\": -3.333333333333334, \"center_x\": -9.275362318840578, \"center_y\": -3.4782608695652177, \"value_uncond\": 3.16227356718863e-08}, {\"x\": -9.130434782608695, \"y\": -3.6231884057971016, \"x2\": -8.840579710144928, \"y2\": -3.333333333333334, \"center_x\": -8.985507246376812, \"center_y\": -3.4782608695652177, \"value_uncond\": 4.8493232200278026e-08}, {\"x\": -8.840579710144928, \"y\": -3.6231884057971016, \"x2\": -8.55072463768116, \"y2\": -3.333333333333334, \"center_x\": -8.695652173913043, \"center_y\": -3.4782608695652177, \"value_uncond\": 7.36730484550044e-08}, {\"x\": -8.55072463768116, \"y\": -3.6231884057971016, \"x2\": -8.260869565217392, \"y2\": -3.333333333333334, \"center_x\": -8.405797101449277, \"center_y\": -3.4782608695652177, \"value_uncond\": 1.1088733950400234e-07}, {\"x\": -8.26086956521739, \"y\": -3.6231884057971016, \"x2\": -7.971014492753623, \"y2\": -3.333333333333334, \"center_x\": -8.115942028985508, \"center_y\": -3.4782608695652177, \"value_uncond\": 1.6534882052923152e-07}, {\"x\": -7.971014492753623, \"y\": -3.6231884057971016, \"x2\": -7.681159420289855, \"y2\": -3.333333333333334, \"center_x\": -7.826086956521739, \"center_y\": -3.4782608695652177, \"value_uncond\": 2.442677058493814e-07}, {\"x\": -7.681159420289855, \"y\": -3.6231884057971016, \"x2\": -7.391304347826088, \"y2\": -3.333333333333334, \"center_x\": -7.536231884057972, \"center_y\": -3.4782608695652177, \"value_uncond\": 3.575006372780089e-07}, {\"x\": -7.391304347826087, \"y\": -3.6231884057971016, \"x2\": -7.101449275362319, \"y2\": -3.333333333333334, \"center_x\": -7.246376811594203, \"center_y\": -3.4782608695652177, \"value_uncond\": 5.183622921447384e-07}, {\"x\": -7.101449275362318, \"y\": -3.6231884057971016, \"x2\": -6.811594202898551, \"y2\": -3.333333333333334, \"center_x\": -6.956521739130435, \"center_y\": -3.4782608695652177, \"value_uncond\": 7.446218869285287e-07}, {\"x\": -6.811594202898551, \"y\": -3.6231884057971016, \"x2\": -6.521739130434783, \"y2\": -3.333333333333334, \"center_x\": -6.666666666666667, \"center_y\": -3.4782608695652177, \"value_uncond\": 1.0597026193421523e-06}, {\"x\": -6.521739130434782, \"y\": -3.6231884057971016, \"x2\": -6.231884057971015, \"y2\": -3.333333333333334, \"center_x\": -6.3768115942028984, \"center_y\": -3.4782608695652177, \"value_uncond\": 1.4940943819444437e-06}, {\"x\": -6.231884057971014, \"y\": -3.6231884057971016, \"x2\": -5.942028985507246, \"y2\": -3.333333333333334, \"center_x\": -6.08695652173913, \"center_y\": -3.4782608695652177, \"value_uncond\": 2.0869780059399955e-06}, {\"x\": -5.942028985507246, \"y\": -3.6231884057971016, \"x2\": -5.6521739130434785, \"y2\": -3.333333333333334, \"center_x\": -5.797101449275362, \"center_y\": -3.4782608695652177, \"value_uncond\": 2.8880421423950747e-06}, {\"x\": -5.6521739130434785, \"y\": -3.6231884057971016, \"x2\": -5.362318840579711, \"y2\": -3.333333333333334, \"center_x\": -5.507246376811595, \"center_y\": -3.4782608695652177, \"value_uncond\": 3.959451200341003e-06}, {\"x\": -5.36231884057971, \"y\": -3.6231884057971016, \"x2\": -5.072463768115942, \"y2\": -3.333333333333334, \"center_x\": -5.217391304347826, \"center_y\": -3.4782608695652177, \"value_uncond\": 5.377894494159164e-06}, {\"x\": -5.0724637681159415, \"y\": -3.6231884057971016, \"x2\": -4.782608695652174, \"y2\": -3.333333333333334, \"center_x\": -4.927536231884058, \"center_y\": -3.4782608695652177, \"value_uncond\": 7.2366134564094345e-06}, {\"x\": -4.782608695652174, \"y\": -3.6231884057971016, \"x2\": -4.492753623188406, \"y2\": -3.333333333333334, \"center_x\": -4.63768115942029, \"center_y\": -3.4782608695652177, \"value_uncond\": 9.647266761096261e-06}, {\"x\": -4.492753623188405, \"y\": -3.6231884057971016, \"x2\": -4.202898550724638, \"y2\": -3.333333333333334, \"center_x\": -4.3478260869565215, \"center_y\": -3.4782608695652177, \"value_uncond\": 1.2741454692988741e-05}, {\"x\": -4.202898550724638, \"y\": -3.6231884057971016, \"x2\": -3.91304347826087, \"y2\": -3.333333333333334, \"center_x\": -4.057971014492754, \"center_y\": -3.4782608695652177, \"value_uncond\": 1.667168728428361e-05}, {\"x\": -3.913043478260869, \"y\": -3.6231884057971016, \"x2\": -3.6231884057971016, \"y2\": -3.333333333333334, \"center_x\": -3.7681159420289854, \"center_y\": -3.4782608695652177, \"value_uncond\": 2.1611549765661293e-05}, {\"x\": -3.6231884057971016, \"y\": -3.6231884057971016, \"x2\": -3.333333333333334, \"y2\": -3.333333333333334, \"center_x\": -3.4782608695652177, \"center_y\": -3.4782608695652177, \"value_uncond\": 2.775479868572752e-05}, {\"x\": -3.333333333333333, \"y\": -3.6231884057971016, \"x2\": -3.0434782608695654, \"y2\": -3.333333333333334, \"center_x\": -3.1884057971014492, \"center_y\": -3.4782608695652177, \"value_uncond\": 3.5313118067461914e-05}, {\"x\": -3.0434782608695645, \"y\": -3.6231884057971016, \"x2\": -2.753623188405797, \"y2\": -3.333333333333334, \"center_x\": -2.8985507246376807, \"center_y\": -3.4782608695652177, \"value_uncond\": 4.451228262978362e-05}, {\"x\": -2.753623188405797, \"y\": -3.6231884057971016, \"x2\": -2.4637681159420293, \"y2\": -3.333333333333334, \"center_x\": -2.608695652173913, \"center_y\": -3.4782608695652177, \"value_uncond\": 5.5586519227812194e-05}, {\"x\": -2.4637681159420284, \"y\": -3.6231884057971016, \"x2\": -2.1739130434782608, \"y2\": -3.333333333333334, \"center_x\": -2.3188405797101446, \"center_y\": -3.4782608695652177, \"value_uncond\": 6.87709317214403e-05}, {\"x\": -2.1739130434782608, \"y\": -3.6231884057971016, \"x2\": -1.8840579710144931, \"y2\": -3.333333333333334, \"center_x\": -2.028985507246377, \"center_y\": -3.4782608695652177, \"value_uncond\": 8.429195978896527e-05}, {\"x\": -1.8840579710144922, \"y\": -3.6231884057971016, \"x2\": -1.5942028985507246, \"y2\": -3.333333333333334, \"center_x\": -1.7391304347826084, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00010235597719542227}, {\"x\": -1.5942028985507246, \"y\": -3.6231884057971016, \"x2\": -1.304347826086957, \"y2\": -3.333333333333334, \"center_x\": -1.4492753623188408, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00012313629466922468}, {\"x\": -1.304347826086957, \"y\": -3.6231884057971016, \"x2\": -1.0144927536231894, \"y2\": -3.333333333333334, \"center_x\": -1.1594202898550732, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00014675900802623028}, {\"x\": -1.0144927536231876, \"y\": -3.6231884057971016, \"x2\": -0.72463768115942, \"y2\": -3.333333333333334, \"center_x\": -0.8695652173913038, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0001732883110062385}, {\"x\": -0.72463768115942, \"y\": -3.6231884057971016, \"x2\": -0.43478260869565233, \"y2\": -3.333333333333334, \"center_x\": -0.5797101449275361, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0002027120588148225}, {\"x\": -0.43478260869565233, \"y\": -3.6231884057971016, \"x2\": -0.1449275362318847, \"y2\": -3.333333333333334, \"center_x\": -0.2898550724637685, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00023492850487774914}, {\"x\": -0.14492753623188293, \"y\": -3.6231884057971016, \"x2\": 0.1449275362318847, \"y2\": -3.333333333333334, \"center_x\": 8.881784197001252e-16, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00026973522155997187}, {\"x\": 0.1449275362318847, \"y\": -3.6231884057971016, \"x2\": 0.43478260869565233, \"y2\": -3.333333333333334, \"center_x\": 0.2898550724637685, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0003068212386903227}, {\"x\": 0.43478260869565233, \"y\": -3.6231884057971016, \"x2\": 0.72463768115942, \"y2\": -3.333333333333334, \"center_x\": 0.5797101449275361, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00034576337825966737}, {\"x\": 0.72463768115942, \"y\": -3.6231884057971016, \"x2\": 1.0144927536231876, \"y2\": -3.333333333333334, \"center_x\": 0.8695652173913038, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0003860276217674317}, {\"x\": 1.0144927536231894, \"y\": -3.6231884057971016, \"x2\": 1.304347826086957, \"y2\": -3.333333333333334, \"center_x\": 1.1594202898550732, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0004269761178313679}, {\"x\": 1.304347826086957, \"y\": -3.6231884057971016, \"x2\": 1.5942028985507246, \"y2\": -3.333333333333334, \"center_x\": 1.4492753623188408, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0004678801297808369}, {\"x\": 1.5942028985507246, \"y\": -3.6231884057971016, \"x2\": 1.8840579710144922, \"y2\": -3.333333333333334, \"center_x\": 1.7391304347826084, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0005079388527825471}, {\"x\": 1.884057971014494, \"y\": -3.6231884057971016, \"x2\": 2.1739130434782616, \"y2\": -3.333333333333334, \"center_x\": 2.028985507246378, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.000546303622539451}, {\"x\": 2.1739130434782616, \"y\": -3.6231884057971016, \"x2\": 2.4637681159420293, \"y2\": -3.333333333333334, \"center_x\": 2.3188405797101455, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0005821066242024599}, {\"x\": 2.4637681159420293, \"y\": -3.6231884057971016, \"x2\": 2.753623188405797, \"y2\": -3.333333333333334, \"center_x\": 2.608695652173913, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0006144928261623858}, {\"x\": 2.753623188405797, \"y\": -3.6231884057971016, \"x2\": 3.0434782608695645, \"y2\": -3.333333333333334, \"center_x\": 2.8985507246376807, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0006426535446946294}, {\"x\": 3.0434782608695663, \"y\": -3.6231884057971016, \"x2\": 3.333333333333334, \"y2\": -3.333333333333334, \"center_x\": 3.18840579710145, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0006658598246582143}, {\"x\": 3.333333333333334, \"y\": -3.6231884057971016, \"x2\": 3.6231884057971016, \"y2\": -3.333333333333334, \"center_x\": 3.4782608695652177, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0006834937243695501}, {\"x\": 3.6231884057971016, \"y\": -3.6231884057971016, \"x2\": 3.913043478260869, \"y2\": -3.333333333333334, \"center_x\": 3.7681159420289854, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0006950756350950657}, {\"x\": 3.913043478260871, \"y\": -3.6231884057971016, \"x2\": 4.202898550724639, \"y2\": -3.333333333333334, \"center_x\": 4.057971014492755, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0007002859507642661}, {\"x\": 4.202898550724639, \"y\": -3.6231884057971016, \"x2\": 4.492753623188406, \"y2\": -3.333333333333334, \"center_x\": 4.347826086956522, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0006989797216658312}, {\"x\": 4.492753623188406, \"y\": -3.6231884057971016, \"x2\": 4.782608695652174, \"y2\": -3.333333333333334, \"center_x\": 4.63768115942029, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0006911933544386626}, {\"x\": 4.782608695652174, \"y\": -3.6231884057971016, \"x2\": 5.0724637681159415, \"y2\": -3.333333333333334, \"center_x\": 4.927536231884058, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0006771429261263549}, {\"x\": 5.072463768115943, \"y\": -3.6231884057971016, \"x2\": 5.362318840579711, \"y2\": -3.333333333333334, \"center_x\": 5.217391304347827, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0006572142212608497}, {\"x\": 5.362318840579711, \"y\": -3.6231884057971016, \"x2\": 5.6521739130434785, \"y2\": -3.333333333333334, \"center_x\": 5.507246376811595, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.000631945133111376}, {\"x\": 5.6521739130434785, \"y\": -3.6231884057971016, \"x2\": 5.942028985507246, \"y2\": -3.333333333333334, \"center_x\": 5.797101449275362, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0006020015495218082}, {\"x\": 5.942028985507246, \"y\": -3.6231884057971016, \"x2\": 6.231884057971014, \"y2\": -3.333333333333334, \"center_x\": 6.08695652173913, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0005681482316218242}, {\"x\": 6.2318840579710155, \"y\": -3.6231884057971016, \"x2\": 6.521739130434783, \"y2\": -3.333333333333334, \"center_x\": 6.376811594202899, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0005312164606825947}, {\"x\": 6.521739130434785, \"y\": -3.6231884057971016, \"x2\": 6.8115942028985526, \"y2\": -3.333333333333334, \"center_x\": 6.666666666666669, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.000492070356843445}, {\"x\": 6.811594202898551, \"y\": -3.6231884057971016, \"x2\": 7.101449275362318, \"y2\": -3.333333333333334, \"center_x\": 6.956521739130435, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0004515737588616033}, {\"x\": 7.10144927536232, \"y\": -3.6231884057971016, \"x2\": 7.391304347826088, \"y2\": -3.333333333333334, \"center_x\": 7.246376811594204, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00041055940496946086}, {\"x\": 7.391304347826086, \"y\": -3.6231884057971016, \"x2\": 7.681159420289854, \"y2\": -3.333333333333334, \"center_x\": 7.53623188405797, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0003698018914274478}, {\"x\": 7.681159420289855, \"y\": -3.6231884057971016, \"x2\": 7.971014492753623, \"y2\": -3.333333333333334, \"center_x\": 7.826086956521739, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00032999553637280677}, {\"x\": 7.971014492753625, \"y\": -3.6231884057971016, \"x2\": 8.260869565217392, \"y2\": -3.333333333333334, \"center_x\": 8.115942028985508, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00029173787646716157}, {\"x\": 8.26086956521739, \"y\": -3.6231884057971016, \"x2\": 8.550724637681158, \"y2\": -3.333333333333334, \"center_x\": 8.405797101449274, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.000255519108711751}, {\"x\": 8.55072463768116, \"y\": -3.6231884057971016, \"x2\": 8.840579710144928, \"y2\": -3.333333333333334, \"center_x\": 8.695652173913043, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0002217173937673012}, {\"x\": 8.84057971014493, \"y\": -3.6231884057971016, \"x2\": 9.130434782608697, \"y2\": -3.333333333333334, \"center_x\": 8.985507246376812, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00019059958929374977}, {\"x\": 9.130434782608695, \"y\": -3.6231884057971016, \"x2\": 9.420289855072463, \"y2\": -3.333333333333334, \"center_x\": 9.275362318840578, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00016232670402423812}, {\"x\": 9.420289855072465, \"y\": -3.6231884057971016, \"x2\": 9.710144927536232, \"y2\": -3.333333333333334, \"center_x\": 9.565217391304348, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00013696316875519372}, {\"x\": 9.710144927536234, \"y\": -3.6231884057971016, \"x2\": 10.000000000000002, \"y2\": -3.333333333333334, \"center_x\": 9.855072463768117, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00011448891361810975}, {\"x\": 10.0, \"y\": -3.6231884057971016, \"x2\": 10.289855072463768, \"y2\": -3.333333333333334, \"center_x\": 10.144927536231883, \"center_y\": -3.4782608695652177, \"value_uncond\": 9.48132182479661e-05}, {\"x\": -10.0, \"y\": -3.333333333333333, \"x2\": -9.710144927536232, \"y2\": -3.0434782608695654, \"center_x\": -9.855072463768117, \"center_y\": -3.1884057971014492, \"value_uncond\": 1.663686445303529e-08}, {\"x\": -9.710144927536232, \"y\": -3.333333333333333, \"x2\": -9.420289855072465, \"y2\": -3.0434782608695654, \"center_x\": -9.565217391304348, \"center_y\": -3.1884057971014492, \"value_uncond\": 2.5993307423532162e-08}, {\"x\": -9.420289855072463, \"y\": -3.333333333333333, \"x2\": -9.130434782608695, \"y2\": -3.0434782608695654, \"center_x\": -9.275362318840578, \"center_y\": -3.1884057971014492, \"value_uncond\": 4.0234390133469245e-08}, {\"x\": -9.130434782608695, \"y\": -3.333333333333333, \"x2\": -8.840579710144928, \"y2\": -3.0434782608695654, \"center_x\": -8.985507246376812, \"center_y\": -3.1884057971014492, \"value_uncond\": 6.169914087836146e-08}, {\"x\": -8.840579710144928, \"y\": -3.333333333333333, \"x2\": -8.55072463768116, \"y2\": -3.0434782608695654, \"center_x\": -8.695652173913043, \"center_y\": -3.1884057971014492, \"value_uncond\": 9.373604499676155e-08}, {\"x\": -8.55072463768116, \"y\": -3.333333333333333, \"x2\": -8.260869565217392, \"y2\": -3.0434782608695654, \"center_x\": -8.405797101449277, \"center_y\": -3.1884057971014492, \"value_uncond\": 1.41084709582318e-07}, {\"x\": -8.26086956521739, \"y\": -3.333333333333333, \"x2\": -7.971014492753623, \"y2\": -3.0434782608695654, \"center_x\": -8.115942028985508, \"center_y\": -3.1884057971014492, \"value_uncond\": 2.1037740132004386e-07}, {\"x\": -7.971014492753623, \"y\": -3.333333333333333, \"x2\": -7.681159420289855, \"y2\": -3.0434782608695654, \"center_x\": -7.826086956521739, \"center_y\": -3.1884057971014492, \"value_uncond\": 3.1078785454001425e-07}, {\"x\": -7.681159420289855, \"y\": -3.333333333333333, \"x2\": -7.391304347826088, \"y2\": -3.0434782608695654, \"center_x\": -7.536231884057972, \"center_y\": -3.1884057971014492, \"value_uncond\": 4.548569188463666e-07}, {\"x\": -7.391304347826087, \"y\": -3.333333333333333, \"x2\": -7.101449275362319, \"y2\": -3.0434782608695654, \"center_x\": -7.246376811594203, \"center_y\": -3.1884057971014492, \"value_uncond\": 6.595251881124395e-07}, {\"x\": -7.101449275362318, \"y\": -3.333333333333333, \"x2\": -6.811594202898551, \"y2\": -3.0434782608695654, \"center_x\": -6.956521739130435, \"center_y\": -3.1884057971014492, \"value_uncond\": 9.474008767444301e-07}, {\"x\": -6.811594202898551, \"y\": -3.333333333333333, \"x2\": -6.521739130434783, \"y2\": -3.0434782608695654, \"center_x\": -6.666666666666667, \"center_y\": -3.1884057971014492, \"value_uncond\": 1.3482858995648702e-06}, {\"x\": -6.521739130434782, \"y\": -3.333333333333333, \"x2\": -6.231884057971015, \"y2\": -3.0434782608695654, \"center_x\": -6.3768115942028984, \"center_y\": -3.1884057971014492, \"value_uncond\": 1.9009733023452697e-06}, {\"x\": -6.231884057971014, \"y\": -3.333333333333333, \"x2\": -5.942028985507246, \"y2\": -3.0434782608695654, \"center_x\": -6.08695652173913, \"center_y\": -3.1884057971014492, \"value_uncond\": 2.6553138274374587e-06}, {\"x\": -5.942028985507246, \"y\": -3.333333333333333, \"x2\": -5.6521739130434785, \"y2\": -3.0434782608695654, \"center_x\": -5.797101449275362, \"center_y\": -3.1884057971014492, \"value_uncond\": 3.674527576762701e-06}, {\"x\": -5.6521739130434785, \"y\": -3.333333333333333, \"x2\": -5.362318840579711, \"y2\": -3.0434782608695654, \"center_x\": -5.507246376811595, \"center_y\": -3.1884057971014492, \"value_uncond\": 5.037707868221586e-06}, {\"x\": -5.36231884057971, \"y\": -3.333333333333333, \"x2\": -5.072463768115942, \"y2\": -3.0434782608695654, \"center_x\": -5.217391304347826, \"center_y\": -3.1884057971014492, \"value_uncond\": 6.842428416685089e-06}, {\"x\": -5.0724637681159415, \"y\": -3.333333333333333, \"x2\": -4.782608695652174, \"y2\": -3.0434782608695654, \"center_x\": -4.927536231884058, \"center_y\": -3.1884057971014492, \"value_uncond\": 9.207322607105823e-06}, {\"x\": -4.782608695652174, \"y\": -3.333333333333333, \"x2\": -4.492753623188406, \"y2\": -3.0434782608695654, \"center_x\": -4.63768115942029, \"center_y\": -3.1884057971014492, \"value_uncond\": 1.227445653706291e-05}, {\"x\": -4.492753623188405, \"y\": -3.333333333333333, \"x2\": -4.202898550724638, \"y2\": -3.0434782608695654, \"center_x\": -4.3478260869565215, \"center_y\": -3.1884057971014492, \"value_uncond\": 1.621126850961822e-05}, {\"x\": -4.202898550724638, \"y\": -3.333333333333333, \"x2\": -3.91304347826087, \"y2\": -3.0434782608695654, \"center_x\": -4.057971014492754, \"center_y\": -3.1884057971014492, \"value_uncond\": 2.1211800817580984e-05}, {\"x\": -3.913043478260869, \"y\": -3.333333333333333, \"x2\": -3.6231884057971016, \"y2\": -3.0434782608695654, \"center_x\": -3.7681159420289854, \"center_y\": -3.1884057971014492, \"value_uncond\": 2.7496910250985696e-05}, {\"x\": -3.6231884057971016, \"y\": -3.333333333333333, \"x2\": -3.333333333333334, \"y2\": -3.0434782608695654, \"center_x\": -3.4782608695652177, \"center_y\": -3.1884057971014492, \"value_uncond\": 3.5313118067461914e-05}, {\"x\": -3.333333333333333, \"y\": -3.333333333333333, \"x2\": -3.0434782608695654, \"y2\": -3.0434782608695654, \"center_x\": -3.1884057971014492, \"center_y\": -3.1884057971014492, \"value_uncond\": 4.492975509448617e-05}, {\"x\": -3.0434782608695645, \"y\": -3.333333333333333, \"x2\": -2.753623188405797, \"y2\": -3.0434782608695654, \"center_x\": -2.8985507246376807, \"center_y\": -3.1884057971014492, \"value_uncond\": 5.6634080101113846e-05}, {\"x\": -2.753623188405797, \"y\": -3.333333333333333, \"x2\": -2.4637681159420293, \"y2\": -3.0434782608695654, \"center_x\": -2.608695652173913, \"center_y\": -3.1884057971014492, \"value_uncond\": 7.072410571871243e-05}, {\"x\": -2.4637681159420284, \"y\": -3.333333333333333, \"x2\": -2.1739130434782608, \"y2\": -3.0434782608695654, \"center_x\": -2.3188405797101446, \"center_y\": -3.1884057971014492, \"value_uncond\": 8.749896041355213e-05}, {\"x\": -2.1739130434782608, \"y\": -3.333333333333333, \"x2\": -1.8840579710144931, \"y2\": -3.0434782608695654, \"center_x\": -2.028985507246377, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.00010724674899898157}, {\"x\": -1.8840579710144922, \"y\": -3.333333333333333, \"x2\": -1.5942028985507246, \"y2\": -3.0434782608695654, \"center_x\": -1.7391304347826084, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0001302300459297184}, {\"x\": -1.5942028985507246, \"y\": -3.333333333333333, \"x2\": -1.304347826086957, \"y2\": -3.0434782608695654, \"center_x\": -1.4492753623188408, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.00015666935873976176}, {\"x\": -1.304347826086957, \"y\": -3.333333333333333, \"x2\": -1.0144927536231894, \"y2\": -3.0434782608695654, \"center_x\": -1.1594202898550732, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.00018672512225998927}, {\"x\": -1.0144927536231876, \"y\": -3.333333333333333, \"x2\": -0.72463768115942, \"y2\": -3.0434782608695654, \"center_x\": -0.8695652173913038, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.00022047901177611992}, {\"x\": -0.72463768115942, \"y\": -3.333333333333333, \"x2\": -0.43478260869565233, \"y2\": -3.0434782608695654, \"center_x\": -0.5797101449275361, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0002579155751652848}, {\"x\": -0.43478260869565233, \"y\": -3.333333333333333, \"x2\": -0.1449275362318847, \"y2\": -3.0434782608695654, \"center_x\": -0.2898550724637685, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.00029890535774004296}, {\"x\": -0.14492753623188293, \"y\": -3.333333333333333, \"x2\": 0.1449275362318847, \"y2\": -3.0434782608695654, \"center_x\": 8.881784197001252e-16, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0003431908058046359}, {\"x\": 0.1449275362318847, \"y\": -3.333333333333333, \"x2\": 0.43478260869565233, \"y2\": -3.0434782608695654, \"center_x\": 0.2898550724637685, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0003903762643051674}, {\"x\": 0.43478260869565233, \"y\": -3.333333333333333, \"x2\": 0.72463768115942, \"y2\": -3.0434782608695654, \"center_x\": 0.5797101449275361, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0004399233133752442}, {\"x\": 0.72463768115942, \"y\": -3.333333333333333, \"x2\": 1.0144927536231876, \"y2\": -3.0434782608695654, \"center_x\": 0.8695652173913038, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.000491152508044845}, {\"x\": 1.0144927536231894, \"y\": -3.333333333333333, \"x2\": 1.304347826086957, \"y2\": -3.0434782608695654, \"center_x\": 1.1594202898550732, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0005432522941958565}, {\"x\": 1.304347826086957, \"y\": -3.333333333333333, \"x2\": 1.5942028985507246, \"y2\": -3.0434782608695654, \"center_x\": 1.4492753623188408, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0005952954821058184}, {\"x\": 1.5942028985507246, \"y\": -3.333333333333333, \"x2\": 1.8840579710144922, \"y2\": -3.0434782608695654, \"center_x\": 1.7391304347826084, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0006462631879432444}, {\"x\": 1.884057971014494, \"y\": -3.333333333333333, \"x2\": 2.1739130434782616, \"y2\": -3.0434782608695654, \"center_x\": 2.028985507246378, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0006950756350950666}, {\"x\": 2.1739130434782616, \"y\": -3.333333333333333, \"x2\": 2.4637681159420293, \"y2\": -3.0434782608695654, \"center_x\": 2.3188405797101455, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0007406286812263477}, {\"x\": 2.4637681159420293, \"y\": -3.333333333333333, \"x2\": 2.753623188405797, \"y2\": -3.0434782608695654, \"center_x\": 2.608695652173913, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0007818344484350156}, {\"x\": 2.753623188405797, \"y\": -3.333333333333333, \"x2\": 3.0434782608695645, \"y2\": -3.0434782608695654, \"center_x\": 2.8985507246376807, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0008176640283809533}, {\"x\": 3.0434782608695663, \"y\": -3.333333333333333, \"x2\": 3.333333333333334, \"y2\": -3.0434782608695654, \"center_x\": 3.18840579710145, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.000847189953376477}, {\"x\": 3.333333333333334, \"y\": -3.333333333333333, \"x2\": 3.6231884057971016, \"y2\": -3.0434782608695654, \"center_x\": 3.4782608695652177, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.000869626000906391}, {\"x\": 3.6231884057971016, \"y\": -3.333333333333333, \"x2\": 3.913043478260869, \"y2\": -3.0434782608695654, \"center_x\": 3.7681159420289854, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0008843619528953801}, {\"x\": 3.913043478260871, \"y\": -3.333333333333333, \"x2\": 4.202898550724639, \"y2\": -3.0434782608695654, \"center_x\": 4.057971014492755, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.000890991166620855}, {\"x\": 4.202898550724639, \"y\": -3.333333333333333, \"x2\": 4.492753623188406, \"y2\": -3.0434782608695654, \"center_x\": 4.347826086956522, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0008893292189735857}, {\"x\": 4.492753623188406, \"y\": -3.333333333333333, \"x2\": 4.782608695652174, \"y2\": -3.0434782608695654, \"center_x\": 4.63768115942029, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0008794224310223179}, {\"x\": 4.782608695652174, \"y\": -3.333333333333333, \"x2\": 5.0724637681159415, \"y2\": -3.0434782608695654, \"center_x\": 4.927536231884058, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0008615457229435064}, {\"x\": 5.072463768115943, \"y\": -3.333333333333333, \"x2\": 5.362318840579711, \"y2\": -3.0434782608695654, \"center_x\": 5.217391304347827, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0008361899379559874}, {\"x\": 5.362318840579711, \"y\": -3.333333333333333, \"x2\": 5.6521739130434785, \"y2\": -3.0434782608695654, \"center_x\": 5.507246376811595, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0008040394509939493}, {\"x\": 5.6521739130434785, \"y\": -3.333333333333333, \"x2\": 5.942028985507246, \"y2\": -3.0434782608695654, \"center_x\": 5.797101449275362, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0007659414876603125}, {\"x\": 5.942028985507246, \"y\": -3.333333333333333, \"x2\": 6.231884057971014, \"y2\": -3.0434782608695654, \"center_x\": 6.08695652173913, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0007228690724893748}, {\"x\": 6.2318840579710155, \"y\": -3.333333333333333, \"x2\": 6.521739130434783, \"y2\": -3.0434782608695654, \"center_x\": 6.376811594202899, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0006758798652396703}, {\"x\": 6.521739130434785, \"y\": -3.333333333333333, \"x2\": 6.8115942028985526, \"y2\": -3.0434782608695654, \"center_x\": 6.666666666666669, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0006260733073753584}, {\"x\": 6.811594202898551, \"y\": -3.333333333333333, \"x2\": 7.101449275362318, \"y2\": -3.0434782608695654, \"center_x\": 6.956521739130435, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0005745484823511837}, {\"x\": 7.10144927536232, \"y\": -3.333333333333333, \"x2\": 7.391304347826088, \"y2\": -3.0434782608695654, \"center_x\": 7.246376811594204, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0005223649036535408}, {\"x\": 7.391304347826086, \"y\": -3.333333333333333, \"x2\": 7.681159420289854, \"y2\": -3.0434782608695654, \"center_x\": 7.53623188405797, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.00047050810929727627}, {\"x\": 7.681159420289855, \"y\": -3.333333333333333, \"x2\": 7.971014492753623, \"y2\": -3.0434782608695654, \"center_x\": 7.826086956521739, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0004198614974519994}, {\"x\": 7.971014492753625, \"y\": -3.333333333333333, \"x2\": 8.260869565217392, \"y2\": -3.0434782608695654, \"center_x\": 8.115942028985508, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.00037118532881786785}, {\"x\": 8.26086956521739, \"y\": -3.333333333333333, \"x2\": 8.550724637681158, \"y2\": -3.0434782608695654, \"center_x\": 8.405797101449274, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0003251032931855033}, {\"x\": 8.55072463768116, \"y\": -3.333333333333333, \"x2\": 8.840579710144928, \"y2\": -3.0434782608695654, \"center_x\": 8.695652173913043, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0002820965337334934}, {\"x\": 8.84057971014493, \"y\": -3.333333333333333, \"x2\": 9.130434782608697, \"y2\": -3.0434782608695654, \"center_x\": 8.985507246376812, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0002425045800746907}, {\"x\": 9.130434782608695, \"y\": -3.333333333333333, \"x2\": 9.420289855072463, \"y2\": -3.0434782608695654, \"center_x\": 9.275362318840578, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.000206532287609695}, {\"x\": 9.420289855072465, \"y\": -3.333333333333333, \"x2\": 9.710144927536232, \"y2\": -3.0434782608695654, \"center_x\": 9.565217391304348, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.00017426163323724657}, {\"x\": 9.710144927536234, \"y\": -3.333333333333333, \"x2\": 10.000000000000002, \"y2\": -3.0434782608695654, \"center_x\": 9.855072463768117, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.00014566708156635937}, {\"x\": 10.0, \"y\": -3.333333333333333, \"x2\": 10.289855072463768, \"y2\": -3.0434782608695654, \"center_x\": 10.144927536231883, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.00012063320682877794}, {\"x\": -10.0, \"y\": -3.0434782608695645, \"x2\": -9.710144927536232, \"y2\": -2.753623188405797, \"center_x\": -9.855072463768117, \"center_y\": -2.8985507246376807, \"value_uncond\": 2.097081348614346e-08}, {\"x\": -9.710144927536232, \"y\": -3.0434782608695645, \"x2\": -9.420289855072465, \"y2\": -2.753623188405797, \"center_x\": -9.565217391304348, \"center_y\": -2.8985507246376807, \"value_uncond\": 3.276463563225292e-08}, {\"x\": -9.420289855072463, \"y\": -3.0434782608695645, \"x2\": -9.130434782608695, \"y2\": -2.753623188405797, \"center_x\": -9.275362318840578, \"center_y\": -2.8985507246376807, \"value_uncond\": 5.071555962961394e-08}, {\"x\": -9.130434782608695, \"y\": -3.0434782608695645, \"x2\": -8.840579710144928, \"y2\": -2.753623188405797, \"center_x\": -8.985507246376812, \"center_y\": -2.8985507246376807, \"value_uncond\": 7.777193708994542e-08}, {\"x\": -8.840579710144928, \"y\": -3.0434782608695645, \"x2\": -8.55072463768116, \"y2\": -2.753623188405797, \"center_x\": -8.695652173913043, \"center_y\": -2.8985507246376807, \"value_uncond\": 1.1815454300928705e-07}, {\"x\": -8.55072463768116, \"y\": -3.0434782608695645, \"x2\": -8.260869565217392, \"y2\": -2.753623188405797, \"center_x\": -8.405797101449277, \"center_y\": -2.8985507246376807, \"value_uncond\": 1.7783766518923127e-07}, {\"x\": -8.26086956521739, \"y\": -3.0434782608695645, \"x2\": -7.971014492753623, \"y2\": -2.753623188405797, \"center_x\": -8.115942028985508, \"center_y\": -2.8985507246376807, \"value_uncond\": 2.651812940615314e-07}, {\"x\": -7.971014492753623, \"y\": -3.0434782608695645, \"x2\": -7.681159420289855, \"y2\": -2.753623188405797, \"center_x\": -7.826086956521739, \"center_y\": -2.8985507246376807, \"value_uncond\": 3.917489470275911e-07}, {\"x\": -7.681159420289855, \"y\": -3.0434782608695645, \"x2\": -7.391304347826088, \"y2\": -2.753623188405797, \"center_x\": -7.536231884057972, \"center_y\": -2.8985507246376807, \"value_uncond\": 5.733483995698952e-07}, {\"x\": -7.391304347826087, \"y\": -3.0434782608695645, \"x2\": -7.101449275362319, \"y2\": -2.753623188405797, \"center_x\": -7.246376811594203, \"center_y\": -2.8985507246376807, \"value_uncond\": 8.31333316945809e-07}, {\"x\": -7.101449275362318, \"y\": -3.0434782608695645, \"x2\": -6.811594202898551, \"y2\": -2.753623188405797, \"center_x\": -6.956521739130435, \"center_y\": -2.8985507246376807, \"value_uncond\": 1.1942014157115696e-06}, {\"x\": -6.811594202898551, \"y\": -3.0434782608695645, \"x2\": -6.521739130434783, \"y2\": -2.753623188405797, \"center_x\": -6.666666666666667, \"center_y\": -2.8985507246376807, \"value_uncond\": 1.6995180916205377e-06}, {\"x\": -6.521739130434782, \"y\": -3.0434782608695645, \"x2\": -6.231884057971015, \"y2\": -2.753623188405797, \"center_x\": -6.3768115942028984, \"center_y\": -2.8985507246376807, \"value_uncond\": 2.3961820857624293e-06}, {\"x\": -6.231884057971014, \"y\": -3.0434782608695645, \"x2\": -5.942028985507246, \"y2\": -2.753623188405797, \"center_x\": -6.08695652173913, \"center_y\": -2.8985507246376807, \"value_uncond\": 3.3470303962360863e-06}, {\"x\": -5.942028985507246, \"y\": -3.0434782608695645, \"x2\": -5.6521739130434785, \"y2\": -2.753623188405797, \"center_x\": -5.797101449275362, \"center_y\": -2.8985507246376807, \"value_uncond\": 4.631752135717058e-06}, {\"x\": -5.6521739130434785, \"y\": -3.0434782608695645, \"x2\": -5.362318840579711, \"y2\": -2.753623188405797, \"center_x\": -5.507246376811595, \"center_y\": -2.8985507246376807, \"value_uncond\": 6.350044649361683e-06}, {\"x\": -5.36231884057971, \"y\": -3.0434782608695645, \"x2\": -5.072463768115942, \"y2\": -2.753623188405797, \"center_x\": -5.217391304347826, \"center_y\": -2.8985507246376807, \"value_uncond\": 8.624899873630453e-06}, {\"x\": -5.0724637681159415, \"y\": -3.0434782608695645, \"x2\": -4.782608695652174, \"y2\": -2.753623188405797, \"center_x\": -4.927536231884058, \"center_y\": -2.8985507246376807, \"value_uncond\": 1.1605855517151936e-05}, {\"x\": -4.782608695652174, \"y\": -3.0434782608695645, \"x2\": -4.492753623188406, \"y2\": -2.753623188405797, \"center_x\": -4.63768115942029, \"center_y\": -2.8985507246376807, \"value_uncond\": 1.547198628738956e-05}, {\"x\": -4.492753623188405, \"y\": -3.0434782608695645, \"x2\": -4.202898550724638, \"y2\": -2.753623188405797, \"center_x\": -4.3478260869565215, \"center_y\": -2.8985507246376807, \"value_uncond\": 2.0434348626731224e-05}, {\"x\": -4.202898550724638, \"y\": -3.0434782608695645, \"x2\": -3.91304347826087, \"y2\": -2.753623188405797, \"center_x\": -4.057971014492754, \"center_y\": -2.8985507246376807, \"value_uncond\": 2.6737533379948934e-05}, {\"x\": -3.913043478260869, \"y\": -3.0434782608695645, \"x2\": -3.6231884057971016, \"y2\": -2.753623188405797, \"center_x\": -3.7681159420289854, \"center_y\": -2.8985507246376807, \"value_uncond\": 3.4659931139454876e-05}, {\"x\": -3.6231884057971016, \"y\": -3.0434782608695645, \"x2\": -3.333333333333334, \"y2\": -2.753623188405797, \"center_x\": -3.4782608695652177, \"center_y\": -2.8985507246376807, \"value_uncond\": 4.451228262978362e-05}, {\"x\": -3.333333333333333, \"y\": -3.0434782608695645, \"x2\": -3.0434782608695654, \"y2\": -2.753623188405797, \"center_x\": -3.1884057971014492, \"center_y\": -2.8985507246376807, \"value_uncond\": 5.6634080101113846e-05}, {\"x\": -3.0434782608695645, \"y\": -3.0434782608695645, \"x2\": -2.753623188405797, \"y2\": -2.753623188405797, \"center_x\": -2.8985507246376807, \"center_y\": -2.8985507246376807, \"value_uncond\": 7.138741402338514e-05}, {\"x\": -2.753623188405797, \"y\": -3.0434782608695645, \"x2\": -2.4637681159420293, \"y2\": -2.753623188405797, \"center_x\": -2.608695652173913, \"center_y\": -2.8985507246376807, \"value_uncond\": 8.914793013961373e-05}, {\"x\": -2.4637681159420284, \"y\": -3.0434782608695645, \"x2\": -2.1739130434782608, \"y2\": -2.753623188405797, \"center_x\": -2.3188405797101446, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.00011029268070578547}, {\"x\": -2.1739130434782608, \"y\": -3.0434782608695645, \"x2\": -1.8840579710144931, \"y2\": -2.753623188405797, \"center_x\": -2.028985507246377, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.00013518482263300295}, {\"x\": -1.8840579710144922, \"y\": -3.0434782608695645, \"x2\": -1.5942028985507246, \"y2\": -2.753623188405797, \"center_x\": -1.7391304347826084, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0001641553317449651}, {\"x\": -1.5942028985507246, \"y\": -3.0434782608695645, \"x2\": -1.304347826086957, \"y2\": -2.753623188405797, \"center_x\": -1.4492753623188408, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.00019748215839588876}, {\"x\": -1.304347826086957, \"y\": -3.0434782608695645, \"x2\": -1.0144927536231894, \"y2\": -2.753623188405797, \"center_x\": -1.1594202898550732, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.000235367531132176}, {\"x\": -1.0144927536231876, \"y\": -3.0434782608695645, \"x2\": -0.72463768115942, \"y2\": -2.753623188405797, \"center_x\": -0.8695652173913038, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0002779144018765324}, {\"x\": -0.72463768115942, \"y\": -3.0434782608695645, \"x2\": -0.43478260869565233, \"y2\": -2.753623188405797, \"center_x\": -0.5797101449275361, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0003251032931855034}, {\"x\": -0.43478260869565233, \"y\": -3.0434782608695645, \"x2\": -0.1449275362318847, \"y2\": -2.753623188405797, \"center_x\": -0.2898550724637685, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.00037677102706885516}, {\"x\": -0.14492753623188293, \"y\": -3.0434782608695645, \"x2\": 0.1449275362318847, \"y2\": -2.753623188405797, \"center_x\": 8.881784197001252e-16, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0004325929563833926}, {\"x\": 0.1449275362318847, \"y\": -3.0434782608695645, \"x2\": 0.43478260869565233, \"y2\": -2.753623188405797, \"center_x\": 0.2898550724637685, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.000492070356843446}, {\"x\": 0.43478260869565233, \"y\": -3.0434782608695645, \"x2\": 0.72463768115942, \"y2\": -2.753623188405797, \"center_x\": 0.5797101449275361, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0005545245487238045}, {\"x\": 0.72463768115942, \"y\": -3.0434782608695645, \"x2\": 1.0144927536231876, \"y2\": -2.753623188405797, \"center_x\": 0.8695652173913038, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0006190990897675365}, {\"x\": 1.0144927536231894, \"y\": -3.0434782608695645, \"x2\": 1.304347826086957, \"y2\": -2.753623188405797, \"center_x\": 1.1594202898550732, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0006847710137725129}, {\"x\": 1.304347826086957, \"y\": -3.0434782608695645, \"x2\": 1.5942028985507246, \"y2\": -2.753623188405797, \"center_x\": 1.4492753623188408, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0007503715955386884}, {\"x\": 1.5942028985507246, \"y\": -3.0434782608695645, \"x2\": 1.8840579710144922, \"y2\": -2.753623188405797, \"center_x\": 1.7391304347826084, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0008146165291889287}, {\"x\": 1.884057971014494, \"y\": -3.0434782608695645, \"x2\": 2.1739130434782616, \"y2\": -2.753623188405797, \"center_x\": 2.028985507246378, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0008761447533271222}, {\"x\": 2.1739130434782616, \"y\": -3.0434782608695645, \"x2\": 2.4637681159420293, \"y2\": -2.753623188405797, \"center_x\": 2.3188405797101455, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0009335644934976026}, {\"x\": 2.4637681159420293, \"y\": -3.0434782608695645, \"x2\": 2.753623188405797, \"y2\": -2.753623188405797, \"center_x\": 2.608695652173913, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0009855044766071462}, {\"x\": 2.753623188405797, \"y\": -3.0434782608695645, \"x2\": 3.0434782608695645, \"y2\": -2.753623188405797, \"center_x\": 2.8985507246376807, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.001030667760857866}, {\"x\": 3.0434782608695663, \"y\": -3.0434782608695645, \"x2\": 3.333333333333334, \"y2\": -2.753623188405797, \"center_x\": 3.18840579710145, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.001067885270673787}, {\"x\": 3.333333333333334, \"y\": -3.0434782608695645, \"x2\": 3.6231884057971016, \"y2\": -2.753623188405797, \"center_x\": 3.4782608695652177, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.001096165970408059}, {\"x\": 3.6231884057971016, \"y\": -3.0434782608695645, \"x2\": 3.913043478260869, \"y2\": -2.753623188405797, \"center_x\": 3.7681159420289854, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0011147406784952837}, {\"x\": 3.913043478260871, \"y\": -3.0434782608695645, \"x2\": 4.202898550724639, \"y2\": -2.753623188405797, \"center_x\": 4.057971014492755, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.001123096820663128}, {\"x\": 4.202898550724639, \"y\": -3.0434782608695645, \"x2\": 4.492753623188406, \"y2\": -2.753623188405797, \"center_x\": 4.347826086956522, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0011210019310742272}, {\"x\": 4.492753623188406, \"y\": -3.0434782608695645, \"x2\": 4.782608695652174, \"y2\": -2.753623188405797, \"center_x\": 4.63768115942029, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0011085143975633734}, {\"x\": 4.782608695652174, \"y\": -3.0434782608695645, \"x2\": 5.0724637681159415, \"y2\": -2.753623188405797, \"center_x\": 4.927536231884058, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.001085980757770534}, {\"x\": 5.072463768115943, \"y\": -3.0434782608695645, \"x2\": 5.362318840579711, \"y2\": -2.753623188405797, \"center_x\": 5.217391304347827, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0010540197209255768}, {\"x\": 5.362318840579711, \"y\": -3.0434782608695645, \"x2\": 5.6521739130434785, \"y2\": -2.753623188405797, \"center_x\": 5.507246376811595, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0010134939435188506}, {\"x\": 5.6521739130434785, \"y\": -3.0434782608695645, \"x2\": 5.942028985507246, \"y2\": -2.753623188405797, \"center_x\": 5.797101449275362, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0009654713557573767}, {\"x\": 5.942028985507246, \"y\": -3.0434782608695645, \"x2\": 6.231884057971014, \"y2\": -2.753623188405797, \"center_x\": 6.08695652173913, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0009111784577478195}, {\"x\": 6.2318840579710155, \"y\": -3.0434782608695645, \"x2\": 6.521739130434783, \"y2\": -2.753623188405797, \"center_x\": 6.376811594202899, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0008519484325302061}, {\"x\": 6.521739130434785, \"y\": -3.0434782608695645, \"x2\": 6.8115942028985526, \"y2\": -2.753623188405797, \"center_x\": 6.666666666666669, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0007891671290996348}, {\"x\": 6.811594202898551, \"y\": -3.0434782608695645, \"x2\": 7.101449275362318, \"y2\": -2.753623188405797, \"center_x\": 6.956521739130435, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0007242199451793485}, {\"x\": 7.10144927536232, \"y\": -3.0434782608695645, \"x2\": 7.391304347826088, \"y2\": -2.753623188405797, \"center_x\": 7.246376811594204, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0006584424004384523}, {\"x\": 7.391304347826086, \"y\": -3.0434782608695645, \"x2\": 7.681159420289854, \"y2\": -2.753623188405797, \"center_x\": 7.53623188405797, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.000593076768260322}, {\"x\": 7.681159420289855, \"y\": -3.0434782608695645, \"x2\": 7.971014492753623, \"y2\": -2.753623188405797, \"center_x\": 7.826086956521739, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0005292365744719645}, {\"x\": 7.971014492753625, \"y\": -3.0434782608695645, \"x2\": 8.260869565217392, \"y2\": -2.753623188405797, \"center_x\": 8.115942028985508, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0004678801297808371}, {\"x\": 8.26086956521739, \"y\": -3.0434782608695645, \"x2\": 8.550724637681158, \"y2\": -2.753623188405797, \"center_x\": 8.405797101449274, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0004097935968866038}, {\"x\": 8.55072463768116, \"y\": -3.0434782608695645, \"x2\": 8.840579710144928, \"y2\": -2.753623188405797, \"center_x\": 8.695652173913043, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0003555834580916702}, {\"x\": 8.84057971014493, \"y\": -3.0434782608695645, \"x2\": 9.130434782608697, \"y2\": -2.753623188405797, \"center_x\": 8.985507246376812, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.00030567769140861566}, {\"x\": 9.130434782608695, \"y\": -3.0434782608695645, \"x2\": 9.420289855072463, \"y2\": -2.753623188405797, \"center_x\": 9.275362318840578, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.00026033451763437723}, {\"x\": 9.420289855072465, \"y\": -3.0434782608695645, \"x2\": 9.710144927536232, \"y2\": -2.753623188405797, \"center_x\": 9.565217391304348, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.00021965726887570564}, {\"x\": 9.710144927536234, \"y\": -3.0434782608695645, \"x2\": 10.000000000000002, \"y2\": -2.753623188405797, \"center_x\": 9.855072463768117, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.00018361375770189993}, {\"x\": 10.0, \"y\": -3.0434782608695645, \"x2\": 10.289855072463768, \"y2\": -2.753623188405797, \"center_x\": 10.144927536231883, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.00015205848961401678}, {\"x\": -10.0, \"y\": -2.753623188405797, \"x2\": -9.710144927536232, \"y2\": -2.4637681159420293, \"center_x\": -9.855072463768117, \"center_y\": -2.608695652173913, \"value_uncond\": 2.6188154329573736e-08}, {\"x\": -9.710144927536232, \"y\": -2.753623188405797, \"x2\": -9.420289855072465, \"y2\": -2.4637681159420293, \"center_x\": -9.565217391304348, \"center_y\": -2.608695652173913, \"value_uncond\": 4.0916168323973e-08}, {\"x\": -9.420289855072463, \"y\": -2.753623188405797, \"x2\": -9.130434782608695, \"y2\": -2.4637681159420293, \"center_x\": -9.275362318840578, \"center_y\": -2.608695652173913, \"value_uncond\": 6.333311310830191e-08}, {\"x\": -9.130434782608695, \"y\": -2.753623188405797, \"x2\": -8.840579710144928, \"y2\": -2.4637681159420293, \"center_x\": -8.985507246376812, \"center_y\": -2.608695652173913, \"value_uncond\": 9.71208624008385e-08}, {\"x\": -8.840579710144928, \"y\": -2.753623188405797, \"x2\": -8.55072463768116, \"y2\": -2.4637681159420293, \"center_x\": -8.695652173913043, \"center_y\": -2.608695652173913, \"value_uncond\": 1.475502802555563e-07}, {\"x\": -8.55072463768116, \"y\": -2.753623188405797, \"x2\": -8.260869565217392, \"y2\": -2.4637681159420293, \"center_x\": -8.405797101449277, \"center_y\": -2.608695652173913, \"value_uncond\": 2.2208200099933804e-07}, {\"x\": -8.26086956521739, \"y\": -2.753623188405797, \"x2\": -7.971014492753623, \"y2\": -2.4637681159420293, \"center_x\": -8.115942028985508, \"center_y\": -2.608695652173913, \"value_uncond\": 3.3115590192951433e-07}, {\"x\": -7.971014492753623, \"y\": -2.753623188405797, \"x2\": -7.681159420289855, \"y2\": -2.4637681159420293, \"center_x\": -7.826086956521739, \"center_y\": -2.608695652173913, \"value_uncond\": 4.892123946448407e-07}, {\"x\": -7.681159420289855, \"y\": -2.753623188405797, \"x2\": -7.391304347826088, \"y2\": -2.4637681159420293, \"center_x\": -7.536231884057972, \"center_y\": -2.608695652173913, \"value_uncond\": 7.159920802534279e-07}, {\"x\": -7.391304347826087, \"y\": -2.753623188405797, \"x2\": -7.101449275362319, \"y2\": -2.4637681159420293, \"center_x\": -7.246376811594203, \"center_y\": -2.608695652173913, \"value_uncond\": 1.0381612147701664e-06}, {\"x\": -7.101449275362318, \"y\": -2.753623188405797, \"x2\": -6.811594202898551, \"y2\": -2.4637681159420293, \"center_x\": -6.956521739130435, \"center_y\": -2.608695652173913, \"value_uncond\": 1.4913074781726702e-06}, {\"x\": -6.811594202898551, \"y\": -2.753623188405797, \"x2\": -6.521739130434783, \"y2\": -2.4637681159420293, \"center_x\": -6.666666666666667, \"center_y\": -2.608695652173913, \"value_uncond\": 2.1223421827994224e-06}, {\"x\": -6.521739130434782, \"y\": -2.753623188405797, \"x2\": -6.231884057971015, \"y2\": -2.4637681159420293, \"center_x\": -6.3768115942028984, \"center_y\": -2.608695652173913, \"value_uncond\": 2.9923296158811253e-06}, {\"x\": -6.231884057971014, \"y\": -2.753623188405797, \"x2\": -5.942028985507246, \"y2\": -2.4637681159420293, \"center_x\": -6.08695652173913, \"center_y\": -2.608695652173913, \"value_uncond\": 4.179740028698538e-06}, {\"x\": -5.942028985507246, \"y\": -2.753623188405797, \"x2\": -5.6521739130434785, \"y2\": -2.4637681159420293, \"center_x\": -5.797101449275362, \"center_y\": -2.608695652173913, \"value_uncond\": 5.7840884344633715e-06}, {\"x\": -5.6521739130434785, \"y\": -2.753623188405797, \"x2\": -5.362318840579711, \"y2\": -2.4637681159420293, \"center_x\": -5.507246376811595, \"center_y\": -2.608695652173913, \"value_uncond\": 7.92987593862528e-06}, {\"x\": -5.36231884057971, \"y\": -2.753623188405797, \"x2\": -5.072463768115942, \"y2\": -2.4637681159420293, \"center_x\": -5.217391304347826, \"center_y\": -2.608695652173913, \"value_uncond\": 1.077069371281184e-05}, {\"x\": -5.0724637681159415, \"y\": -2.753623188405797, \"x2\": -4.782608695652174, \"y2\": -2.4637681159420293, \"center_x\": -4.927536231884058, \"center_y\": -2.608695652173913, \"value_uncond\": 1.4493283038864286e-05}, {\"x\": -4.782608695652174, \"y\": -2.753623188405797, \"x2\": -4.492753623188406, \"y2\": -2.4637681159420293, \"center_x\": -4.63768115942029, \"center_y\": -2.608695652173913, \"value_uncond\": 1.9321270724520628e-05}, {\"x\": -4.492753623188405, \"y\": -2.753623188405797, \"x2\": -4.202898550724638, \"y2\": -2.4637681159420293, \"center_x\": -4.3478260869565215, \"center_y\": -2.608695652173913, \"value_uncond\": 2.551822206681418e-05}, {\"x\": -4.202898550724638, \"y\": -2.753623188405797, \"x2\": -3.91304347826087, \"y2\": -2.4637681159420293, \"center_x\": -4.057971014492754, \"center_y\": -2.608695652173913, \"value_uncond\": 3.33895798085704e-05}, {\"x\": -3.913043478260869, \"y\": -2.753623188405797, \"x2\": -3.6231884057971016, \"y2\": -2.4637681159420293, \"center_x\": -3.7681159420289854, \"center_y\": -2.608695652173913, \"value_uncond\": 4.328299549906327e-05}, {\"x\": -3.6231884057971016, \"y\": -2.753623188405797, \"x2\": -3.333333333333334, \"y2\": -2.4637681159420293, \"center_x\": -3.4782608695652177, \"center_y\": -2.608695652173913, \"value_uncond\": 5.5586519227812194e-05}, {\"x\": -3.333333333333333, \"y\": -2.753623188405797, \"x2\": -3.0434782608695654, \"y2\": -2.4637681159420293, \"center_x\": -3.1884057971014492, \"center_y\": -2.608695652173913, \"value_uncond\": 7.072410571871243e-05}, {\"x\": -3.0434782608695645, \"y\": -2.753623188405797, \"x2\": -2.753623188405797, \"y2\": -2.4637681159420293, \"center_x\": -2.8985507246376807, \"center_y\": -2.608695652173913, \"value_uncond\": 8.914793013961373e-05}, {\"x\": -2.753623188405797, \"y\": -2.753623188405797, \"x2\": -2.4637681159420293, \"y2\": -2.4637681159420293, \"center_x\": -2.608695652173913, \"center_y\": -2.608695652173913, \"value_uncond\": 0.00011132709535568892}, {\"x\": -2.4637681159420284, \"y\": -2.753623188405797, \"x2\": -2.1739130434782608, \"y2\": -2.4637681159420293, \"center_x\": -2.3188405797101446, \"center_y\": -2.608695652173913, \"value_uncond\": 0.00013773246067225788}, {\"x\": -2.1739130434782608, \"y\": -2.753623188405797, \"x2\": -1.8840579710144931, \"y2\": -2.4637681159420293, \"center_x\": -2.028985507246377, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0001688175330188482}, {\"x\": -1.8840579710144922, \"y\": -2.753623188405797, \"x2\": -1.5942028985507246, \"y2\": -2.4637681159420293, \"center_x\": -1.7391304347826084, \"center_y\": -2.608695652173913, \"value_uncond\": 0.00020499563188619514}, {\"x\": -1.5942028985507246, \"y\": -2.753623188405797, \"x2\": -1.304347826086957, \"y2\": -2.4637681159420293, \"center_x\": -1.4492753623188408, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0002466138590582609}, {\"x\": -1.304347826086957, \"y\": -2.753623188405797, \"x2\": -1.0144927536231894, \"y2\": -2.4637681159420293, \"center_x\": -1.1594202898550732, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0002939247556387334}, {\"x\": -1.0144927536231876, \"y\": -2.753623188405797, \"x2\": -0.72463768115942, \"y2\": -2.4637681159420293, \"center_x\": -0.8695652173913038, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0003470568870188469}, {\"x\": -0.72463768115942, \"y\": -2.753623188405797, \"x2\": -0.43478260869565233, \"y2\": -2.4637681159420293, \"center_x\": -0.5797101449275361, \"center_y\": -2.608695652173913, \"value_uncond\": 0.00040598592995069906}, {\"x\": -0.43478260869565233, \"y\": -2.753623188405797, \"x2\": -0.1449275362318847, \"y2\": -2.4637681159420293, \"center_x\": -0.2898550724637685, \"center_y\": -2.608695652173913, \"value_uncond\": 0.00047050810929727627}, {\"x\": -0.14492753623188293, \"y\": -2.753623188405797, \"x2\": 0.1449275362318847, \"y2\": -2.4637681159420293, \"center_x\": 8.881784197001252e-16, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0005402180087644379}, {\"x\": 0.1449275362318847, \"y\": -2.753623188405797, \"x2\": 0.43478260869565233, \"y2\": -2.4637681159420293, \"center_x\": 0.2898550724637685, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0006144928261623863}, {\"x\": 0.43478260869565233, \"y\": -2.753623188405797, \"x2\": 0.72463768115942, \"y2\": -2.4637681159420293, \"center_x\": 0.5797101449275361, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0006924850326436628}, {\"x\": 0.72463768115942, \"y\": -2.753623188405797, \"x2\": 1.0144927536231876, \"y2\": -2.4637681159420293, \"center_x\": 0.8695652173913038, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0007731251111857775}, {\"x\": 1.0144927536231894, \"y\": -2.753623188405797, \"x2\": 1.304347826086957, \"y2\": -2.4637681159420293, \"center_x\": 1.1594202898550732, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0008551355912321876}, {\"x\": 1.304347826086957, \"y\": -2.753623188405797, \"x2\": 1.5942028985507246, \"y2\": -2.4637681159420293, \"center_x\": 1.4492753623188408, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0009370569797628511}, {\"x\": 1.5942028985507246, \"y\": -2.753623188405797, \"x2\": 1.8840579710144922, \"y2\": -2.4637681159420293, \"center_x\": 1.7391304347826084, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0010172854476969823}, {\"x\": 1.884057971014494, \"y\": -2.753623188405797, \"x2\": 2.1739130434782616, \"y2\": -2.4637681159420293, \"center_x\": 2.028985507246378, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0010941213143847621}, {\"x\": 2.1739130434782616, \"y\": -2.753623188405797, \"x2\": 2.4637681159420293, \"y2\": -2.4637681159420293, \"center_x\": 2.3188405797101455, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0011658265449969248}, {\"x\": 2.4637681159420293, \"y\": -2.753623188405797, \"x2\": 2.753623188405797, \"y2\": -2.4637681159420293, \"center_x\": 2.608695652173913, \"center_y\": -2.608695652173913, \"value_uncond\": 0.001230688706612493}, {\"x\": 2.753623188405797, \"y\": -2.753623188405797, \"x2\": 3.0434782608695645, \"y2\": -2.4637681159420293, \"center_x\": 2.8985507246376807, \"center_y\": -2.608695652173913, \"value_uncond\": 0.001287088190531882}, {\"x\": 3.0434782608695663, \"y\": -2.753623188405797, \"x2\": 3.333333333333334, \"y2\": -2.4637681159420293, \"center_x\": 3.18840579710145, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0013335650661888887}, {\"x\": 3.333333333333334, \"y\": -2.753623188405797, \"x2\": 3.6231884057971016, \"y2\": -2.4637681159420293, \"center_x\": 3.4782608695652177, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0013688817376036064}, {\"x\": 3.6231884057971016, \"y\": -2.753623188405797, \"x2\": 3.913043478260869, \"y2\": -2.4637681159420293, \"center_x\": 3.7681159420289854, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0013920776580831067}, {\"x\": 3.913043478260871, \"y\": -2.753623188405797, \"x2\": 4.202898550724639, \"y2\": -2.4637681159420293, \"center_x\": 4.057971014492755, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0014025127297047182}, {\"x\": 4.202898550724639, \"y\": -2.753623188405797, \"x2\": 4.492753623188406, \"y2\": -2.4637681159420293, \"center_x\": 4.347826086956522, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0013998966513206438}, {\"x\": 4.492753623188406, \"y\": -2.753623188405797, \"x2\": 4.782608695652174, \"y2\": -2.4637681159420293, \"center_x\": 4.63768115942029, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0013843023371089397}, {\"x\": 4.782608695652174, \"y\": -2.753623188405797, \"x2\": 5.0724637681159415, \"y2\": -2.4637681159420293, \"center_x\": 4.927536231884058, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0013561625400098994}, {\"x\": 5.072463768115943, \"y\": -2.753623188405797, \"x2\": 5.362318840579711, \"y2\": -2.4637681159420293, \"center_x\": 5.217391304347827, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0013162498982813378}, {\"x\": 5.362318840579711, \"y\": -2.753623188405797, \"x2\": 5.6521739130434785, \"y2\": -2.4637681159420293, \"center_x\": 5.507246376811595, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0012656416892218962}, {\"x\": 5.6521739130434785, \"y\": -2.753623188405797, \"x2\": 5.942028985507246, \"y2\": -2.4637681159420293, \"center_x\": 5.797101449275362, \"center_y\": -2.608695652173913, \"value_uncond\": 0.001205671534013852}, {\"x\": 5.942028985507246, \"y\": -2.753623188405797, \"x2\": 6.231884057971014, \"y2\": -2.4637681159420293, \"center_x\": 6.08695652173913, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0011378710744363743}, {\"x\": 6.2318840579710155, \"y\": -2.753623188405797, \"x2\": 6.521739130434783, \"y2\": -2.4637681159420293, \"center_x\": 6.376811594202899, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0010639051769108295}, {\"x\": 6.521739130434785, \"y\": -2.753623188405797, \"x2\": 6.8115942028985526, \"y2\": -2.4637681159420293, \"center_x\": 6.666666666666669, \"center_y\": -2.608695652173913, \"value_uncond\": 0.000985504476607145}, {\"x\": 6.811594202898551, \"y\": -2.753623188405797, \"x2\": 7.101449275362318, \"y2\": -2.4637681159420293, \"center_x\": 6.956521739130435, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0009043990451512076}, {\"x\": 7.10144927536232, \"y\": -2.753623188405797, \"x2\": 7.391304347826088, \"y2\": -2.4637681159420293, \"center_x\": 7.246376811594204, \"center_y\": -2.608695652173913, \"value_uncond\": 0.000822256666924762}, {\"x\": 7.391304347826086, \"y\": -2.753623188405797, \"x2\": 7.681159420289854, \"y2\": -2.4637681159420293, \"center_x\": 7.53623188405797, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0007406286812263477}, {\"x\": 7.681159420289855, \"y\": -2.753623188405797, \"x2\": 7.971014492753623, \"y2\": -2.4637681159420293, \"center_x\": 7.826086956521739, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0006609056486189536}, {\"x\": 7.971014492753625, \"y\": -2.753623188405797, \"x2\": 8.260869565217392, \"y2\": -2.4637681159420293, \"center_x\": 8.115942028985508, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0005842842984864515}, {\"x\": 8.26086956521739, \"y\": -2.753623188405797, \"x2\": 8.550724637681158, \"y2\": -2.4637681159420293, \"center_x\": 8.405797101449274, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0005117463834022718}, {\"x\": 8.55072463768116, \"y\": -2.753623188405797, \"x2\": 8.840579710144928, \"y2\": -2.4637681159420293, \"center_x\": 8.695652173913043, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0004440492727523974}, {\"x\": 8.84057971014493, \"y\": -2.753623188405797, \"x2\": 9.130434782608697, \"y2\": -2.4637681159420293, \"center_x\": 8.985507246376812, \"center_y\": -2.608695652173913, \"value_uncond\": 0.00038172742144724434}, {\"x\": 9.130434782608695, \"y\": -2.753623188405797, \"x2\": 9.420289855072463, \"y2\": -2.4637681159420293, \"center_x\": 9.275362318840578, \"center_y\": -2.608695652173913, \"value_uncond\": 0.00032510329318550315}, {\"x\": 9.420289855072465, \"y\": -2.753623188405797, \"x2\": 9.710144927536232, \"y2\": -2.4637681159420293, \"center_x\": 9.565217391304348, \"center_y\": -2.608695652173913, \"value_uncond\": 0.00027430592812866244}, {\"x\": 9.710144927536234, \"y\": -2.753623188405797, \"x2\": 10.000000000000002, \"y2\": -2.4637681159420293, \"center_x\": 9.855072463768117, \"center_y\": -2.608695652173913, \"value_uncond\": 0.00022929513091647812}, {\"x\": 10.0, \"y\": -2.753623188405797, \"x2\": 10.289855072463768, \"y2\": -2.4637681159420293, \"center_x\": 10.144927536231883, \"center_y\": -2.608695652173913, \"value_uncond\": 0.00018988920938927623}, {\"x\": -10.0, \"y\": -2.4637681159420284, \"x2\": -9.710144927536232, \"y2\": -2.1739130434782608, \"center_x\": -9.855072463768117, \"center_y\": -2.3188405797101446, \"value_uncond\": 3.239965010092863e-08}, {\"x\": -9.710144927536232, \"y\": -2.4637681159420284, \"x2\": -9.420289855072465, \"y2\": -2.1739130434782608, \"center_x\": -9.565217391304348, \"center_y\": -2.3188405797101446, \"value_uncond\": 5.0620960930811905e-08}, {\"x\": -9.420289855072463, \"y\": -2.4637681159420284, \"x2\": -9.130434782608695, \"y2\": -2.1739130434782608, \"center_x\": -9.275362318840578, \"center_y\": -2.3188405797101446, \"value_uncond\": 7.835491874256564e-08}, {\"x\": -9.130434782608695, \"y\": -2.4637681159420284, \"x2\": -8.840579710144928, \"y2\": -2.1739130434782608, \"center_x\": -8.985507246376812, \"center_y\": -2.3188405797101446, \"value_uncond\": 1.2015669068110387e-07}, {\"x\": -8.840579710144928, \"y\": -2.4637681159420284, \"x2\": -8.55072463768116, \"y2\": -2.1739130434782608, \"center_x\": -8.695652173913043, \"center_y\": -2.3188405797101446, \"value_uncond\": 1.8254732244247453e-07}, {\"x\": -8.55072463768116, \"y\": -2.4637681159420284, \"x2\": -8.260869565217392, \"y2\": -2.1739130434782608, \"center_x\": -8.405797101449277, \"center_y\": -2.3188405797101446, \"value_uncond\": 2.747570155399246e-07}, {\"x\": -8.26086956521739, \"y\": -2.4637681159420284, \"x2\": -7.971014492753623, \"y2\": -2.1739130434782608, \"center_x\": -8.115942028985508, \"center_y\": -2.3188405797101446, \"value_uncond\": 4.0970185284334017e-07}, {\"x\": -7.971014492753623, \"y\": -2.4637681159420284, \"x2\": -7.681159420289855, \"y2\": -2.1739130434782608, \"center_x\": -7.826086956521739, \"center_y\": -2.3188405797101446, \"value_uncond\": 6.052473271715371e-07}, {\"x\": -7.681159420289855, \"y\": -2.4637681159420284, \"x2\": -7.391304347826088, \"y2\": -2.1739130434782608, \"center_x\": -7.536231884057972, \"center_y\": -2.3188405797101446, \"value_uncond\": 8.858162581182814e-07}, {\"x\": -7.391304347826087, \"y\": -2.4637681159420284, \"x2\": -7.101449275362319, \"y2\": -2.1739130434782608, \"center_x\": -7.246376811594203, \"center_y\": -2.3188405797101446, \"value_uncond\": 1.2843997970839784e-06}, {\"x\": -7.101449275362318, \"y\": -2.4637681159420284, \"x2\": -6.811594202898551, \"y2\": -2.1739130434782608, \"center_x\": -6.956521739130435, \"center_y\": -2.3188405797101446, \"value_uncond\": 1.8450265672647442e-06}, {\"x\": -6.811594202898551, \"y\": -2.4637681159420284, \"x2\": -6.521739130434783, \"y2\": -2.1739130434782608, \"center_x\": -6.666666666666667, \"center_y\": -2.3188405797101446, \"value_uncond\": 2.6257346452051987e-06}, {\"x\": -6.521739130434782, \"y\": -2.4637681159420284, \"x2\": -6.231884057971015, \"y2\": -2.1739130434782608, \"center_x\": -6.3768115942028984, \"center_y\": -2.3188405797101446, \"value_uncond\": 3.7020719872461713e-06}, {\"x\": -6.231884057971014, \"y\": -2.4637681159420284, \"x2\": -5.942028985507246, \"y2\": -2.1739130434782608, \"center_x\": -6.08695652173913, \"center_y\": -2.3188405797101446, \"value_uncond\": 5.171120986168483e-06}, {\"x\": -5.942028985507246, \"y\": -2.4637681159420284, \"x2\": -5.6521739130434785, \"y2\": -2.1739130434782608, \"center_x\": -5.797101449275362, \"center_y\": -2.3188405797101446, \"value_uncond\": 7.15600034546198e-06}, {\"x\": -5.6521739130434785, \"y\": -2.4637681159420284, \"x2\": -5.362318840579711, \"y2\": -2.1739130434782608, \"center_x\": -5.507246376811595, \"center_y\": -2.3188405797101446, \"value_uncond\": 9.810741242848559e-06}, {\"x\": -5.36231884057971, \"y\": -2.4637681159420284, \"x2\": -5.072463768115942, \"y2\": -2.1739130434782608, \"center_x\": -5.217391304347826, \"center_y\": -2.3188405797101446, \"value_uncond\": 1.3325364714431008e-05}, {\"x\": -5.0724637681159415, \"y\": -2.4637681159420284, \"x2\": -4.782608695652174, \"y2\": -2.1739130434782608, \"center_x\": -4.927536231884058, \"center_y\": -2.3188405797101446, \"value_uncond\": 1.7930904689325227e-05}, {\"x\": -4.782608695652174, \"y\": -2.4637681159420284, \"x2\": -4.492753623188406, \"y2\": -2.1739130434782608, \"center_x\": -4.63768115942029, \"center_y\": -2.3188405797101446, \"value_uncond\": 2.3904029398240288e-05}, {\"x\": -4.492753623188405, \"y\": -2.4637681159420284, \"x2\": -4.202898550724638, \"y2\": -2.1739130434782608, \"center_x\": -4.3478260869565215, \"center_y\": -2.3188405797101446, \"value_uncond\": 3.157081846080717e-05}, {\"x\": -4.202898550724638, \"y\": -2.4637681159420284, \"x2\": -3.91304347826087, \"y2\": -2.1739130434782608, \"center_x\": -4.057971014492754, \"center_y\": -2.3188405797101446, \"value_uncond\": 4.130916173779552e-05}, {\"x\": -3.913043478260869, \"y\": -2.4637681159420284, \"x2\": -3.6231884057971016, \"y2\": -2.1739130434782608, \"center_x\": -3.7681159420289854, \"center_y\": -2.3188405797101446, \"value_uncond\": 5.354916928628562e-05}, {\"x\": -3.6231884057971016, \"y\": -2.4637681159420284, \"x2\": -3.333333333333334, \"y2\": -2.1739130434782608, \"center_x\": -3.4782608695652177, \"center_y\": -2.3188405797101446, \"value_uncond\": 6.87709317214403e-05}, {\"x\": -3.333333333333333, \"y\": -2.4637681159420284, \"x2\": -3.0434782608695654, \"y2\": -2.1739130434782608, \"center_x\": -3.1884057971014492, \"center_y\": -2.3188405797101446, \"value_uncond\": 8.749896041355213e-05}, {\"x\": -3.0434782608695645, \"y\": -2.4637681159420284, \"x2\": -2.753623188405797, \"y2\": -2.1739130434782608, \"center_x\": -2.8985507246376807, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.00011029268070578547}, {\"x\": -2.753623188405797, \"y\": -2.4637681159420284, \"x2\": -2.4637681159420293, \"y2\": -2.1739130434782608, \"center_x\": -2.608695652173913, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.00013773246067225788}, {\"x\": -2.4637681159420284, \"y\": -2.4637681159420284, \"x2\": -2.1739130434782608, \"y2\": -2.1739130434782608, \"center_x\": -2.3188405797101446, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.00017040084143240576}, {\"x\": -2.1739130434782608, \"y\": -2.4637681159420284, \"x2\": -1.8840579710144931, \"y2\": -2.1739130434782608, \"center_x\": -2.028985507246377, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.00020885889596793423}, {\"x\": -1.8840579710144922, \"y\": -2.4637681159420284, \"x2\": -1.5942028985507246, \"y2\": -2.1739130434782608, \"center_x\": -1.7391304347826084, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0002536179778744869}, {\"x\": -1.5942028985507246, \"y\": -2.4637681159420284, \"x2\": -1.304347826086957, \"y2\": -2.1739130434782608, \"center_x\": -1.4492753623188408, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.00030510751704652234}, {\"x\": -1.304347826086957, \"y\": -2.4637681159420284, \"x2\": -1.0144927536231894, \"y2\": -2.1739130434782608, \"center_x\": -1.1594202898550732, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0003636399541124481}, {\"x\": -1.0144927536231876, \"y\": -2.4637681159420284, \"x2\": -0.72463768115942, \"y2\": -2.1739130434782608, \"center_x\": -0.8695652173913038, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0004293743485324563}, {\"x\": -0.72463768115942, \"y\": -2.4637681159420284, \"x2\": -0.43478260869565233, \"y2\": -2.1739130434782608, \"center_x\": -0.5797101449275361, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0005022806078948621}, {\"x\": -0.43478260869565233, \"y\": -2.4637681159420284, \"x2\": -0.1449275362318847, \"y2\": -2.1739130434782608, \"center_x\": -0.2898550724637685, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0005821066242024608}, {\"x\": -0.14492753623188293, \"y\": -2.4637681159420284, \"x2\": 0.1449275362318847, \"y2\": -2.1739130434782608, \"center_x\": 8.881784197001252e-16, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0006683508215935073}, {\"x\": 0.1449275362318847, \"y\": -2.4637681159420284, \"x2\": 0.43478260869565233, \"y2\": -2.1739130434782608, \"center_x\": 0.2898550724637685, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0007602426771522744}, {\"x\": 0.43478260869565233, \"y\": -2.4637681159420284, \"x2\": 0.72463768115942, \"y2\": -2.1739130434782608, \"center_x\": 0.5797101449275361, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0008567336390120467}, {\"x\": 0.72463768115942, \"y\": -2.4637681159420284, \"x2\": 1.0144927536231876, \"y2\": -2.1739130434782608, \"center_x\": 0.8695652173913038, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0009565005143708588}, {\"x\": 1.0144927536231894, \"y\": -2.4637681159420284, \"x2\": 1.304347826086957, \"y2\": -2.1739130434782608, \"center_x\": 1.1594202898550732, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0010579628329700835}, {\"x\": 1.304347826086957, \"y\": -2.4637681159420284, \"x2\": 1.5942028985507246, \"y2\": -2.1739130434782608, \"center_x\": 1.4492753623188408, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0011593149286837688}, {\"x\": 1.5942028985507246, \"y\": -2.4637681159420284, \"x2\": 1.8840579710144922, \"y2\": -2.1739130434782608, \"center_x\": 1.7391304347826084, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0012585725646548536}, {\"x\": 1.884057971014494, \"y\": -2.4637681159420284, \"x2\": 2.1739130434782616, \"y2\": -2.1739130434782608, \"center_x\": 2.028985507246378, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0013536329176891404}, {\"x\": 2.1739130434782616, \"y\": -2.4637681159420284, \"x2\": 2.4637681159420293, \"y2\": -2.1739130434782608, \"center_x\": 2.3188405797101455, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0014423457132914212}, {\"x\": 2.4637681159420293, \"y\": -2.4637681159420284, \"x2\": 2.753623188405797, \"y2\": -2.1739130434782608, \"center_x\": 2.608695652173913, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0015225923513204752}, {\"x\": 2.753623188405797, \"y\": -2.4637681159420284, \"x2\": 3.0434782608695645, \"y2\": -2.1739130434782608, \"center_x\": 2.8985507246376807, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.001592369072576375}, {\"x\": 3.0434782608695663, \"y\": -2.4637681159420284, \"x2\": 3.333333333333334, \"y2\": -2.1739130434782608, \"center_x\": 3.18840579710145, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0016498696696066464}, {\"x\": 3.333333333333334, \"y\": -2.4637681159420284, \"x2\": 3.6231884057971016, \"y2\": -2.1739130434782608, \"center_x\": 3.4782608695652177, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.001693563004469659}, {\"x\": 3.6231884057971016, \"y\": -2.4637681159420284, \"x2\": 3.913043478260869, \"y2\": -2.1739130434782608, \"center_x\": 3.7681159420289854, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0017222607010635757}, {\"x\": 3.913043478260871, \"y\": -2.4637681159420284, \"x2\": 4.202898550724639, \"y2\": -2.1739130434782608, \"center_x\": 4.057971014492755, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.001735170838412833}, {\"x\": 4.202898550724639, \"y\": -2.4637681159420284, \"x2\": 4.492753623188406, \"y2\": -2.1739130434782608, \"center_x\": 4.347826086956522, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0017319342596446646}, {\"x\": 4.492753623188406, \"y\": -2.4637681159420284, \"x2\": 4.782608695652174, \"y2\": -2.1739130434782608, \"center_x\": 4.63768115942029, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0017126411732490121}, {\"x\": 4.782608695652174, \"y\": -2.4637681159420284, \"x2\": 5.0724637681159415, \"y2\": -2.1739130434782608, \"center_x\": 4.927536231884058, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.001677826975637138}, {\"x\": 5.072463768115943, \"y\": -2.4637681159420284, \"x2\": 5.362318840579711, \"y2\": -2.1739130434782608, \"center_x\": 5.217391304347827, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0016284475649946408}, {\"x\": 5.362318840579711, \"y\": -2.4637681159420284, \"x2\": 5.6521739130434785, \"y2\": -2.1739130434782608, \"center_x\": 5.507246376811595, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0015658357350380376}, {\"x\": 5.6521739130434785, \"y\": -2.4637681159420284, \"x2\": 5.942028985507246, \"y2\": -2.1739130434782608, \"center_x\": 5.797101449275362, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0014916414248630431}, {\"x\": 5.942028985507246, \"y\": -2.4637681159420284, \"x2\": 6.231884057971014, \"y2\": -2.1739130434782608, \"center_x\": 6.08695652173913, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0014077595621190266}, {\"x\": 6.2318840579710155, \"y\": -2.4637681159420284, \"x2\": 6.521739130434783, \"y2\": -2.1739130434782608, \"center_x\": 6.376811594202899, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0013162498982813384}, {\"x\": 6.521739130434785, \"y\": -2.4637681159420284, \"x2\": 6.8115942028985526, \"y2\": -2.1739130434782608, \"center_x\": 6.666666666666669, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0012192535530811497}, {\"x\": 6.811594202898551, \"y\": -2.4637681159420284, \"x2\": 7.101449275362318, \"y2\": -2.1739130434782608, \"center_x\": 6.956521739130435, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.001118910949040142}, {\"x\": 7.10144927536232, \"y\": -2.4637681159420284, \"x2\": 7.391304347826088, \"y2\": -2.1739130434782608, \"center_x\": 7.246376811594204, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0010172854476969823}, {\"x\": 7.391304347826086, \"y\": -2.4637681159420284, \"x2\": 7.681159420289854, \"y2\": -2.1739130434782608, \"center_x\": 7.53623188405797, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0009162963462204569}, {\"x\": 7.681159420289855, \"y\": -2.4637681159420284, \"x2\": 7.971014492753623, \"y2\": -2.1739130434782608, \"center_x\": 7.826086956521739, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0008176640283809533}, {\"x\": 7.971014492753625, \"y\": -2.4637681159420284, \"x2\": 8.260869565217392, \"y2\": -2.1739130434782608, \"center_x\": 8.115942028985508, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0007228690724893741}, {\"x\": 8.26086956521739, \"y\": -2.4637681159420284, \"x2\": 8.550724637681158, \"y2\": -2.1739130434782608, \"center_x\": 8.405797101449274, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0006331260902921042}, {\"x\": 8.55072463768116, \"y\": -2.4637681159420284, \"x2\": 8.840579710144928, \"y2\": -2.1739130434782608, \"center_x\": 8.695652173913043, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0005493720895215017}, {\"x\": 8.84057971014493, \"y\": -2.4637681159420284, \"x2\": 9.130434782608697, \"y2\": -2.1739130434782608, \"center_x\": 8.985507246376812, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.000472268290967481}, {\"x\": 9.130434782608695, \"y\": -2.4637681159420284, \"x2\": 9.420289855072463, \"y2\": -2.1739130434782608, \"center_x\": 9.275362318840578, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0004022136426000418}, {\"x\": 9.420289855072465, \"y\": -2.4637681159420284, \"x2\": 9.710144927536232, \"y2\": -2.1739130434782608, \"center_x\": 9.565217391304348, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0003393677912590714}, {\"x\": 9.710144927536234, \"y\": -2.4637681159420284, \"x2\": 10.000000000000002, \"y2\": -2.1739130434782608, \"center_x\": 9.855072463768117, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0002836810077581909}, {\"x\": 10.0, \"y\": -2.4637681159420284, \"x2\": 10.289855072463768, \"y2\": -2.1739130434782608, \"center_x\": 10.144927536231883, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.00023492850487774955}, {\"x\": -10.0, \"y\": -2.1739130434782608, \"x2\": -9.710144927536232, \"y2\": -1.8840579710144931, \"center_x\": -9.855072463768117, \"center_y\": -2.028985507246377, \"value_uncond\": 3.9711982012199266e-08}, {\"x\": -9.710144927536232, \"y\": -2.1739130434782608, \"x2\": -9.420289855072465, \"y2\": -1.8840579710144931, \"center_x\": -9.565217391304348, \"center_y\": -2.028985507246377, \"value_uncond\": 6.204569134735891e-08}, {\"x\": -9.420289855072463, \"y\": -2.1739130434782608, \"x2\": -9.130434782608695, \"y2\": -1.8840579710144931, \"center_x\": -9.275362318840578, \"center_y\": -2.028985507246377, \"value_uncond\": 9.603897307467887e-08}, {\"x\": -9.130434782608695, \"y\": -2.1739130434782608, \"x2\": -8.840579710144928, \"y2\": -1.8840579710144931, \"center_x\": -8.985507246376812, \"center_y\": -2.028985507246377, \"value_uncond\": 1.4727505772775686e-07}, {\"x\": -8.840579710144928, \"y\": -2.1739130434782608, \"x2\": -8.55072463768116, \"y2\": -1.8840579710144931, \"center_x\": -8.695652173913043, \"center_y\": -2.028985507246377, \"value_uncond\": 2.2374673685142385e-07}, {\"x\": -8.55072463768116, \"y\": -2.1739130434782608, \"x2\": -8.260869565217392, \"y2\": -1.8840579710144931, \"center_x\": -8.405797101449277, \"center_y\": -2.028985507246377, \"value_uncond\": 3.3676739177298414e-07}, {\"x\": -8.26086956521739, \"y\": -2.1739130434782608, \"x2\": -7.971014492753623, \"y2\": -1.8840579710144931, \"center_x\": -8.115942028985508, \"center_y\": -2.028985507246377, \"value_uncond\": 5.021681579830735e-07}, {\"x\": -7.971014492753623, \"y\": -2.1739130434782608, \"x2\": -7.681159420289855, \"y2\": -1.8840579710144931, \"center_x\": -7.826086956521739, \"center_y\": -2.028985507246377, \"value_uncond\": 7.418466216361657e-07}, {\"x\": -7.681159420289855, \"y\": -2.1739130434782608, \"x2\": -7.391304347826088, \"y2\": -1.8840579710144931, \"center_x\": -7.536231884057972, \"center_y\": -2.028985507246377, \"value_uncond\": 1.0857376298486197e-06}, {\"x\": -7.391304347826087, \"y\": -2.1739130434782608, \"x2\": -7.101449275362319, \"y2\": -1.8840579710144931, \"center_x\": -7.246376811594203, \"center_y\": -2.028985507246377, \"value_uncond\": 1.574278162862302e-06}, {\"x\": -7.101449275362318, \"y\": -2.1739130434782608, \"x2\": -6.811594202898551, \"y2\": -1.8840579710144931, \"center_x\": -6.956521739130435, \"center_y\": -2.028985507246377, \"value_uncond\": 2.261433738420133e-06}, {\"x\": -6.811594202898551, \"y\": -2.1739130434782608, \"x2\": -6.521739130434783, \"y2\": -1.8840579710144931, \"center_x\": -6.666666666666667, \"center_y\": -2.028985507246377, \"value_uncond\": 3.2183411448696105e-06}, {\"x\": -6.521739130434782, \"y\": -2.1739130434782608, \"x2\": -6.231884057971015, \"y2\": -1.8840579710144931, \"center_x\": -6.3768115942028984, \"center_y\": -2.028985507246377, \"value_uncond\": 4.537598884784661e-06}, {\"x\": -6.231884057971014, \"y\": -2.1739130434782608, \"x2\": -5.942028985507246, \"y2\": -1.8840579710144931, \"center_x\": -6.08695652173913, \"center_y\": -2.028985507246377, \"value_uncond\": 6.338200040615355e-06}, {\"x\": -5.942028985507246, \"y\": -2.1739130434782608, \"x2\": -5.6521739130434785, \"y2\": -1.8840579710144931, \"center_x\": -5.797101449275362, \"center_y\": -2.028985507246377, \"value_uncond\": 8.771050184586184e-06}, {\"x\": -5.6521739130434785, \"y\": -2.1739130434782608, \"x2\": -5.362318840579711, \"y2\": -1.8840579710144931, \"center_x\": -5.507246376811595, \"center_y\": -2.028985507246377, \"value_uncond\": 1.2024944051824084e-05}, {\"x\": -5.36231884057971, \"y\": -2.1739130434782608, \"x2\": -5.072463768115942, \"y2\": -1.8840579710144931, \"center_x\": -5.217391304347826, \"center_y\": -2.028985507246377, \"value_uncond\": 1.6332788847936102e-05}, {\"x\": -5.0724637681159415, \"y\": -2.1739130434782608, \"x2\": -4.782608695652174, \"y2\": -1.8840579710144931, \"center_x\": -4.927536231884058, \"center_y\": -2.028985507246377, \"value_uncond\": 2.197776094083601e-05}, {\"x\": -4.782608695652174, \"y\": -2.1739130434782608, \"x2\": -4.492753623188406, \"y2\": -1.8840579710144931, \"center_x\": -4.63768115942029, \"center_y\": -2.028985507246377, \"value_uncond\": 2.929897028285477e-05}, {\"x\": -4.492753623188405, \"y\": -2.1739130434782608, \"x2\": -4.202898550724638, \"y2\": -1.8840579710144931, \"center_x\": -4.3478260869565215, \"center_y\": -2.028985507246377, \"value_uncond\": 3.869608995530632e-05}, {\"x\": -4.202898550724638, \"y\": -2.1739130434782608, \"x2\": -3.91304347826087, \"y2\": -1.8840579710144931, \"center_x\": -4.057971014492754, \"center_y\": -2.028985507246377, \"value_uncond\": 5.063229642172422e-05}, {\"x\": -3.913043478260869, \"y\": -2.1739130434782608, \"x2\": -3.6231884057971016, \"y2\": -1.8840579710144931, \"center_x\": -3.7681159420289854, \"center_y\": -2.028985507246377, \"value_uncond\": 6.563477200651124e-05}, {\"x\": -3.6231884057971016, \"y\": -2.1739130434782608, \"x2\": -3.333333333333334, \"y2\": -1.8840579710144931, \"center_x\": -3.4782608695652177, \"center_y\": -2.028985507246377, \"value_uncond\": 8.429195978896527e-05}, {\"x\": -3.333333333333333, \"y\": -2.1739130434782608, \"x2\": -3.0434782608695654, \"y2\": -1.8840579710144931, \"center_x\": -3.1884057971014492, \"center_y\": -2.028985507246377, \"value_uncond\": 0.00010724674899898157}, {\"x\": -3.0434782608695645, \"y\": -2.1739130434782608, \"x2\": -2.753623188405797, \"y2\": -1.8840579710144931, \"center_x\": -2.8985507246376807, \"center_y\": -2.028985507246377, \"value_uncond\": 0.00013518482263300295}, {\"x\": -2.753623188405797, \"y\": -2.1739130434782608, \"x2\": -2.4637681159420293, \"y2\": -1.8840579710144931, \"center_x\": -2.608695652173913, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0001688175330188482}, {\"x\": -2.4637681159420284, \"y\": -2.1739130434782608, \"x2\": -2.1739130434782608, \"y2\": -1.8840579710144931, \"center_x\": -2.3188405797101446, \"center_y\": -2.028985507246377, \"value_uncond\": 0.00020885889596793423}, {\"x\": -2.1739130434782608, \"y\": -2.1739130434782608, \"x2\": -1.8840579710144931, \"y2\": -1.8840579710144931, \"center_x\": -2.028985507246377, \"center_y\": -2.028985507246377, \"value_uncond\": 0.00025599661397357725}, {\"x\": -1.8840579710144922, \"y\": -2.1739130434782608, \"x2\": -1.5942028985507246, \"y2\": -1.8840579710144931, \"center_x\": -1.7391304347826084, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0003108574488905764}, {\"x\": -1.5942028985507246, \"y\": -2.1739130434782608, \"x2\": -1.304347826086957, \"y2\": -1.8840579710144931, \"center_x\": -1.4492753623188408, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0003739677493736574}, {\"x\": -1.304347826086957, \"y\": -2.1739130434782608, \"x2\": -1.0144927536231894, \"y2\": -1.8840579710144931, \"center_x\": -1.1594202898550732, \"center_y\": -2.028985507246377, \"value_uncond\": 0.00044571047130588027}, {\"x\": -1.0144927536231876, \"y\": -2.1739130434782608, \"x2\": -0.72463768115942, \"y2\": -1.8840579710144931, \"center_x\": -0.8695652173913038, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0005262805725464293}, {\"x\": -0.72463768115942, \"y\": -2.1739130434782608, \"x2\": -0.43478260869565233, \"y2\": -1.8840579710144931, \"center_x\": -0.5797101449275361, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0006156411690762544}, {\"x\": -0.43478260869565233, \"y\": -2.1739130434782608, \"x2\": -0.1449275362318847, \"y2\": -1.8840579710144931, \"center_x\": -0.2898550724637685, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0007134832542172296}, {\"x\": -0.14492753623188293, \"y\": -2.1739130434782608, \"x2\": 0.1449275362318847, \"y2\": -1.8840579710144931, \"center_x\": 8.881784197001252e-16, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0008191920506017823}, {\"x\": 0.1449275362318847, \"y\": -2.1739130434782608, \"x2\": 0.43478260869565233, \"y2\": -1.8840579710144931, \"center_x\": 0.2898550724637685, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0009318231346921867}, {\"x\": 0.43478260869565233, \"y\": -2.1739130434782608, \"x2\": 0.72463768115942, \"y2\": -1.8840579710144931, \"center_x\": 0.5797101449275361, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0010500913051748446}, {\"x\": 0.72463768115942, \"y\": -2.1739130434782608, \"x2\": 1.0144927536231876, \"y2\": -1.8840579710144931, \"center_x\": 0.8695652173913038, \"center_y\": -2.028985507246377, \"value_uncond\": 0.001172374735623031}, {\"x\": 1.0144927536231894, \"y\": -2.1739130434782608, \"x2\": 1.304347826086957, \"y2\": -1.8840579710144931, \"center_x\": 1.1594202898550732, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0012967362567683765}, {\"x\": 1.304347826086957, \"y\": -2.1739130434782608, \"x2\": 1.5942028985507246, \"y2\": -1.8840579710144931, \"center_x\": 1.4492753623188408, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0014209626786384445}, {\"x\": 1.5942028985507246, \"y\": -2.1739130434782608, \"x2\": 1.8840579710144922, \"y2\": -1.8840579710144931, \"center_x\": 1.7391304347826084, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0015426219385989153}, {\"x\": 1.884057971014494, \"y\": -2.1739130434782608, \"x2\": 2.1739130434782616, \"y2\": -1.8840579710144931, \"center_x\": 2.028985507246378, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0016591366237270336}, {\"x\": 2.1739130434782616, \"y\": -2.1739130434782608, \"x2\": 2.4637681159420293, \"y2\": -1.8840579710144931, \"center_x\": 2.3188405797101455, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0017678711604345368}, {\"x\": 2.4637681159420293, \"y\": -2.1739130434782608, \"x2\": 2.753623188405797, \"y2\": -1.8840579710144931, \"center_x\": 2.608695652173913, \"center_y\": -2.028985507246377, \"value_uncond\": 0.001866228798125751}, {\"x\": 2.753623188405797, \"y\": -2.1739130434782608, \"x2\": 3.0434782608695645, \"y2\": -1.8840579710144931, \"center_x\": 2.8985507246376807, \"center_y\": -2.028985507246377, \"value_uncond\": 0.00195175354579286}, {\"x\": 3.0434782608695663, \"y\": -2.1739130434782608, \"x2\": 3.333333333333334, \"y2\": -1.8840579710144931, \"center_x\": 3.18840579710145, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0020222315499640042}, {\"x\": 3.333333333333334, \"y\": -2.1739130434782608, \"x2\": 3.6231884057971016, \"y2\": -1.8840579710144931, \"center_x\": 3.4782608695652177, \"center_y\": -2.028985507246377, \"value_uncond\": 0.002075786107581996}, {\"x\": 3.6231884057971016, \"y\": -2.1739130434782608, \"x2\": 3.913043478260869, \"y2\": -1.8840579710144931, \"center_x\": 3.7681159420289854, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0021109606359296495}, {\"x\": 3.913043478260871, \"y\": -2.1739130434782608, \"x2\": 4.202898550724639, \"y2\": -1.8840579710144931, \"center_x\": 4.057971014492755, \"center_y\": -2.028985507246377, \"value_uncond\": 0.002126784484045035}, {\"x\": 4.202898550724639, \"y\": -2.1739130434782608, \"x2\": 4.492753623188406, \"y2\": -1.8840579710144931, \"center_x\": 4.347826086956522, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0021228174363324154}, {\"x\": 4.492753623188406, \"y\": -2.1739130434782608, \"x2\": 4.782608695652174, \"y2\": -1.8840579710144931, \"center_x\": 4.63768115942029, \"center_y\": -2.028985507246377, \"value_uncond\": 0.002099170060588626}, {\"x\": 4.782608695652174, \"y\": -2.1739130434782608, \"x2\": 5.0724637681159415, \"y2\": -1.8840579710144931, \"center_x\": 4.927536231884058, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0020564985877478664}, {\"x\": 5.072463768115943, \"y\": -2.1739130434782608, \"x2\": 5.362318840579711, \"y2\": -1.8840579710144931, \"center_x\": 5.217391304347827, \"center_y\": -2.028985507246377, \"value_uncond\": 0.001995974654276386}, {\"x\": 5.362318840579711, \"y\": -2.1739130434782608, \"x2\": 5.6521739130434785, \"y2\": -1.8840579710144931, \"center_x\": 5.507246376811595, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0019192318543621285}, {\"x\": 5.6521739130434785, \"y\": -2.1739130434782608, \"x2\": 5.942028985507246, \"y2\": -1.8840579710144931, \"center_x\": 5.797101449275362, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0018282925046500629}, {\"x\": 5.942028985507246, \"y\": -2.1739130434782608, \"x2\": 6.231884057971014, \"y2\": -1.8840579710144931, \"center_x\": 6.08695652173913, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0017254792022204579}, {\"x\": 6.2318840579710155, \"y\": -2.1739130434782608, \"x2\": 6.521739130434783, \"y2\": -1.8840579710144931, \"center_x\": 6.376811594202899, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0016133165673480364}, {\"x\": 6.521739130434785, \"y\": -2.1739130434782608, \"x2\": 6.8115942028985526, \"y2\": -1.8840579710144931, \"center_x\": 6.666666666666669, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0014944289527028226}, {\"x\": 6.811594202898551, \"y\": -2.1739130434782608, \"x2\": 7.101449275362318, \"y2\": -1.8840579710144931, \"center_x\": 6.956521739130435, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0013714398563909602}, {\"x\": 7.10144927536232, \"y\": -2.1739130434782608, \"x2\": 7.391304347826088, \"y2\": -1.8840579710144931, \"center_x\": 7.246376811594204, \"center_y\": -2.028985507246377, \"value_uncond\": 0.001246878323511795}, {\"x\": 7.391304347826086, \"y\": -2.1739130434782608, \"x2\": 7.681159420289854, \"y2\": -1.8840579710144931, \"center_x\": 7.53623188405797, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0011230968206631274}, {\"x\": 7.681159420289855, \"y\": -2.1739130434782608, \"x2\": 7.971014492753623, \"y2\": -1.8840579710144931, \"center_x\": 7.826086956521739, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0010022040079425468}, {\"x\": 7.971014492753625, \"y\": -2.1739130434782608, \"x2\": 8.260869565217392, \"y2\": -1.8840579710144931, \"center_x\": 8.115942028985508, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0008860146178878153}, {\"x\": 8.26086956521739, \"y\": -2.1739130434782608, \"x2\": 8.550724637681158, \"y2\": -1.8840579710144931, \"center_x\": 8.405797101449274, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0007760173900277234}, {\"x\": 8.55072463768116, \"y\": -2.1739130434782608, \"x2\": 8.840579710144928, \"y2\": -1.8840579710144931, \"center_x\": 8.695652173913043, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0006733608069568906}, {\"x\": 8.84057971014493, \"y\": -2.1739130434782608, \"x2\": 9.130434782608697, \"y2\": -1.8840579710144931, \"center_x\": 8.985507246376812, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0005788553215053133}, {\"x\": 9.130434782608695, \"y\": -2.1739130434782608, \"x2\": 9.420289855072463, \"y2\": -1.8840579710144931, \"center_x\": 9.275362318840578, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0004929899208860965}, {\"x\": 9.420289855072465, \"y\": -2.1739130434782608, \"x2\": 9.710144927536232, \"y2\": -1.8840579710144931, \"center_x\": 9.565217391304348, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0004159602829048383}, {\"x\": 9.710144927536234, \"y\": -2.1739130434782608, \"x2\": 10.000000000000002, \"y2\": -1.8840579710144931, \"center_x\": 9.855072463768117, \"center_y\": -2.028985507246377, \"value_uncond\": 0.00034770545491085266}, {\"x\": 10.0, \"y\": -2.1739130434782608, \"x2\": 10.289855072463768, \"y2\": -1.8840579710144931, \"center_x\": 10.144927536231883, \"center_y\": -2.028985507246377, \"value_uncond\": 0.00028794991707613093}, {\"x\": -10.0, \"y\": -1.8840579710144922, \"x2\": -9.710144927536232, \"y2\": -1.5942028985507246, \"center_x\": -9.855072463768117, \"center_y\": -1.7391304347826084, \"value_uncond\": 4.822237773806992e-08}, {\"x\": -9.710144927536232, \"y\": -1.8840579710144922, \"x2\": -9.420289855072465, \"y2\": -1.5942028985507246, \"center_x\": -9.565217391304348, \"center_y\": -1.7391304347826084, \"value_uncond\": 7.53422673351565e-08}, {\"x\": -9.420289855072463, \"y\": -1.8840579710144922, \"x2\": -9.130434782608695, \"y2\": -1.5942028985507246, \"center_x\": -9.275362318840578, \"center_y\": -1.7391304347826084, \"value_uncond\": 1.1662041032756351e-07}, {\"x\": -9.130434782608695, \"y\": -1.8840579710144922, \"x2\": -8.840579710144928, \"y2\": -1.5942028985507246, \"center_x\": -8.985507246376812, \"center_y\": -1.7391304347826084, \"value_uncond\": 1.7883654013950458e-07}, {\"x\": -8.840579710144928, \"y\": -1.8840579710144922, \"x2\": -8.55072463768116, \"y2\": -1.5942028985507246, \"center_x\": -8.695652173913043, \"center_y\": -1.7391304347826084, \"value_uncond\": 2.7169632728971814e-07}, {\"x\": -8.55072463768116, \"y\": -1.8840579710144922, \"x2\": -8.260869565217392, \"y2\": -1.5942028985507246, \"center_x\": -8.405797101449277, \"center_y\": -1.7391304347826084, \"value_uncond\": 4.089376443349696e-07}, {\"x\": -8.26086956521739, \"y\": -1.8840579710144922, \"x2\": -7.971014492753623, \"y2\": -1.5942028985507246, \"center_x\": -8.115942028985508, \"center_y\": -1.7391304347826084, \"value_uncond\": 6.09784286134387e-07}, {\"x\": -7.971014492753623, \"y\": -1.8840579710144922, \"x2\": -7.681159420289855, \"y2\": -1.5942028985507246, \"center_x\": -7.826086956521739, \"center_y\": -1.7391304347826084, \"value_uncond\": 9.008265566110717e-07}, {\"x\": -7.681159420289855, \"y\": -1.8840579710144922, \"x2\": -7.391304347826088, \"y2\": -1.5942028985507246, \"center_x\": -7.536231884057972, \"center_y\": -1.7391304347826084, \"value_uncond\": 1.3184144295521006e-06}, {\"x\": -7.391304347826087, \"y\": -1.8840579710144922, \"x2\": -7.101449275362319, \"y2\": -1.5942028985507246, \"center_x\": -7.246376811594203, \"center_y\": -1.7391304347826084, \"value_uncond\": 1.9116506501997293e-06}, {\"x\": -7.101449275362318, \"y\": -1.8840579710144922, \"x2\": -6.811594202898551, \"y2\": -1.5942028985507246, \"center_x\": -6.956521739130435, \"center_y\": -1.7391304347826084, \"value_uncond\": 2.746065707075796e-06}, {\"x\": -6.811594202898551, \"y\": -1.8840579710144922, \"x2\": -6.521739130434783, \"y2\": -1.5942028985507246, \"center_x\": -6.666666666666667, \"center_y\": -1.7391304347826084, \"value_uncond\": 3.9080412136115375e-06}, {\"x\": -6.521739130434782, \"y\": -1.8840579710144922, \"x2\": -6.231884057971015, \"y2\": -1.5942028985507246, \"center_x\": -6.3768115942028984, \"center_y\": -1.7391304347826084, \"value_uncond\": 5.510019806584133e-06}, {\"x\": -6.231884057971014, \"y\": -1.8840579710144922, \"x2\": -5.942028985507246, \"y2\": -1.5942028985507246, \"center_x\": -6.08695652173913, \"center_y\": -1.7391304347826084, \"value_uncond\": 7.696495139530241e-06}, {\"x\": -5.942028985507246, \"y\": -1.8840579710144922, \"x2\": -5.6521739130434785, \"y2\": -1.5942028985507246, \"center_x\": -5.797101449275362, \"center_y\": -1.7391304347826084, \"value_uncond\": 1.0650712297128669e-05}, {\"x\": -5.6521739130434785, \"y\": -1.8840579710144922, \"x2\": -5.362318840579711, \"y2\": -1.5942028985507246, \"center_x\": -5.507246376811595, \"center_y\": -1.7391304347826084, \"value_uncond\": 1.4601925287135904e-05}, {\"x\": -5.36231884057971, \"y\": -1.8840579710144922, \"x2\": -5.072463768115942, \"y2\": -1.5942028985507246, \"center_x\": -5.217391304347826, \"center_y\": -1.7391304347826084, \"value_uncond\": 1.9832954021266523e-05}, {\"x\": -5.0724637681159415, \"y\": -1.8840579710144922, \"x2\": -4.782608695652174, \"y2\": -1.5942028985507246, \"center_x\": -4.927536231884058, \"center_y\": -1.7391304347826084, \"value_uncond\": 2.6687660404369246e-05}, {\"x\": -4.782608695652174, \"y\": -1.8840579710144922, \"x2\": -4.492753623188406, \"y2\": -1.5942028985507246, \"center_x\": -4.63768115942029, \"center_y\": -1.7391304347826084, \"value_uncond\": 3.557782665902412e-05}, {\"x\": -4.492753623188405, \"y\": -1.8840579710144922, \"x2\": -4.202898550724638, \"y2\": -1.5942028985507246, \"center_x\": -4.3478260869565215, \"center_y\": -1.7391304347826084, \"value_uncond\": 4.698877699526274e-05}, {\"x\": -4.202898550724638, \"y\": -1.8840579710144922, \"x2\": -3.91304347826087, \"y2\": -1.5942028985507246, \"center_x\": -4.057971014492754, \"center_y\": -1.7391304347826084, \"value_uncond\": 6.148294796880874e-05}, {\"x\": -3.913043478260869, \"y\": -1.8840579710144922, \"x2\": -3.6231884057971016, \"y2\": -1.5942028985507246, \"center_x\": -3.7681159420289854, \"center_y\": -1.7391304347826084, \"value_uncond\": 7.97004986423945e-05}, {\"x\": -3.6231884057971016, \"y\": -1.8840579710144922, \"x2\": -3.333333333333334, \"y2\": -1.5942028985507246, \"center_x\": -3.4782608695652177, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.00010235597719542227}, {\"x\": -3.333333333333333, \"y\": -1.8840579710144922, \"x2\": -3.0434782608695654, \"y2\": -1.5942028985507246, \"center_x\": -3.1884057971014492, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0001302300459297184}, {\"x\": -3.0434782608695645, \"y\": -1.8840579710144922, \"x2\": -2.753623188405797, \"y2\": -1.5942028985507246, \"center_x\": -2.8985507246376807, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0001641553317449651}, {\"x\": -2.753623188405797, \"y\": -1.8840579710144922, \"x2\": -2.4637681159420293, \"y2\": -1.5942028985507246, \"center_x\": -2.608695652173913, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.00020499563188619514}, {\"x\": -2.4637681159420284, \"y\": -1.8840579710144922, \"x2\": -2.1739130434782608, \"y2\": -1.5942028985507246, \"center_x\": -2.3188405797101446, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0002536179778744869}, {\"x\": -2.1739130434782608, \"y\": -1.8840579710144922, \"x2\": -1.8840579710144931, \"y2\": -1.5942028985507246, \"center_x\": -2.028985507246377, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0003108574488905764}, {\"x\": -1.8840579710144922, \"y\": -1.8840579710144922, \"x2\": -1.5942028985507246, \"y2\": -1.5942028985507246, \"center_x\": -1.7391304347826084, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0003774751237167975}, {\"x\": -1.5942028985507246, \"y\": -1.8840579710144922, \"x2\": -1.304347826086957, \"y2\": -1.5942028985507246, \"center_x\": -1.4492753623188408, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.00045411014908831735}, {\"x\": -1.304347826086957, \"y\": -1.8840579710144922, \"x2\": -1.0144927536231894, \"y2\": -1.5942028985507246, \"center_x\": -1.1594202898550732, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0005412275494716625}, {\"x\": -1.0144927536231876, \"y\": -1.8840579710144922, \"x2\": -0.72463768115942, \"y2\": -1.5942028985507246, \"center_x\": -0.8695652173913038, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0006390640627744426}, {\"x\": -0.72463768115942, \"y\": -1.8840579710144922, \"x2\": -0.43478260869565233, \"y2\": -1.5942028985507246, \"center_x\": -0.5797101449275361, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.000747574900622746}, {\"x\": -0.43478260869565233, \"y\": -1.8840579710144922, \"x2\": -0.1449275362318847, \"y2\": -1.5942028985507246, \"center_x\": -0.2898550724637685, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0008663848352892936}, {\"x\": -0.14492753623188293, \"y\": -1.8840579710144922, \"x2\": 0.1449275362318847, \"y2\": -1.5942028985507246, \"center_x\": 8.881784197001252e-16, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0009947473407901947}, {\"x\": 0.1449275362318847, \"y\": -1.8840579710144922, \"x2\": 0.43478260869565233, \"y2\": -1.5942028985507246, \"center_x\": 0.2898550724637685, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.001131515600817794}, {\"x\": 0.43478260869565233, \"y\": -1.8840579710144922, \"x2\": 0.72463768115942, \"y2\": -1.5942028985507246, \"center_x\": 0.5797101449275361, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0012751289915987729}, {\"x\": 0.72463768115942, \"y\": -1.8840579710144922, \"x2\": 1.0144927536231876, \"y2\": -1.5942028985507246, \"center_x\": 0.8695652173913038, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0014236181244848623}, {\"x\": 1.0144927536231894, \"y\": -1.8840579710144922, \"x2\": 1.304347826086957, \"y2\": -1.5942028985507246, \"center_x\": 1.1594202898550732, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.001574630689078329}, {\"x\": 1.304347826086957, \"y\": -1.8840579710144922, \"x2\": 1.5942028985507246, \"y2\": -1.5942028985507246, \"center_x\": 1.4492753623188408, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0017254792022204585}, {\"x\": 1.5942028985507246, \"y\": -1.8840579710144922, \"x2\": 1.8840579710144922, \"y2\": -1.5942028985507246, \"center_x\": 1.7391304347826084, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0018732104030289617}, {\"x\": 1.884057971014494, \"y\": -1.8840579710144922, \"x2\": 2.1739130434782616, \"y2\": -1.5942028985507246, \"center_x\": 2.028985507246378, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.002014694531334479}, {\"x\": 2.1739130434782616, \"y\": -1.8840579710144922, \"x2\": 2.4637681159420293, \"y2\": -1.5942028985507246, \"center_x\": 2.3188405797101455, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.002146731202298736}, {\"x\": 2.4637681159420293, \"y\": -1.8840579710144922, \"x2\": 2.753623188405797, \"y2\": -1.5942028985507246, \"center_x\": 2.608695652173913, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0022661671739586985}, {\"x\": 2.753623188405797, \"y\": -1.8840579710144922, \"x2\": 3.0434782608695645, \"y2\": -1.5942028985507246, \"center_x\": 2.8985507246376807, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0023700201291370505}, {\"x\": 3.0434782608695663, \"y\": -1.8840579710144922, \"x2\": 3.333333333333334, \"y2\": -1.5942028985507246, \"center_x\": 3.18840579710145, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.002455601778985758}, {\"x\": 3.333333333333334, \"y\": -1.8840579710144922, \"x2\": 3.6231884057971016, \"y2\": -1.5942028985507246, \"center_x\": 3.4782608695652177, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0025206332374069643}, {\"x\": 3.6231884057971016, \"y\": -1.8840579710144922, \"x2\": 3.913043478260869, \"y2\": -1.5942028985507246, \"center_x\": 3.7681159420289854, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.002563345771679817}, {\"x\": 3.913043478260871, \"y\": -1.8840579710144922, \"x2\": 4.202898550724639, \"y2\": -1.5942028985507246, \"center_x\": 4.057971014492755, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.002582560717457531}, {\"x\": 4.202898550724639, \"y\": -1.8840579710144922, \"x2\": 4.492753623188406, \"y2\": -1.5942028985507246, \"center_x\": 4.347826086956522, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0025777435196343624}, {\"x\": 4.492753623188406, \"y\": -1.8840579710144922, \"x2\": 4.782608695652174, \"y2\": -1.5942028985507246, \"center_x\": 4.63768115942029, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0025490284410144945}, {\"x\": 4.782608695652174, \"y\": -1.8840579710144922, \"x2\": 5.0724637681159415, \"y2\": -1.5942028985507246, \"center_x\": 4.927536231884058, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0024972123447709275}, {\"x\": 5.072463768115943, \"y\": -1.8840579710144922, \"x2\": 5.362318840579711, \"y2\": -1.5942028985507246, \"center_x\": 5.217391304347827, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0024237179525454537}, {\"x\": 5.362318840579711, \"y\": -1.8840579710144922, \"x2\": 5.6521739130434785, \"y2\": -1.5942028985507246, \"center_x\": 5.507246376811595, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0023305289426137506}, {\"x\": 5.6521739130434785, \"y\": -1.8840579710144922, \"x2\": 5.942028985507246, \"y2\": -1.5942028985507246, \"center_x\": 5.797101449275362, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.002220101020085922}, {\"x\": 5.942028985507246, \"y\": -1.8840579710144922, \"x2\": 6.231884057971014, \"y2\": -1.5942028985507246, \"center_x\": 6.08695652173913, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0020952545214967607}, {\"x\": 6.2318840579710155, \"y\": -1.8840579710144922, \"x2\": 6.521739130434783, \"y2\": -1.5942028985507246, \"center_x\": 6.376811594202899, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.001959055100746278}, {\"x\": 6.521739130434785, \"y\": -1.8840579710144922, \"x2\": 6.8115942028985526, \"y2\": -1.5942028985507246, \"center_x\": 6.666666666666669, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0018146895170783953}, {\"x\": 6.811594202898551, \"y\": -1.8840579710144922, \"x2\": 7.101449275362318, \"y2\": -1.5942028985507246, \"center_x\": 6.956521739130435, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0016653434920375757}, {\"x\": 7.10144927536232, \"y\": -1.8840579710144922, \"x2\": 7.391304347826088, \"y2\": -1.5942028985507246, \"center_x\": 7.246376811594204, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.001514088052601515}, {\"x\": 7.391304347826086, \"y\": -1.8840579710144922, \"x2\": 7.681159420289854, \"y2\": -1.5942028985507246, \"center_x\": 7.53623188405797, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0013637798059488858}, {\"x\": 7.681159420289855, \"y\": -1.8840579710144922, \"x2\": 7.971014492753623, \"y2\": -1.5942028985507246, \"center_x\": 7.826086956521739, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0012169793043008256}, {\"x\": 7.971014492753625, \"y\": -1.8840579710144922, \"x2\": 8.260869565217392, \"y2\": -1.5942028985507246, \"center_x\": 8.115942028985508, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0010758901827693436}, {\"x\": 8.26086956521739, \"y\": -1.8840579710144922, \"x2\": 8.550724637681158, \"y2\": -1.5942028985507246, \"center_x\": 8.405797101449274, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0009423202221871583}, {\"x\": 8.55072463768116, \"y\": -1.8840579710144922, \"x2\": 8.840579710144928, \"y2\": -1.5942028985507246, \"center_x\": 8.695652173913043, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0008176640283809529}, {\"x\": 8.84057971014493, \"y\": -1.8840579710144922, \"x2\": 9.130434782608697, \"y2\": -1.5942028985507246, \"center_x\": 8.985507246376812, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0007029057366299728}, {\"x\": 9.130434782608695, \"y\": -1.8840579710144922, \"x2\": 9.420289855072463, \"y2\": -1.5942028985507246, \"center_x\": 9.275362318840578, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0005986391255598276}, {\"x\": 9.420289855072465, \"y\": -1.8840579710144922, \"x2\": 9.710144927536232, \"y2\": -1.5942028985507246, \"center_x\": 9.565217391304348, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0005051018073111961}, {\"x\": 9.710144927536234, \"y\": -1.8840579710144922, \"x2\": 10.000000000000002, \"y2\": -1.5942028985507246, \"center_x\": 9.855072463768117, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.00042221976689926533}, {\"x\": 10.0, \"y\": -1.8840579710144922, \"x2\": 10.289855072463768, \"y2\": -1.5942028985507246, \"center_x\": 10.144927536231883, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.00034965843977834024}, {\"x\": -10.0, \"y\": -1.5942028985507246, \"x2\": -9.710144927536232, \"y2\": -1.304347826086957, \"center_x\": -9.855072463768117, \"center_y\": -1.4492753623188408, \"value_uncond\": 5.801248815659017e-08}, {\"x\": -9.710144927536232, \"y\": -1.5942028985507246, \"x2\": -9.420289855072465, \"y2\": -1.304347826086957, \"center_x\": -9.565217391304348, \"center_y\": -1.4492753623188408, \"value_uncond\": 9.063825959002471e-08}, {\"x\": -9.420289855072463, \"y\": -1.5942028985507246, \"x2\": -9.130434782608695, \"y2\": -1.304347826086957, \"center_x\": -9.275362318840578, \"center_y\": -1.4492753623188408, \"value_uncond\": 1.4029669398909313e-07}, {\"x\": -9.130434782608695, \"y\": -1.5942028985507246, \"x2\": -8.840579710144928, \"y2\": -1.304347826086957, \"center_x\": -8.985507246376812, \"center_y\": -1.4492753623188408, \"value_uncond\": 2.1514394672036343e-07}, {\"x\": -8.840579710144928, \"y\": -1.5942028985507246, \"x2\": -8.55072463768116, \"y2\": -1.304347826086957, \"center_x\": -8.695652173913043, \"center_y\": -1.4492753623188408, \"value_uncond\": 3.268561341934916e-07}, {\"x\": -8.55072463768116, \"y\": -1.5942028985507246, \"x2\": -8.260869565217392, \"y2\": -1.304347826086957, \"center_x\": -8.405797101449277, \"center_y\": -1.4492753623188408, \"value_uncond\": 4.919601927890292e-07}, {\"x\": -8.26086956521739, \"y\": -1.5942028985507246, \"x2\": -7.971014492753623, \"y2\": -1.304347826086957, \"center_x\": -8.115942028985508, \"center_y\": -1.4492753623188408, \"value_uncond\": 7.33582733510017e-07}, {\"x\": -7.971014492753623, \"y\": -1.5942028985507246, \"x2\": -7.681159420289855, \"y2\": -1.304347826086957, \"center_x\": -7.826086956521739, \"center_y\": -1.4492753623188408, \"value_uncond\": 1.0837124255962345e-06}, {\"x\": -7.681159420289855, \"y\": -1.5942028985507246, \"x2\": -7.391304347826088, \"y2\": -1.304347826086957, \"center_x\": -7.536231884057972, \"center_y\": -1.4492753623188408, \"value_uncond\": 1.586079016993117e-06}, {\"x\": -7.391304347826087, \"y\": -1.5942028985507246, \"x2\": -7.101449275362319, \"y2\": -1.304347826086957, \"center_x\": -7.246376811594203, \"center_y\": -1.4492753623188408, \"value_uncond\": 2.299754095632208e-06}, {\"x\": -7.101449275362318, \"y\": -1.5942028985507246, \"x2\": -6.811594202898551, \"y2\": -1.304347826086957, \"center_x\": -6.956521739130435, \"center_y\": -1.4492753623188408, \"value_uncond\": 3.3035721542860862e-06}, {\"x\": -6.811594202898551, \"y\": -1.5942028985507246, \"x2\": -6.521739130434783, \"y2\": -1.304347826086957, \"center_x\": -6.666666666666667, \"center_y\": -1.4492753623188408, \"value_uncond\": 4.701452007438475e-06}, {\"x\": -6.521739130434782, \"y\": -1.5942028985507246, \"x2\": -6.231884057971015, \"y2\": -1.304347826086957, \"center_x\": -6.3768115942028984, \"center_y\": -1.4492753623188408, \"value_uncond\": 6.628664403656853e-06}, {\"x\": -6.231884057971014, \"y\": -1.5942028985507246, \"x2\": -5.942028985507246, \"y2\": -1.304347826086957, \"center_x\": -6.08695652173913, \"center_y\": -1.4492753623188408, \"value_uncond\": 9.259038107877462e-06}, {\"x\": -5.942028985507246, \"y\": -1.5942028985507246, \"x2\": -5.6521739130434785, \"y2\": -1.304347826086957, \"center_x\": -5.797101449275362, \"center_y\": -1.4492753623188408, \"value_uncond\": 1.2813020634373129e-05}, {\"x\": -5.6521739130434785, \"y\": -1.5942028985507246, \"x2\": -5.362318840579711, \"y2\": -1.304347826086957, \"center_x\": -5.507246376811595, \"center_y\": -1.4492753623188408, \"value_uncond\": 1.7566409155196697e-05}, {\"x\": -5.36231884057971, \"y\": -1.5942028985507246, \"x2\": -5.072463768115942, \"y2\": -1.304347826086957, \"center_x\": -5.217391304347826, \"center_y\": -1.4492753623188408, \"value_uncond\": 2.38594416998354e-05}, {\"x\": -5.0724637681159415, \"y\": -1.5942028985507246, \"x2\": -4.782608695652174, \"y2\": -1.304347826086957, \"center_x\": -4.927536231884058, \"center_y\": -1.4492753623188408, \"value_uncond\": 3.21057910405215e-05}, {\"x\": -4.782608695652174, \"y\": -1.5942028985507246, \"x2\": -4.492753623188406, \"y2\": -1.304347826086957, \"center_x\": -4.63768115942029, \"center_y\": -1.4492753623188408, \"value_uncond\": 4.28008394547585e-05}, {\"x\": -4.492753623188405, \"y\": -1.5942028985507246, \"x2\": -4.202898550724638, \"y2\": -1.304347826086957, \"center_x\": -4.3478260869565215, \"center_y\": -1.4492753623188408, \"value_uncond\": 5.652844170681153e-05}, {\"x\": -4.202898550724638, \"y\": -1.5942028985507246, \"x2\": -3.91304347826087, \"y2\": -1.304347826086957, \"center_x\": -4.057971014492754, \"center_y\": -1.4492753623188408, \"value_uncond\": 7.396522026032139e-05}, {\"x\": -3.913043478260869, \"y\": -1.5942028985507246, \"x2\": -3.6231884057971016, \"y2\": -1.304347826086957, \"center_x\": -3.7681159420289854, \"center_y\": -1.4492753623188408, \"value_uncond\": 9.588129931461353e-05}, {\"x\": -3.6231884057971016, \"y\": -1.5942028985507246, \"x2\": -3.333333333333334, \"y2\": -1.304347826086957, \"center_x\": -3.4782608695652177, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.00012313629466922468}, {\"x\": -3.333333333333333, \"y\": -1.5942028985507246, \"x2\": -3.0434782608695654, \"y2\": -1.304347826086957, \"center_x\": -3.1884057971014492, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.00015666935873976176}, {\"x\": -3.0434782608695645, \"y\": -1.5942028985507246, \"x2\": -2.753623188405797, \"y2\": -1.304347826086957, \"center_x\": -2.8985507246376807, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.00019748215839588876}, {\"x\": -2.753623188405797, \"y\": -1.5942028985507246, \"x2\": -2.4637681159420293, \"y2\": -1.304347826086957, \"center_x\": -2.608695652173913, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0002466138590582609}, {\"x\": -2.4637681159420284, \"y\": -1.5942028985507246, \"x2\": -2.1739130434782608, \"y2\": -1.304347826086957, \"center_x\": -2.3188405797101446, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.00030510751704652234}, {\"x\": -2.1739130434782608, \"y\": -1.5942028985507246, \"x2\": -1.8840579710144931, \"y2\": -1.304347826086957, \"center_x\": -2.028985507246377, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0003739677493736574}, {\"x\": -1.8840579710144922, \"y\": -1.5942028985507246, \"x2\": -1.5942028985507246, \"y2\": -1.304347826086957, \"center_x\": -1.7391304347826084, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.00045411014908831735}, {\"x\": -1.5942028985507246, \"y\": -1.5942028985507246, \"x2\": -1.304347826086957, \"y2\": -1.304347826086957, \"center_x\": -1.4492753623188408, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.000546303622539451}, {\"x\": -1.304347826086957, \"y\": -1.5942028985507246, \"x2\": -1.0144927536231894, \"y2\": -1.304347826086957, \"center_x\": -1.1594202898550732, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0006511076034925066}, {\"x\": -1.0144927536231876, \"y\": -1.5942028985507246, \"x2\": -0.72463768115942, \"y2\": -1.304347826086957, \"center_x\": -0.8695652173913038, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0007688068924012487}, {\"x\": -0.72463768115942, \"y\": -1.5942028985507246, \"x2\": -0.43478260869565233, \"y2\": -1.304347826086957, \"center_x\": -0.5797101449275361, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0008993476079530388}, {\"x\": -0.43478260869565233, \"y\": -1.5942028985507246, \"x2\": -0.1449275362318847, \"y2\": -1.304347826086957, \"center_x\": -0.2898550724637685, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.001042278343661805}, {\"x\": -0.14492753623188293, \"y\": -1.5942028985507246, \"x2\": 0.1449275362318847, \"y2\": -1.304347826086957, \"center_x\": 8.881784197001252e-16, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0011967010137874715}, {\"x\": 0.1449275362318847, \"y\": -1.5942028985507246, \"x2\": 0.43478260869565233, \"y2\": -1.304347826086957, \"center_x\": 0.2898550724637685, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0013612359752973578}, {\"x\": 0.43478260869565233, \"y\": -1.5942028985507246, \"x2\": 0.72463768115942, \"y2\": -1.304347826086957, \"center_x\": 0.5797101449275361, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0015340057664732067}, {\"x\": 0.72463768115942, \"y\": -1.5942028985507246, \"x2\": 1.0144927536231876, \"y2\": -1.304347826086957, \"center_x\": 0.8695652173913038, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0017126411732490106}, {\"x\": 1.0144927536231894, \"y\": -1.5942028985507246, \"x2\": 1.304347826086957, \"y2\": -1.304347826086957, \"center_x\": 1.1594202898550732, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0018943123190095946}, {\"x\": 1.304347826086957, \"y\": -1.5942028985507246, \"x2\": 1.5942028985507246, \"y2\": -1.304347826086957, \"center_x\": 1.4492753623188408, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0020757861075819967}, {\"x\": 1.5942028985507246, \"y\": -1.5942028985507246, \"x2\": 1.8840579710144922, \"y2\": -1.304347826086957, \"center_x\": 1.7391304347826084, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0022535097068581106}, {\"x\": 1.884057971014494, \"y\": -1.5942028985507246, \"x2\": 2.1739130434782616, \"y2\": -1.304347826086957, \"center_x\": 2.028985507246378, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0024237179525454533}, {\"x\": 2.1739130434782616, \"y\": -1.5942028985507246, \"x2\": 2.4637681159420293, \"y2\": -1.304347826086957, \"center_x\": 2.3188405797101455, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0025825607174575303}, {\"x\": 2.4637681159420293, \"y\": -1.5942028985507246, \"x2\": 2.753623188405797, \"y2\": -1.304347826086957, \"center_x\": 2.608695652173913, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.002726244588232826}, {\"x\": 2.753623188405797, \"y\": -1.5942028985507246, \"x2\": 3.0434782608695645, \"y2\": -1.304347826086957, \"center_x\": 2.8985507246376807, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0028511817774572105}, {\"x\": 3.0434782608695663, \"y\": -1.5942028985507246, \"x2\": 3.333333333333334, \"y2\": -1.304347826086957, \"center_x\": 3.18840579710145, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0029541382196973053}, {\"x\": 3.333333333333334, \"y\": -1.5942028985507246, \"x2\": 3.6231884057971016, \"y2\": -1.304347826086957, \"center_x\": 3.4782608695652177, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0030323723692441797}, {\"x\": 3.6231884057971016, \"y\": -1.5942028985507246, \"x2\": 3.913043478260869, \"y2\": -1.304347826086957, \"center_x\": 3.7681159420289854, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0030837564051393158}, {\"x\": 3.913043478260871, \"y\": -1.5942028985507246, \"x2\": 4.202898550724639, \"y2\": -1.304347826086957, \"center_x\": 4.057971014492755, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.003106872370519827}, {\"x\": 4.202898550724639, \"y\": -1.5942028985507246, \"x2\": 4.492753623188406, \"y2\": -1.304347826086957, \"center_x\": 4.347826086956522, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.003101077184865929}, {\"x\": 4.492753623188406, \"y\": -1.5942028985507246, \"x2\": 4.782608695652174, \"y2\": -1.304347826086957, \"center_x\": 4.63768115942029, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.00306653236902547}, {\"x\": 4.782608695652174, \"y\": -1.5942028985507246, \"x2\": 5.0724637681159415, \"y2\": -1.304347826086957, \"center_x\": 4.927536231884058, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.003004196565387203}, {\"x\": 5.072463768115943, \"y\": -1.5942028985507246, \"x2\": 5.362318840579711, \"y2\": -1.304347826086957, \"center_x\": 5.217391304347827, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.002915781336637707}, {\"x\": 5.362318840579711, \"y\": -1.5942028985507246, \"x2\": 5.6521739130434785, \"y2\": -1.304347826086957, \"center_x\": 5.507246376811595, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0028036730875515294}, {\"x\": 5.6521739130434785, \"y\": -1.5942028985507246, \"x2\": 5.942028985507246, \"y2\": -1.304347826086957, \"center_x\": 5.797101449275362, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0026708260806577767}, {\"x\": 5.942028985507246, \"y\": -1.5942028985507246, \"x2\": 6.231884057971014, \"y2\": -1.304347826086957, \"center_x\": 6.08695652173913, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.002520633237406963}, {\"x\": 6.2318840579710155, \"y\": -1.5942028985507246, \"x2\": 6.521739130434783, \"y2\": -1.304347826086957, \"center_x\": 6.376811594202899, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0023567826009630436}, {\"x\": 6.521739130434785, \"y\": -1.5942028985507246, \"x2\": 6.8115942028985526, \"y2\": -1.304347826086957, \"center_x\": 6.666666666666669, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0021831079066490715}, {\"x\": 6.811594202898551, \"y\": -1.5942028985507246, \"x2\": 7.101449275362318, \"y2\": -1.304347826086957, \"center_x\": 6.956521739130435, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0020034416414148196}, {\"x\": 7.10144927536232, \"y\": -1.5942028985507246, \"x2\": 7.391304347826088, \"y2\": -1.304347826086957, \"center_x\": 7.246376811594204, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.001821478312344528}, {\"x\": 7.391304347826086, \"y\": -1.5942028985507246, \"x2\": 7.681159420289854, \"y2\": -1.304347826086957, \"center_x\": 7.53623188405797, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0016406544752011858}, {\"x\": 7.681159420289855, \"y\": -1.5942028985507246, \"x2\": 7.971014492753623, \"y2\": -1.304347826086957, \"center_x\": 7.826086956521739, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0014640505256925686}, {\"x\": 7.971014492753625, \"y\": -1.5942028985507246, \"x2\": 8.260869565217392, \"y2\": -1.304347826086957, \"center_x\": 8.115942028985508, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0012943174810814762}, {\"x\": 8.26086956521739, \"y\": -1.5942028985507246, \"x2\": 8.550724637681158, \"y2\": -1.304347826086957, \"center_x\": 8.405797101449274, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.001133630137988626}, {\"x\": 8.55072463768116, \"y\": -1.5942028985507246, \"x2\": 8.840579710144928, \"y2\": -1.304347826086957, \"center_x\": 8.695652173913043, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0009836662352107881}, {\"x\": 8.84057971014493, \"y\": -1.5942028985507246, \"x2\": 9.130434782608697, \"y2\": -1.304347826086957, \"center_x\": 8.985507246376812, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0008456097072387457}, {\"x\": 9.130434782608695, \"y\": -1.5942028985507246, \"x2\": 9.420289855072463, \"y2\": -1.304347826086957, \"center_x\": 9.275362318840578, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0007201748816751926}, {\"x\": 9.420289855072465, \"y\": -1.5942028985507246, \"x2\": 9.710144927536232, \"y2\": -1.304347826086957, \"center_x\": 9.565217391304348, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0006076476106938192}, {\"x\": 9.710144927536234, \"y\": -1.5942028985507246, \"x2\": 10.000000000000002, \"y2\": -1.304347826086957, \"center_x\": 9.855072463768117, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0005079388527825467}, {\"x\": 10.0, \"y\": -1.5942028985507246, \"x2\": 10.289855072463768, \"y2\": -1.304347826086957, \"center_x\": 10.144927536231883, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.00042064612007878583}, {\"x\": -10.0, \"y\": -1.304347826086957, \"x2\": -9.710144927536232, \"y2\": -1.0144927536231894, \"center_x\": -9.855072463768117, \"center_y\": -1.1594202898550732, \"value_uncond\": 6.914172005796482e-08}, {\"x\": -9.710144927536232, \"y\": -1.304347826086957, \"x2\": -9.420289855072465, \"y2\": -1.0144927536231894, \"center_x\": -9.565217391304348, \"center_y\": -1.1594202898550732, \"value_uncond\": 1.080264848182127e-07}, {\"x\": -9.420289855072463, \"y\": -1.304347826086957, \"x2\": -9.130434782608695, \"y2\": -1.0144927536231894, \"center_x\": -9.275362318840578, \"center_y\": -1.1594202898550732, \"value_uncond\": 1.6721149271632956e-07}, {\"x\": -9.130434782608695, \"y\": -1.304347826086957, \"x2\": -8.840579710144928, \"y2\": -1.0144927536231894, \"center_x\": -8.985507246376812, \"center_y\": -1.1594202898550732, \"value_uncond\": 2.564175922975858e-07}, {\"x\": -8.840579710144928, \"y\": -1.304347826086957, \"x2\": -8.55072463768116, \"y2\": -1.0144927536231894, \"center_x\": -8.695652173913043, \"center_y\": -1.1594202898550732, \"value_uncond\": 3.895608695257747e-07}, {\"x\": -8.55072463768116, \"y\": -1.304347826086957, \"x2\": -8.260869565217392, \"y2\": -1.0144927536231894, \"center_x\": -8.405797101449277, \"center_y\": -1.1594202898550732, \"value_uncond\": 5.863388213528535e-07}, {\"x\": -8.26086956521739, \"y\": -1.304347826086957, \"x2\": -7.971014492753623, \"y2\": -1.0144927536231894, \"center_x\": -8.115942028985508, \"center_y\": -1.1594202898550732, \"value_uncond\": 8.743147141490828e-07}, {\"x\": -7.971014492753623, \"y\": -1.304347826086957, \"x2\": -7.681159420289855, \"y2\": -1.0144927536231894, \"center_x\": -7.826086956521739, \"center_y\": -1.1594202898550732, \"value_uncond\": 1.291613987520393e-06}, {\"x\": -7.681159420289855, \"y\": -1.304347826086957, \"x2\": -7.391304347826088, \"y2\": -1.0144927536231894, \"center_x\": -7.536231884057972, \"center_y\": -1.1594202898550732, \"value_uncond\": 1.8903555918294522e-06}, {\"x\": -7.391304347826087, \"y\": -1.304347826086957, \"x2\": -7.101449275362319, \"y2\": -1.0144927536231894, \"center_x\": -7.246376811594203, \"center_y\": -1.1594202898550732, \"value_uncond\": 2.740943526730923e-06}, {\"x\": -7.101449275362318, \"y\": -1.304347826086957, \"x2\": -6.811594202898551, \"y2\": -1.0144927536231894, \"center_x\": -6.956521739130435, \"center_y\": -1.1594202898550732, \"value_uncond\": 3.937336051961573e-06}, {\"x\": -6.811594202898551, \"y\": -1.304347826086957, \"x2\": -6.521739130434783, \"y2\": -1.0144927536231894, \"center_x\": -6.666666666666667, \"center_y\": -1.1594202898550732, \"value_uncond\": 5.603387975479224e-06}, {\"x\": -6.521739130434782, \"y\": -1.304347826086957, \"x2\": -6.231884057971015, \"y2\": -1.0144927536231894, \"center_x\": -6.3768115942028984, \"center_y\": -1.1594202898550732, \"value_uncond\": 7.900320657144142e-06}, {\"x\": -6.231884057971014, \"y\": -1.304347826086957, \"x2\": -5.942028985507246, \"y2\": -1.0144927536231894, \"center_x\": -6.08695652173913, \"center_y\": -1.1594202898550732, \"value_uncond\": 1.1035310520260253e-05}, {\"x\": -5.942028985507246, \"y\": -1.304347826086957, \"x2\": -5.6521739130434785, \"y2\": -1.0144927536231894, \"center_x\": -5.797101449275362, \"center_y\": -1.1594202898550732, \"value_uncond\": 1.5271096171697562e-05}, {\"x\": -5.6521739130434785, \"y\": -1.304347826086957, \"x2\": -5.362318840579711, \"y2\": -1.0144927536231894, \"center_x\": -5.507246376811595, \"center_y\": -1.1594202898550732, \"value_uncond\": 2.0936384265295586e-05}, {\"x\": -5.36231884057971, \"y\": -1.304347826086957, \"x2\": -5.072463768115942, \"y2\": -1.0144927536231894, \"center_x\": -5.217391304347826, \"center_y\": -1.1594202898550732, \"value_uncond\": 2.8436684775465024e-05}, {\"x\": -5.0724637681159415, \"y\": -1.304347826086957, \"x2\": -4.782608695652174, \"y2\": -1.0144927536231894, \"center_x\": -4.927536231884058, \"center_y\": -1.1594202898550732, \"value_uncond\": 3.826503028746719e-05}, {\"x\": -4.782608695652174, \"y\": -1.304347826086957, \"x2\": -4.492753623188406, \"y2\": -1.0144927536231894, \"center_x\": -4.63768115942029, \"center_y\": -1.1594202898550732, \"value_uncond\": 5.1011838206953956e-05}, {\"x\": -4.492753623188405, \"y\": -1.304347826086957, \"x2\": -4.202898550724638, \"y2\": -1.0144927536231894, \"center_x\": -4.3478260869565215, \"center_y\": -1.1594202898550732, \"value_uncond\": 6.737297116537058e-05}, {\"x\": -4.202898550724638, \"y\": -1.304347826086957, \"x2\": -3.91304347826087, \"y2\": -1.0144927536231894, \"center_x\": -4.057971014492754, \"center_y\": -1.1594202898550732, \"value_uncond\": 8.815485623475879e-05}, {\"x\": -3.913043478260869, \"y\": -1.304347826086957, \"x2\": -3.6231884057971016, \"y2\": -1.0144927536231894, \"center_x\": -3.7681159420289854, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0001142753597830617}, {\"x\": -3.6231884057971016, \"y\": -1.304347826086957, \"x2\": -3.333333333333334, \"y2\": -1.0144927536231894, \"center_x\": -3.4782608695652177, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.00014675900802623028}, {\"x\": -3.333333333333333, \"y\": -1.304347826086957, \"x2\": -3.0434782608695654, \"y2\": -1.0144927536231894, \"center_x\": -3.1884057971014492, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.00018672512225998927}, {\"x\": -3.0434782608695645, \"y\": -1.304347826086957, \"x2\": -2.753623188405797, \"y2\": -1.0144927536231894, \"center_x\": -2.8985507246376807, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.000235367531132176}, {\"x\": -2.753623188405797, \"y\": -1.304347826086957, \"x2\": -2.4637681159420293, \"y2\": -1.0144927536231894, \"center_x\": -2.608695652173913, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0002939247556387334}, {\"x\": -2.4637681159420284, \"y\": -1.304347826086957, \"x2\": -2.1739130434782608, \"y2\": -1.0144927536231894, \"center_x\": -2.3188405797101446, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0003636399541124481}, {\"x\": -2.1739130434782608, \"y\": -1.304347826086957, \"x2\": -1.8840579710144931, \"y2\": -1.0144927536231894, \"center_x\": -2.028985507246377, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.00044571047130588027}, {\"x\": -1.8840579710144922, \"y\": -1.304347826086957, \"x2\": -1.5942028985507246, \"y2\": -1.0144927536231894, \"center_x\": -1.7391304347826084, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0005412275494716625}, {\"x\": -1.5942028985507246, \"y\": -1.304347826086957, \"x2\": -1.304347826086957, \"y2\": -1.0144927536231894, \"center_x\": -1.4492753623188408, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0006511076034925066}, {\"x\": -1.304347826086957, \"y\": -1.304347826086957, \"x2\": -1.0144927536231894, \"y2\": -1.0144927536231894, \"center_x\": -1.1594202898550732, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0007760173900277227}, {\"x\": -1.0144927536231876, \"y\": -1.304347826086957, \"x2\": -0.72463768115942, \"y2\": -1.0144927536231894, \"center_x\": -0.8695652173913038, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0009162963462204561}, {\"x\": -0.72463768115942, \"y\": -1.304347826086957, \"x2\": -0.43478260869565233, \"y2\": -1.0144927536231894, \"center_x\": -0.5797101449275361, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0010718802540591508}, {\"x\": -0.43478260869565233, \"y\": -1.304347826086957, \"x2\": -0.1449275362318847, \"y2\": -1.0144927536231894, \"center_x\": -0.2898550724637685, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0012422311083334794}, {\"x\": -0.14492753623188293, \"y\": -1.304347826086957, \"x2\": 0.1449275362318847, \"y2\": -1.0144927536231894, \"center_x\": 8.881784197001252e-16, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.001426278532736519}, {\"x\": 0.1449275362318847, \"y\": -1.304347826086957, \"x2\": 0.43478260869565233, \"y2\": -1.0144927536231894, \"center_x\": 0.2898550724637685, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.001622378210753385}, {\"x\": 0.43478260869565233, \"y\": -1.304347826086957, \"x2\": 0.72463768115942, \"y2\": -1.0144927536231894, \"center_x\": 0.5797101449275361, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0018282925046500629}, {\"x\": 0.72463768115942, \"y\": -1.304347826086957, \"x2\": 1.0144927536231876, \"y2\": -1.0144927536231894, \"center_x\": 0.8695652173913038, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0020411976855896296}, {\"x\": 1.0144927536231894, \"y\": -1.304347826086957, \"x2\": 1.304347826086957, \"y2\": -1.0144927536231894, \"center_x\": 1.1594202898550732, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.002257720987760061}, {\"x\": 1.304347826086957, \"y\": -1.304347826086957, \"x2\": 1.5942028985507246, \"y2\": -1.0144927536231894, \"center_x\": 1.4492753623188408, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.002474009071344113}, {\"x\": 1.5942028985507246, \"y\": -1.304347826086957, \"x2\": 1.8840579710144922, \"y2\": -1.0144927536231894, \"center_x\": 1.7391304347826084, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0026858275218073005}, {\"x\": 1.884057971014494, \"y\": -1.304347826086957, \"x2\": 2.1739130434782616, \"y2\": -1.0144927536231894, \"center_x\": 2.028985507246378, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0028886888581993115}, {\"x\": 2.1739130434782616, \"y\": -1.304347826086957, \"x2\": 2.4637681159420293, \"y2\": -1.0144927536231894, \"center_x\": 2.3188405797101455, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0030780043372240864}, {\"x\": 2.4637681159420293, \"y\": -1.304347826086957, \"x2\": 2.753623188405797, \"y2\": -1.0144927536231894, \"center_x\": 2.608695652173913, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.003249252809504304}, {\"x\": 2.753623188405797, \"y\": -1.304347826086957, \"x2\": 3.0434782608695645, \"y2\": -1.0144927536231894, \"center_x\": 2.8985507246376807, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0033981581993035538}, {\"x\": 3.0434782608695663, \"y\": -1.304347826086957, \"x2\": 3.333333333333334, \"y2\": -1.0144927536231894, \"center_x\": 3.18840579710145, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0035208660115993097}, {\"x\": 3.333333333333334, \"y\": -1.304347826086957, \"x2\": 3.6231884057971016, \"y2\": -1.0144927536231894, \"center_x\": 3.4782608695652177, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0036141087570637355}, {\"x\": 3.6231884057971016, \"y\": -1.304347826086957, \"x2\": 3.913043478260869, \"y2\": -1.0144927536231894, \"center_x\": 3.7681159420289854, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0036753504093045447}, {\"x\": 3.913043478260871, \"y\": -1.304347826086957, \"x2\": 4.202898550724639, \"y2\": -1.0144927536231894, \"center_x\": 4.057971014492755, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0037029009877747312}, {\"x\": 4.202898550724639, \"y\": -1.304347826086957, \"x2\": 4.492753623188406, \"y2\": -1.0144927536231894, \"center_x\": 4.347826086956522, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0036959940420997896}, {\"x\": 4.492753623188406, \"y\": -1.304347826086957, \"x2\": 4.782608695652174, \"y2\": -1.0144927536231894, \"center_x\": 4.63768115942029, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.003654822079610475}, {\"x\": 4.782608695652174, \"y\": -1.304347826086957, \"x2\": 5.0724637681159415, \"y2\": -1.0144927536231894, \"center_x\": 4.927536231884058, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0035805276505711356}, {\"x\": 5.072463768115943, \"y\": -1.304347826086957, \"x2\": 5.362318840579711, \"y2\": -1.0144927536231894, \"center_x\": 5.217391304347827, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0034751506672816477}, {\"x\": 5.362318840579711, \"y\": -1.304347826086957, \"x2\": 5.6521739130434785, \"y2\": -1.0144927536231894, \"center_x\": 5.507246376811595, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0033415353471874256}, {\"x\": 5.6521739130434785, \"y\": -1.304347826086957, \"x2\": 5.942028985507246, \"y2\": -1.0144927536231894, \"center_x\": 5.797101449275362, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.003183202704457242}, {\"x\": 5.942028985507246, \"y\": -1.304347826086957, \"x2\": 6.231884057971014, \"y2\": -1.0144927536231894, \"center_x\": 6.08695652173913, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.003004196565387202}, {\"x\": 6.2318840579710155, \"y\": -1.304347826086957, \"x2\": 6.521739130434783, \"y2\": -1.0144927536231894, \"center_x\": 6.376811594202899, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0028089124947273613}, {\"x\": 6.521739130434785, \"y\": -1.304347826086957, \"x2\": 6.8115942028985526, \"y2\": -1.0144927536231894, \"center_x\": 6.666666666666669, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0026019196992624204}, {\"x\": 6.811594202898551, \"y\": -1.304347826086957, \"x2\": 7.101449275362318, \"y2\": -1.0144927536231894, \"center_x\": 6.956521739130435, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.002387785897913383}, {\"x\": 7.10144927536232, \"y\": -1.304347826086957, \"x2\": 7.391304347826088, \"y2\": -1.0144927536231894, \"center_x\": 7.246376811594204, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0021709143594019938}, {\"x\": 7.391304347826086, \"y\": -1.304347826086957, \"x2\": 7.681159420289854, \"y2\": -1.0144927536231894, \"center_x\": 7.53623188405797, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.001955400915230719}, {\"x\": 7.681159420289855, \"y\": -1.304347826086957, \"x2\": 7.971014492753623, \"y2\": -1.0144927536231894, \"center_x\": 7.826086956521739, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0017449169103885887}, {\"x\": 7.971014492753625, \"y\": -1.304347826086957, \"x2\": 8.260869565217392, \"y2\": -1.0144927536231894, \"center_x\": 8.115942028985508, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.001542621938598914}, {\"x\": 8.26086956521739, \"y\": -1.304347826086957, \"x2\": 8.550724637681158, \"y2\": -1.0144927536231894, \"center_x\": 8.405797101449274, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0013511080138212909}, {\"x\": 8.55072463768116, \"y\": -1.304347826086957, \"x2\": 8.840579710144928, \"y2\": -1.0144927536231894, \"center_x\": 8.695652173913043, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.00117237473562303}, {\"x\": 8.84057971014493, \"y\": -1.304347826086957, \"x2\": 9.130434782608697, \"y2\": -1.0144927536231894, \"center_x\": 8.985507246376812, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0010078331668585262}, {\"x\": 9.130434782608695, \"y\": -1.304347826086957, \"x2\": 9.420289855072463, \"y2\": -1.0144927536231894, \"center_x\": 9.275362318840578, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0008583346731682558}, {\"x\": 9.420289855072465, \"y\": -1.304347826086957, \"x2\": 9.710144927536232, \"y2\": -1.0144927536231894, \"center_x\": 9.565217391304348, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0007242199451793476}, {\"x\": 9.710144927536234, \"y\": -1.304347826086957, \"x2\": 10.000000000000002, \"y2\": -1.0144927536231894, \"center_x\": 9.855072463768117, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.000605382859477733}, {\"x\": 10.0, \"y\": -1.304347826086957, \"x2\": 10.289855072463768, \"y2\": -1.0144927536231894, \"center_x\": 10.144927536231883, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0005013437141232592}, {\"x\": -10.0, \"y\": -1.0144927536231876, \"x2\": -9.710144927536232, \"y2\": -0.72463768115942, \"center_x\": -9.855072463768117, \"center_y\": -0.8695652173913038, \"value_uncond\": 8.164031666641845e-08}, {\"x\": -9.710144927536232, \"y\": -1.0144927536231876, \"x2\": -9.420289855072465, \"y2\": -0.72463768115942, \"center_x\": -9.565217391304348, \"center_y\": -0.8695652173913038, \"value_uncond\": 1.2755419479766016e-07}, {\"x\": -9.420289855072463, \"y\": -1.0144927536231876, \"x2\": -9.130434782608695, \"y2\": -0.72463768115942, \"center_x\": -9.275362318840578, \"center_y\": -0.8695652173913038, \"value_uncond\": 1.9743794635396995e-07}, {\"x\": -9.130434782608695, \"y\": -1.0144927536231876, \"x2\": -8.840579710144928, \"y2\": -0.72463768115942, \"center_x\": -8.985507246376812, \"center_y\": -0.8695652173913038, \"value_uncond\": 3.0276963628422175e-07}, {\"x\": -8.840579710144928, \"y\": -1.0144927536231876, \"x2\": -8.55072463768116, \"y2\": -0.72463768115942, \"center_x\": -8.695652173913043, \"center_y\": -0.8695652173913038, \"value_uncond\": 4.5998093079354775e-07}, {\"x\": -8.55072463768116, \"y\": -1.0144927536231876, \"x2\": -8.260869565217392, \"y2\": -0.72463768115942, \"center_x\": -8.405797101449277, \"center_y\": -0.8695652173913038, \"value_uncond\": 6.923300000192465e-07}, {\"x\": -8.26086956521739, \"y\": -1.0144927536231876, \"x2\": -7.971014492753623, \"y2\": -0.72463768115942, \"center_x\": -8.115942028985508, \"center_y\": -0.8695652173913038, \"value_uncond\": 1.032362661348308e-06}, {\"x\": -7.971014492753623, \"y\": -1.0144927536231876, \"x2\": -7.681159420289855, \"y2\": -0.72463768115942, \"center_x\": -7.826086956521739, \"center_y\": -0.8695652173913038, \"value_uncond\": 1.5250962062201841e-06}, {\"x\": -7.681159420289855, \"y\": -1.0144927536231876, \"x2\": -7.391304347826088, \"y2\": -0.72463768115942, \"center_x\": -7.536231884057972, \"center_y\": -0.8695652173913038, \"value_uncond\": 2.2320710129818836e-06}, {\"x\": -7.391304347826087, \"y\": -1.0144927536231876, \"x2\": -7.101449275362319, \"y2\": -0.72463768115942, \"center_x\": -7.246376811594203, \"center_y\": -0.8695652173913038, \"value_uncond\": 3.2364178574019272e-06}, {\"x\": -7.101449275362318, \"y\": -1.0144927536231876, \"x2\": -6.811594202898551, \"y2\": -0.72463768115942, \"center_x\": -6.956521739130435, \"center_y\": -0.8695652173913038, \"value_uncond\": 4.649079627101635e-06}, {\"x\": -6.811594202898551, \"y\": -1.0144927536231876, \"x2\": -6.521739130434783, \"y2\": -0.72463768115942, \"center_x\": -6.666666666666667, \"center_y\": -0.8695652173913038, \"value_uncond\": 6.616300091166552e-06}, {\"x\": -6.521739130434782, \"y\": -1.0144927536231876, \"x2\": -6.231884057971015, \"y2\": -0.72463768115942, \"center_x\": -6.3768115942028984, \"center_y\": -0.8695652173913038, \"value_uncond\": 9.328444239957765e-06}, {\"x\": -6.231884057971014, \"y\": -1.0144927536231876, \"x2\": -5.942028985507246, \"y2\": -0.72463768115942, \"center_x\": -6.08695652173913, \"center_y\": -0.8695652173913038, \"value_uncond\": 1.3030139322987851e-05}, {\"x\": -5.942028985507246, \"y\": -1.0144927536231876, \"x2\": -5.6521739130434785, \"y2\": -0.72463768115942, \"center_x\": -5.797101449275362, \"center_y\": -0.8695652173913038, \"value_uncond\": 1.8031618627010143e-05}, {\"x\": -5.6521739130434785, \"y\": -1.0144927536231876, \"x2\": -5.362318840579711, \"y2\": -0.72463768115942, \"center_x\": -5.507246376811595, \"center_y\": -0.8695652173913038, \"value_uncond\": 2.4721008384454473e-05}, {\"x\": -5.36231884057971, \"y\": -1.0144927536231876, \"x2\": -5.072463768115942, \"y2\": -0.72463768115942, \"center_x\": -5.217391304347826, \"center_y\": -0.8695652173913038, \"value_uncond\": 3.3577121715597955e-05}, {\"x\": -5.0724637681159415, \"y\": -1.0144927536231876, \"x2\": -4.782608695652174, \"y2\": -0.72463768115942, \"center_x\": -4.927536231884058, \"center_y\": -0.8695652173913038, \"value_uncond\": 4.51821156213635e-05}, {\"x\": -4.782608695652174, \"y\": -1.0144927536231876, \"x2\": -4.492753623188406, \"y2\": -0.72463768115942, \"center_x\": -4.63768115942029, \"center_y\": -0.8695652173913038, \"value_uncond\": 6.0233135962779376e-05}, {\"x\": -4.492753623188405, \"y\": -1.0144927536231876, \"x2\": -4.202898550724638, \"y2\": -0.72463768115942, \"center_x\": -4.3478260869565215, \"center_y\": -0.8695652173913038, \"value_uncond\": 7.955183492813199e-05}, {\"x\": -4.202898550724638, \"y\": -1.0144927536231876, \"x2\": -3.91304347826087, \"y2\": -0.72463768115942, \"center_x\": -4.057971014492754, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0001040904156369658}, {\"x\": -3.913043478260869, \"y\": -1.0144927536231876, \"x2\": -3.6231884057971016, \"y2\": -0.72463768115942, \"center_x\": -3.7681159420289854, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0001349326651410567}, {\"x\": -3.6231884057971016, \"y\": -1.0144927536231876, \"x2\": -3.333333333333334, \"y2\": -0.72463768115942, \"center_x\": -3.4782608695652177, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0001732883110062385}, {\"x\": -3.333333333333333, \"y\": -1.0144927536231876, \"x2\": -3.0434782608695654, \"y2\": -0.72463768115942, \"center_x\": -3.1884057971014492, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.00022047901177611992}, {\"x\": -3.0434782608695645, \"y\": -1.0144927536231876, \"x2\": -2.753623188405797, \"y2\": -0.72463768115942, \"center_x\": -2.8985507246376807, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0002779144018765324}, {\"x\": -2.753623188405797, \"y\": -1.0144927536231876, \"x2\": -2.4637681159420293, \"y2\": -0.72463768115942, \"center_x\": -2.608695652173913, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0003470568870188469}, {\"x\": -2.4637681159420284, \"y\": -1.0144927536231876, \"x2\": -2.1739130434782608, \"y2\": -0.72463768115942, \"center_x\": -2.3188405797101446, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0004293743485324563}, {\"x\": -2.1739130434782608, \"y\": -1.0144927536231876, \"x2\": -1.8840579710144931, \"y2\": -0.72463768115942, \"center_x\": -2.028985507246377, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0005262805725464293}, {\"x\": -1.8840579710144922, \"y\": -1.0144927536231876, \"x2\": -1.5942028985507246, \"y2\": -0.72463768115942, \"center_x\": -1.7391304347826084, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0006390640627744426}, {\"x\": -1.5942028985507246, \"y\": -1.0144927536231876, \"x2\": -1.304347826086957, \"y2\": -0.72463768115942, \"center_x\": -1.4492753623188408, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0007688068924012487}, {\"x\": -1.304347826086957, \"y\": -1.0144927536231876, \"x2\": -1.0144927536231894, \"y2\": -0.72463768115942, \"center_x\": -1.1594202898550732, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0009162963462204561}, {\"x\": -1.0144927536231876, \"y\": -1.0144927536231876, \"x2\": -0.72463768115942, \"y2\": -0.72463768115942, \"center_x\": -0.8695652173913038, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.001081933220680743}, {\"x\": -0.72463768115942, \"y\": -1.0144927536231876, \"x2\": -0.43478260869565233, \"y2\": -0.72463768115942, \"center_x\": -0.5797101449275361, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0012656416892218969}, {\"x\": -0.43478260869565233, \"y\": -1.0144927536231876, \"x2\": -0.1449275362318847, \"y2\": -0.72463768115942, \"center_x\": -0.2898550724637685, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0014667864926154442}, {\"x\": -0.14492753623188293, \"y\": -1.0144927536231876, \"x2\": 0.1449275362318847, \"y2\": -0.72463768115942, \"center_x\": 8.881784197001252e-16, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0016841037649845162}, {\"x\": 0.1449275362318847, \"y\": -1.0144927536231876, \"x2\": 0.43478260869565233, \"y2\": -0.72463768115942, \"center_x\": 0.2898550724637685, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0019156519503356758}, {\"x\": 0.43478260869565233, \"y\": -1.0144927536231876, \"x2\": 0.72463768115942, \"y2\": -0.72463768115942, \"center_x\": 0.5797101449275361, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0021587889180850073}, {\"x\": 0.72463768115942, \"y\": -1.0144927536231876, \"x2\": 1.0144927536231876, \"y2\": -0.72463768115942, \"center_x\": 0.8695652173913038, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0024101805001465397}, {\"x\": 1.0144927536231894, \"y\": -1.0144927536231876, \"x2\": 1.304347826086957, \"y2\": -0.72463768115942, \"center_x\": 1.1594202898550732, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.002665844243253208}, {\"x\": 1.304347826086957, \"y\": -1.0144927536231876, \"x2\": 1.5942028985507246, \"y2\": -0.72463768115942, \"center_x\": 1.4492753623188408, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.002921230247827166}, {\"x\": 1.5942028985507246, \"y\": -1.0144927536231876, \"x2\": 1.8840579710144922, \"y2\": -0.72463768115942, \"center_x\": 1.7391304347826084, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0031713386535351415}, {\"x\": 1.884057971014494, \"y\": -1.0144927536231876, \"x2\": 2.1739130434782616, \"y2\": -0.72463768115942, \"center_x\": 2.028985507246378, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.00341087078736884}, {\"x\": 2.1739130434782616, \"y\": -1.0144927536231876, \"x2\": 2.4637681159420293, \"y2\": -0.72463768115942, \"center_x\": 2.3188405797101455, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0036344084090027826}, {\"x\": 2.4637681159420293, \"y\": -1.0144927536231876, \"x2\": 2.753623188405797, \"y2\": -0.72463768115942, \"center_x\": 2.608695652173913, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0038366130908341948}, {\"x\": 2.753623188405797, \"y\": -1.0144927536231876, \"x2\": 3.0434782608695645, \"y2\": -0.72463768115942, \"center_x\": 2.8985507246376807, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.004012435780324067}, {\"x\": 3.0434782608695663, \"y\": -1.0144927536231876, \"x2\": 3.333333333333334, \"y2\": -0.72463768115942, \"center_x\": 3.18840579710145, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.004157325213865357}, {\"x\": 3.333333333333334, \"y\": -1.0144927536231876, \"x2\": 3.6231884057971016, \"y2\": -0.72463768115942, \"center_x\": 3.4782608695652177, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.004267423245273602}, {\"x\": 3.6231884057971016, \"y\": -1.0144927536231876, \"x2\": 3.913043478260869, \"y2\": -0.72463768115942, \"center_x\": 3.7681159420289854, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.00433973541624538}, {\"x\": 3.913043478260871, \"y\": -1.0144927536231876, \"x2\": 4.202898550724639, \"y2\": -0.72463768115942, \"center_x\": 4.057971014492755, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.004372266252168516}, {\"x\": 4.202898550724639, \"y\": -1.0144927536231876, \"x2\": 4.492753623188406, \"y2\": -0.72463768115942, \"center_x\": 4.347826086956522, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.004364110753120658}, {\"x\": 4.492753623188406, \"y\": -1.0144927536231876, \"x2\": 4.782608695652174, \"y2\": -0.72463768115942, \"center_x\": 4.63768115942029, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.004315496225559185}, {\"x\": 4.782608695652174, \"y\": -1.0144927536231876, \"x2\": 5.0724637681159415, \"y2\": -0.72463768115942, \"center_x\": 4.927536231884058, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0042277717560458795}, {\"x\": 5.072463768115943, \"y\": -1.0144927536231876, \"x2\": 5.362318840579711, \"y2\": -0.72463768115942, \"center_x\": 5.217391304347827, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.004103346007338828}, {\"x\": 5.362318840579711, \"y\": -1.0144927536231876, \"x2\": 5.6521739130434785, \"y2\": -0.72463768115942, \"center_x\": 5.507246376811595, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.00394557733981317}, {\"x\": 5.6521739130434785, \"y\": -1.0144927536231876, \"x2\": 5.942028985507246, \"y2\": -0.72463768115942, \"center_x\": 5.797101449275362, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0037586232536219923}, {\"x\": 5.942028985507246, \"y\": -1.0144927536231876, \"x2\": 6.231884057971014, \"y2\": -0.72463768115942, \"center_x\": 6.08695652173913, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.003547258568643672}, {\"x\": 6.2318840579710155, \"y\": -1.0144927536231876, \"x2\": 6.521739130434783, \"y2\": -0.72463768115942, \"center_x\": 6.376811594202899, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0033166734261969566}, {\"x\": 6.521739130434785, \"y\": -1.0144927536231876, \"x2\": 6.8115942028985526, \"y2\": -0.72463768115942, \"center_x\": 6.666666666666669, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0030722629985238}, {\"x\": 6.811594202898551, \"y\": -1.0144927536231876, \"x2\": 7.101449275362318, \"y2\": -0.72463768115942, \"center_x\": 6.956521739130435, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0028194207010446017}, {\"x\": 7.10144927536232, \"y\": -1.0144927536231876, \"x2\": 7.391304347826088, \"y2\": -0.72463768115942, \"center_x\": 7.246376811594204, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.002563345771679815}, {\"x\": 7.391304347826086, \"y\": -1.0144927536231876, \"x2\": 7.681159420289854, \"y2\": -0.72463768115942, \"center_x\": 7.53623188405797, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0023088744363809113}, {\"x\": 7.681159420289855, \"y\": -1.0144927536231876, \"x2\": 7.971014492753623, \"y2\": -0.72463768115942, \"center_x\": 7.826086956521739, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0020603417010928485}, {\"x\": 7.971014492753625, \"y\": -1.0144927536231876, \"x2\": 8.260869565217392, \"y2\": -0.72463768115942, \"center_x\": 8.115942028985508, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.001821478312344528}, {\"x\": 8.26086956521739, \"y\": -1.0144927536231876, \"x2\": 8.550724637681158, \"y2\": -0.72463768115942, \"center_x\": 8.405797101449274, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0015953448367560417}, {\"x\": 8.55072463768116, \"y\": -1.0144927536231876, \"x2\": 8.840579710144928, \"y2\": -0.72463768115942, \"center_x\": 8.695652173913043, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0013843023371089397}, {\"x\": 8.84057971014493, \"y\": -1.0144927536231876, \"x2\": 9.130434782608697, \"y2\": -0.72463768115942, \"center_x\": 8.985507246376812, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.001190016950985169}, {\"x\": 9.130434782608695, \"y\": -1.0144927536231876, \"x2\": 9.420289855072463, \"y2\": -0.72463768115942, \"center_x\": 9.275362318840578, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0010134939435188506}, {\"x\": 9.420289855072465, \"y\": -1.0144927536231876, \"x2\": 9.710144927536232, \"y2\": -0.72463768115942, \"center_x\": 9.565217391304348, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0008551355912321872}, {\"x\": 9.710144927536234, \"y\": -1.0144927536231876, \"x2\": 10.000000000000002, \"y2\": -0.72463768115942, \"center_x\": 9.855072463768117, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0007148165870150437}, {\"x\": 10.0, \"y\": -1.0144927536231876, \"x2\": 10.289855072463768, \"y2\": -0.72463768115942, \"center_x\": 10.144927536231883, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0005919705142629914}, {\"x\": -10.0, \"y\": -0.72463768115942, \"x2\": -9.710144927536232, \"y2\": -0.43478260869565233, \"center_x\": -9.855072463768117, \"center_y\": -0.5797101449275361, \"value_uncond\": 9.550255627540823e-08}, {\"x\": -9.710144927536232, \"y\": -0.72463768115942, \"x2\": -9.420289855072465, \"y2\": -0.43478260869565233, \"center_x\": -9.565217391304348, \"center_y\": -0.5797101449275361, \"value_uncond\": 1.4921244997863546e-07}, {\"x\": -9.420289855072463, \"y\": -0.72463768115942, \"x2\": -9.130434782608695, \"y2\": -0.43478260869565233, \"center_x\": -9.275362318840578, \"center_y\": -0.5797101449275361, \"value_uncond\": 2.3096221759667814e-07}, {\"x\": -9.130434782608695, \"y\": -0.72463768115942, \"x2\": -8.840579710144928, \"y2\": -0.43478260869565233, \"center_x\": -8.985507246376812, \"center_y\": -0.5797101449275361, \"value_uncond\": 3.5417885927447224e-07}, {\"x\": -8.840579710144928, \"y\": -0.72463768115942, \"x2\": -8.55072463768116, \"y2\": -0.43478260869565233, \"center_x\": -8.695652173913043, \"center_y\": -0.5797101449275361, \"value_uncond\": 5.380840805434449e-07}, {\"x\": -8.55072463768116, \"y\": -0.72463768115942, \"x2\": -8.260869565217392, \"y2\": -0.43478260869565233, \"center_x\": -8.405797101449277, \"center_y\": -0.5797101449275361, \"value_uncond\": 8.098852073070005e-07}, {\"x\": -8.26086956521739, \"y\": -0.72463768115942, \"x2\": -7.971014492753623, \"y2\": -0.43478260869565233, \"center_x\": -8.115942028985508, \"center_y\": -0.5797101449275361, \"value_uncond\": 1.2076542226667024e-06}, {\"x\": -7.971014492753623, \"y\": -0.72463768115942, \"x2\": -7.681159420289855, \"y2\": -0.43478260869565233, \"center_x\": -7.826086956521739, \"center_y\": -0.5797101449275361, \"value_uncond\": 1.7840521963563896e-06}, {\"x\": -7.681159420289855, \"y\": -0.72463768115942, \"x2\": -7.391304347826088, \"y2\": -0.43478260869565233, \"center_x\": -7.536231884057972, \"center_y\": -0.5797101449275361, \"value_uncond\": 2.611068847258569e-06}, {\"x\": -7.391304347826087, \"y\": -0.72463768115942, \"x2\": -7.101449275362319, \"y2\": -0.43478260869565233, \"center_x\": -7.246376811594203, \"center_y\": -0.5797101449275361, \"value_uncond\": 3.785950265482027e-06}, {\"x\": -7.101449275362318, \"y\": -0.72463768115942, \"x2\": -6.811594202898551, \"y2\": -0.43478260869565233, \"center_x\": -6.956521739130435, \"center_y\": -0.5797101449275361, \"value_uncond\": 5.4384770520955155e-06}, {\"x\": -6.811594202898551, \"y\": -0.72463768115942, \"x2\": -6.521739130434783, \"y2\": -0.43478260869565233, \"center_x\": -6.666666666666667, \"center_y\": -0.5797101449275361, \"value_uncond\": 7.739724655570018e-06}, {\"x\": -6.521739130434782, \"y\": -0.72463768115942, \"x2\": -6.231884057971015, \"y2\": -0.43478260869565233, \"center_x\": -6.3768115942028984, \"center_y\": -0.5797101449275361, \"value_uncond\": 1.091238137437345e-05}, {\"x\": -6.231884057971014, \"y\": -0.72463768115942, \"x2\": -5.942028985507246, \"y2\": -0.43478260869565233, \"center_x\": -6.08695652173913, \"center_y\": -0.5797101449275361, \"value_uncond\": 1.5242611307532183e-05}, {\"x\": -5.942028985507246, \"y\": -0.72463768115942, \"x2\": -5.6521739130434785, \"y2\": -0.43478260869565233, \"center_x\": -5.797101449275362, \"center_y\": -0.5797101449275361, \"value_uncond\": 2.1093324266478302e-05}, {\"x\": -5.6521739130434785, \"y\": -0.72463768115942, \"x2\": -5.362318840579711, \"y2\": -0.43478260869565233, \"center_x\": -5.507246376811595, \"center_y\": -0.5797101449275361, \"value_uncond\": 2.8918548957470345e-05}, {\"x\": -5.36231884057971, \"y\": -0.72463768115942, \"x2\": -5.072463768115942, \"y2\": -0.43478260869565233, \"center_x\": -5.217391304347826, \"center_y\": -0.5797101449275361, \"value_uncond\": 3.927839929030012e-05}, {\"x\": -5.0724637681159415, \"y\": -0.72463768115942, \"x2\": -4.782608695652174, \"y2\": -0.43478260869565233, \"center_x\": -4.927536231884058, \"center_y\": -0.5797101449275361, \"value_uncond\": 5.285388048410386e-05}, {\"x\": -4.782608695652174, \"y\": -0.72463768115942, \"x2\": -4.492753623188406, \"y2\": -0.43478260869565233, \"center_x\": -4.63768115942029, \"center_y\": -0.5797101449275361, \"value_uncond\": 7.046051132351661e-05}, {\"x\": -4.492753623188405, \"y\": -0.72463768115942, \"x2\": -4.202898550724638, \"y2\": -0.43478260869565233, \"center_x\": -4.3478260869565215, \"center_y\": -0.5797101449275361, \"value_uncond\": 9.305945765838754e-05}, {\"x\": -4.202898550724638, \"y\": -0.72463768115942, \"x2\": -3.91304347826087, \"y2\": -0.43478260869565233, \"center_x\": -4.057971014492754, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.00012176460336035191}, {\"x\": -3.913043478260869, \"y\": -0.72463768115942, \"x2\": -3.6231884057971016, \"y2\": -0.43478260869565233, \"center_x\": -3.7681159420289854, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0001578437587237487}, {\"x\": -3.6231884057971016, \"y\": -0.72463768115942, \"x2\": -3.333333333333334, \"y2\": -0.43478260869565233, \"center_x\": -3.4782608695652177, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0002027120588148225}, {\"x\": -3.333333333333333, \"y\": -0.72463768115942, \"x2\": -3.0434782608695654, \"y2\": -0.43478260869565233, \"center_x\": -3.1884057971014492, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0002579155751652848}, {\"x\": -3.0434782608695645, \"y\": -0.72463768115942, \"x2\": -2.753623188405797, \"y2\": -0.43478260869565233, \"center_x\": -2.8985507246376807, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0003251032931855034}, {\"x\": -2.753623188405797, \"y\": -0.72463768115942, \"x2\": -2.4637681159420293, \"y2\": -0.43478260869565233, \"center_x\": -2.608695652173913, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.00040598592995069906}, {\"x\": -2.4637681159420284, \"y\": -0.72463768115942, \"x2\": -2.1739130434782608, \"y2\": -0.43478260869565233, \"center_x\": -2.3188405797101446, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0005022806078948621}, {\"x\": -2.1739130434782608, \"y\": -0.72463768115942, \"x2\": -1.8840579710144931, \"y2\": -0.43478260869565233, \"center_x\": -2.028985507246377, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0006156411690762544}, {\"x\": -1.8840579710144922, \"y\": -0.72463768115942, \"x2\": -1.5942028985507246, \"y2\": -0.43478260869565233, \"center_x\": -1.7391304347826084, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.000747574900622746}, {\"x\": -1.5942028985507246, \"y\": -0.72463768115942, \"x2\": -1.304347826086957, \"y2\": -0.43478260869565233, \"center_x\": -1.4492753623188408, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0008993476079530388}, {\"x\": -1.304347826086957, \"y\": -0.72463768115942, \"x2\": -1.0144927536231894, \"y2\": -0.43478260869565233, \"center_x\": -1.1594202898550732, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0010718802540591508}, {\"x\": -1.0144927536231876, \"y\": -0.72463768115942, \"x2\": -0.72463768115942, \"y2\": -0.43478260869565233, \"center_x\": -0.8695652173913038, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0012656416892218969}, {\"x\": -0.72463768115942, \"y\": -0.72463768115942, \"x2\": -0.43478260869565233, \"y2\": -0.43478260869565233, \"center_x\": -0.5797101449275361, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.001480543211796923}, {\"x\": -0.43478260869565233, \"y\": -0.72463768115942, \"x2\": -0.1449275362318847, \"y2\": -0.43478260869565233, \"center_x\": -0.2898550724637685, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.001715841697765436}, {\"x\": -0.14492753623188293, \"y\": -0.72463768115942, \"x2\": 0.1449275362318847, \"y2\": -0.43478260869565233, \"center_x\": 8.881784197001252e-16, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0019700586812547044}, {\"x\": 0.1449275362318847, \"y\": -0.72463768115942, \"x2\": 0.43478260869565233, \"y2\": -0.43478260869565233, \"center_x\": 0.2898550724637685, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.002240922936869036}, {\"x\": 0.43478260869565233, \"y\": -0.72463768115942, \"x2\": 0.72463768115942, \"y2\": -0.43478260869565233, \"center_x\": 0.5797101449275361, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.002525343709512413}, {\"x\": 0.72463768115942, \"y\": -0.72463768115942, \"x2\": 1.0144927536231876, \"y2\": -0.43478260869565233, \"center_x\": 0.8695652173913038, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0028194207010446004}, {\"x\": 1.0144927536231894, \"y\": -0.72463768115942, \"x2\": 1.304347826086957, \"y2\": -0.43478260869565233, \"center_x\": 1.1594202898550732, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0031184952515928535}, {\"x\": 1.304347826086957, \"y\": -0.72463768115942, \"x2\": 1.5942028985507246, \"y2\": -0.43478260869565233, \"center_x\": 1.4492753623188408, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0034172449045790543}, {\"x\": 1.5942028985507246, \"y\": -0.72463768115942, \"x2\": 1.8840579710144922, \"y2\": -0.43478260869565233, \"center_x\": 1.7391304347826084, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.003709820840910567}, {\"x\": 1.884057971014494, \"y\": -0.72463768115942, \"x2\": 2.1739130434782616, \"y2\": -0.43478260869565233, \"center_x\": 2.028985507246378, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.003990024691474894}, {\"x\": 2.1739130434782616, \"y\": -0.72463768115942, \"x2\": 2.4637681159420293, \"y2\": -0.43478260869565233, \"center_x\": 2.3188405797101455, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.004251518217730996}, {\"x\": 2.4637681159420293, \"y\": -0.72463768115942, \"x2\": 2.753623188405797, \"y2\": -0.43478260869565233, \"center_x\": 2.608695652173913, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.004488056545781097}, {\"x\": 2.753623188405797, \"y\": -0.72463768115942, \"x2\": 3.0434782608695645, \"y2\": -0.43478260869565233, \"center_x\": 2.8985507246376807, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.004693733311662716}, {\"x\": 3.0434782608695663, \"y\": -0.72463768115942, \"x2\": 3.333333333333334, \"y2\": -0.43478260869565233, \"center_x\": 3.18840579710145, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.004863224463161162}, {\"x\": 3.333333333333334, \"y\": -0.72463768115942, \"x2\": 3.6231884057971016, \"y2\": -0.43478260869565233, \"center_x\": 3.4782608695652177, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.004992016754393206}, {\"x\": 3.6231884057971016, \"y\": -0.72463768115942, \"x2\": 3.913043478260869, \"y2\": -0.43478260869565233, \"center_x\": 3.7681159420289854, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.005076607278531506}, {\"x\": 3.913043478260871, \"y\": -0.72463768115942, \"x2\": 4.202898550724639, \"y2\": -0.43478260869565233, \"center_x\": 4.057971014492755, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.005114661736369165}, {\"x\": 4.202898550724639, \"y\": -0.72463768115942, \"x2\": 4.492753623188406, \"y2\": -0.43478260869565233, \"center_x\": 4.347826086956522, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.005105121462169169}, {\"x\": 4.492753623188406, \"y\": -0.72463768115942, \"x2\": 4.782608695652174, \"y2\": -0.43478260869565233, \"center_x\": 4.63768115942029, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.005048252358228621}, {\"x\": 4.782608695652174, \"y\": -0.72463768115942, \"x2\": 5.0724637681159415, \"y2\": -0.43478260869565233, \"center_x\": 4.927536231884058, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.004945632581278748}, {\"x\": 5.072463768115943, \"y\": -0.72463768115942, \"x2\": 5.362318840579711, \"y2\": -0.43478260869565233, \"center_x\": 5.217391304347827, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.004800079776571257}, {\"x\": 5.362318840579711, \"y\": -0.72463768115942, \"x2\": 5.6521739130434785, \"y2\": -0.43478260869565233, \"center_x\": 5.507246376811595, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.004615522542301451}, {\"x\": 5.6521739130434785, \"y\": -0.72463768115942, \"x2\": 5.942028985507246, \"y2\": -0.43478260869565233, \"center_x\": 5.797101449275362, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.004396824307575779}, {\"x\": 5.942028985507246, \"y\": -0.72463768115942, \"x2\": 6.231884057971014, \"y2\": -0.43478260869565233, \"center_x\": 6.08695652173913, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.004149570639951542}, {\"x\": 6.2318840579710155, \"y\": -0.72463768115942, \"x2\": 6.521739130434783, \"y2\": -0.43478260869565233, \"center_x\": 6.376811594202899, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.003879832948551227}, {\"x\": 6.521739130434785, \"y\": -0.72463768115942, \"x2\": 6.8115942028985526, \"y2\": -0.43478260869565233, \"center_x\": 6.666666666666669, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0035939224869526182}, {\"x\": 6.811594202898551, \"y\": -0.72463768115942, \"x2\": 7.101449275362318, \"y2\": -0.43478260869565233, \"center_x\": 6.956521739130435, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.00329814845360981}, {\"x\": 7.10144927536232, \"y\": -0.72463768115942, \"x2\": 7.391304347826088, \"y2\": -0.43478260869565233, \"center_x\": 7.246376811594204, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0029985928988180773}, {\"x\": 7.391304347826086, \"y\": -0.72463768115942, \"x2\": 7.681159420289854, \"y2\": -0.43478260869565233, \"center_x\": 7.53623188405797, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.002700913222743788}, {\"x\": 7.681159420289855, \"y\": -0.72463768115942, \"x2\": 7.971014492753623, \"y2\": -0.43478260869565233, \"center_x\": 7.826086956521739, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0024101805001465392}, {\"x\": 7.971014492753625, \"y\": -0.72463768115942, \"x2\": 8.260869565217392, \"y2\": -0.43478260869565233, \"center_x\": 8.115942028985508, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.00213075894523904}, {\"x\": 8.26086956521739, \"y\": -0.72463768115942, \"x2\": 8.550724637681158, \"y2\": -0.43478260869565233, \"center_x\": 8.405797101449274, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0018662287981257527}, {\"x\": 8.55072463768116, \"y\": -0.72463768115942, \"x2\": 8.840579710144928, \"y2\": -0.43478260869565233, \"center_x\": 8.695652173913043, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0016193520217726706}, {\"x\": 8.84057971014493, \"y\": -0.72463768115942, \"x2\": 9.130434782608697, \"y2\": -0.43478260869565233, \"center_x\": 8.985507246376812, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0013920776580831054}, {\"x\": 9.130434782608695, \"y\": -0.72463768115942, \"x2\": 9.420289855072463, \"y2\": -0.43478260869565233, \"center_x\": 9.275362318840578, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0011855816626873544}, {\"x\": 9.420289855072465, \"y\": -0.72463768115942, \"x2\": 9.710144927536232, \"y2\": -0.43478260869565233, \"center_x\": 9.565217391304348, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0010003346172510537}, {\"x\": 9.710144927536234, \"y\": -0.72463768115942, \"x2\": 10.000000000000002, \"y2\": -0.43478260869565233, \"center_x\": 9.855072463768117, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0008361899379559863}, {\"x\": 10.0, \"y\": -0.72463768115942, \"x2\": 10.289855072463768, \"y2\": -0.43478260869565233, \"center_x\": 10.144927536231883, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0006924850326436628}, {\"x\": -10.0, \"y\": -0.43478260869565233, \"x2\": -9.710144927536232, \"y2\": -0.1449275362318847, \"center_x\": -9.855072463768117, \"center_y\": -0.2898550724637685, \"value_uncond\": 1.1068050361167863e-07}, {\"x\": -9.710144927536232, \"y\": -0.43478260869565233, \"x2\": -9.420289855072465, \"y2\": -0.1449275362318847, \"center_x\": -9.565217391304348, \"center_y\": -0.2898550724637685, \"value_uncond\": 1.7292635666361052e-07}, {\"x\": -9.420289855072463, \"y\": -0.43478260869565233, \"x2\": -9.130434782608695, \"y2\": -0.1449275362318847, \"center_x\": -9.275362318840578, \"center_y\": -0.2898550724637685, \"value_uncond\": 2.6766838036410634e-07}, {\"x\": -9.130434782608695, \"y\": -0.43478260869565233, \"x2\": -8.840579710144928, \"y2\": -0.1449275362318847, \"center_x\": -8.985507246376812, \"center_y\": -0.2898550724637685, \"value_uncond\": 4.1046748947810695e-07}, {\"x\": -8.840579710144928, \"y\": -0.43478260869565233, \"x2\": -8.55072463768116, \"y2\": -0.1449275362318847, \"center_x\": -8.695652173913043, \"center_y\": -0.2898550724637685, \"value_uncond\": 6.236002400630083e-07}, {\"x\": -8.55072463768116, \"y\": -0.43478260869565233, \"x2\": -8.260869565217392, \"y2\": -0.1449275362318847, \"center_x\": -8.405797101449277, \"center_y\": -0.2898550724637685, \"value_uncond\": 9.385979402885297e-07}, {\"x\": -8.26086956521739, \"y\": -0.43478260869565233, \"x2\": -7.971014492753623, \"y2\": -0.1449275362318847, \"center_x\": -8.115942028985508, \"center_y\": -0.2898550724637685, \"value_uncond\": 1.3995832443276615e-06}, {\"x\": -7.971014492753623, \"y\": -0.43478260869565233, \"x2\": -7.681159420289855, \"y2\": -0.1449275362318847, \"center_x\": -7.826086956521739, \"center_y\": -0.2898550724637685, \"value_uncond\": 2.067586494677862e-06}, {\"x\": -7.681159420289855, \"y\": -0.43478260869565233, \"x2\": -7.391304347826088, \"y2\": -0.1449275362318847, \"center_x\": -7.536231884057972, \"center_y\": -0.2898550724637685, \"value_uncond\": 3.0260385297535673e-06}, {\"x\": -7.391304347826087, \"y\": -0.43478260869565233, \"x2\": -7.101449275362319, \"y2\": -0.1449275362318847, \"center_x\": -7.246376811594203, \"center_y\": -0.2898550724637685, \"value_uncond\": 4.387640481830946e-06}, {\"x\": -7.101449275362318, \"y\": -0.43478260869565233, \"x2\": -6.811594202898551, \"y2\": -0.1449275362318847, \"center_x\": -6.956521739130435, \"center_y\": -0.2898550724637685, \"value_uncond\": 6.302798610653378e-06}, {\"x\": -6.811594202898551, \"y\": -0.43478260869565233, \"x2\": -6.521739130434783, \"y2\": -0.1449275362318847, \"center_x\": -6.666666666666667, \"center_y\": -0.2898550724637685, \"value_uncond\": 8.969776895016973e-06}, {\"x\": -6.521739130434782, \"y\": -0.43478260869565233, \"x2\": -6.231884057971015, \"y2\": -0.1449275362318847, \"center_x\": -6.3768115942028984, \"center_y\": -0.2898550724637685, \"value_uncond\": 1.2646654845922255e-05}, {\"x\": -6.231884057971014, \"y\": -0.43478260869565233, \"x2\": -5.942028985507246, \"y2\": -0.1449275362318847, \"center_x\": -6.08695652173913, \"center_y\": -0.2898550724637685, \"value_uncond\": 1.7665075801841584e-05}, {\"x\": -5.942028985507246, \"y\": -0.43478260869565233, \"x2\": -5.6521739130434785, \"y2\": -0.1449275362318847, \"center_x\": -5.797101449275362, \"center_y\": -0.2898550724637685, \"value_uncond\": 2.4445625789593858e-05}, {\"x\": -5.6521739130434785, \"y\": -0.43478260869565233, \"x2\": -5.362318840579711, \"y2\": -0.1449275362318847, \"center_x\": -5.507246376811595, \"center_y\": -0.2898550724637685, \"value_uncond\": 3.3514490995420406e-05}, {\"x\": -5.36231884057971, \"y\": -0.43478260869565233, \"x2\": -5.072463768115942, \"y2\": -0.1449275362318847, \"center_x\": -5.217391304347826, \"center_y\": -0.2898550724637685, \"value_uncond\": 4.5520802626206266e-05}, {\"x\": -5.0724637681159415, \"y\": -0.43478260869565233, \"x2\": -4.782608695652174, \"y2\": -0.1449275362318847, \"center_x\": -4.927536231884058, \"center_y\": -0.2898550724637685, \"value_uncond\": 6.125379610721919e-05}, {\"x\": -4.782608695652174, \"y\": -0.43478260869565233, \"x2\": -4.492753623188406, \"y2\": -0.1449275362318847, \"center_x\": -4.63768115942029, \"center_y\": -0.2898550724637685, \"value_uncond\": 8.165859828436157e-05}, {\"x\": -4.492753623188405, \"y\": -0.43478260869565233, \"x2\": -4.202898550724638, \"y2\": -0.1449275362318847, \"center_x\": -4.3478260869565215, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.00010784913033906096}, {\"x\": -4.202898550724638, \"y\": -0.43478260869565233, \"x2\": -3.91304347826087, \"y2\": -0.1449275362318847, \"center_x\": -4.057971014492754, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0001411163025116883}, {\"x\": -3.913043478260869, \"y\": -0.43478260869565233, \"x2\": -3.6231884057971016, \"y2\": -0.1449275362318847, \"center_x\": -3.7681159420289854, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.00018292941455016692}, {\"x\": -3.6231884057971016, \"y\": -0.43478260869565233, \"x2\": -3.333333333333334, \"y2\": -0.1449275362318847, \"center_x\": -3.4782608695652177, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.00023492850487774914}, {\"x\": -3.333333333333333, \"y\": -0.43478260869565233, \"x2\": -3.0434782608695654, \"y2\": -0.1449275362318847, \"center_x\": -3.1884057971014492, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.00029890535774004296}, {\"x\": -3.0434782608695645, \"y\": -0.43478260869565233, \"x2\": -2.753623188405797, \"y2\": -0.1449275362318847, \"center_x\": -2.8985507246376807, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.00037677102706885516}, {\"x\": -2.753623188405797, \"y\": -0.43478260869565233, \"x2\": -2.4637681159420293, \"y2\": -0.1449275362318847, \"center_x\": -2.608695652173913, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.00047050810929727627}, {\"x\": -2.4637681159420284, \"y\": -0.43478260869565233, \"x2\": -2.1739130434782608, \"y2\": -0.1449275362318847, \"center_x\": -2.3188405797101446, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0005821066242024608}, {\"x\": -2.1739130434782608, \"y\": -0.43478260869565233, \"x2\": -1.8840579710144931, \"y2\": -0.1449275362318847, \"center_x\": -2.028985507246377, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0007134832542172296}, {\"x\": -1.8840579710144922, \"y\": -0.43478260869565233, \"x2\": -1.5942028985507246, \"y2\": -0.1449275362318847, \"center_x\": -1.7391304347826084, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0008663848352892936}, {\"x\": -1.5942028985507246, \"y\": -0.43478260869565233, \"x2\": -1.304347826086957, \"y2\": -0.1449275362318847, \"center_x\": -1.4492753623188408, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.001042278343661805}, {\"x\": -1.304347826086957, \"y\": -0.43478260869565233, \"x2\": -1.0144927536231894, \"y2\": -0.1449275362318847, \"center_x\": -1.1594202898550732, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0012422311083334794}, {\"x\": -1.0144927536231876, \"y\": -0.43478260869565233, \"x2\": -0.72463768115942, \"y2\": -0.1449275362318847, \"center_x\": -0.8695652173913038, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0014667864926154442}, {\"x\": -0.72463768115942, \"y\": -0.43478260869565233, \"x2\": -0.43478260869565233, \"y2\": -0.1449275362318847, \"center_x\": -0.5797101449275361, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.001715841697765436}, {\"x\": -0.43478260869565233, \"y\": -0.43478260869565233, \"x2\": -0.1449275362318847, \"y2\": -0.1449275362318847, \"center_x\": -0.2898550724637685, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.001988535497195876}, {\"x\": -0.14492753623188293, \"y\": -0.43478260869565233, \"x2\": 0.1449275362318847, \"y2\": -0.1449275362318847, \"center_x\": 8.881784197001252e-16, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.002283154456693605}, {\"x\": 0.1449275362318847, \"y\": -0.43478260869565233, \"x2\": 0.43478260869565233, \"y2\": -0.1449275362318847, \"center_x\": 0.2898550724637685, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.002597066391525409}, {\"x\": 0.43478260869565233, \"y\": -0.43478260869565233, \"x2\": 0.72463768115942, \"y2\": -0.1449275362318847, \"center_x\": 0.5797101449275361, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0029266893417531576}, {\"x\": 0.72463768115942, \"y\": -0.43478260869565233, \"x2\": 1.0144927536231876, \"y2\": -0.1449275362318847, \"center_x\": 0.8695652173913038, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.003267503146040521}, {\"x\": 1.0144927536231894, \"y\": -0.43478260869565233, \"x2\": 1.304347826086957, \"y2\": -0.1449275362318847, \"center_x\": 1.1594202898550732, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.003614108757063738}, {\"x\": 1.304347826086957, \"y\": -0.43478260869565233, \"x2\": 1.5942028985507246, \"y2\": -0.1449275362318847, \"center_x\": 1.4492753623188408, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.003960337835487279}, {\"x\": 1.5942028985507246, \"y\": -0.43478260869565233, \"x2\": 1.8840579710144922, \"y2\": -0.1449275362318847, \"center_x\": 1.7391304347826084, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.004299412026176441}, {\"x\": 1.884057971014494, \"y\": -0.43478260869565233, \"x2\": 2.1739130434782616, \"y2\": -0.1449275362318847, \"center_x\": 2.028985507246378, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.004624147870994629}, {\"x\": 2.1739130434782616, \"y\": -0.43478260869565233, \"x2\": 2.4637681159420293, \"y2\": -0.1449275362318847, \"center_x\": 2.3188405797101455, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.004927199813329617}, {\"x\": 2.4637681159420293, \"y\": -0.43478260869565233, \"x2\": 2.753623188405797, \"y2\": -0.1449275362318847, \"center_x\": 2.608695652173913, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.005201330499387401}, {\"x\": 2.753623188405797, \"y\": -0.43478260869565233, \"x2\": 3.0434782608695645, \"y2\": -0.1449275362318847, \"center_x\": 2.8985507246376807, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.005439694883722322}, {\"x\": 3.0434782608695663, \"y\": -0.43478260869565233, \"x2\": 3.333333333333334, \"y2\": -0.1449275362318847, \"center_x\": 3.18840579710145, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.005636122777772336}, {\"x\": 3.333333333333334, \"y\": -0.43478260869565233, \"x2\": 3.6231884057971016, \"y2\": -0.1449275362318847, \"center_x\": 3.4782608695652177, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.005785383658431456}, {\"x\": 3.6231884057971016, \"y\": -0.43478260869565233, \"x2\": 3.913043478260869, \"y2\": -0.1449275362318847, \"center_x\": 3.7681159420289854, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.005883417911937755}, {\"x\": 3.913043478260871, \"y\": -0.43478260869565233, \"x2\": 4.202898550724639, \"y2\": -0.1449275362318847, \"center_x\": 4.057971014492755, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.005927520255606916}, {\"x\": 4.202898550724639, \"y\": -0.43478260869565233, \"x2\": 4.492753623188406, \"y2\": -0.1449275362318847, \"center_x\": 4.347826086956522, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.005916463772992943}, {\"x\": 4.492753623188406, \"y\": -0.43478260869565233, \"x2\": 4.782608695652174, \"y2\": -0.1449275362318847, \"center_x\": 4.63768115942029, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.005850556625482321}, {\"x\": 4.782608695652174, \"y\": -0.43478260869565233, \"x2\": 5.0724637681159415, \"y2\": -0.1449275362318847, \"center_x\": 4.927536231884058, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.005731627781728902}, {\"x\": 5.072463768115943, \"y\": -0.43478260869565233, \"x2\": 5.362318840579711, \"y2\": -0.1449275362318847, \"center_x\": 5.217391304347827, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.005562942687262318}, {\"x\": 5.362318840579711, \"y\": -0.43478260869565233, \"x2\": 5.6521739130434785, \"y2\": -0.1449275362318847, \"center_x\": 5.507246376811595, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0053490543011205476}, {\"x\": 5.6521739130434785, \"y\": -0.43478260869565233, \"x2\": 5.942028985507246, \"y2\": -0.1449275362318847, \"center_x\": 5.797101449275362, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.005095598983248022}, {\"x\": 5.942028985507246, \"y\": -0.43478260869565233, \"x2\": 6.231884057971014, \"y2\": -0.1449275362318847, \"center_x\": 6.08695652173913, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.004809049999432688}, {\"x\": 6.2318840579710155, \"y\": -0.43478260869565233, \"x2\": 6.521739130434783, \"y2\": -0.1449275362318847, \"center_x\": 6.376811594202899, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.004496443670434078}, {\"x\": 6.521739130434785, \"y\": -0.43478260869565233, \"x2\": 6.8115942028985526, \"y2\": -0.1449275362318847, \"center_x\": 6.666666666666669, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.004165094279258357}, {\"x\": 6.811594202898551, \"y\": -0.43478260869565233, \"x2\": 7.101449275362318, \"y2\": -0.1449275362318847, \"center_x\": 6.956521739130435, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0038223137271730825}, {\"x\": 7.10144927536232, \"y\": -0.43478260869565233, \"x2\": 7.391304347826088, \"y2\": -0.1449275362318847, \"center_x\": 7.246376811594204, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.003475150667281647}, {\"x\": 7.391304347826086, \"y\": -0.43478260869565233, \"x2\": 7.681159420289854, \"y2\": -0.1449275362318847, \"center_x\": 7.53623188405797, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.003130161614131584}, {\"x\": 7.681159420289855, \"y\": -0.43478260869565233, \"x2\": 7.971014492753623, \"y2\": -0.1449275362318847, \"center_x\": 7.826086956521739, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.002793223573848532}, {\"x\": 7.971014492753625, \"y\": -0.43478260869565233, \"x2\": 8.260869565217392, \"y2\": -0.1449275362318847, \"center_x\": 8.115942028985508, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.002469394352692033}, {\"x\": 8.26086956521739, \"y\": -0.43478260869565233, \"x2\": 8.550724637681158, \"y2\": -0.1449275362318847, \"center_x\": 8.405797101449274, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.002162823188057046}, {\"x\": 8.55072463768116, \"y\": -0.43478260869565233, \"x2\": 8.840579710144928, \"y2\": -0.1449275362318847, \"center_x\": 8.695652173913043, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0018767109937615424}, {\"x\": 8.84057971014493, \"y\": -0.43478260869565233, \"x2\": 9.130434782608697, \"y2\": -0.1449275362318847, \"center_x\": 8.985507246376812, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.001613316567348035}, {\"x\": 9.130434782608695, \"y\": -0.43478260869565233, \"x2\": 9.420289855072463, \"y2\": -0.1449275362318847, \"center_x\": 9.275362318840578, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0013740027557021192}, {\"x\": 9.420289855072465, \"y\": -0.43478260869565233, \"x2\": 9.710144927536232, \"y2\": -0.1449275362318847, \"center_x\": 9.565217391304348, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0011593149286837669}, {\"x\": 9.710144927536234, \"y\": -0.43478260869565233, \"x2\": 10.000000000000002, \"y2\": -0.1449275362318847, \"center_x\": 9.855072463768117, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0009690832063289839}, {\"x\": 10.0, \"y\": -0.43478260869565233, \"x2\": 10.289855072463768, \"y2\": -0.1449275362318847, \"center_x\": 10.144927536231883, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0008025396926080617}, {\"x\": -10.0, \"y\": -0.14492753623188293, \"x2\": -9.710144927536232, \"y2\": 0.1449275362318847, \"center_x\": -9.855072463768117, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 1.2707879011787393e-07}, {\"x\": -9.710144927536232, \"y\": -0.14492753623188293, \"x2\": -9.420289855072465, \"y2\": 0.1449275362318847, \"center_x\": -9.565217391304348, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 1.98546911761475e-07}, {\"x\": -9.420289855072463, \"y\": -0.14492753623188293, \"x2\": -9.130434782608695, \"y2\": 0.1449275362318847, \"center_x\": -9.275362318840578, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 3.073257965000113e-07}, {\"x\": -9.130434782608695, \"y\": -0.14492753623188293, \"x2\": -8.840579710144928, \"y2\": 0.1449275362318847, \"center_x\": -8.985507246376812, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 4.7128184498154966e-07}, {\"x\": -8.840579710144928, \"y\": -0.14492753623188293, \"x2\": -8.55072463768116, \"y2\": 0.1449275362318847, \"center_x\": -8.695652173913043, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 7.159920802534279e-07}, {\"x\": -8.55072463768116, \"y\": -0.14492753623188293, \"x2\": -8.260869565217392, \"y2\": 0.1449275362318847, \"center_x\": -8.405797101449277, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 1.077659450100381e-06}, {\"x\": -8.26086956521739, \"y\": -0.14492753623188293, \"x2\": -7.971014492753623, \"y2\": 0.1449275362318847, \"center_x\": -8.115942028985508, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 1.6069437665590913e-06}, {\"x\": -7.971014492753623, \"y\": -0.14492753623188293, \"x2\": -7.681159420289855, \"y2\": 0.1449275362318847, \"center_x\": -7.826086956521739, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 2.373917552178486e-06}, {\"x\": -7.681159420289855, \"y\": -0.14492753623188293, \"x2\": -7.391304347826088, \"y2\": 0.1449275362318847, \"center_x\": -7.536231884057972, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 3.4743726551907147e-06}, {\"x\": -7.391304347826087, \"y\": -0.14492753623188293, \"x2\": -7.101449275362319, \"y2\": 0.1449275362318847, \"center_x\": -7.246376811594203, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 5.037707868221594e-06}, {\"x\": -7.101449275362318, \"y\": -0.14492753623188293, \"x2\": -6.811594202898551, \"y2\": 0.1449275362318847, \"center_x\": -6.956521739130435, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 7.236613456409447e-06}, {\"x\": -6.811594202898551, \"y\": -0.14492753623188293, \"x2\": -6.521739130434783, \"y2\": 0.1449275362318847, \"center_x\": -6.666666666666667, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 1.0298727944401408e-05}, {\"x\": -6.521739130434782, \"y\": -0.14492753623188293, \"x2\": -6.231884057971015, \"y2\": 0.1449275362318847, \"center_x\": -6.3768115942028984, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 1.4520367584310195e-05}, {\"x\": -6.231884057971014, \"y\": -0.14492753623188293, \"x2\": -5.942028985507246, \"y2\": 0.1449275362318847, \"center_x\": -6.08695652173913, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 2.0282311581402023e-05}, {\"x\": -5.942028985507246, \"y\": -0.14492753623188293, \"x2\": -5.6521739130434785, \"y2\": 0.1449275362318847, \"center_x\": -5.797101449275362, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 2.80674594679753e-05}, {\"x\": -5.6521739130434785, \"y\": -0.14492753623188293, \"x2\": -5.362318840579711, \"y2\": 0.1449275362318847, \"center_x\": -5.507246376811595, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 3.8479956524746164e-05}, {\"x\": -5.36231884057971, \"y\": -0.14492753623188293, \"x2\": -5.072463768115942, \"y2\": 0.1449275362318847, \"center_x\": -5.217391304347826, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 5.226510843525332e-05}, {\"x\": -5.0724637681159415, \"y\": -0.14492753623188293, \"x2\": -4.782608695652174, \"y2\": 0.1449275362318847, \"center_x\": -4.927536231884058, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 7.032908276910843e-05}, {\"x\": -4.782608695652174, \"y\": -0.14492753623188293, \"x2\": -4.492753623188406, \"y2\": 0.1449275362318847, \"center_x\": -4.63768115942029, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 9.37570351966054e-05}, {\"x\": -4.492753623188405, \"y\": -0.14492753623188293, \"x2\": -4.202898550724638, \"y2\": 0.1449275362318847, \"center_x\": -4.3478260869565215, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0001238279240835204}, {\"x\": -4.202898550724638, \"y\": -0.14492753623188293, \"x2\": -3.91304347826087, \"y2\": 0.1449275362318847, \"center_x\": -4.057971014492754, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.00016202391933461542}, {\"x\": -3.913043478260869, \"y\": -0.14492753623188293, \"x2\": -3.6231884057971016, \"y2\": 0.1449275362318847, \"center_x\": -3.7681159420289854, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.00021003201033098035}, {\"x\": -3.6231884057971016, \"y\": -0.14492753623188293, \"x2\": -3.333333333333334, \"y2\": 0.1449275362318847, \"center_x\": -3.4782608695652177, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.00026973522155997187}, {\"x\": -3.333333333333333, \"y\": -0.14492753623188293, \"x2\": -3.0434782608695654, \"y2\": 0.1449275362318847, \"center_x\": -3.1884057971014492, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0003431908058046359}, {\"x\": -3.0434782608695645, \"y\": -0.14492753623188293, \"x2\": -2.753623188405797, \"y2\": 0.1449275362318847, \"center_x\": -2.8985507246376807, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0004325929563833926}, {\"x\": -2.753623188405797, \"y\": -0.14492753623188293, \"x2\": -2.4637681159420293, \"y2\": 0.1449275362318847, \"center_x\": -2.608695652173913, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0005402180087644379}, {\"x\": -2.4637681159420284, \"y\": -0.14492753623188293, \"x2\": -2.1739130434782608, \"y2\": 0.1449275362318847, \"center_x\": -2.3188405797101446, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0006683508215935073}, {\"x\": -2.1739130434782608, \"y\": -0.14492753623188293, \"x2\": -1.8840579710144931, \"y2\": 0.1449275362318847, \"center_x\": -2.028985507246377, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0008191920506017823}, {\"x\": -1.8840579710144922, \"y\": -0.14492753623188293, \"x2\": -1.5942028985507246, \"y2\": 0.1449275362318847, \"center_x\": -1.7391304347826084, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0009947473407901947}, {\"x\": -1.5942028985507246, \"y\": -0.14492753623188293, \"x2\": -1.304347826086957, \"y2\": 0.1449275362318847, \"center_x\": -1.4492753623188408, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0011967010137874715}, {\"x\": -1.304347826086957, \"y\": -0.14492753623188293, \"x2\": -1.0144927536231894, \"y2\": 0.1449275362318847, \"center_x\": -1.1594202898550732, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.001426278532736519}, {\"x\": -1.0144927536231876, \"y\": -0.14492753623188293, \"x2\": -0.72463768115942, \"y2\": 0.1449275362318847, \"center_x\": -0.8695652173913038, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0016841037649845162}, {\"x\": -0.72463768115942, \"y\": -0.14492753623188293, \"x2\": -0.43478260869565233, \"y2\": 0.1449275362318847, \"center_x\": -0.5797101449275361, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0019700586812547044}, {\"x\": -0.43478260869565233, \"y\": -0.14492753623188293, \"x2\": -0.1449275362318847, \"y2\": 0.1449275362318847, \"center_x\": -0.2898550724637685, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.002283154456693605}, {\"x\": -0.14492753623188293, \"y\": -0.14492753623188293, \"x2\": 0.1449275362318847, \"y2\": 0.1449275362318847, \"center_x\": 8.881784197001252e-16, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0026214237967945083}, {\"x\": 0.1449275362318847, \"y\": -0.14492753623188293, \"x2\": 0.43478260869565233, \"y2\": 0.1449275362318847, \"center_x\": 0.2898550724637685, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.002981844535590075}, {\"x\": 0.43478260869565233, \"y\": -0.14492753623188293, \"x2\": 0.72463768115942, \"y2\": 0.1449275362318847, \"center_x\": 0.5797101449275361, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.003360304014388531}, {\"x\": 0.72463768115942, \"y\": -0.14492753623188293, \"x2\": 1.0144927536231876, \"y2\": 0.1449275362318847, \"center_x\": 0.8695652173913038, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.003751612370341276}, {\"x\": 1.0144927536231894, \"y\": -0.14492753623188293, \"x2\": 1.304347826086957, \"y2\": 0.1449275362318847, \"center_x\": 1.1594202898550732, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.004149570639951545}, {\"x\": 1.304347826086957, \"y\": -0.14492753623188293, \"x2\": 1.5942028985507246, \"y2\": 0.1449275362318847, \"center_x\": 1.4492753623188408, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.004547096590357931}, {\"x\": 1.5942028985507246, \"y\": -0.14492753623188293, \"x2\": 1.8840579710144922, \"y2\": 0.1449275362318847, \"center_x\": 1.7391304347826084, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.004936407593713624}, {\"x\": 1.884057971014494, \"y\": -0.14492753623188293, \"x2\": 2.1739130434782616, \"y2\": 0.1449275362318847, \"center_x\": 2.028985507246378, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.005309255899610263}, {\"x\": 2.1739130434782616, \"y\": -0.14492753623188293, \"x2\": 2.4637681159420293, \"y2\": 0.1449275362318847, \"center_x\": 2.3188405797101455, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.005657207642854213}, {\"x\": 2.4637681159420293, \"y\": -0.14492753623188293, \"x2\": 2.753623188405797, \"y2\": 0.1449275362318847, \"center_x\": 2.608695652173913, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.005971953192265772}, {\"x\": 2.753623188405797, \"y\": -0.14492753623188293, \"x2\": 3.0434782608695645, \"y2\": 0.1449275362318847, \"center_x\": 2.8985507246376807, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.006245633348933196}, {\"x\": 3.0434782608695663, \"y\": -0.14492753623188293, \"x2\": 3.333333333333334, \"y2\": 0.1449275362318847, \"center_x\": 3.18840579710145, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0064711637567894525}, {\"x\": 3.333333333333334, \"y\": -0.14492753623188293, \"x2\": 3.6231884057971016, \"y2\": 0.1449275362318847, \"center_x\": 3.4782608695652177, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.00664253894489519}, {\"x\": 3.6231884057971016, \"y\": -0.14492753623188293, \"x2\": 3.913043478260869, \"y2\": 0.1449275362318847, \"center_x\": 3.7681159420289854, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.006755097832135153}, {\"x\": 3.913043478260871, \"y\": -0.14492753623188293, \"x2\": 4.202898550724639, \"y2\": 0.1449275362318847, \"center_x\": 4.057971014492755, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.006805734324488884}, {\"x\": 4.202898550724639, \"y\": -0.14492753623188293, \"x2\": 4.492753623188406, \"y2\": 0.1449275362318847, \"center_x\": 4.347826086956522, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.006793039727087408}, {\"x\": 4.492753623188406, \"y\": -0.14492753623188293, \"x2\": 4.782608695652174, \"y2\": 0.1449275362318847, \"center_x\": 4.63768115942029, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0067173678581270435}, {\"x\": 4.782608695652174, \"y\": -0.14492753623188293, \"x2\": 5.0724637681159415, \"y2\": 0.1449275362318847, \"center_x\": 4.927536231884058, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.006580818663995012}, {\"x\": 5.072463768115943, \"y\": -0.14492753623188293, \"x2\": 5.362318840579711, \"y2\": 0.1449275362318847, \"center_x\": 5.217391304347827, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.006387141394591343}, {\"x\": 5.362318840579711, \"y\": -0.14492753623188293, \"x2\": 5.6521739130434785, \"y2\": 0.1449275362318847, \"center_x\": 5.507246376811595, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.006141563569733192}, {\"x\": 5.6521739130434785, \"y\": -0.14492753623188293, \"x2\": 5.942028985507246, \"y2\": 0.1449275362318847, \"center_x\": 5.797101449275362, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.005850556625482325}, {\"x\": 5.942028985507246, \"y\": -0.14492753623188293, \"x2\": 6.231884057971014, \"y2\": 0.1449275362318847, \"center_x\": 6.08695652173913, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.005521552898678568}, {\"x\": 6.2318840579710155, \"y\": -0.14492753623188293, \"x2\": 6.521739130434783, \"y2\": 0.1449275362318847, \"center_x\": 6.376811594202899, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.005162631202661442}, {\"x\": 6.521739130434785, \"y\": -0.14492753623188293, \"x2\": 6.8115942028985526, \"y2\": 0.1449275362318847, \"center_x\": 6.666666666666669, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.004782189495559725}, {\"x\": 6.811594202898551, \"y\": -0.14492753623188293, \"x2\": 7.101449275362318, \"y2\": 0.1449275362318847, \"center_x\": 6.956521739130435, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.004388623000888145}, {\"x\": 7.10144927536232, \"y\": -0.14492753623188293, \"x2\": 7.391304347826088, \"y2\": 0.1449275362318847, \"center_x\": 7.246376811594204, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.003990024691474892}, {\"x\": 7.391304347826086, \"y\": -0.14492753623188293, \"x2\": 7.681159420289854, \"y2\": 0.1449275362318847, \"center_x\": 7.53623188405797, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.003593922486952622}, {\"x\": 7.681159420289855, \"y\": -0.14492753623188293, \"x2\": 7.971014492753623, \"y2\": 0.1449275362318847, \"center_x\": 7.826086956521739, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0032070641234048475}, {\"x\": 7.971014492753625, \"y\": -0.14492753623188293, \"x2\": 8.260869565217392, \"y2\": 0.1449275362318847, \"center_x\": 8.115942028985508, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.002835256765410144}, {\"x\": 8.26086956521739, \"y\": -0.14492753623188293, \"x2\": 8.550724637681158, \"y2\": 0.1449275362318847, \"center_x\": 8.405797101449274, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.002483264396243414}, {\"x\": 8.55072463768116, \"y\": -0.14492753623188293, \"x2\": 8.840579710144928, \"y2\": 0.1449275362318847, \"center_x\": 8.695652173913043, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0021547621731544497}, {\"x\": 8.84057971014493, \"y\": -0.14492753623188293, \"x2\": 9.130434782608697, \"y2\": 0.1449275362318847, \"center_x\": 8.985507246376812, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0018523435543355879}, {\"x\": 9.130434782608695, \"y\": -0.14492753623188293, \"x2\": 9.420289855072463, \"y2\": 0.1449275362318847, \"center_x\": 9.275362318840578, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0015775733043811879}, {\"x\": 9.420289855072465, \"y\": -0.14492753623188293, \"x2\": 9.710144927536232, \"y2\": 0.1449275362318847, \"center_x\": 9.565217391304348, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0013310775944750685}, {\"x\": 9.710144927536234, \"y\": -0.14492753623188293, \"x2\": 10.000000000000002, \"y2\": 0.1449275362318847, \"center_x\": 9.855072463768117, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.001112661375447905}, {\"x\": 10.0, \"y\": -0.14492753623188293, \"x2\": 10.289855072463768, \"y2\": 0.1449275362318847, \"center_x\": 10.144927536231883, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0009214429807440965}, {\"x\": -10.0, \"y\": 0.1449275362318847, \"x2\": -9.710144927536232, \"y2\": 0.43478260869565233, \"center_x\": -9.855072463768117, \"center_y\": 0.2898550724637685, \"value_uncond\": 1.445509102212839e-07}, {\"x\": -9.710144927536232, \"y\": 0.1449275362318847, \"x2\": -9.420289855072465, \"y2\": 0.43478260869565233, \"center_x\": -9.565217391304348, \"center_y\": 0.2898550724637685, \"value_uncond\": 2.258452161066759e-07}, {\"x\": -9.420289855072463, \"y\": 0.1449275362318847, \"x2\": -9.130434782608695, \"y2\": 0.43478260869565233, \"center_x\": -9.275362318840578, \"center_y\": 0.2898550724637685, \"value_uncond\": 3.4958015871375006e-07}, {\"x\": -9.130434782608695, \"y\": 0.1449275362318847, \"x2\": -8.840579710144928, \"y2\": 0.43478260869565233, \"center_x\": -8.985507246376812, \"center_y\": 0.2898550724637685, \"value_uncond\": 5.360785981646451e-07}, {\"x\": -8.840579710144928, \"y\": 0.1449275362318847, \"x2\": -8.55072463768116, \"y2\": 0.43478260869565233, \"center_x\": -8.695652173913043, \"center_y\": 0.2898550724637685, \"value_uncond\": 8.144341539281496e-07}, {\"x\": -8.55072463768116, \"y\": 0.1449275362318847, \"x2\": -8.260869565217392, \"y2\": 0.43478260869565233, \"center_x\": -8.405797101449277, \"center_y\": 0.2898550724637685, \"value_uncond\": 1.2258273333896651e-06}, {\"x\": -8.26086956521739, \"y\": 0.1449275362318847, \"x2\": -7.971014492753623, \"y2\": 0.43478260869565233, \"center_x\": -8.115942028985508, \"center_y\": 0.2898550724637685, \"value_uncond\": 1.8278831889654851e-06}, {\"x\": -7.971014492753623, \"y\": 0.1449275362318847, \"x2\": -7.681159420289855, \"y2\": 0.43478260869565233, \"center_x\": -7.826086956521739, \"center_y\": 0.2898550724637685, \"value_uncond\": 2.7003085458980758e-06}, {\"x\": -7.681159420289855, \"y\": 0.1449275362318847, \"x2\": -7.391304347826088, \"y2\": 0.43478260869565233, \"center_x\": -7.536231884057972, \"center_y\": 0.2898550724637685, \"value_uncond\": 3.952065716788075e-06}, {\"x\": -7.391304347826087, \"y\": 0.1449275362318847, \"x2\": -7.101449275362319, \"y2\": 0.43478260869565233, \"center_x\": -7.246376811594203, \"center_y\": 0.2898550724637685, \"value_uncond\": 5.73034459255472e-06}, {\"x\": -7.101449275362318, \"y\": 0.1449275362318847, \"x2\": -6.811594202898551, \"y2\": 0.43478260869565233, \"center_x\": -6.956521739130435, \"center_y\": 0.2898550724637685, \"value_uncond\": 8.23157870068867e-06}, {\"x\": -6.811594202898551, \"y\": 0.1449275362318847, \"x2\": -6.521739130434783, \"y2\": 0.43478260869565233, \"center_x\": -6.666666666666667, \"center_y\": 0.2898550724637685, \"value_uncond\": 1.1714704689143955e-05}, {\"x\": -6.521739130434782, \"y\": 0.1449275362318847, \"x2\": -6.231884057971015, \"y2\": 0.43478260869565233, \"center_x\": -6.3768115942028984, \"center_y\": 0.2898550724637685, \"value_uncond\": 1.6516779465029294e-05}, {\"x\": -6.231884057971014, \"y\": 0.1449275362318847, \"x2\": -5.942028985507246, \"y2\": 0.43478260869565233, \"center_x\": -6.08695652173913, \"center_y\": 0.2898550724637685, \"value_uncond\": 2.307093573808732e-05}, {\"x\": -5.942028985507246, \"y\": 0.1449275362318847, \"x2\": -5.6521739130434785, \"y2\": 0.43478260869565233, \"center_x\": -5.797101449275362, \"center_y\": 0.2898550724637685, \"value_uncond\": 3.192646711486255e-05}, {\"x\": -5.6521739130434785, \"y\": 0.1449275362318847, \"x2\": -5.362318840579711, \"y2\": 0.43478260869565233, \"center_x\": -5.507246376811595, \"center_y\": 0.2898550724637685, \"value_uncond\": 4.37705830828896e-05}, {\"x\": -5.36231884057971, \"y\": 0.1449275362318847, \"x2\": -5.072463768115942, \"y2\": 0.43478260869565233, \"center_x\": -5.217391304347826, \"center_y\": 0.2898550724637685, \"value_uncond\": 5.9451061739903565e-05}, {\"x\": -5.0724637681159415, \"y\": 0.1449275362318847, \"x2\": -4.782608695652174, \"y2\": 0.43478260869565233, \"center_x\": -4.927536231884058, \"center_y\": 0.2898550724637685, \"value_uncond\": 7.999866004289843e-05}, {\"x\": -4.782608695652174, \"y\": 0.1449275362318847, \"x2\": -4.492753623188406, \"y2\": 0.43478260869565233, \"center_x\": -4.63768115942029, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.00010664773220414889}, {\"x\": -4.492753623188405, \"y\": 0.1449275362318847, \"x2\": -4.202898550724638, \"y2\": 0.43478260869565233, \"center_x\": -4.3478260869565215, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0001408530811513238}, {\"x\": -4.202898550724638, \"y\": 0.1449275362318847, \"x2\": -3.91304347826087, \"y2\": 0.43478260869565233, \"center_x\": -4.057971014492754, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.00018430066099712087}, {\"x\": -3.913043478260869, \"y\": 0.1449275362318847, \"x2\": -3.6231884057971016, \"y2\": 0.43478260869565233, \"center_x\": -3.7681159420289854, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.00023890940605263985}, {\"x\": -3.6231884057971016, \"y\": 0.1449275362318847, \"x2\": -3.333333333333334, \"y2\": 0.43478260869565233, \"center_x\": -3.4782608695652177, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0003068212386903227}, {\"x\": -3.333333333333333, \"y\": 0.1449275362318847, \"x2\": -3.0434782608695654, \"y2\": 0.43478260869565233, \"center_x\": -3.1884057971014492, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0003903762643051674}, {\"x\": -3.0434782608695645, \"y\": 0.1449275362318847, \"x2\": -2.753623188405797, \"y2\": 0.43478260869565233, \"center_x\": -2.8985507246376807, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.000492070356843446}, {\"x\": -2.753623188405797, \"y\": 0.1449275362318847, \"x2\": -2.4637681159420293, \"y2\": 0.43478260869565233, \"center_x\": -2.608695652173913, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0006144928261623863}, {\"x\": -2.4637681159420284, \"y\": 0.1449275362318847, \"x2\": -2.1739130434782608, \"y2\": 0.43478260869565233, \"center_x\": -2.3188405797101446, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0007602426771522744}, {\"x\": -2.1739130434782608, \"y\": 0.1449275362318847, \"x2\": -1.8840579710144931, \"y2\": 0.43478260869565233, \"center_x\": -2.028985507246377, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0009318231346921867}, {\"x\": -1.8840579710144922, \"y\": 0.1449275362318847, \"x2\": -1.5942028985507246, \"y2\": 0.43478260869565233, \"center_x\": -1.7391304347826084, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.001131515600817794}, {\"x\": -1.5942028985507246, \"y\": 0.1449275362318847, \"x2\": -1.304347826086957, \"y2\": 0.43478260869565233, \"center_x\": -1.4492753623188408, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0013612359752973578}, {\"x\": -1.304347826086957, \"y\": 0.1449275362318847, \"x2\": -1.0144927536231894, \"y2\": 0.43478260869565233, \"center_x\": -1.1594202898550732, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.001622378210753385}, {\"x\": -1.0144927536231876, \"y\": 0.1449275362318847, \"x2\": -0.72463768115942, \"y2\": 0.43478260869565233, \"center_x\": -0.8695652173913038, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0019156519503356758}, {\"x\": -0.72463768115942, \"y\": 0.1449275362318847, \"x2\": -0.43478260869565233, \"y2\": 0.43478260869565233, \"center_x\": -0.5797101449275361, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.002240922936869036}, {\"x\": -0.43478260869565233, \"y\": 0.1449275362318847, \"x2\": -0.1449275362318847, \"y2\": 0.43478260869565233, \"center_x\": -0.2898550724637685, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.002597066391525409}, {\"x\": -0.14492753623188293, \"y\": 0.1449275362318847, \"x2\": 0.1449275362318847, \"y2\": 0.43478260869565233, \"center_x\": 8.881784197001252e-16, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.002981844535590075}, {\"x\": 0.1449275362318847, \"y\": 0.1449275362318847, \"x2\": 0.43478260869565233, \"y2\": 0.43478260869565233, \"center_x\": 0.2898550724637685, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0033918196841353316}, {\"x\": 0.43478260869565233, \"y\": 0.1449275362318847, \"x2\": 0.72463768115942, \"y2\": 0.43478260869565233, \"center_x\": 0.5797101449275361, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0038223137271730843}, {\"x\": 0.72463768115942, \"y\": 0.1449275362318847, \"x2\": 1.0144927536231876, \"y2\": 0.43478260869565233, \"center_x\": 0.8695652173913038, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0042674232452736}, {\"x\": 1.0144927536231894, \"y\": 0.1449275362318847, \"x2\": 1.304347826086957, \"y2\": 0.43478260869565233, \"center_x\": 1.1594202898550732, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.004720096976656257}, {\"x\": 1.304347826086957, \"y\": 0.1449275362318847, \"x2\": 1.5942028985507246, \"y2\": 0.43478260869565233, \"center_x\": 1.4492753623188408, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.005172278949072928}, {\"x\": 1.5942028985507246, \"y\": 0.1449275362318847, \"x2\": 1.8840579710144922, \"y2\": 0.43478260869565233, \"center_x\": 1.7391304347826084, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.005615116497667997}, {\"x\": 1.884057971014494, \"y\": 0.1449275362318847, \"x2\": 2.1739130434782616, \"y2\": 0.43478260869565233, \"center_x\": 2.028985507246378, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.006039227885113778}, {\"x\": 2.1739130434782616, \"y\": 0.1449275362318847, \"x2\": 2.4637681159420293, \"y2\": 0.43478260869565233, \"center_x\": 2.3188405797101455, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.006435019670291636}, {\"x\": 2.4637681159420293, \"y\": 0.1449275362318847, \"x2\": 2.753623188405797, \"y2\": 0.43478260869565233, \"center_x\": 2.608695652173913, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.006793039727087407}, {\"x\": 2.753623188405797, \"y\": 0.1449275362318847, \"x2\": 3.0434782608695645, \"y2\": 0.43478260869565233, \"center_x\": 2.8985507246376807, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.007104348291790332}, {\"x\": 3.0434782608695663, \"y\": 0.1449275362318847, \"x2\": 3.333333333333334, \"y2\": 0.43478260869565233, \"center_x\": 3.18840579710145, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.007360886977026161}, {\"x\": 3.333333333333334, \"y\": 0.1449275362318847, \"x2\": 3.6231884057971016, \"y2\": 0.43478260869565233, \"center_x\": 3.4782608695652177, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.007555824616950575}, {\"x\": 3.6231884057971016, \"y\": 0.1449275362318847, \"x2\": 3.913043478260869, \"y2\": 0.43478260869565233, \"center_x\": 3.7681159420289854, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.007683859276305922}, {\"x\": 3.913043478260871, \"y\": 0.1449275362318847, \"x2\": 4.202898550724639, \"y2\": 0.43478260869565233, \"center_x\": 4.057971014492755, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.007741457802805548}, {\"x\": 4.202898550724639, \"y\": 0.1449275362318847, \"x2\": 4.492753623188406, \"y2\": 0.43478260869565233, \"center_x\": 4.347826086956522, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.007727017819488317}, {\"x\": 4.492753623188406, \"y\": 0.1449275362318847, \"x2\": 4.782608695652174, \"y2\": 0.43478260869565233, \"center_x\": 4.63768115942029, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.007640941791173754}, {\"x\": 4.782608695652174, \"y\": 0.1449275362318847, \"x2\": 5.0724637681159415, \"y2\": 0.43478260869565233, \"center_x\": 4.927536231884058, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0074856183868239065}, {\"x\": 5.072463768115943, \"y\": 0.1449275362318847, \"x2\": 5.362318840579711, \"y2\": 0.43478260869565233, \"center_x\": 5.217391304347827, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.007265312342396628}, {\"x\": 5.362318840579711, \"y\": 0.1449275362318847, \"x2\": 5.6521739130434785, \"y2\": 0.43478260869565233, \"center_x\": 5.507246376811595, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.006985969911763776}, {\"x\": 5.6521739130434785, \"y\": 0.1449275362318847, \"x2\": 5.942028985507246, \"y2\": 0.43478260869565233, \"center_x\": 5.797101449275362, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.006654952291646691}, {\"x\": 5.942028985507246, \"y\": 0.1449275362318847, \"x2\": 6.231884057971014, \"y2\": 0.43478260869565233, \"center_x\": 6.08695652173913, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.006280713694225636}, {\"x\": 6.2318840579710155, \"y\": 0.1449275362318847, \"x2\": 6.521739130434783, \"y2\": 0.43478260869565233, \"center_x\": 6.376811594202899, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0058724436925257605}, {\"x\": 6.521739130434785, \"y\": 0.1449275362318847, \"x2\": 6.8115942028985526, \"y2\": 0.43478260869565233, \"center_x\": 6.666666666666669, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.005439694883722319}, {\"x\": 6.811594202898551, \"y\": 0.1449275362318847, \"x2\": 7.101449275362318, \"y2\": 0.43478260869565233, \"center_x\": 6.956521739130435, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.004992016754393205}, {\"x\": 7.10144927536232, \"y\": 0.1449275362318847, \"x2\": 7.391304347826088, \"y2\": 0.43478260869565233, \"center_x\": 7.246376811594204, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.004538614983846708}, {\"x\": 7.391304347826086, \"y\": 0.1449275362318847, \"x2\": 7.681159420289854, \"y2\": 0.43478260869565233, \"center_x\": 7.53623188405797, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.004088052508777173}, {\"x\": 7.681159420289855, \"y\": 0.1449275362318847, \"x2\": 7.971014492753623, \"y2\": 0.43478260869565233, \"center_x\": 7.826086956521739, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0036480048145421467}, {\"x\": 7.971014492753625, \"y\": 0.1449275362318847, \"x2\": 8.260869565217392, \"y2\": 0.43478260869565233, \"center_x\": 8.115942028985508, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0032250774953942927}, {\"x\": 8.26086956521739, \"y\": 0.1449275362318847, \"x2\": 8.550724637681158, \"y2\": 0.43478260869565233, \"center_x\": 8.405797101449274, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0028246895368151965}, {\"x\": 8.55072463768116, \"y\": 0.1449275362318847, \"x2\": 8.840579710144928, \"y2\": 0.43478260869565233, \"center_x\": 8.695652173913043, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.002451021395080612}, {\"x\": 8.84057971014493, \"y\": 0.1449275362318847, \"x2\": 9.130434782608697, \"y2\": 0.43478260869565233, \"center_x\": 8.985507246376812, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.002107023104118119}, {\"x\": 9.130434782608695, \"y\": 0.1449275362318847, \"x2\": 9.420289855072463, \"y2\": 0.43478260869565233, \"center_x\": 9.275362318840578, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.001794474568711094}, {\"x\": 9.420289855072465, \"y\": 0.1449275362318847, \"x2\": 9.710144927536232, \"y2\": 0.43478260869565233, \"center_x\": 9.565217391304348, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0015140880526015143}, {\"x\": 9.710144927536234, \"y\": 0.1449275362318847, \"x2\": 10.000000000000002, \"y2\": 0.43478260869565233, \"center_x\": 9.855072463768117, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.001265641689221894}, {\"x\": 10.0, \"y\": 0.1449275362318847, \"x2\": 10.289855072463768, \"y2\": 0.43478260869565233, \"center_x\": 10.144927536231883, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.001048132591284704}, {\"x\": -10.0, \"y\": 0.43478260869565233, \"x2\": -9.710144927536232, \"y2\": 0.72463768115942, \"center_x\": -9.855072463768117, \"center_y\": 0.5797101449275361, \"value_uncond\": 1.628974945214488e-07}, {\"x\": -9.710144927536232, \"y\": 0.43478260869565233, \"x2\": -9.420289855072465, \"y2\": 0.72463768115942, \"center_x\": -9.565217391304348, \"center_y\": 0.5797101449275361, \"value_uncond\": 2.545097765009833e-07}, {\"x\": -9.420289855072463, \"y\": 0.43478260869565233, \"x2\": -9.130434782608695, \"y2\": 0.72463768115942, \"center_x\": -9.275362318840578, \"center_y\": 0.5797101449275361, \"value_uncond\": 3.9394931447823936e-07}, {\"x\": -9.130434782608695, \"y\": 0.43478260869565233, \"x2\": -8.840579710144928, \"y2\": 0.72463768115942, \"center_x\": -8.985507246376812, \"center_y\": 0.5797101449275361, \"value_uncond\": 6.04118371678944e-07}, {\"x\": -8.840579710144928, \"y\": 0.43478260869565233, \"x2\": -8.55072463768116, \"y2\": 0.72463768115942, \"center_x\": -8.695652173913043, \"center_y\": 0.5797101449275361, \"value_uncond\": 9.178031665417845e-07}, {\"x\": -8.55072463768116, \"y\": 0.43478260869565233, \"x2\": -8.260869565217392, \"y2\": 0.72463768115942, \"center_x\": -8.405797101449277, \"center_y\": 0.5797101449275361, \"value_uncond\": 1.3814108885194928e-06}, {\"x\": -8.26086956521739, \"y\": 0.43478260869565233, \"x2\": -7.971014492753623, \"y2\": 0.72463768115942, \"center_x\": -8.115942028985508, \"center_y\": 0.5797101449275361, \"value_uncond\": 2.0598804345440314e-06}, {\"x\": -7.971014492753623, \"y\": 0.43478260869565233, \"x2\": -7.681159420289855, \"y2\": 0.72463768115942, \"center_x\": -7.826086956521739, \"center_y\": 0.5797101449275361, \"value_uncond\": 3.043035120901547e-06}, {\"x\": -7.681159420289855, \"y\": 0.43478260869565233, \"x2\": -7.391304347826088, \"y2\": 0.72463768115942, \"center_x\": -7.536231884057972, \"center_y\": 0.5797101449275361, \"value_uncond\": 4.453666894683446e-06}, {\"x\": -7.391304347826087, \"y\": 0.43478260869565233, \"x2\": -7.101449275362319, \"y2\": 0.72463768115942, \"center_x\": -7.246376811594203, \"center_y\": 0.5797101449275361, \"value_uncond\": 6.4576471738761325e-06}, {\"x\": -7.101449275362318, \"y\": 0.43478260869565233, \"x2\": -6.811594202898551, \"y2\": 0.72463768115942, \"center_x\": -6.956521739130435, \"center_y\": 0.5797101449275361, \"value_uncond\": 9.276341077656326e-06}, {\"x\": -6.811594202898551, \"y\": 0.43478260869565233, \"x2\": -6.521739130434783, \"y2\": 0.72463768115942, \"center_x\": -6.666666666666667, \"center_y\": 0.5797101449275361, \"value_uncond\": 1.3201549820744305e-05}, {\"x\": -6.521739130434782, \"y\": 0.43478260869565233, \"x2\": -6.231884057971015, \"y2\": 0.72463768115942, \"center_x\": -6.3768115942028984, \"center_y\": 0.5797101449275361, \"value_uncond\": 1.8613109999084778e-05}, {\"x\": -6.231884057971014, \"y\": 0.43478260869565233, \"x2\": -5.942028985507246, \"y2\": 0.72463768115942, \"center_x\": -6.08695652173913, \"center_y\": 0.5797101449275361, \"value_uncond\": 2.5999128073608017e-05}, {\"x\": -5.942028985507246, \"y\": 0.43478260869565233, \"x2\": -5.6521739130434785, \"y2\": 0.72463768115942, \"center_x\": -5.797101449275362, \"center_y\": 0.5797101449275361, \"value_uncond\": 3.5978614689945916e-05}, {\"x\": -5.6521739130434785, \"y\": 0.43478260869565233, \"x2\": -5.362318840579711, \"y2\": 0.72463768115942, \"center_x\": -5.507246376811595, \"center_y\": 0.5797101449275361, \"value_uncond\": 4.932600083272101e-05}, {\"x\": -5.36231884057971, \"y\": 0.43478260869565233, \"x2\": -5.072463768115942, \"y2\": 0.72463768115942, \"center_x\": -5.217391304347826, \"center_y\": 0.5797101449275361, \"value_uncond\": 6.699666566779119e-05}, {\"x\": -5.0724637681159415, \"y\": 0.43478260869565233, \"x2\": -4.782608695652174, \"y2\": 0.72463768115942, \"center_x\": -4.927536231884058, \"center_y\": 0.5797101449275361, \"value_uncond\": 9.015219112845478e-05}, {\"x\": -4.782608695652174, \"y\": 0.43478260869565233, \"x2\": -4.492753623188406, \"y2\": 0.72463768115942, \"center_x\": -4.63768115942029, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.00012018359722436608}, {\"x\": -4.492753623188405, \"y\": 0.43478260869565233, \"x2\": -4.202898550724638, \"y2\": 0.72463768115942, \"center_x\": -4.3478260869565215, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.00015873033231027375}, {\"x\": -4.202898550724638, \"y\": 0.43478260869565233, \"x2\": -3.91304347826087, \"y2\": 0.72463768115942, \"center_x\": -4.057971014492754, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.00020769233392663476}, {\"x\": -3.913043478260869, \"y\": 0.43478260869565233, \"x2\": -3.6231884057971016, \"y2\": 0.72463768115942, \"center_x\": -3.7681159420289854, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0002692320899536763}, {\"x\": -3.6231884057971016, \"y\": 0.43478260869565233, \"x2\": -3.333333333333334, \"y2\": 0.72463768115942, \"center_x\": -3.4782608695652177, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.00034576337825966737}, {\"x\": -3.333333333333333, \"y\": 0.43478260869565233, \"x2\": -3.0434782608695654, \"y2\": 0.72463768115942, \"center_x\": -3.1884057971014492, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0004399233133752442}, {\"x\": -3.0434782608695645, \"y\": 0.43478260869565233, \"x2\": -2.753623188405797, \"y2\": 0.72463768115942, \"center_x\": -2.8985507246376807, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0005545245487238045}, {\"x\": -2.753623188405797, \"y\": 0.43478260869565233, \"x2\": -2.4637681159420293, \"y2\": 0.72463768115942, \"center_x\": -2.608695652173913, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0006924850326436628}, {\"x\": -2.4637681159420284, \"y\": 0.43478260869565233, \"x2\": -2.1739130434782608, \"y2\": 0.72463768115942, \"center_x\": -2.3188405797101446, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0008567336390120467}, {\"x\": -2.1739130434782608, \"y\": 0.43478260869565233, \"x2\": -1.8840579710144931, \"y2\": 0.72463768115942, \"center_x\": -2.028985507246377, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0010500913051748446}, {\"x\": -1.8840579710144922, \"y\": 0.43478260869565233, \"x2\": -1.5942028985507246, \"y2\": 0.72463768115942, \"center_x\": -1.7391304347826084, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0012751289915987729}, {\"x\": -1.5942028985507246, \"y\": 0.43478260869565233, \"x2\": -1.304347826086957, \"y2\": 0.72463768115942, \"center_x\": -1.4492753623188408, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0015340057664732067}, {\"x\": -1.304347826086957, \"y\": 0.43478260869565233, \"x2\": -1.0144927536231894, \"y2\": 0.72463768115942, \"center_x\": -1.1594202898550732, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0018282925046500629}, {\"x\": -1.0144927536231876, \"y\": 0.43478260869565233, \"x2\": -0.72463768115942, \"y2\": 0.72463768115942, \"center_x\": -0.8695652173913038, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0021587889180850073}, {\"x\": -0.72463768115942, \"y\": 0.43478260869565233, \"x2\": -0.43478260869565233, \"y2\": 0.72463768115942, \"center_x\": -0.5797101449275361, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.002525343709512413}, {\"x\": -0.43478260869565233, \"y\": 0.43478260869565233, \"x2\": -0.1449275362318847, \"y2\": 0.72463768115942, \"center_x\": -0.2898550724637685, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0029266893417531576}, {\"x\": -0.14492753623188293, \"y\": 0.43478260869565233, \"x2\": 0.1449275362318847, \"y2\": 0.72463768115942, \"center_x\": 8.881784197001252e-16, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.003360304014388531}, {\"x\": 0.1449275362318847, \"y\": 0.43478260869565233, \"x2\": 0.43478260869565233, \"y2\": 0.72463768115942, \"center_x\": 0.2898550724637685, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0038223137271730843}, {\"x\": 0.43478260869565233, \"y\": 0.43478260869565233, \"x2\": 0.72463768115942, \"y2\": 0.72463768115942, \"center_x\": 0.5797101449275361, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.004307446618483878}, {\"x\": 0.72463768115942, \"y\": 0.43478260869565233, \"x2\": 1.0144927536231876, \"y2\": 0.72463768115942, \"center_x\": 0.8695652173913038, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.004809049999432688}, {\"x\": 1.0144927536231894, \"y\": 0.43478260869565233, \"x2\": 1.304347826086957, \"y2\": 0.72463768115942, \"center_x\": 1.1594202898550732, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.005319177653177842}, {\"x\": 1.304347826086957, \"y\": 0.43478260869565233, \"x2\": 1.5942028985507246, \"y2\": 0.72463768115942, \"center_x\": 1.4492753623188408, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.005828751133287251}, {\"x\": 1.5942028985507246, \"y\": 0.43478260869565233, \"x2\": 1.8840579710144922, \"y2\": 0.72463768115942, \"center_x\": 1.7391304347826084, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.00632779418348823}, {\"x\": 1.884057971014494, \"y\": 0.43478260869565233, \"x2\": 2.1739130434782616, \"y2\": 0.72463768115942, \"center_x\": 2.028985507246378, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.006805734324488883}, {\"x\": 2.1739130434782616, \"y\": 0.43478260869565233, \"x2\": 2.4637681159420293, \"y2\": 0.72463768115942, \"center_x\": 2.3188405797101455, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.007251760503493538}, {\"x\": 2.4637681159420293, \"y\": 0.43478260869565233, \"x2\": 2.753623188405797, \"y2\": 0.72463768115942, \"center_x\": 2.608695652173913, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.007655220918590051}, {\"x\": 2.753623188405797, \"y\": 0.43478260869565233, \"x2\": 3.0434782608695645, \"y2\": 0.72463768115942, \"center_x\": 2.8985507246376807, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.008006041159953762}, {\"x\": 3.0434782608695663, \"y\": 0.43478260869565233, \"x2\": 3.333333333333334, \"y2\": 0.72463768115942, \"center_x\": 3.18840579710145, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.008295140059495594}, {\"x\": 3.333333333333334, \"y\": 0.43478260869565233, \"x2\": 3.6231884057971016, \"y2\": 0.72463768115942, \"center_x\": 3.4782608695652177, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.008514819431164715}, {\"x\": 3.6231884057971016, \"y\": 0.43478260869565233, \"x2\": 3.913043478260869, \"y2\": 0.72463768115942, \"center_x\": 3.7681159420289854, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.008659104411376637}, {\"x\": 3.913043478260871, \"y\": 0.43478260869565233, \"x2\": 4.202898550724639, \"y2\": 0.72463768115942, \"center_x\": 4.057971014492755, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.008724013415689048}, {\"x\": 4.202898550724639, \"y\": 0.43478260869565233, \"x2\": 4.492753623188406, \"y2\": 0.72463768115942, \"center_x\": 4.347826086956522, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.008707740691430809}, {\"x\": 4.492753623188406, \"y\": 0.43478260869565233, \"x2\": 4.782608695652174, \"y2\": 0.72463768115942, \"center_x\": 4.63768115942029, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.008610739784765228}, {\"x\": 4.782608695652174, \"y\": 0.43478260869565233, \"x2\": 5.0724637681159415, \"y2\": 0.72463768115942, \"center_x\": 4.927536231884058, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.008435702537539325}, {\"x\": 5.072463768115943, \"y\": 0.43478260869565233, \"x2\": 5.362318840579711, \"y2\": 0.72463768115942, \"center_x\": 5.217391304347827, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.008187434971391197}, {\"x\": 5.362318840579711, \"y\": 0.43478260869565233, \"x2\": 5.6521739130434785, \"y2\": 0.72463768115942, \"center_x\": 5.507246376811595, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.007872638046252756}, {\"x\": 5.6521739130434785, \"y\": 0.43478260869565233, \"x2\": 5.942028985507246, \"y2\": 0.72463768115942, \"center_x\": 5.797101449275362, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0074996072512409475}, {\"x\": 5.942028985507246, \"y\": 0.43478260869565233, \"x2\": 6.231884057971014, \"y2\": 0.72463768115942, \"center_x\": 6.08695652173913, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.00707786981783574}, {\"x\": 6.2318840579710155, \"y\": 0.43478260869565233, \"x2\": 6.521739130434783, \"y2\": 0.72463768115942, \"center_x\": 6.376811594202899, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.006617781671290226}, {\"x\": 6.521739130434785, \"y\": 0.43478260869565233, \"x2\": 6.8115942028985526, \"y2\": 0.72463768115942, \"center_x\": 6.666666666666669, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.006130107836491764}, {\"x\": 6.811594202898551, \"y\": 0.43478260869565233, \"x2\": 7.101449275362318, \"y2\": 0.72463768115942, \"center_x\": 6.956521739130435, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.005625609832929387}, {\"x\": 7.10144927536232, \"y\": 0.43478260869565233, \"x2\": 7.391304347826088, \"y2\": 0.72463768115942, \"center_x\": 7.246376811594204, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.005114661736369161}, {\"x\": 7.391304347826086, \"y\": 0.43478260869565233, \"x2\": 7.681159420289854, \"y2\": 0.72463768115942, \"center_x\": 7.53623188405797, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.004606913302257929}, {\"x\": 7.681159420289855, \"y\": 0.43478260869565233, \"x2\": 7.971014492753623, \"y2\": 0.72463768115942, \"center_x\": 7.826086956521739, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.004111014198259955}, {\"x\": 7.971014492753625, \"y\": 0.43478260869565233, \"x2\": 8.260869565217392, \"y2\": 0.72463768115942, \"center_x\": 8.115942028985508, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0036344084090027774}, {\"x\": 8.26086956521739, \"y\": 0.43478260869565233, \"x2\": 8.550724637681158, \"y2\": 0.72463768115942, \"center_x\": 8.405797101449274, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0031832027044572447}, {\"x\": 8.55072463768116, \"y\": 0.43478260869565233, \"x2\": 8.840579710144928, \"y2\": 0.72463768115942, \"center_x\": 8.695652173913043, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0027621081296955365}, {\"x\": 8.84057971014493, \"y\": 0.43478260869565233, \"x2\": 9.130434782608697, \"y2\": 0.72463768115942, \"center_x\": 8.985507246376812, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0023744491406814394}, {\"x\": 9.130434782608695, \"y\": 0.43478260869565233, \"x2\": 9.420289855072463, \"y2\": 0.72463768115942, \"center_x\": 9.275362318840578, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.002022231549964005}, {\"x\": 9.420289855072465, \"y\": 0.43478260869565233, \"x2\": 9.710144927536232, \"y2\": 0.72463768115942, \"center_x\": 9.565217391304348, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0017062580226999535}, {\"x\": 9.710144927536234, \"y\": 0.43478260869565233, \"x2\": 10.000000000000002, \"y2\": 0.72463768115942, \"center_x\": 9.855072463768117, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0014262785327365166}, {\"x\": 10.0, \"y\": 0.43478260869565233, \"x2\": 10.289855072463768, \"y2\": 0.72463768115942, \"center_x\": 10.144927536231883, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0011811629050635496}, {\"x\": -10.0, \"y\": 0.72463768115942, \"x2\": -9.710144927536232, \"y2\": 1.0144927536231876, \"center_x\": -9.855072463768117, \"center_y\": 0.8695652173913038, \"value_uncond\": 1.8186695398019615e-07}, {\"x\": -9.710144927536232, \"y\": 0.72463768115942, \"x2\": -9.420289855072465, \"y2\": 1.0144927536231876, \"center_x\": -9.565217391304348, \"center_y\": 0.8695652173913038, \"value_uncond\": 2.841475121909858e-07}, {\"x\": -9.420289855072463, \"y\": 0.72463768115942, \"x2\": -9.130434782608695, \"y2\": 1.0144927536231876, \"center_x\": -9.275362318840578, \"center_y\": 0.8695652173913038, \"value_uncond\": 4.398248239312864e-07}, {\"x\": -9.130434782608695, \"y\": 0.72463768115942, \"x2\": -8.840579710144928, \"y2\": 1.0144927536231876, \"center_x\": -8.985507246376812, \"center_y\": 0.8695652173913038, \"value_uncond\": 6.744681274779165e-07}, {\"x\": -8.840579710144928, \"y\": 0.72463768115942, \"x2\": -8.55072463768116, \"y2\": 1.0144927536231876, \"center_x\": -8.695652173913043, \"center_y\": 0.8695652173913038, \"value_uncond\": 1.024681605709748e-06}, {\"x\": -8.55072463768116, \"y\": 0.72463768115942, \"x2\": -8.260869565217392, \"y2\": 1.0144927536231876, \"center_x\": -8.405797101449277, \"center_y\": 0.8695652173913038, \"value_uncond\": 1.5422765784592037e-06}, {\"x\": -8.26086956521739, \"y\": 0.72463768115942, \"x2\": -7.971014492753623, \"y2\": 1.0144927536231876, \"center_x\": -8.115942028985508, \"center_y\": 0.8695652173913038, \"value_uncond\": 2.2997540956322e-06}, {\"x\": -7.971014492753623, \"y\": 0.72463768115942, \"x2\": -7.681159420289855, \"y2\": 1.0144927536231876, \"center_x\": -7.826086956521739, \"center_y\": 0.8695652173913038, \"value_uncond\": 3.3973974241835387e-06}, {\"x\": -7.681159420289855, \"y\": 0.72463768115942, \"x2\": -7.391304347826088, \"y2\": 1.0144927536231876, \"center_x\": -7.536231884057972, \"center_y\": 0.8695652173913038, \"value_uncond\": 4.97229766828531e-06}, {\"x\": -7.391304347826087, \"y\": 0.72463768115942, \"x2\": -7.101449275362319, \"y2\": 1.0144927536231876, \"center_x\": -7.246376811594203, \"center_y\": 0.8695652173913038, \"value_uncond\": 7.209642019613979e-06}, {\"x\": -7.101449275362318, \"y\": 0.72463768115942, \"x2\": -6.811594202898551, \"y2\": 1.0144927536231876, \"center_x\": -6.956521739130435, \"center_y\": 0.8695652173913038, \"value_uncond\": 1.0356573628286171e-05}, {\"x\": -6.811594202898551, \"y\": 0.72463768115942, \"x2\": -6.521739130434783, \"y2\": 1.0144927536231876, \"center_x\": -6.666666666666667, \"center_y\": 0.8695652173913038, \"value_uncond\": 1.4738874043274142e-05}, {\"x\": -6.521739130434782, \"y\": 0.72463768115942, \"x2\": -6.231884057971015, \"y2\": 1.0144927536231876, \"center_x\": -6.3768115942028984, \"center_y\": 0.8695652173913038, \"value_uncond\": 2.078061193989797e-05}, {\"x\": -6.231884057971014, \"y\": 0.72463768115942, \"x2\": -5.942028985507246, \"y2\": 1.0144927536231876, \"center_x\": -6.08695652173913, \"center_y\": 0.8695652173913038, \"value_uncond\": 2.9026733914962152e-05}, {\"x\": -5.942028985507246, \"y\": 0.72463768115942, \"x2\": -5.6521739130434785, \"y2\": 1.0144927536231876, \"center_x\": -5.797101449275362, \"center_y\": 0.8695652173913038, \"value_uncond\": 4.0168334579425016e-05}, {\"x\": -5.6521739130434785, \"y\": 0.72463768115942, \"x2\": -5.362318840579711, \"y2\": 1.0144927536231876, \"center_x\": -5.507246376811595, \"center_y\": 0.8695652173913038, \"value_uncond\": 5.507002762581109e-05}, {\"x\": -5.36231884057971, \"y\": 0.72463768115942, \"x2\": -5.072463768115942, \"y2\": 1.0144927536231876, \"center_x\": -5.217391304347826, \"center_y\": 0.8695652173913038, \"value_uncond\": 7.47984463949287e-05}, {\"x\": -5.0724637681159415, \"y\": 0.72463768115942, \"x2\": -4.782608695652174, \"y2\": 1.0144927536231876, \"center_x\": -4.927536231884058, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.00010065043936580447}, {\"x\": -4.782608695652174, \"y\": 0.72463768115942, \"x2\": -4.492753623188406, \"y2\": 1.0144927536231876, \"center_x\": -4.63768115942029, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.00013417901122291513}, {\"x\": -4.492753623188405, \"y\": 0.72463768115942, \"x2\": -4.202898550724638, \"y2\": 1.0144927536231876, \"center_x\": -4.3478260869565215, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.00017721452454710887}, {\"x\": -4.202898550724638, \"y\": 0.72463768115942, \"x2\": -3.91304347826087, \"y2\": 1.0144927536231876, \"center_x\": -4.057971014492754, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.00023187816514453103}, {\"x\": -3.913043478260869, \"y\": 0.72463768115942, \"x2\": -3.6231884057971016, \"y2\": 1.0144927536231876, \"center_x\": -3.7681159420289854, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.00030058424322266115}, {\"x\": -3.6231884057971016, \"y\": 0.72463768115942, \"x2\": -3.333333333333334, \"y2\": 1.0144927536231876, \"center_x\": -3.4782608695652177, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0003860276217674317}, {\"x\": -3.333333333333333, \"y\": 0.72463768115942, \"x2\": -3.0434782608695654, \"y2\": 1.0144927536231876, \"center_x\": -3.1884057971014492, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.000491152508044845}, {\"x\": -3.0434782608695645, \"y\": 0.72463768115942, \"x2\": -2.753623188405797, \"y2\": 1.0144927536231876, \"center_x\": -2.8985507246376807, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0006190990897675365}, {\"x\": -2.753623188405797, \"y\": 0.72463768115942, \"x2\": -2.4637681159420293, \"y2\": 1.0144927536231876, \"center_x\": -2.608695652173913, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0007731251111857775}, {\"x\": -2.4637681159420284, \"y\": 0.72463768115942, \"x2\": -2.1739130434782608, \"y2\": 1.0144927536231876, \"center_x\": -2.3188405797101446, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0009565005143708588}, {\"x\": -2.1739130434782608, \"y\": 0.72463768115942, \"x2\": -1.8840579710144931, \"y2\": 1.0144927536231876, \"center_x\": -2.028985507246377, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.001172374735623031}, {\"x\": -1.8840579710144922, \"y\": 0.72463768115942, \"x2\": -1.5942028985507246, \"y2\": 1.0144927536231876, \"center_x\": -1.7391304347826084, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0014236181244848623}, {\"x\": -1.5942028985507246, \"y\": 0.72463768115942, \"x2\": -1.304347826086957, \"y2\": 1.0144927536231876, \"center_x\": -1.4492753623188408, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0017126411732490106}, {\"x\": -1.304347826086957, \"y\": 0.72463768115942, \"x2\": -1.0144927536231894, \"y2\": 1.0144927536231876, \"center_x\": -1.1594202898550732, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0020411976855896296}, {\"x\": -1.0144927536231876, \"y\": 0.72463768115942, \"x2\": -0.72463768115942, \"y2\": 1.0144927536231876, \"center_x\": -0.8695652173913038, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0024101805001465397}, {\"x\": -0.72463768115942, \"y\": 0.72463768115942, \"x2\": -0.43478260869565233, \"y2\": 1.0144927536231876, \"center_x\": -0.5797101449275361, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0028194207010446004}, {\"x\": -0.43478260869565233, \"y\": 0.72463768115942, \"x2\": -0.1449275362318847, \"y2\": 1.0144927536231876, \"center_x\": -0.2898550724637685, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.003267503146040521}, {\"x\": -0.14492753623188293, \"y\": 0.72463768115942, \"x2\": 0.1449275362318847, \"y2\": 1.0144927536231876, \"center_x\": 8.881784197001252e-16, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.003751612370341276}, {\"x\": 0.1449275362318847, \"y\": 0.72463768115942, \"x2\": 0.43478260869565233, \"y2\": 1.0144927536231876, \"center_x\": 0.2898550724637685, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0042674232452736}, {\"x\": 0.43478260869565233, \"y\": 0.72463768115942, \"x2\": 0.72463768115942, \"y2\": 1.0144927536231876, \"center_x\": 0.5797101449275361, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.004809049999432688}, {\"x\": 0.72463768115942, \"y\": 0.72463768115942, \"x2\": 1.0144927536231876, \"y2\": 1.0144927536231876, \"center_x\": 0.8695652173913038, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.00536906523642159}, {\"x\": 1.0144927536231894, \"y\": 0.72463768115942, \"x2\": 1.304347826086957, \"y2\": 1.0144927536231876, \"center_x\": 1.1594202898550732, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.005938597400192714}, {\"x\": 1.304347826086957, \"y\": 0.72463768115942, \"x2\": 1.5942028985507246, \"y2\": 1.0144927536231876, \"center_x\": 1.4492753623188408, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.006507510856650965}, {\"x\": 1.5942028985507246, \"y\": 0.72463768115942, \"x2\": 1.8840579710144922, \"y2\": 1.0144927536231876, \"center_x\": 1.7391304347826084, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.007064667611649967}, {\"x\": 1.884057971014494, \"y\": 0.72463768115942, \"x2\": 2.1739130434782616, \"y2\": 1.0144927536231876, \"center_x\": 2.028985507246378, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.007598264017684372}, {\"x\": 2.1739130434782616, \"y\": 0.72463768115942, \"x2\": 2.4637681159420293, \"y2\": 1.0144927536231876, \"center_x\": 2.3188405797101455, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.008096230071792845}, {\"x\": 2.4637681159420293, \"y\": 0.72463768115942, \"x2\": 2.753623188405797, \"y2\": 1.0144927536231876, \"center_x\": 2.608695652173913, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.008546673566708152}, {\"x\": 2.753623188405797, \"y\": 0.72463768115942, \"x2\": 3.0434782608695645, \"y2\": 1.0144927536231876, \"center_x\": 2.8985507246376807, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.008938346924722965}, {\"x\": 3.0434782608695663, \"y\": 0.72463768115942, \"x2\": 3.333333333333334, \"y2\": 1.0144927536231876, \"center_x\": 3.18840579710145, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.009261111473147475}, {\"x\": 3.333333333333334, \"y\": 0.72463768115942, \"x2\": 3.6231884057971016, \"y2\": 1.0144927536231876, \"center_x\": 3.4782608695652177, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.009506372569980895}, {\"x\": 3.6231884057971016, \"y\": 0.72463768115942, \"x2\": 3.913043478260869, \"y2\": 1.0144927536231876, \"center_x\": 3.7681159420289854, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.00966745957707897}, {\"x\": 3.913043478260871, \"y\": 0.72463768115942, \"x2\": 4.202898550724639, \"y2\": 1.0144927536231876, \"center_x\": 4.057971014492755, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.009739927253361315}, {\"x\": 4.202898550724639, \"y\": 0.72463768115942, \"x2\": 4.492753623188406, \"y2\": 1.0144927536231876, \"center_x\": 4.347826086956522, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.009721759565745862}, {\"x\": 4.492753623188406, \"y\": 0.72463768115942, \"x2\": 4.782608695652174, \"y2\": 1.0144927536231876, \"center_x\": 4.63768115942029, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.00961346287597533}, {\"x\": 4.782608695652174, \"y\": 0.72463768115942, \"x2\": 5.0724637681159415, \"y2\": 1.0144927536231876, \"center_x\": 4.927536231884058, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.009418042491643623}, {\"x\": 5.072463768115943, \"y\": 0.72463768115942, \"x2\": 5.362318840579711, \"y2\": 1.0144927536231876, \"center_x\": 5.217391304347827, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.009140864096972293}, {\"x\": 5.362318840579711, \"y\": 0.72463768115942, \"x2\": 5.6521739130434785, \"y2\": 1.0144927536231876, \"center_x\": 5.507246376811595, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.008789408980578704}, {\"x\": 5.6521739130434785, \"y\": 0.72463768115942, \"x2\": 5.942028985507246, \"y2\": 1.0144927536231876, \"center_x\": 5.797101449275362, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.008372938643641286}, {\"x\": 5.942028985507246, \"y\": 0.72463768115942, \"x2\": 6.231884057971014, \"y2\": 1.0144927536231876, \"center_x\": 6.08695652173913, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.007902089766449183}, {\"x\": 6.2318840579710155, \"y\": 0.72463768115942, \"x2\": 6.521739130434783, \"y2\": 1.0144927536231876, \"center_x\": 6.376811594202899, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.007388424224689674}, {\"x\": 6.521739130434785, \"y\": 0.72463768115942, \"x2\": 6.8115942028985526, \"y2\": 1.0144927536231876, \"center_x\": 6.666666666666669, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.006843960633452795}, {\"x\": 6.811594202898551, \"y\": 0.72463768115942, \"x2\": 7.101449275362318, \"y2\": 1.0144927536231876, \"center_x\": 6.956521739130435, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.006280713694225632}, {\"x\": 7.10144927536232, \"y\": 0.72463768115942, \"x2\": 7.391304347826088, \"y2\": 1.0144927536231876, \"center_x\": 7.246376811594204, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0057102655468408235}, {\"x\": 7.391304347826086, \"y\": 0.72463768115942, \"x2\": 7.681159420289854, \"y2\": 1.0144927536231876, \"center_x\": 7.53623188405797, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.00514338966350509}, {\"x\": 7.681159420289855, \"y\": 0.72463768115942, \"x2\": 7.971014492753623, \"y2\": 1.0144927536231876, \"center_x\": 7.826086956521739, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.004589742968136519}, {\"x\": 7.971014492753625, \"y\": 0.72463768115942, \"x2\": 8.260869565217392, \"y2\": 1.0144927536231876, \"center_x\": 8.115942028985508, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.004057636299484735}, {\"x\": 8.26086956521739, \"y\": 0.72463768115942, \"x2\": 8.550724637681158, \"y2\": 1.0144927536231876, \"center_x\": 8.405797101449274, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0035538875626164724}, {\"x\": 8.55072463768116, \"y\": 0.72463768115942, \"x2\": 8.840579710144928, \"y2\": 1.0144927536231876, \"center_x\": 8.695652173913043, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.003083756405139314}, {\"x\": 8.84057971014493, \"y\": 0.72463768115942, \"x2\": 9.130434782608697, \"y2\": 1.0144927536231876, \"center_x\": 8.985507246376812, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.002650954416857332}, {\"x\": 9.130434782608695, \"y\": 0.72463768115942, \"x2\": 9.420289855072463, \"y2\": 1.0144927536231876, \"center_x\": 9.275362318840578, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.002257720987760062}, {\"x\": 9.420289855072465, \"y\": 0.72463768115942, \"x2\": 9.710144927536232, \"y2\": 1.0144927536231876, \"center_x\": 9.565217391304348, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0019049522535894748}, {\"x\": 9.710144927536234, \"y\": 0.72463768115942, \"x2\": 10.000000000000002, \"y2\": 1.0144927536231876, \"center_x\": 9.855072463768117, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0015923690725763713}, {\"x\": 10.0, \"y\": 0.72463768115942, \"x2\": 10.289855072463768, \"y2\": 1.0144927536231876, \"center_x\": 10.144927536231883, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0013187096605099884}, {\"x\": -10.0, \"y\": 1.0144927536231894, \"x2\": -9.710144927536232, \"y2\": 1.304347826086957, \"center_x\": -9.855072463768117, \"center_y\": 1.1594202898550732, \"value_uncond\": 2.0115878137617703e-07}, {\"x\": -9.710144927536232, \"y\": 1.0144927536231894, \"x2\": -9.420289855072465, \"y2\": 1.304347826086957, \"center_x\": -9.565217391304348, \"center_y\": 1.1594202898550732, \"value_uncond\": 3.1428891303493833e-07}, {\"x\": -9.420289855072463, \"y\": 1.0144927536231894, \"x2\": -9.130434782608695, \"y2\": 1.304347826086957, \"center_x\": -9.275362318840578, \"center_y\": 1.1594202898550732, \"value_uncond\": 4.864799440729798e-07}, {\"x\": -9.130434782608695, \"y\": 1.0144927536231894, \"x2\": -8.840579710144928, \"y2\": 1.304347826086957, \"center_x\": -8.985507246376812, \"center_y\": 1.1594202898550732, \"value_uncond\": 7.460134105248357e-07}, {\"x\": -8.840579710144928, \"y\": 1.0144927536231894, \"x2\": -8.55072463768116, \"y2\": 1.304347826086957, \"center_x\": -8.695652173913043, \"center_y\": 1.1594202898550732, \"value_uncond\": 1.1333763423870968e-06}, {\"x\": -8.55072463768116, \"y\": 1.0144927536231894, \"x2\": -8.260869565217392, \"y2\": 1.304347826086957, \"center_x\": -8.405797101449277, \"center_y\": 1.1594202898550732, \"value_uncond\": 1.705876027932241e-06}, {\"x\": -8.26086956521739, \"y\": 1.0144927536231894, \"x2\": -7.971014492753623, \"y2\": 1.304347826086957, \"center_x\": -8.115942028985508, \"center_y\": 1.1594202898550732, \"value_uncond\": 2.5437041816438e-06}, {\"x\": -7.971014492753623, \"y\": 1.0144927536231894, \"x2\": -7.681159420289855, \"y2\": 1.304347826086957, \"center_x\": -7.826086956521739, \"center_y\": 1.1594202898550732, \"value_uncond\": 3.757781778066953e-06}, {\"x\": -7.681159420289855, \"y\": 1.0144927536231894, \"x2\": -7.391304347826088, \"y2\": 1.304347826086957, \"center_x\": -7.536231884057972, \"center_y\": 1.1594202898550732, \"value_uncond\": 5.499742079040889e-06}, {\"x\": -7.391304347826087, \"y\": 1.0144927536231894, \"x2\": -7.101449275362319, \"y2\": 1.304347826086957, \"center_x\": -7.246376811594203, \"center_y\": 1.1594202898550732, \"value_uncond\": 7.97441630315065e-06}, {\"x\": -7.101449275362318, \"y\": 1.0144927536231894, \"x2\": -6.811594202898551, \"y2\": 1.304347826086957, \"center_x\": -6.956521739130435, \"center_y\": 1.1594202898550732, \"value_uncond\": 1.1455163704592264e-05}, {\"x\": -6.811594202898551, \"y\": 1.0144927536231894, \"x2\": -6.521739130434783, \"y2\": 1.304347826086957, \"center_x\": -6.666666666666667, \"center_y\": 1.1594202898550732, \"value_uncond\": 1.6302323630079804e-05}, {\"x\": -6.521739130434782, \"y\": 1.0144927536231894, \"x2\": -6.231884057971015, \"y2\": 1.304347826086957, \"center_x\": -6.3768115942028984, \"center_y\": 1.1594202898550732, \"value_uncond\": 2.2984948516464915e-05}, {\"x\": -6.231884057971014, \"y\": 1.0144927536231894, \"x2\": -5.942028985507246, \"y2\": 1.304347826086957, \"center_x\": -6.08695652173913, \"center_y\": 1.1594202898550732, \"value_uncond\": 3.210579104052153e-05}, {\"x\": -5.942028985507246, \"y\": 1.0144927536231894, \"x2\": -5.6521739130434785, \"y2\": 1.304347826086957, \"center_x\": -5.797101449275362, \"center_y\": 1.1594202898550732, \"value_uncond\": 4.442925477702533e-05}, {\"x\": -5.6521739130434785, \"y\": 1.0144927536231894, \"x2\": -5.362318840579711, \"y2\": 1.304347826086957, \"center_x\": -5.507246376811595, \"center_y\": 1.1594202898550732, \"value_uncond\": 6.09116686958249e-05}, {\"x\": -5.36231884057971, \"y\": 1.0144927536231894, \"x2\": -5.072463768115942, \"y2\": 1.304347826086957, \"center_x\": -5.217391304347826, \"center_y\": 1.1594202898550732, \"value_uncond\": 8.273281097165984e-05}, {\"x\": -5.0724637681159415, \"y\": 1.0144927536231894, \"x2\": -4.782608695652174, \"y2\": 1.304347826086957, \"center_x\": -4.927536231884058, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.00011132709535568892}, {\"x\": -4.782608695652174, \"y\": 1.0144927536231894, \"x2\": -4.492753623188406, \"y2\": 1.304347826086957, \"center_x\": -4.63768115942029, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.00014841226398282928}, {\"x\": -4.492753623188405, \"y\": 1.0144927536231894, \"x2\": -4.202898550724638, \"y2\": 1.304347826086957, \"center_x\": -4.3478260869565215, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0001960128380658796}, {\"x\": -4.202898550724638, \"y\": 1.0144927536231894, \"x2\": -3.91304347826087, \"y2\": 1.304347826086957, \"center_x\": -4.057971014492754, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0002564750115807015}, {\"x\": -3.913043478260869, \"y\": 1.0144927536231894, \"x2\": -3.6231884057971016, \"y2\": 1.304347826086957, \"center_x\": -3.7681159420289854, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0003324691965431773}, {\"x\": -3.6231884057971016, \"y\": 1.0144927536231894, \"x2\": -3.333333333333334, \"y2\": 1.304347826086957, \"center_x\": -3.4782608695652177, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0004269761178313679}, {\"x\": -3.333333333333333, \"y\": 1.0144927536231894, \"x2\": -3.0434782608695654, \"y2\": 1.304347826086957, \"center_x\": -3.1884057971014492, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0005432522941958565}, {\"x\": -3.0434782608695645, \"y\": 1.0144927536231894, \"x2\": -2.753623188405797, \"y2\": 1.304347826086957, \"center_x\": -2.8985507246376807, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0006847710137725129}, {\"x\": -2.753623188405797, \"y\": 1.0144927536231894, \"x2\": -2.4637681159420293, \"y2\": 1.304347826086957, \"center_x\": -2.608695652173913, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0008551355912321876}, {\"x\": -2.4637681159420284, \"y\": 1.0144927536231894, \"x2\": -2.1739130434782608, \"y2\": 1.304347826086957, \"center_x\": -2.3188405797101446, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0010579628329700835}, {\"x\": -2.1739130434782608, \"y\": 1.0144927536231894, \"x2\": -1.8840579710144931, \"y2\": 1.304347826086957, \"center_x\": -2.028985507246377, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0012967362567683765}, {\"x\": -1.8840579710144922, \"y\": 1.0144927536231894, \"x2\": -1.5942028985507246, \"y2\": 1.304347826086957, \"center_x\": -1.7391304347826084, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.001574630689078329}, {\"x\": -1.5942028985507246, \"y\": 1.0144927536231894, \"x2\": -1.304347826086957, \"y2\": 1.304347826086957, \"center_x\": -1.4492753623188408, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0018943123190095946}, {\"x\": -1.304347826086957, \"y\": 1.0144927536231894, \"x2\": -1.0144927536231894, \"y2\": 1.304347826086957, \"center_x\": -1.1594202898550732, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.002257720987760061}, {\"x\": -1.0144927536231876, \"y\": 1.0144927536231894, \"x2\": -0.72463768115942, \"y2\": 1.304347826086957, \"center_x\": -0.8695652173913038, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.002665844243253208}, {\"x\": -0.72463768115942, \"y\": 1.0144927536231894, \"x2\": -0.43478260869565233, \"y2\": 1.304347826086957, \"center_x\": -0.5797101449275361, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0031184952515928535}, {\"x\": -0.43478260869565233, \"y\": 1.0144927536231894, \"x2\": -0.1449275362318847, \"y2\": 1.304347826086957, \"center_x\": -0.2898550724637685, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.003614108757063738}, {\"x\": -0.14492753623188293, \"y\": 1.0144927536231894, \"x2\": 0.1449275362318847, \"y2\": 1.304347826086957, \"center_x\": 8.881784197001252e-16, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.004149570639951545}, {\"x\": 0.1449275362318847, \"y\": 1.0144927536231894, \"x2\": 0.43478260869565233, \"y2\": 1.304347826086957, \"center_x\": 0.2898550724637685, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.004720096976656257}, {\"x\": 0.43478260869565233, \"y\": 1.0144927536231894, \"x2\": 0.72463768115942, \"y2\": 1.304347826086957, \"center_x\": 0.5797101449275361, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.005319177653177842}, {\"x\": 0.72463768115942, \"y\": 1.0144927536231894, \"x2\": 1.0144927536231876, \"y2\": 1.304347826086957, \"center_x\": 0.8695652173913038, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.005938597400192714}, {\"x\": 1.0144927536231894, \"y\": 1.0144927536231894, \"x2\": 1.304347826086957, \"y2\": 1.304347826086957, \"center_x\": 1.1594202898550732, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.006568543597186876}, {\"x\": 1.304347826086957, \"y\": 1.0144927536231894, \"x2\": 1.5942028985507246, \"y2\": 1.304347826086957, \"center_x\": 1.4492753623188408, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.007197805456502516}, {\"x\": 1.5942028985507246, \"y\": 1.0144927536231894, \"x2\": 1.8840579710144922, \"y2\": 1.304347826086957, \"center_x\": 1.7391304347826084, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.007814063503488382}, {\"x\": 1.884057971014494, \"y\": 1.0144927536231894, \"x2\": 2.1739130434782616, \"y2\": 1.304347826086957, \"center_x\": 2.028985507246378, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.00840426199989184}, {\"x\": 2.1739130434782616, \"y\": 1.0144927536231894, \"x2\": 2.4637681159420293, \"y2\": 1.304347826086957, \"center_x\": 2.3188405797101455, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.008955050597924176}, {\"x\": 2.4637681159420293, \"y\": 1.0144927536231894, \"x2\": 2.753623188405797, \"y2\": 1.304347826086957, \"center_x\": 2.608695652173913, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.00945327560545279}, {\"x\": 2.753623188405797, \"y\": 1.0144927536231894, \"x2\": 3.0434782608695645, \"y2\": 1.304347826086957, \"center_x\": 2.8985507246376807, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.009886496340014353}, {\"x\": 3.0434782608695663, \"y\": 1.0144927536231894, \"x2\": 3.333333333333334, \"y2\": 1.304347826086957, \"center_x\": 3.18840579710145, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.010243498653032564}, {\"x\": 3.333333333333334, \"y\": 1.0144927536231894, \"x2\": 3.6231884057971016, \"y2\": 1.304347826086957, \"center_x\": 3.4782608695652177, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.010514776212139686}, {\"x\": 3.6231884057971016, \"y\": 1.0144927536231894, \"x2\": 3.913043478260869, \"y2\": 1.304347826086957, \"center_x\": 3.7681159420289854, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.01069295078060424}, {\"x\": 3.913043478260871, \"y\": 1.0144927536231894, \"x2\": 4.202898550724639, \"y2\": 1.304347826086957, \"center_x\": 4.057971014492755, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.010773105581303807}, {\"x\": 4.202898550724639, \"y\": 1.0144927536231894, \"x2\": 4.492753623188406, \"y2\": 1.304347826086957, \"center_x\": 4.347826086956522, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.010753010727229628}, {\"x\": 4.492753623188406, \"y\": 1.0144927536231894, \"x2\": 4.782608695652174, \"y2\": 1.304347826086957, \"center_x\": 4.63768115942029, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.010633226293254413}, {\"x\": 4.782608695652174, \"y\": 1.0144927536231894, \"x2\": 5.0724637681159415, \"y2\": 1.304347826086957, \"center_x\": 4.927536231884058, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.010417076379771448}, {\"x\": 5.072463768115943, \"y\": 1.0144927536231894, \"x2\": 5.362318840579711, \"y2\": 1.304347826086957, \"center_x\": 5.217391304347827, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0101104958445195}, {\"x\": 5.362318840579711, \"y\": 1.0144927536231894, \"x2\": 5.6521739130434785, \"y2\": 1.304347826086957, \"center_x\": 5.507246376811595, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.009721759565745867}, {\"x\": 5.6521739130434785, \"y\": 1.0144927536231894, \"x2\": 5.942028985507246, \"y2\": 1.304347826086957, \"center_x\": 5.797101449275362, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.009261111473147477}, {\"x\": 5.942028985507246, \"y\": 1.0144927536231894, \"x2\": 6.231884057971014, \"y2\": 1.304347826086957, \"center_x\": 6.08695652173913, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.008740316549850866}, {\"x\": 6.2318840579710155, \"y\": 1.0144927536231894, \"x2\": 6.521739130434783, \"y2\": 1.304347826086957, \"center_x\": 6.376811594202899, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.008172163115959143}, {\"x\": 6.521739130434785, \"y\": 1.0144927536231894, \"x2\": 6.8115942028985526, \"y2\": 1.304347826086957, \"center_x\": 6.666666666666669, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0075699446803392575}, {\"x\": 6.811594202898551, \"y\": 1.0144927536231894, \"x2\": 7.101449275362318, \"y2\": 1.304347826086957, \"center_x\": 6.956521739130435, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.006946950423113533}, {\"x\": 7.10144927536232, \"y\": 1.0144927536231894, \"x2\": 7.391304347826088, \"y2\": 1.304347826086957, \"center_x\": 7.246376811594204, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.006315991078081992}, {\"x\": 7.391304347826086, \"y\": 1.0144927536231894, \"x2\": 7.681159420289854, \"y2\": 1.304347826086957, \"center_x\": 7.53623188405797, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0056889829307097284}, {\"x\": 7.681159420289855, \"y\": 1.0144927536231894, \"x2\": 7.971014492753623, \"y2\": 1.304347826086957, \"center_x\": 7.826086956521739, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0050766072785315055}, {\"x\": 7.971014492753625, \"y\": 1.0144927536231894, \"x2\": 8.260869565217392, \"y2\": 1.304347826086957, \"center_x\": 8.115942028985508, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.004488056545781094}, {\"x\": 8.26086956521739, \"y\": 1.0144927536231894, \"x2\": 8.550724637681158, \"y2\": 1.304347826086957, \"center_x\": 8.405797101449274, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.003930871857686288}, {\"x\": 8.55072463768116, \"y\": 1.0144927536231894, \"x2\": 8.840579710144928, \"y2\": 1.304347826086957, \"center_x\": 8.695652173913043, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0034108707873688375}, {\"x\": 8.84057971014493, \"y\": 1.0144927536231894, \"x2\": 9.130434782608697, \"y2\": 1.304347826086957, \"center_x\": 8.985507246376812, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0029321586374448324}, {\"x\": 9.130434782608695, \"y\": 1.0144927536231894, \"x2\": 9.420289855072463, \"y2\": 1.304347826086957, \"center_x\": 9.275362318840578, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0024972123447709275}, {\"x\": 9.420289855072465, \"y\": 1.0144927536231894, \"x2\": 9.710144927536232, \"y2\": 1.304347826086957, \"center_x\": 9.565217391304348, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.00210702310411812}, {\"x\": 9.710144927536234, \"y\": 1.0144927536231894, \"x2\": 10.000000000000002, \"y2\": 1.304347826086957, \"center_x\": 9.855072463768117, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0017612821633085447}, {\"x\": 10.0, \"y\": 1.0144927536231894, \"x2\": 10.289855072463768, \"y2\": 1.304347826086957, \"center_x\": 10.144927536231883, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0014585938923575234}, {\"x\": -10.0, \"y\": 1.304347826086957, \"x2\": -9.710144927536232, \"y2\": 1.5942028985507246, \"center_x\": -9.855072463768117, \"center_y\": 1.4492753623188408, \"value_uncond\": 2.2042965122937443e-07}, {\"x\": -9.710144927536232, \"y\": 1.304347826086957, \"x2\": -9.420289855072465, \"y2\": 1.5942028985507246, \"center_x\": -9.565217391304348, \"center_y\": 1.4492753623188408, \"value_uncond\": 3.4439756997730165e-07}, {\"x\": -9.420289855072463, \"y\": 1.304347826086957, \"x2\": -9.130434782608695, \"y2\": 1.5942028985507246, \"center_x\": -9.275362318840578, \"center_y\": 1.4492753623188408, \"value_uncond\": 5.330843807487501e-07}, {\"x\": -9.130434782608695, \"y\": 1.304347826086957, \"x2\": -8.840579710144928, \"y2\": 1.5942028985507246, \"center_x\": -8.985507246376812, \"center_y\": 1.4492753623188408, \"value_uncond\": 8.17480970850127e-07}, {\"x\": -8.840579710144928, \"y\": 1.304347826086957, \"x2\": -8.55072463768116, \"y2\": 1.5942028985507246, \"center_x\": -8.695652173913043, \"center_y\": 1.4492753623188408, \"value_uncond\": 1.241952999291727e-06}, {\"x\": -8.55072463768116, \"y\": 1.304347826086957, \"x2\": -8.260869565217392, \"y2\": 1.5942028985507246, \"center_x\": -8.405797101449277, \"center_y\": 1.4492753623188408, \"value_uncond\": 1.8692977522789205e-06}, {\"x\": -8.26086956521739, \"y\": 1.304347826086957, \"x2\": -7.971014492753623, \"y2\": 1.5942028985507246, \"center_x\": -8.115942028985508, \"center_y\": 1.4492753623188408, \"value_uncond\": 2.7873892541727638e-06}, {\"x\": -7.971014492753623, \"y\": 1.304347826086957, \"x2\": -7.681159420289855, \"y2\": 1.5942028985507246, \"center_x\": -7.826086956521739, \"center_y\": 1.4492753623188408, \"value_uncond\": 4.117774630909027e-06}, {\"x\": -7.681159420289855, \"y\": 1.304347826086957, \"x2\": -7.391304347826088, \"y2\": 1.5942028985507246, \"center_x\": -7.536231884057972, \"center_y\": 1.4492753623188408, \"value_uncond\": 6.026613504221936e-06}, {\"x\": -7.391304347826087, \"y\": 1.304347826086957, \"x2\": -7.101449275362319, \"y2\": 1.5942028985507246, \"center_x\": -7.246376811594203, \"center_y\": 1.4492753623188408, \"value_uncond\": 8.738359779452854e-06}, {\"x\": -7.101449275362318, \"y\": 1.304347826086957, \"x2\": -6.811594202898551, \"y2\": 1.5942028985507246, \"center_x\": -6.956521739130435, \"center_y\": 1.4492753623188408, \"value_uncond\": 1.2552560335194498e-05}, {\"x\": -6.811594202898551, \"y\": 1.304347826086957, \"x2\": -6.521739130434783, \"y2\": 1.5942028985507246, \"center_x\": -6.666666666666667, \"center_y\": 1.4492753623188408, \"value_uncond\": 1.7864074774279058e-05}, {\"x\": -6.521739130434782, \"y\": 1.304347826086957, \"x2\": -6.231884057971015, \"y2\": 1.5942028985507246, \"center_x\": -6.3768115942028984, \"center_y\": 1.4492753623188408, \"value_uncond\": 2.5186890427292652e-05}, {\"x\": -6.231884057971014, \"y\": 1.304347826086957, \"x2\": -5.942028985507246, \"y2\": 1.5942028985507246, \"center_x\": -6.08695652173913, \"center_y\": 1.4492753623188408, \"value_uncond\": 3.518150325374492e-05}, {\"x\": -5.942028985507246, \"y\": 1.304347826086957, \"x2\": -5.6521739130434785, \"y2\": 1.5942028985507246, \"center_x\": -5.797101449275362, \"center_y\": 1.4492753623188408, \"value_uncond\": 4.8685546153544873e-05}, {\"x\": -5.6521739130434785, \"y\": 1.304347826086957, \"x2\": -5.362318840579711, \"y2\": 1.5942028985507246, \"center_x\": -5.507246376811595, \"center_y\": 1.4492753623188408, \"value_uncond\": 6.674696373961032e-05}, {\"x\": -5.36231884057971, \"y\": 1.304347826086957, \"x2\": -5.072463768115942, \"y2\": 1.5942028985507246, \"center_x\": -5.217391304347826, \"center_y\": 1.4492753623188408, \"value_uncond\": 9.065855610650711e-05}, {\"x\": -5.0724637681159415, \"y\": 1.304347826086957, \"x2\": -4.782608695652174, \"y2\": 1.5942028985507246, \"center_x\": -4.927536231884058, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.00012199215283444759}, {\"x\": -4.782608695652174, \"y\": 1.304347826086957, \"x2\": -4.492753623188406, \"y2\": 1.5942028985507246, \"center_x\": -4.63768115942029, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.00016263005454740363}, {\"x\": -4.492753623188405, \"y\": 1.304347826086957, \"x2\": -4.202898550724638, \"y2\": 1.5942028985507246, \"center_x\": -4.3478260869565215, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0002147907301672421}, {\"x\": -4.202898550724638, \"y\": 1.304347826086957, \"x2\": -3.91304347826087, \"y2\": 1.5942028985507246, \"center_x\": -4.057971014492754, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0002810451374034776}, {\"x\": -3.913043478260869, \"y\": 1.304347826086957, \"x2\": -3.6231884057971016, \"y2\": 1.5942028985507246, \"center_x\": -3.7681159420289854, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.00036431951186597375}, {\"x\": -3.6231884057971016, \"y\": 1.304347826086957, \"x2\": -3.333333333333334, \"y2\": 1.5942028985507246, \"center_x\": -3.4782608695652177, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0004678801297808369}, {\"x\": -3.333333333333333, \"y\": 1.304347826086957, \"x2\": -3.0434782608695654, \"y2\": 1.5942028985507246, \"center_x\": -3.1884057971014492, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0005952954821058184}, {\"x\": -3.0434782608695645, \"y\": 1.304347826086957, \"x2\": -2.753623188405797, \"y2\": 1.5942028985507246, \"center_x\": -2.8985507246376807, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0007503715955386884}, {\"x\": -2.753623188405797, \"y\": 1.304347826086957, \"x2\": -2.4637681159420293, \"y2\": 1.5942028985507246, \"center_x\": -2.608695652173913, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0009370569797628511}, {\"x\": -2.4637681159420284, \"y\": 1.304347826086957, \"x2\": -2.1739130434782608, \"y2\": 1.5942028985507246, \"center_x\": -2.3188405797101446, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0011593149286837688}, {\"x\": -2.1739130434782608, \"y\": 1.304347826086957, \"x2\": -1.8840579710144931, \"y2\": 1.5942028985507246, \"center_x\": -2.028985507246377, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0014209626786384445}, {\"x\": -1.8840579710144922, \"y\": 1.304347826086957, \"x2\": -1.5942028985507246, \"y2\": 1.5942028985507246, \"center_x\": -1.7391304347826084, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0017254792022204585}, {\"x\": -1.5942028985507246, \"y\": 1.304347826086957, \"x2\": -1.304347826086957, \"y2\": 1.5942028985507246, \"center_x\": -1.4492753623188408, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0020757861075819967}, {\"x\": -1.304347826086957, \"y\": 1.304347826086957, \"x2\": -1.0144927536231894, \"y2\": 1.5942028985507246, \"center_x\": -1.1594202898550732, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.002474009071344113}, {\"x\": -1.0144927536231876, \"y\": 1.304347826086957, \"x2\": -0.72463768115942, \"y2\": 1.5942028985507246, \"center_x\": -0.8695652173913038, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.002921230247827166}, {\"x\": -0.72463768115942, \"y\": 1.304347826086957, \"x2\": -0.43478260869565233, \"y2\": 1.5942028985507246, \"center_x\": -0.5797101449275361, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0034172449045790543}, {\"x\": -0.43478260869565233, \"y\": 1.304347826086957, \"x2\": -0.1449275362318847, \"y2\": 1.5942028985507246, \"center_x\": -0.2898550724637685, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.003960337835487279}, {\"x\": -0.14492753623188293, \"y\": 1.304347826086957, \"x2\": 0.1449275362318847, \"y2\": 1.5942028985507246, \"center_x\": 8.881784197001252e-16, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.004547096590357931}, {\"x\": 0.1449275362318847, \"y\": 1.304347826086957, \"x2\": 0.43478260869565233, \"y2\": 1.5942028985507246, \"center_x\": 0.2898550724637685, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.005172278949072928}, {\"x\": 0.43478260869565233, \"y\": 1.304347826086957, \"x2\": 0.72463768115942, \"y2\": 1.5942028985507246, \"center_x\": 0.5797101449275361, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.005828751133287251}, {\"x\": 0.72463768115942, \"y\": 1.304347826086957, \"x2\": 1.0144927536231876, \"y2\": 1.5942028985507246, \"center_x\": 0.8695652173913038, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.006507510856650965}, {\"x\": 1.0144927536231894, \"y\": 1.304347826086957, \"x2\": 1.304347826086957, \"y2\": 1.5942028985507246, \"center_x\": 1.1594202898550732, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.007197805456502516}, {\"x\": 1.304347826086957, \"y\": 1.304347826086957, \"x2\": 1.5942028985507246, \"y2\": 1.5942028985507246, \"center_x\": 1.4492753623188408, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.007887350159606992}, {\"x\": 1.5942028985507246, \"y\": 1.304347826086957, \"x2\": 1.8840579710144922, \"y2\": 1.5942028985507246, \"center_x\": 1.7391304347826084, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.008562645294301409}, {\"x\": 1.884057971014494, \"y\": 1.304347826086957, \"x2\": 2.1739130434782616, \"y2\": 1.5942028985507246, \"center_x\": 2.028985507246378, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.009209384391785931}, {\"x\": 2.1739130434782616, \"y\": 1.304347826086957, \"x2\": 2.4637681159420293, \"y2\": 1.5942028985507246, \"center_x\": 2.3188405797101455, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.009812938150338193}, {\"x\": 2.4637681159420293, \"y\": 1.304347826086957, \"x2\": 2.753623188405797, \"y2\": 1.5942028985507246, \"center_x\": 2.608695652173913, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.010358892763365544}, {\"x\": 2.753623188405797, \"y\": 1.304347826086957, \"x2\": 3.0434782608695645, \"y2\": 1.5942028985507246, \"center_x\": 2.8985507246376807, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.010833615739769736}, {\"x\": 3.0434782608695663, \"y\": 1.304347826086957, \"x2\": 3.333333333333334, \"y2\": 1.5942028985507246, \"center_x\": 3.18840579710145, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.01122481862342373}, {\"x\": 3.333333333333334, \"y\": 1.304347826086957, \"x2\": 3.6231884057971016, \"y2\": 1.5942028985507246, \"center_x\": 3.4782608695652177, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.011522084382001354}, {\"x\": 3.6231884057971016, \"y\": 1.304347826086957, \"x2\": 3.913043478260869, \"y2\": 1.5942028985507246, \"center_x\": 3.7681159420289854, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.011717327948878703}, {\"x\": 3.913043478260871, \"y\": 1.304347826086957, \"x2\": 4.202898550724639, \"y2\": 1.5942028985507246, \"center_x\": 4.057971014492755, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.01180516152314124}, {\"x\": 4.202898550724639, \"y\": 1.304347826086957, \"x2\": 4.492753623188406, \"y2\": 1.5942028985507246, \"center_x\": 4.347826086956522, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.011783141596172239}, {\"x\": 4.492753623188406, \"y\": 1.304347826086957, \"x2\": 4.782608695652174, \"y2\": 1.5942028985507246, \"center_x\": 4.63768115942029, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.011651881897623518}, {\"x\": 4.782608695652174, \"y\": 1.304347826086957, \"x2\": 5.0724637681159415, \"y2\": 1.5942028985507246, \"center_x\": 4.927536231884058, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.011415024974369399}, {\"x\": 5.072463768115943, \"y\": 1.304347826086957, \"x2\": 5.362318840579711, \"y2\": 1.5942028985507246, \"center_x\": 5.217391304347827, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.01107907423934817}, {\"x\": 5.362318840579711, \"y\": 1.304347826086957, \"x2\": 5.6521739130434785, \"y2\": 1.5942028985507246, \"center_x\": 5.507246376811595, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.010653097298326468}, {\"x\": 5.6521739130434785, \"y\": 1.304347826086957, \"x2\": 5.942028985507246, \"y2\": 1.5942028985507246, \"center_x\": 5.797101449275362, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.010148319442265323}, {\"x\": 5.942028985507246, \"y\": 1.304347826086957, \"x2\": 6.231884057971014, \"y2\": 1.5942028985507246, \"center_x\": 6.08695652173913, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.009577632731404702}, {\"x\": 6.2318840579710155, \"y\": 1.304347826086957, \"x2\": 6.521739130434783, \"y2\": 1.5942028985507246, \"center_x\": 6.376811594202899, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.008955050597924173}, {\"x\": 6.521739130434785, \"y\": 1.304347826086957, \"x2\": 6.8115942028985526, \"y2\": 1.5942028985507246, \"center_x\": 6.666666666666669, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.008295140059495587}, {\"x\": 6.811594202898551, \"y\": 1.304347826086957, \"x2\": 7.101449275362318, \"y2\": 1.5942028985507246, \"center_x\": 6.956521739130435, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.007612463390355489}, {\"x\": 7.10144927536232, \"y\": 1.304347826086957, \"x2\": 7.391304347826088, \"y2\": 1.5942028985507246, \"center_x\": 7.246376811594204, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.00692105858359676}, {\"x\": 7.391304347826086, \"y\": 1.304347826086957, \"x2\": 7.681159420289854, \"y2\": 1.5942028985507246, \"center_x\": 7.53623188405797, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.00623398349645561}, {\"x\": 7.681159420289855, \"y\": 1.304347826086957, \"x2\": 7.971014492753623, \"y2\": 1.5942028985507246, \"center_x\": 7.826086956521739, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.005562942687262318}, {\"x\": 7.971014492753625, \"y\": 1.304347826086957, \"x2\": 8.260869565217392, \"y2\": 1.5942028985507246, \"center_x\": 8.115942028985508, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0049180092080305235}, {\"x\": 8.26086956521739, \"y\": 1.304347826086957, \"x2\": 8.550724637681158, \"y2\": 1.5942028985507246, \"center_x\": 8.405797101449274, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.004307446618483881}, {\"x\": 8.55072463768116, \"y\": 1.304347826086957, \"x2\": 8.840579710144928, \"y2\": 1.5942028985507246, \"center_x\": 8.695652173913043, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.003737629811159793}, {\"x\": 8.84057971014493, \"y\": 1.304347826086957, \"x2\": 9.130434782608697, \"y2\": 1.5942028985507246, \"center_x\": 8.985507246376812, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0032130573737791934}, {\"x\": 9.130434782608695, \"y\": 1.304347826086957, \"x2\": 9.420289855072463, \"y2\": 1.5942028985507246, \"center_x\": 9.275362318840578, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.002736443532008462}, {\"x\": 9.420289855072465, \"y\": 1.304347826086957, \"x2\": 9.710144927536232, \"y2\": 1.5942028985507246, \"center_x\": 9.565217391304348, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0023088744363809082}, {\"x\": 9.710144927536234, \"y\": 1.304347826086957, \"x2\": 10.000000000000002, \"y2\": 1.5942028985507246, \"center_x\": 9.855072463768117, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0019300117564770617}, {\"x\": 10.0, \"y\": 1.304347826086957, \"x2\": 10.289855072463768, \"y2\": 1.5942028985507246, \"center_x\": 10.144927536231883, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.001598326161940756}, {\"x\": -10.0, \"y\": 1.5942028985507246, \"x2\": -9.710144927536232, \"y2\": 1.8840579710144922, \"center_x\": -9.855072463768117, \"center_y\": 1.7391304347826084, \"value_uncond\": 2.3930228500439113e-07}, {\"x\": -9.710144927536232, \"y\": 1.5942028985507246, \"x2\": -9.420289855072465, \"y2\": 1.8840579710144922, \"center_x\": -9.565217391304348, \"center_y\": 1.7391304347826084, \"value_uncond\": 3.738840259732958e-07}, {\"x\": -9.420289855072463, \"y\": 1.5942028985507246, \"x2\": -9.130434782608695, \"y2\": 1.8840579710144922, \"center_x\": -9.275362318840578, \"center_y\": 1.7391304347826084, \"value_uncond\": 5.787257281488953e-07}, {\"x\": -9.130434782608695, \"y\": 1.5942028985507246, \"x2\": -8.840579710144928, \"y2\": 1.8840579710144922, \"center_x\": -8.985507246376812, \"center_y\": 1.7391304347826084, \"value_uncond\": 8.874716408659564e-07}, {\"x\": -8.840579710144928, \"y\": 1.5942028985507246, \"x2\": -8.55072463768116, \"y2\": 1.8840579710144922, \"center_x\": -8.695652173913043, \"center_y\": 1.7391304347826084, \"value_uncond\": 1.3482858995648677e-06}, {\"x\": -8.55072463768116, \"y\": 1.5942028985507246, \"x2\": -8.260869565217392, \"y2\": 1.8840579710144922, \"center_x\": -8.405797101449277, \"center_y\": 1.7391304347826084, \"value_uncond\": 2.0293423365645064e-06}, {\"x\": -8.26086956521739, \"y\": 1.5942028985507246, \"x2\": -7.971014492753623, \"y2\": 1.8840579710144922, \"center_x\": -8.115942028985508, \"center_y\": 1.7391304347826084, \"value_uncond\": 3.0260385297535673e-06}, {\"x\": -7.971014492753623, \"y\": 1.5942028985507246, \"x2\": -7.681159420289855, \"y2\": 1.8840579710144922, \"center_x\": -7.826086956521739, \"center_y\": 1.7391304347826084, \"value_uncond\": 4.470328165080958e-06}, {\"x\": -7.681159420289855, \"y\": 1.5942028985507246, \"x2\": -7.391304347826088, \"y2\": 1.8840579710144922, \"center_x\": -7.536231884057972, \"center_y\": 1.7391304347826084, \"value_uncond\": 6.5425970342707065e-06}, {\"x\": -7.391304347826087, \"y\": 1.5942028985507246, \"x2\": -7.101449275362319, \"y2\": 1.8840579710144922, \"center_x\": -7.246376811594203, \"center_y\": 1.7391304347826084, \"value_uncond\": 9.486516222981147e-06}, {\"x\": -7.101449275362318, \"y\": 1.5942028985507246, \"x2\": -6.811594202898551, \"y2\": 1.8840579710144922, \"center_x\": -6.956521739130435, \"center_y\": 1.7391304347826084, \"value_uncond\": 1.362727906211575e-05}, {\"x\": -6.811594202898551, \"y\": 1.5942028985507246, \"x2\": -6.521739130434783, \"y2\": 1.8840579710144922, \"center_x\": -6.666666666666667, \"center_y\": 1.7391304347826084, \"value_uncond\": 1.9393552043168186e-05}, {\"x\": -6.521739130434782, \"y\": 1.5942028985507246, \"x2\": -6.231884057971015, \"y2\": 1.8840579710144922, \"center_x\": -6.3768115942028984, \"center_y\": 1.7391304347826084, \"value_uncond\": 2.7343328802596077e-05}, {\"x\": -6.231884057971014, \"y\": 1.5942028985507246, \"x2\": -5.942028985507246, \"y2\": 1.8840579710144922, \"center_x\": -6.08695652173913, \"center_y\": 1.7391304347826084, \"value_uncond\": 3.819365530706185e-05}, {\"x\": -5.942028985507246, \"y\": 1.5942028985507246, \"x2\": -5.6521739130434785, \"y2\": 1.8840579710144922, \"center_x\": -5.797101449275362, \"center_y\": 1.7391304347826084, \"value_uncond\": 5.285388048410381e-05}, {\"x\": -5.6521739130434785, \"y\": 1.5942028985507246, \"x2\": -5.362318840579711, \"y2\": 1.8840579710144922, \"center_x\": -5.507246376811595, \"center_y\": 1.7391304347826084, \"value_uncond\": 7.246167133555524e-05}, {\"x\": -5.36231884057971, \"y\": 1.5942028985507246, \"x2\": -5.072463768115942, \"y2\": 1.8840579710144922, \"center_x\": -5.217391304347826, \"center_y\": 1.7391304347826084, \"value_uncond\": 9.8420514256999e-05}, {\"x\": -5.0724637681159415, \"y\": 1.5942028985507246, \"x2\": -4.782608695652174, \"y2\": 1.8840579710144922, \"center_x\": -4.927536231884058, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.00013243681493426047}, {\"x\": -4.782608695652174, \"y\": 1.5942028985507246, \"x2\": -4.492753623188406, \"y2\": 1.8840579710144922, \"center_x\": -4.63768115942029, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.00017655403184885278}, {\"x\": -4.492753623188405, \"y\": 1.5942028985507246, \"x2\": -4.202898550724638, \"y2\": 1.8840579710144922, \"center_x\": -4.3478260869565215, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.00023318057366654825}, {\"x\": -4.202898550724638, \"y\": 1.5942028985507246, \"x2\": -3.91304347826087, \"y2\": 1.8840579710144922, \"center_x\": -4.057971014492754, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.00030510751704652234}, {\"x\": -3.913043478260869, \"y\": 1.5942028985507246, \"x2\": -3.6231884057971016, \"y2\": 1.8840579710144922, \"center_x\": -3.7681159420289854, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.00039551163455088756}, {\"x\": -3.6231884057971016, \"y\": 1.5942028985507246, \"x2\": -3.333333333333334, \"y2\": 1.8840579710144922, \"center_x\": -3.4782608695652177, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0005079388527825471}, {\"x\": -3.333333333333333, \"y\": 1.5942028985507246, \"x2\": -3.0434782608695654, \"y2\": 1.8840579710144922, \"center_x\": -3.1884057971014492, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0006462631879432444}, {\"x\": -3.0434782608695645, \"y\": 1.5942028985507246, \"x2\": -2.753623188405797, \"y2\": 1.8840579710144922, \"center_x\": -2.8985507246376807, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0008146165291889287}, {\"x\": -2.753623188405797, \"y\": 1.5942028985507246, \"x2\": -2.4637681159420293, \"y2\": 1.8840579710144922, \"center_x\": -2.608695652173913, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0010172854476969823}, {\"x\": -2.4637681159420284, \"y\": 1.5942028985507246, \"x2\": -2.1739130434782608, \"y2\": 1.8840579710144922, \"center_x\": -2.3188405797101446, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0012585725646548536}, {\"x\": -2.1739130434782608, \"y\": 1.5942028985507246, \"x2\": -1.8840579710144931, \"y2\": 1.8840579710144922, \"center_x\": -2.028985507246377, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0015426219385989153}, {\"x\": -1.8840579710144922, \"y\": 1.5942028985507246, \"x2\": -1.5942028985507246, \"y2\": 1.8840579710144922, \"center_x\": -1.7391304347826084, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0018732104030289617}, {\"x\": -1.5942028985507246, \"y\": 1.5942028985507246, \"x2\": -1.304347826086957, \"y2\": 1.8840579710144922, \"center_x\": -1.4492753623188408, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0022535097068581106}, {\"x\": -1.304347826086957, \"y\": 1.5942028985507246, \"x2\": -1.0144927536231894, \"y2\": 1.8840579710144922, \"center_x\": -1.1594202898550732, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0026858275218073005}, {\"x\": -1.0144927536231876, \"y\": 1.5942028985507246, \"x2\": -0.72463768115942, \"y2\": 1.8840579710144922, \"center_x\": -0.8695652173913038, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0031713386535351415}, {\"x\": -0.72463768115942, \"y\": 1.5942028985507246, \"x2\": -0.43478260869565233, \"y2\": 1.8840579710144922, \"center_x\": -0.5797101449275361, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.003709820840910567}, {\"x\": -0.43478260869565233, \"y\": 1.5942028985507246, \"x2\": -0.1449275362318847, \"y2\": 1.8840579710144922, \"center_x\": -0.2898550724637685, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.004299412026176441}, {\"x\": -0.14492753623188293, \"y\": 1.5942028985507246, \"x2\": 0.1449275362318847, \"y2\": 1.8840579710144922, \"center_x\": 8.881784197001252e-16, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.004936407593713624}, {\"x\": 0.1449275362318847, \"y\": 1.5942028985507246, \"x2\": 0.43478260869565233, \"y2\": 1.8840579710144922, \"center_x\": 0.2898550724637685, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.005615116497667997}, {\"x\": 0.43478260869565233, \"y\": 1.5942028985507246, \"x2\": 0.72463768115942, \"y2\": 1.8840579710144922, \"center_x\": 0.5797101449275361, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.00632779418348823}, {\"x\": 0.72463768115942, \"y\": 1.5942028985507246, \"x2\": 1.0144927536231876, \"y2\": 1.8840579710144922, \"center_x\": 0.8695652173913038, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.007064667611649967}, {\"x\": 1.0144927536231894, \"y\": 1.5942028985507246, \"x2\": 1.304347826086957, \"y2\": 1.8840579710144922, \"center_x\": 1.1594202898550732, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.007814063503488382}, {\"x\": 1.304347826086957, \"y\": 1.5942028985507246, \"x2\": 1.5942028985507246, \"y2\": 1.8840579710144922, \"center_x\": 1.4492753623188408, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.008562645294301409}, {\"x\": 1.5942028985507246, \"y\": 1.5942028985507246, \"x2\": 1.8840579710144922, \"y2\": 1.8840579710144922, \"center_x\": 1.7391304347826084, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.009295757504403146}, {\"x\": 1.884057971014494, \"y\": 1.5942028985507246, \"x2\": 2.1739130434782616, \"y2\": 1.8840579710144922, \"center_x\": 2.028985507246378, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.009997868781023904}, {\"x\": 2.1739130434782616, \"y\": 1.5942028985507246, \"x2\": 2.4637681159420293, \"y2\": 1.8840579710144922, \"center_x\": 2.3188405797101455, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.010653097298326468}, {\"x\": 2.4637681159420293, \"y\": 1.5942028985507246, \"x2\": 2.753623188405797, \"y2\": 1.8840579710144922, \"center_x\": 2.608695652173913, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.011245795175755779}, {\"x\": 2.753623188405797, \"y\": 1.5942028985507246, \"x2\": 3.0434782608695645, \"y2\": 1.8840579710144922, \"center_x\": 2.8985507246376807, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.011761162742523815}, {\"x\": 3.0434782608695663, \"y\": 1.5942028985507246, \"x2\": 3.333333333333334, \"y2\": 1.8840579710144922, \"center_x\": 3.18840579710145, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.012185859435716389}, {\"x\": 3.333333333333334, \"y\": 1.5942028985507246, \"x2\": 3.6231884057971016, \"y2\": 1.8840579710144922, \"center_x\": 3.4782608695652177, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.01250857634283142}, {\"x\": 3.6231884057971016, \"y\": 1.5942028985507246, \"x2\": 3.913043478260869, \"y2\": 1.8840579710144922, \"center_x\": 3.7681159420289854, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.012720536174122625}, {\"x\": 3.913043478260871, \"y\": 1.5942028985507246, \"x2\": 4.202898550724639, \"y2\": 1.8840579710144922, \"center_x\": 4.057971014492755, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.012815889838676837}, {\"x\": 4.202898550724639, \"y\": 1.5942028985507246, \"x2\": 4.492753623188406, \"y2\": 1.8840579710144922, \"center_x\": 4.347826086956522, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.012791984620799281}, {\"x\": 4.492753623188406, \"y\": 1.5942028985507246, \"x2\": 4.782608695652174, \"y2\": 1.8840579710144922, \"center_x\": 4.63768115942029, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.012649486796134982}, {\"x\": 4.782608695652174, \"y\": 1.5942028985507246, \"x2\": 5.0724637681159415, \"y2\": 1.8840579710144922, \"center_x\": 4.927536231884058, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.012392350777284051}, {\"x\": 5.072463768115943, \"y\": 1.5942028985507246, \"x2\": 5.362318840579711, \"y2\": 1.8840579710144922, \"center_x\": 5.217391304347827, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.012027636783086286}, {\"x\": 5.362318840579711, \"y\": 1.5942028985507246, \"x2\": 5.6521739130434785, \"y2\": 1.8840579710144922, \"center_x\": 5.507246376811595, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.011565188764967345}, {\"x\": 5.6521739130434785, \"y\": 1.5942028985507246, \"x2\": 5.942028985507246, \"y2\": 1.8840579710144922, \"center_x\": 5.797101449275362, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.011017193095140902}, {\"x\": 5.942028985507246, \"y\": 1.5942028985507246, \"x2\": 6.231884057971014, \"y2\": 1.8840579710144922, \"center_x\": 6.08695652173913, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.010397645619704042}, {\"x\": 6.2318840579710155, \"y\": 1.5942028985507246, \"x2\": 6.521739130434783, \"y2\": 1.8840579710144922, \"center_x\": 6.376811594202899, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.00972175956574586}, {\"x\": 6.521739130434785, \"y\": 1.5942028985507246, \"x2\": 6.8115942028985526, \"y2\": 1.8840579710144922, \"center_x\": 6.666666666666669, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.009005349142448897}, {\"x\": 6.811594202898551, \"y\": 1.5942028985507246, \"x2\": 7.101449275362318, \"y2\": 1.8840579710144922, \"center_x\": 6.956521739130435, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.008264223409439334}, {\"x\": 7.10144927536232, \"y\": 1.5942028985507246, \"x2\": 7.391304347826088, \"y2\": 1.8840579710144922, \"center_x\": 7.246376811594204, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0075136222575633805}, {\"x\": 7.391304347826086, \"y\": 1.5942028985507246, \"x2\": 7.681159420289854, \"y2\": 1.8840579710144922, \"center_x\": 7.53623188405797, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.006767721525037255}, {\"x\": 7.681159420289855, \"y\": 1.5942028985507246, \"x2\": 7.971014492753623, \"y2\": 1.8840579710144922, \"center_x\": 7.826086956521739, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.006039227885113773}, {\"x\": 7.971014492753625, \"y\": 1.5942028985507246, \"x2\": 8.260869565217392, \"y2\": 1.8840579710144922, \"center_x\": 8.115942028985508, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.005339076819251023}, {\"x\": 8.26086956521739, \"y\": 1.5942028985507246, \"x2\": 8.550724637681158, \"y2\": 1.8840579710144922, \"center_x\": 8.405797101449274, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.004676239392426481}, {\"x\": 8.55072463768116, \"y\": 1.5942028985507246, \"x2\": 8.840579710144928, \"y2\": 1.8840579710144922, \"center_x\": 8.695652173913043, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.004057636299484736}, {\"x\": 8.84057971014493, \"y\": 1.5942028985507246, \"x2\": 9.130434782608697, \"y2\": 1.8840579710144922, \"center_x\": 8.985507246376812, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0034881512859423654}, {\"x\": 9.130434782608695, \"y\": 1.5942028985507246, \"x2\": 9.420289855072463, \"y2\": 1.8840579710144922, \"center_x\": 9.275362318840578, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.002970730962658479}, {\"x\": 9.420289855072465, \"y\": 1.5942028985507246, \"x2\": 9.710144927536232, \"y2\": 1.8840579710144922, \"center_x\": 9.565217391304348, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.002506554473650362}, {\"x\": 9.710144927536234, \"y\": 1.5942028985507246, \"x2\": 10.000000000000002, \"y2\": 1.8840579710144922, \"center_x\": 9.855072463768117, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.002095254521496756}, {\"x\": 10.0, \"y\": 1.5942028985507246, \"x2\": 10.289855072463768, \"y2\": 1.8840579710144922, \"center_x\": 10.144927536231883, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0017351708384128314}, {\"x\": -10.0, \"y\": 1.884057971014494, \"x2\": -9.710144927536232, \"y2\": 2.1739130434782616, \"center_x\": -9.855072463768117, \"center_y\": 2.028985507246378, \"value_uncond\": 2.573768564143178e-07}, {\"x\": -9.710144927536232, \"y\": 1.884057971014494, \"x2\": -9.420289855072465, \"y2\": 2.1739130434782616, \"center_x\": -9.565217391304348, \"center_y\": 2.028985507246378, \"value_uncond\": 4.021235955468218e-07}, {\"x\": -9.420289855072463, \"y\": 1.884057971014494, \"x2\": -9.130434782608695, \"y2\": 2.1739130434782616, \"center_x\": -9.275362318840578, \"center_y\": 2.028985507246378, \"value_uncond\": 6.224370512563913e-07}, {\"x\": -9.130434782608695, \"y\": 1.884057971014494, \"x2\": -8.840579710144928, \"y2\": 2.1739130434782616, \"center_x\": -8.985507246376812, \"center_y\": 2.028985507246378, \"value_uncond\": 9.54502632846757e-07}, {\"x\": -8.840579710144928, \"y\": 1.884057971014494, \"x2\": -8.55072463768116, \"y2\": 2.1739130434782616, \"center_x\": -8.695652173913043, \"center_y\": 2.028985507246378, \"value_uncond\": 1.4501223269614357e-06}, {\"x\": -8.55072463768116, \"y\": 1.884057971014494, \"x2\": -8.260869565217392, \"y2\": 2.1739130434782616, \"center_x\": -8.405797101449277, \"center_y\": 2.028985507246378, \"value_uncond\": 2.1826191553660887e-06}, {\"x\": -8.26086956521739, \"y\": 1.884057971014494, \"x2\": -7.971014492753623, \"y2\": 2.1739130434782616, \"center_x\": -8.115942028985508, \"center_y\": 2.028985507246378, \"value_uncond\": 3.2545961028424198e-06}, {\"x\": -7.971014492753623, \"y\": 1.884057971014494, \"x2\": -7.681159420289855, \"y2\": 2.1739130434782616, \"center_x\": -7.826086956521739, \"center_y\": 2.028985507246378, \"value_uncond\": 4.807973355740461e-06}, {\"x\": -7.681159420289855, \"y\": 1.884057971014494, \"x2\": -7.391304347826088, \"y2\": 2.1739130434782616, \"center_x\": -7.536231884057972, \"center_y\": 2.028985507246378, \"value_uncond\": 7.036761297266066e-06}, {\"x\": -7.391304347826087, \"y\": 1.884057971014494, \"x2\": -7.101449275362319, \"y2\": 2.1739130434782616, \"center_x\": -7.246376811594203, \"center_y\": 2.028985507246378, \"value_uncond\": 1.0203035561275618e-05}, {\"x\": -7.101449275362318, \"y\": 1.884057971014494, \"x2\": -6.811594202898551, \"y2\": 2.1739130434782616, \"center_x\": -6.956521739130435, \"center_y\": 2.028985507246378, \"value_uncond\": 1.465655142584053e-05}, {\"x\": -6.811594202898551, \"y\": 1.884057971014494, \"x2\": -6.521739130434783, \"y2\": 2.1739130434782616, \"center_x\": -6.666666666666667, \"center_y\": 2.028985507246378, \"value_uncond\": 2.0858352687633163e-05}, {\"x\": -6.521739130434782, \"y\": 1.884057971014494, \"x2\": -6.231884057971015, \"y2\": 2.1739130434782616, \"center_x\": -6.3768115942028984, \"center_y\": 2.028985507246378, \"value_uncond\": 2.9408578405283986e-05}, {\"x\": -6.231884057971014, \"y\": 1.884057971014494, \"x2\": -5.942028985507246, \"y2\": 2.1739130434782616, \"center_x\": -6.08695652173913, \"center_y\": 2.028985507246378, \"value_uncond\": 4.107843323653689e-05}, {\"x\": -5.942028985507246, \"y\": 1.884057971014494, \"x2\": -5.6521739130434785, \"y2\": 2.1739130434782616, \"center_x\": -5.797101449275362, \"center_y\": 2.028985507246378, \"value_uncond\": 5.684594949875671e-05}, {\"x\": -5.6521739130434785, \"y\": 1.884057971014494, \"x2\": -5.362318840579711, \"y2\": 2.1739130434782616, \"center_x\": -5.507246376811595, \"center_y\": 2.028985507246378, \"value_uncond\": 7.793472251437328e-05}, {\"x\": -5.36231884057971, \"y\": 1.884057971014494, \"x2\": -5.072463768115942, \"y2\": 2.1739130434782616, \"center_x\": -5.217391304347826, \"center_y\": 2.028985507246378, \"value_uncond\": 0.00010585424441593667}, {\"x\": -5.0724637681159415, \"y\": 1.884057971014494, \"x2\": -4.782608695652174, \"y2\": 2.1739130434782616, \"center_x\": -4.927536231884058, \"center_y\": 2.028985507246378, \"value_uncond\": 0.00014243980620861715}, {\"x\": -4.782608695652174, \"y\": 1.884057971014494, \"x2\": -4.492753623188406, \"y2\": 2.1739130434782616, \"center_x\": -4.63768115942029, \"center_y\": 2.028985507246378, \"value_uncond\": 0.00018988920938927623}, {\"x\": -4.492753623188405, \"y\": 1.884057971014494, \"x2\": -4.202898550724638, \"y2\": 2.1739130434782616, \"center_x\": -4.3478260869565215, \"center_y\": 2.028985507246378, \"value_uncond\": 0.0002507927704329367}, {\"x\": -4.202898550724638, \"y\": 1.884057971014494, \"x2\": -3.91304347826087, \"y2\": 2.1739130434782616, \"center_x\": -4.057971014492754, \"center_y\": 2.028985507246378, \"value_uncond\": 0.000328152376833221}, {\"x\": -3.913043478260869, \"y\": 1.884057971014494, \"x2\": -3.6231884057971016, \"y2\": 2.1739130434782616, \"center_x\": -3.7681159420289854, \"center_y\": 2.028985507246378, \"value_uncond\": 0.00042538474371077597}, {\"x\": -3.6231884057971016, \"y\": 1.884057971014494, \"x2\": -3.333333333333334, \"y2\": 2.1739130434782616, \"center_x\": -3.4782608695652177, \"center_y\": 2.028985507246378, \"value_uncond\": 0.000546303622539451}, {\"x\": -3.333333333333333, \"y\": 1.884057971014494, \"x2\": -3.0434782608695654, \"y2\": 2.1739130434782616, \"center_x\": -3.1884057971014492, \"center_y\": 2.028985507246378, \"value_uncond\": 0.0006950756350950666}, {\"x\": -3.0434782608695645, \"y\": 1.884057971014494, \"x2\": -2.753623188405797, \"y2\": 2.1739130434782616, \"center_x\": -2.8985507246376807, \"center_y\": 2.028985507246378, \"value_uncond\": 0.0008761447533271222}, {\"x\": -2.753623188405797, \"y\": 1.884057971014494, \"x2\": -2.4637681159420293, \"y2\": 2.1739130434782616, \"center_x\": -2.608695652173913, \"center_y\": 2.028985507246378, \"value_uncond\": 0.0010941213143847621}, {\"x\": -2.4637681159420284, \"y\": 1.884057971014494, \"x2\": -2.1739130434782608, \"y2\": 2.1739130434782616, \"center_x\": -2.3188405797101446, \"center_y\": 2.028985507246378, \"value_uncond\": 0.0013536329176891404}, {\"x\": -2.1739130434782608, \"y\": 1.884057971014494, \"x2\": -1.8840579710144931, \"y2\": 2.1739130434782616, \"center_x\": -2.028985507246377, \"center_y\": 2.028985507246378, \"value_uncond\": 0.0016591366237270336}, {\"x\": -1.8840579710144922, \"y\": 1.884057971014494, \"x2\": -1.5942028985507246, \"y2\": 2.1739130434782616, \"center_x\": -1.7391304347826084, \"center_y\": 2.028985507246378, \"value_uncond\": 0.002014694531334479}, {\"x\": -1.5942028985507246, \"y\": 1.884057971014494, \"x2\": -1.304347826086957, \"y2\": 2.1739130434782616, \"center_x\": -1.4492753623188408, \"center_y\": 2.028985507246378, \"value_uncond\": 0.0024237179525454533}, {\"x\": -1.304347826086957, \"y\": 1.884057971014494, \"x2\": -1.0144927536231894, \"y2\": 2.1739130434782616, \"center_x\": -1.1594202898550732, \"center_y\": 2.028985507246378, \"value_uncond\": 0.0028886888581993115}, {\"x\": -1.0144927536231876, \"y\": 1.884057971014494, \"x2\": -0.72463768115942, \"y2\": 2.1739130434782616, \"center_x\": -0.8695652173913038, \"center_y\": 2.028985507246378, \"value_uncond\": 0.00341087078736884}, {\"x\": -0.72463768115942, \"y\": 1.884057971014494, \"x2\": -0.43478260869565233, \"y2\": 2.1739130434782616, \"center_x\": -0.5797101449275361, \"center_y\": 2.028985507246378, \"value_uncond\": 0.003990024691474894}, {\"x\": -0.43478260869565233, \"y\": 1.884057971014494, \"x2\": -0.1449275362318847, \"y2\": 2.1739130434782616, \"center_x\": -0.2898550724637685, \"center_y\": 2.028985507246378, \"value_uncond\": 0.004624147870994629}, {\"x\": -0.14492753623188293, \"y\": 1.884057971014494, \"x2\": 0.1449275362318847, \"y2\": 2.1739130434782616, \"center_x\": 8.881784197001252e-16, \"center_y\": 2.028985507246378, \"value_uncond\": 0.005309255899610263}, {\"x\": 0.1449275362318847, \"y\": 1.884057971014494, \"x2\": 0.43478260869565233, \"y2\": 2.1739130434782616, \"center_x\": 0.2898550724637685, \"center_y\": 2.028985507246378, \"value_uncond\": 0.006039227885113778}, {\"x\": 0.43478260869565233, \"y\": 1.884057971014494, \"x2\": 0.72463768115942, \"y2\": 2.1739130434782616, \"center_x\": 0.5797101449275361, \"center_y\": 2.028985507246378, \"value_uncond\": 0.006805734324488883}, {\"x\": 0.72463768115942, \"y\": 1.884057971014494, \"x2\": 1.0144927536231876, \"y2\": 2.1739130434782616, \"center_x\": 0.8695652173913038, \"center_y\": 2.028985507246378, \"value_uncond\": 0.007598264017684372}, {\"x\": 1.0144927536231894, \"y\": 1.884057971014494, \"x2\": 1.304347826086957, \"y2\": 2.1739130434782616, \"center_x\": 1.1594202898550732, \"center_y\": 2.028985507246378, \"value_uncond\": 0.00840426199989184}, {\"x\": 1.304347826086957, \"y\": 1.884057971014494, \"x2\": 1.5942028985507246, \"y2\": 2.1739130434782616, \"center_x\": 1.4492753623188408, \"center_y\": 2.028985507246378, \"value_uncond\": 0.009209384391785931}, {\"x\": 1.5942028985507246, \"y\": 1.884057971014494, \"x2\": 1.8840579710144922, \"y2\": 2.1739130434782616, \"center_x\": 1.7391304347826084, \"center_y\": 2.028985507246378, \"value_uncond\": 0.009997868781023904}, {\"x\": 1.884057971014494, \"y\": 1.884057971014494, \"x2\": 2.1739130434782616, \"y2\": 2.1739130434782616, \"center_x\": 2.028985507246378, \"center_y\": 2.028985507246378, \"value_uncond\": 0.010753010727229631}, {\"x\": 2.1739130434782616, \"y\": 1.884057971014494, \"x2\": 2.4637681159420293, \"y2\": 2.1739130434782616, \"center_x\": 2.3188405797101455, \"center_y\": 2.028985507246378, \"value_uncond\": 0.01145772884562643}, {\"x\": 2.4637681159420293, \"y\": 1.884057971014494, \"x2\": 2.753623188405797, \"y2\": 2.1739130434782616, \"center_x\": 2.608695652173913, \"center_y\": 2.028985507246378, \"value_uncond\": 0.012095193366675175}, {\"x\": 2.753623188405797, \"y\": 1.884057971014494, \"x2\": 3.0434782608695645, \"y2\": 2.1739130434782616, \"center_x\": 2.8985507246376807, \"center_y\": 2.028985507246378, \"value_uncond\": 0.012649486796134986}, {\"x\": 3.0434782608695663, \"y\": 1.884057971014494, \"x2\": 3.333333333333334, \"y2\": 2.1739130434782616, \"center_x\": 3.18840579710145, \"center_y\": 2.028985507246378, \"value_uncond\": 0.013106260954482262}, {\"x\": 3.333333333333334, \"y\": 1.884057971014494, \"x2\": 3.6231884057971016, \"y2\": 2.1739130434782616, \"center_x\": 3.4782608695652177, \"center_y\": 2.028985507246378, \"value_uncond\": 0.013453352763753928}, {\"x\": 3.6231884057971016, \"y\": 1.884057971014494, \"x2\": 3.913043478260869, \"y2\": 2.1739130434782616, \"center_x\": 3.7681159420289854, \"center_y\": 2.028985507246378, \"value_uncond\": 0.013681321982948132}, {\"x\": 3.913043478260871, \"y\": 1.884057971014494, \"x2\": 4.202898550724639, \"y2\": 2.1739130434782616, \"center_x\": 4.057971014492755, \"center_y\": 2.028985507246378, \"value_uncond\": 0.013783877737608386}, {\"x\": 4.202898550724639, \"y\": 1.884057971014494, \"x2\": 4.492753623188406, \"y2\": 2.1739130434782616, \"center_x\": 4.347826086956522, \"center_y\": 2.028985507246378, \"value_uncond\": 0.013758166951649482}, {\"x\": 4.492753623188406, \"y\": 1.884057971014494, \"x2\": 4.782608695652174, \"y2\": 2.1739130434782616, \"center_x\": 4.63768115942029, \"center_y\": 2.028985507246378, \"value_uncond\": 0.013604906224710316}, {\"x\": 4.782608695652174, \"y\": 1.884057971014494, \"x2\": 5.0724637681159415, \"y2\": 2.1739130434782616, \"center_x\": 4.927536231884058, \"center_y\": 2.028985507246378, \"value_uncond\": 0.013328348647328505}, {\"x\": 5.072463768115943, \"y\": 1.884057971014494, \"x2\": 5.362318840579711, \"y2\": 2.1739130434782616, \"center_x\": 5.217391304347827, \"center_y\": 2.028985507246378, \"value_uncond\": 0.012936087698732852}, {\"x\": 5.362318840579711, \"y\": 1.884057971014494, \"x2\": 5.6521739130434785, \"y2\": 2.1739130434782616, \"center_x\": 5.507246376811595, \"center_y\": 2.028985507246378, \"value_uncond\": 0.01243871084687245}, {\"x\": 5.6521739130434785, \"y\": 1.884057971014494, \"x2\": 5.942028985507246, \"y2\": 2.1739130434782616, \"center_x\": 5.797101449275362, \"center_y\": 2.028985507246378, \"value_uncond\": 0.011849324904210014}, {\"x\": 5.942028985507246, \"y\": 1.884057971014494, \"x2\": 6.231884057971014, \"y2\": 2.1739130434782616, \"center_x\": 6.08695652173913, \"center_y\": 2.028985507246378, \"value_uncond\": 0.011182982827182043}, {\"x\": 6.2318840579710155, \"y\": 1.884057971014494, \"x2\": 6.521739130434783, \"y2\": 2.1739130434782616, \"center_x\": 6.376811594202899, \"center_y\": 2.028985507246378, \"value_uncond\": 0.010456046902358579}, {\"x\": 6.521739130434785, \"y\": 1.884057971014494, \"x2\": 6.8115942028985526, \"y2\": 2.1739130434782616, \"center_x\": 6.666666666666669, \"center_y\": 2.028985507246378, \"value_uncond\": 0.009685525790755987}, {\"x\": 6.811594202898551, \"y\": 1.884057971014494, \"x2\": 7.101449275362318, \"y2\": 2.1739130434782616, \"center_x\": 6.956521739130435, \"center_y\": 2.028985507246378, \"value_uncond\": 0.00888842261488678}, {\"x\": 7.10144927536232, \"y\": 1.884057971014494, \"x2\": 7.391304347826088, \"y2\": 2.1739130434782616, \"center_x\": 7.246376811594204, \"center_y\": 2.028985507246378, \"value_uncond\": 0.008081128338999469}, {\"x\": 7.391304347826086, \"y\": 1.884057971014494, \"x2\": 7.681159420289854, \"y2\": 2.1739130434782616, \"center_x\": 7.53623188405797, \"center_y\": 2.028985507246378, \"value_uncond\": 0.007278889506506966}, {\"x\": 7.681159420289855, \"y\": 1.884057971014494, \"x2\": 7.971014492753623, \"y2\": 2.1739130434782616, \"center_x\": 7.826086956521739, \"center_y\": 2.028985507246378, \"value_uncond\": 0.006495372529400421}, {\"x\": 7.971014492753625, \"y\": 1.884057971014494, \"x2\": 8.260869565217392, \"y2\": 2.1739130434782616, \"center_x\": 8.115942028985508, \"center_y\": 2.028985507246378, \"value_uncond\": 0.0057423388492432005}, {\"x\": 8.26086956521739, \"y\": 1.884057971014494, \"x2\": 8.550724637681158, \"y2\": 2.1739130434782616, \"center_x\": 8.405797101449274, \"center_y\": 2.028985507246378, \"value_uncond\": 0.005029437118168106}, {\"x\": 8.55072463768116, \"y\": 1.884057971014494, \"x2\": 8.840579710144928, \"y2\": 2.1739130434782616, \"center_x\": 8.695652173913043, \"center_y\": 2.028985507246378, \"value_uncond\": 0.004364110753120656}, {\"x\": 8.84057971014493, \"y\": 1.884057971014494, \"x2\": 9.130434782608697, \"y2\": 2.1739130434782616, \"center_x\": 8.985507246376812, \"center_y\": 2.028985507246378, \"value_uncond\": 0.003751612370341272}, {\"x\": 9.130434782608695, \"y\": 1.884057971014494, \"x2\": 9.420289855072463, \"y2\": 2.1739130434782616, \"center_x\": 9.275362318840578, \"center_y\": 2.028985507246378, \"value_uncond\": 0.0031951111390670145}, {\"x\": 9.420289855072465, \"y\": 1.884057971014494, \"x2\": 9.710144927536232, \"y2\": 2.1739130434782616, \"center_x\": 9.565217391304348, \"center_y\": 2.028985507246378, \"value_uncond\": 0.002695875264406846}, {\"x\": 9.710144927536234, \"y\": 1.884057971014494, \"x2\": 10.000000000000002, \"y2\": 2.1739130434782616, \"center_x\": 9.855072463768117, \"center_y\": 2.028985507246378, \"value_uncond\": 0.0022535097068581075}, {\"x\": 10.0, \"y\": 1.884057971014494, \"x2\": 10.289855072463768, \"y2\": 2.1739130434782616, \"center_x\": 10.144927536231883, \"center_y\": 2.028985507246378, \"value_uncond\": 0.001866228798125752}, {\"x\": -10.0, \"y\": 2.1739130434782616, \"x2\": -9.710144927536232, \"y2\": 2.4637681159420293, \"center_x\": -9.855072463768117, \"center_y\": 2.3188405797101455, \"value_uncond\": 2.742445168837601e-07}, {\"x\": -9.710144927536232, \"y\": 2.1739130434782616, \"x2\": -9.420289855072465, \"y2\": 2.4637681159420293, \"center_x\": -9.565217391304348, \"center_y\": 2.3188405797101455, \"value_uncond\": 4.284774968685328e-07}, {\"x\": -9.420289855072463, \"y\": 2.1739130434782616, \"x2\": -9.130434782608695, \"y2\": 2.4637681159420293, \"center_x\": -9.275362318840578, \"center_y\": 2.3188405797101455, \"value_uncond\": 6.632295956617537e-07}, {\"x\": -9.130434782608695, \"y\": 2.1739130434782616, \"x2\": -8.840579710144928, \"y2\": 2.4637681159420293, \"center_x\": -8.985507246376812, \"center_y\": 2.3188405797101455, \"value_uncond\": 1.0170576991893582e-06}, {\"x\": -8.840579710144928, \"y\": 2.1739130434782616, \"x2\": -8.55072463768116, \"y2\": 2.4637681159420293, \"center_x\": -8.695652173913043, \"center_y\": 2.3188405797101455, \"value_uncond\": 1.5451587315205457e-06}, {\"x\": -8.55072463768116, \"y\": 2.1739130434782616, \"x2\": -8.260869565217392, \"y2\": 2.4637681159420293, \"center_x\": -8.405797101449277, \"center_y\": 2.3188405797101455, \"value_uncond\": 2.325661072031476e-06}, {\"x\": -8.26086956521739, \"y\": 2.1739130434782616, \"x2\": -7.971014492753623, \"y2\": 2.4637681159420293, \"center_x\": -8.115942028985508, \"center_y\": 2.3188405797101455, \"value_uncond\": 3.4678919787526597e-06}, {\"x\": -7.971014492753623, \"y\": 2.1739130434782616, \"x2\": -7.681159420289855, \"y2\": 2.4637681159420293, \"center_x\": -7.826086956521739, \"center_y\": 2.3188405797101455, \"value_uncond\": 5.123072635608127e-06}, {\"x\": -7.681159420289855, \"y\": 2.1739130434782616, \"x2\": -7.391304347826088, \"y2\": 2.4637681159420293, \"center_x\": -7.536231884057972, \"center_y\": 2.3188405797101455, \"value_uncond\": 7.497928249183951e-06}, {\"x\": -7.391304347826087, \"y\": 2.1739130434782616, \"x2\": -7.101449275362319, \"y2\": 2.4637681159420293, \"center_x\": -7.246376811594203, \"center_y\": 2.3188405797101455, \"value_uncond\": 1.0871710056732976e-05}, {\"x\": -7.101449275362318, \"y\": 2.1739130434782616, \"x2\": -6.811594202898551, \"y2\": 2.4637681159420293, \"center_x\": -6.956521739130435, \"center_y\": 2.3188405797101455, \"value_uncond\": 1.5617095184701392e-05}, {\"x\": -6.811594202898551, \"y\": 2.1739130434782616, \"x2\": -6.521739130434783, \"y2\": 2.4637681159420293, \"center_x\": -6.666666666666667, \"center_y\": 2.3188405797101455, \"value_uncond\": 2.2225342773643506e-05}, {\"x\": -6.521739130434782, \"y\": 2.1739130434782616, \"x2\": -6.231884057971015, \"y2\": 2.4637681159420293, \"center_x\": -6.3768115942028984, \"center_y\": 2.3188405797101455, \"value_uncond\": 3.133592308708699e-05}, {\"x\": -6.231884057971014, \"y\": 2.1739130434782616, \"x2\": -5.942028985507246, \"y2\": 2.4637681159420293, \"center_x\": -6.08695652173913, \"center_y\": 2.3188405797101455, \"value_uncond\": 4.377058308288967e-05}, {\"x\": -5.942028985507246, \"y\": 2.1739130434782616, \"x2\": -5.6521739130434785, \"y2\": 2.4637681159420293, \"center_x\": -5.797101449275362, \"center_y\": 2.3188405797101455, \"value_uncond\": 6.057145220543583e-05}, {\"x\": -5.6521739130434785, \"y\": 2.1739130434782616, \"x2\": -5.362318840579711, \"y2\": 2.4637681159420293, \"center_x\": -5.507246376811595, \"center_y\": 2.3188405797101455, \"value_uncond\": 8.304231632240589e-05}, {\"x\": -5.36231884057971, \"y\": 2.1739130434782616, \"x2\": -5.072463768115942, \"y2\": 2.4637681159420293, \"center_x\": -5.217391304347826, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0001127915948791156}, {\"x\": -5.0724637681159415, \"y\": 2.1739130434782616, \"x2\": -4.782608695652174, \"y2\": 2.4637681159420293, \"center_x\": -4.927536231884058, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.00015177485801526626}, {\"x\": -4.782608695652174, \"y\": 2.1739130434782616, \"x2\": -4.492753623188406, \"y2\": 2.4637681159420293, \"center_x\": -4.63768115942029, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0002023339441467523}, {\"x\": -4.492753623188405, \"y\": 2.1739130434782616, \"x2\": -4.202898550724638, \"y2\": 2.4637681159420293, \"center_x\": -4.3478260869565215, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0002672289308507321}, {\"x\": -4.202898550724638, \"y\": 2.1739130434782616, \"x2\": -3.91304347826087, \"y2\": 2.4637681159420293, \"center_x\": -4.057971014492754, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.00034965843977834024}, {\"x\": -3.913043478260869, \"y\": 2.1739130434782616, \"x2\": -3.6231884057971016, \"y2\": 2.4637681159420293, \"center_x\": -3.7681159420289854, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.00045326310669087074}, {\"x\": -3.6231884057971016, \"y\": 2.1739130434782616, \"x2\": -3.333333333333334, \"y2\": 2.4637681159420293, \"center_x\": -3.4782608695652177, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0005821066242024599}, {\"x\": -3.333333333333333, \"y\": 2.1739130434782616, \"x2\": -3.0434782608695654, \"y2\": 2.4637681159420293, \"center_x\": -3.1884057971014492, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0007406286812263477}, {\"x\": -3.0434782608695645, \"y\": 2.1739130434782616, \"x2\": -2.753623188405797, \"y2\": 2.4637681159420293, \"center_x\": -2.8985507246376807, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0009335644934976026}, {\"x\": -2.753623188405797, \"y\": 2.1739130434782616, \"x2\": -2.4637681159420293, \"y2\": 2.4637681159420293, \"center_x\": -2.608695652173913, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0011658265449969248}, {\"x\": -2.4637681159420284, \"y\": 2.1739130434782616, \"x2\": -2.1739130434782608, \"y2\": 2.4637681159420293, \"center_x\": -2.3188405797101446, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0014423457132914212}, {\"x\": -2.1739130434782608, \"y\": 2.1739130434782616, \"x2\": -1.8840579710144931, \"y2\": 2.4637681159420293, \"center_x\": -2.028985507246377, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0017678711604345368}, {\"x\": -1.8840579710144922, \"y\": 2.1739130434782616, \"x2\": -1.5942028985507246, \"y2\": 2.4637681159420293, \"center_x\": -1.7391304347826084, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.002146731202298736}, {\"x\": -1.5942028985507246, \"y\": 2.1739130434782616, \"x2\": -1.304347826086957, \"y2\": 2.4637681159420293, \"center_x\": -1.4492753623188408, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0025825607174575303}, {\"x\": -1.304347826086957, \"y\": 2.1739130434782616, \"x2\": -1.0144927536231894, \"y2\": 2.4637681159420293, \"center_x\": -1.1594202898550732, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0030780043372240864}, {\"x\": -1.0144927536231876, \"y\": 2.1739130434782616, \"x2\": -0.72463768115942, \"y2\": 2.4637681159420293, \"center_x\": -0.8695652173913038, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0036344084090027826}, {\"x\": -0.72463768115942, \"y\": 2.1739130434782616, \"x2\": -0.43478260869565233, \"y2\": 2.4637681159420293, \"center_x\": -0.5797101449275361, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.004251518217730996}, {\"x\": -0.43478260869565233, \"y\": 2.1739130434782616, \"x2\": -0.1449275362318847, \"y2\": 2.4637681159420293, \"center_x\": -0.2898550724637685, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.004927199813329617}, {\"x\": -0.14492753623188293, \"y\": 2.1739130434782616, \"x2\": 0.1449275362318847, \"y2\": 2.4637681159420293, \"center_x\": 8.881784197001252e-16, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.005657207642854213}, {\"x\": 0.1449275362318847, \"y\": 2.1739130434782616, \"x2\": 0.43478260869565233, \"y2\": 2.4637681159420293, \"center_x\": 0.2898550724637685, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.006435019670291636}, {\"x\": 0.43478260869565233, \"y\": 2.1739130434782616, \"x2\": 0.72463768115942, \"y2\": 2.4637681159420293, \"center_x\": 0.5797101449275361, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.007251760503493538}, {\"x\": 0.72463768115942, \"y\": 2.1739130434782616, \"x2\": 1.0144927536231876, \"y2\": 2.4637681159420293, \"center_x\": 0.8695652173913038, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.008096230071792845}, {\"x\": 1.0144927536231894, \"y\": 2.1739130434782616, \"x2\": 1.304347826086957, \"y2\": 2.4637681159420293, \"center_x\": 1.1594202898550732, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.008955050597924176}, {\"x\": 1.304347826086957, \"y\": 2.1739130434782616, \"x2\": 1.5942028985507246, \"y2\": 2.4637681159420293, \"center_x\": 1.4492753623188408, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.009812938150338193}, {\"x\": 1.5942028985507246, \"y\": 2.1739130434782616, \"x2\": 1.8840579710144922, \"y2\": 2.4637681159420293, \"center_x\": 1.7391304347826084, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.010653097298326468}, {\"x\": 1.884057971014494, \"y\": 2.1739130434782616, \"x2\": 2.1739130434782616, \"y2\": 2.4637681159420293, \"center_x\": 2.028985507246378, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.01145772884562643}, {\"x\": 2.1739130434782616, \"y\": 2.1739130434782616, \"x2\": 2.4637681159420293, \"y2\": 2.4637681159420293, \"center_x\": 2.3188405797101455, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.012208631947837958}, {\"x\": 2.4637681159420293, \"y\": 2.1739130434782616, \"x2\": 2.753623188405797, \"y2\": 2.4637681159420293, \"center_x\": 2.608695652173913, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.012887873865860803}, {\"x\": 2.753623188405797, \"y\": 2.1739130434782616, \"x2\": 3.0434782608695645, \"y2\": 2.4637681159420293, \"center_x\": 2.8985507246376807, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.013478493923514094}, {\"x\": 3.0434782608695663, \"y\": 2.1739130434782616, \"x2\": 3.333333333333334, \"y2\": 2.4637681159420293, \"center_x\": 3.18840579710145, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.013965203607228947}, {\"x\": 3.333333333333334, \"y\": 2.1739130434782616, \"x2\": 3.6231884057971016, \"y2\": 2.4637681159420293, \"center_x\": 3.4782608695652177, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.014335042709602577}, {\"x\": 3.6231884057971016, \"y\": 2.1739130434782616, \"x2\": 3.913043478260869, \"y2\": 2.4637681159420293, \"center_x\": 3.7681159420289854, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.014577952306266703}, {\"x\": 3.913043478260871, \"y\": 2.1739130434782616, \"x2\": 4.202898550724639, \"y2\": 2.4637681159420293, \"center_x\": 4.057971014492755, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.01468722923886384}, {\"x\": 4.202898550724639, \"y\": 2.1739130434782616, \"x2\": 4.492753623188406, \"y2\": 2.4637681159420293, \"center_x\": 4.347826086956522, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.014659833449777619}, {\"x\": 4.492753623188406, \"y\": 2.1739130434782616, \"x2\": 4.782608695652174, \"y2\": 2.4637681159420293, \"center_x\": 4.63768115942029, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.014496528502307806}, {\"x\": 4.782608695652174, \"y\": 2.1739130434782616, \"x2\": 5.0724637681159415, \"y2\": 2.4637681159420293, \"center_x\": 4.927536231884058, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.014201846221017042}, {\"x\": 5.072463768115943, \"y\": 2.1739130434782616, \"x2\": 5.362318840579711, \"y2\": 2.4637681159420293, \"center_x\": 5.217391304347827, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.013783877737608382}, {\"x\": 5.362318840579711, \"y\": 2.1739130434782616, \"x2\": 5.6521739130434785, \"y2\": 2.4637681159420293, \"center_x\": 5.507246376811595, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.013253904389002227}, {\"x\": 5.6521739130434785, \"y\": 2.1739130434782616, \"x2\": 5.942028985507246, \"y2\": 2.4637681159420293, \"center_x\": 5.797101449275362, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.012625891966458132}, {\"x\": 5.942028985507246, \"y\": 2.1739130434782616, \"x2\": 6.231884057971014, \"y2\": 2.4637681159420293, \"center_x\": 6.08695652173913, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.011915879949294914}, {\"x\": 6.2318840579710155, \"y\": 2.1739130434782616, \"x2\": 6.521739130434783, \"y2\": 2.4637681159420293, \"center_x\": 6.376811594202899, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.011141302956296993}, {\"x\": 6.521739130434785, \"y\": 2.1739130434782616, \"x2\": 6.8115942028985526, \"y2\": 2.4637681159420293, \"center_x\": 6.666666666666669, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.01032028434202024}, {\"x\": 6.811594202898551, \"y\": 2.1739130434782616, \"x2\": 7.101449275362318, \"y2\": 2.4637681159420293, \"center_x\": 6.956521739130435, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.009470941559540745}, {\"x\": 7.10144927536232, \"y\": 2.1739130434782616, \"x2\": 7.391304347826088, \"y2\": 2.4637681159420293, \"center_x\": 7.246376811594204, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.008610739784765224}, {\"x\": 7.391304347826086, \"y\": 2.1739130434782616, \"x2\": 7.681159420289854, \"y2\": 2.4637681159420293, \"center_x\": 7.53623188405797, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.007755924771063552}, {\"x\": 7.681159420289855, \"y\": 2.1739130434782616, \"x2\": 7.971014492753623, \"y2\": 2.4637681159420293, \"center_x\": 7.826086956521739, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.006921058583596764}, {\"x\": 7.971014492753625, \"y\": 2.1739130434782616, \"x2\": 8.260869565217392, \"y2\": 2.4637681159420293, \"center_x\": 8.115942028985508, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.006118673471395866}, {\"x\": 8.26086956521739, \"y\": 2.1739130434782616, \"x2\": 8.550724637681158, \"y2\": 2.4637681159420293, \"center_x\": 8.405797101449274, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.005359050428562672}, {\"x\": 8.55072463768116, \"y\": 2.1739130434782616, \"x2\": 8.840579710144928, \"y2\": 2.4637681159420293, \"center_x\": 8.695652173913043, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.004650120689912263}, {\"x\": 8.84057971014493, \"y\": 2.1739130434782616, \"x2\": 9.130434782608697, \"y2\": 2.4637681159420293, \"center_x\": 8.985507246376812, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.003997481111445207}, {\"x\": 9.130434782608695, \"y\": 2.1739130434782616, \"x2\": 9.420289855072463, \"y2\": 2.4637681159420293, \"center_x\": 9.275362318840578, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0034045085596694277}, {\"x\": 9.420289855072465, \"y\": 2.1739130434782616, \"x2\": 9.710144927536232, \"y2\": 2.4637681159420293, \"center_x\": 9.565217391304348, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0028725543538226468}, {\"x\": 9.710144927536234, \"y\": 2.1739130434782616, \"x2\": 10.000000000000002, \"y2\": 2.4637681159420293, \"center_x\": 9.855072463768117, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0024011975647697976}, {\"x\": 10.0, \"y\": 2.1739130434782616, \"x2\": 10.289855072463768, \"y2\": 2.4637681159420293, \"center_x\": 10.144927536231883, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.001988535497195876}, {\"x\": -10.0, \"y\": 2.4637681159420293, \"x2\": -9.710144927536232, \"y2\": 2.753623188405797, \"center_x\": -9.855072463768117, \"center_y\": 2.608695652173913, \"value_uncond\": 2.8950244033097844e-07}, {\"x\": -9.710144927536232, \"y\": 2.4637681159420293, \"x2\": -9.420289855072465, \"y2\": 2.753623188405797, \"center_x\": -9.565217391304348, \"center_y\": 2.608695652173913, \"value_uncond\": 4.523163576062548e-07}, {\"x\": -9.420289855072463, \"y\": 2.4637681159420293, \"x2\": -9.130434782608695, \"y2\": 2.753623188405797, \"center_x\": -9.275362318840578, \"center_y\": 2.608695652173913, \"value_uncond\": 7.001291716807186e-07}, {\"x\": -9.130434782608695, \"y\": 2.4637681159420293, \"x2\": -8.840579710144928, \"y2\": 2.753623188405797, \"center_x\": -8.985507246376812, \"center_y\": 2.608695652173913, \"value_uncond\": 1.0736429271894232e-06}, {\"x\": -8.840579710144928, \"y\": 2.4637681159420293, \"x2\": -8.55072463768116, \"y2\": 2.753623188405797, \"center_x\": -8.695652173913043, \"center_y\": 2.608695652173913, \"value_uncond\": 1.6311254954406947e-06}, {\"x\": -8.55072463768116, \"y\": 2.4637681159420293, \"x2\": -8.260869565217392, \"y2\": 2.753623188405797, \"center_x\": -8.405797101449277, \"center_y\": 2.608695652173913, \"value_uncond\": 2.455052022138501e-06}, {\"x\": -8.26086956521739, \"y\": 2.4637681159420293, \"x2\": -7.971014492753623, \"y2\": 2.753623188405797, \"center_x\": -8.115942028985508, \"center_y\": 2.608695652173913, \"value_uncond\": 3.660832318768493e-06}, {\"x\": -7.971014492753623, \"y\": 2.4637681159420293, \"x2\": -7.681159420289855, \"y2\": 2.753623188405797, \"center_x\": -7.826086956521739, \"center_y\": 2.608695652173913, \"value_uncond\": 5.4081009416499825e-06}, {\"x\": -7.681159420289855, \"y\": 2.4637681159420293, \"x2\": -7.391304347826088, \"y2\": 2.753623188405797, \"center_x\": -7.536231884057972, \"center_y\": 2.608695652173913, \"value_uncond\": 7.915084502802953e-06}, {\"x\": -7.391304347826087, \"y\": 2.4637681159420293, \"x2\": -7.101449275362319, \"y2\": 2.753623188405797, \"center_x\": -7.246376811594203, \"center_y\": 2.608695652173913, \"value_uncond\": 1.1476570717835243e-05}, {\"x\": -7.101449275362318, \"y\": 2.4637681159420293, \"x2\": -6.811594202898551, \"y2\": 2.753623188405797, \"center_x\": -6.956521739130435, \"center_y\": 2.608695652173913, \"value_uncond\": 1.6485971053228203e-05}, {\"x\": -6.811594202898551, \"y\": 2.4637681159420293, \"x2\": -6.521739130434783, \"y2\": 2.753623188405797, \"center_x\": -6.666666666666667, \"center_y\": 2.608695652173913, \"value_uncond\": 2.346187644250868e-05}, {\"x\": -6.521739130434782, \"y\": 2.4637681159420293, \"x2\": -6.231884057971015, \"y2\": 2.753623188405797, \"center_x\": -6.3768115942028984, \"center_y\": 2.608695652173913, \"value_uncond\": 3.3079334846211935e-05}, {\"x\": -6.231884057971014, \"y\": 2.4637681159420293, \"x2\": -5.942028985507246, \"y2\": 2.753623188405797, \"center_x\": -6.08695652173913, \"center_y\": 2.608695652173913, \"value_uncond\": 4.62058121022611e-05}, {\"x\": -5.942028985507246, \"y\": 2.4637681159420293, \"x2\": -5.6521739130434785, \"y2\": 2.753623188405797, \"center_x\": -5.797101449275362, \"center_y\": 2.608695652173913, \"value_uncond\": 6.394141777973059e-05}, {\"x\": -5.6521739130434785, \"y\": 2.4637681159420293, \"x2\": -5.362318840579711, \"y2\": 2.753623188405797, \"center_x\": -5.507246376811595, \"center_y\": 2.608695652173913, \"value_uncond\": 8.766247544071558e-05}, {\"x\": -5.36231884057971, \"y\": 2.4637681159420293, \"x2\": -5.072463768115942, \"y2\": 2.753623188405797, \"center_x\": -5.217391304347826, \"center_y\": 2.608695652173913, \"value_uncond\": 0.00011906689088032833}, {\"x\": -5.0724637681159415, \"y\": 2.4637681159420293, \"x2\": -4.782608695652174, \"y2\": 2.753623188405797, \"center_x\": -4.927536231884058, \"center_y\": 2.608695652173913, \"value_uncond\": 0.00016021903473436135}, {\"x\": -4.782608695652174, \"y\": 2.4637681159420293, \"x2\": -4.492753623188406, \"y2\": 2.753623188405797, \"center_x\": -4.63768115942029, \"center_y\": 2.608695652173913, \"value_uncond\": 0.00021359103641479342}, {\"x\": -4.492753623188405, \"y\": 2.4637681159420293, \"x2\": -4.202898550724638, \"y2\": 2.753623188405797, \"center_x\": -4.3478260869565215, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0002820965337334932}, {\"x\": -4.202898550724638, \"y\": 2.4637681159420293, \"x2\": -3.91304347826087, \"y2\": 2.753623188405797, \"center_x\": -4.057971014492754, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0003691121075031647}, {\"x\": -3.913043478260869, \"y\": 2.4637681159420293, \"x2\": -3.6231884057971016, \"y2\": 2.753623188405797, \"center_x\": -3.7681159420289854, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0004784809446331656}, {\"x\": -3.6231884057971016, \"y\": 2.4637681159420293, \"x2\": -3.333333333333334, \"y2\": 2.753623188405797, \"center_x\": -3.4782608695652177, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0006144928261623858}, {\"x\": -3.333333333333333, \"y\": 2.4637681159420293, \"x2\": -3.0434782608695654, \"y2\": 2.753623188405797, \"center_x\": -3.1884057971014492, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0007818344484350156}, {\"x\": -3.0434782608695645, \"y\": 2.4637681159420293, \"x2\": -2.753623188405797, \"y2\": 2.753623188405797, \"center_x\": -2.8985507246376807, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0009855044766071462}, {\"x\": -2.753623188405797, \"y\": 2.4637681159420293, \"x2\": -2.4637681159420293, \"y2\": 2.753623188405797, \"center_x\": -2.608695652173913, \"center_y\": 2.608695652173913, \"value_uncond\": 0.001230688706612493}, {\"x\": -2.4637681159420284, \"y\": 2.4637681159420293, \"x2\": -2.1739130434782608, \"y2\": 2.753623188405797, \"center_x\": -2.3188405797101446, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0015225923513204752}, {\"x\": -2.1739130434782608, \"y\": 2.4637681159420293, \"x2\": -1.8840579710144931, \"y2\": 2.753623188405797, \"center_x\": -2.028985507246377, \"center_y\": 2.608695652173913, \"value_uncond\": 0.001866228798125751}, {\"x\": -1.8840579710144922, \"y\": 2.4637681159420293, \"x2\": -1.5942028985507246, \"y2\": 2.753623188405797, \"center_x\": -1.7391304347826084, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0022661671739586985}, {\"x\": -1.5942028985507246, \"y\": 2.4637681159420293, \"x2\": -1.304347826086957, \"y2\": 2.753623188405797, \"center_x\": -1.4492753623188408, \"center_y\": 2.608695652173913, \"value_uncond\": 0.002726244588232826}, {\"x\": -1.304347826086957, \"y\": 2.4637681159420293, \"x2\": -1.0144927536231894, \"y2\": 2.753623188405797, \"center_x\": -1.1594202898550732, \"center_y\": 2.608695652173913, \"value_uncond\": 0.003249252809504304}, {\"x\": -1.0144927536231876, \"y\": 2.4637681159420293, \"x2\": -0.72463768115942, \"y2\": 2.753623188405797, \"center_x\": -0.8695652173913038, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0038366130908341948}, {\"x\": -0.72463768115942, \"y\": 2.4637681159420293, \"x2\": -0.43478260869565233, \"y2\": 2.753623188405797, \"center_x\": -0.5797101449275361, \"center_y\": 2.608695652173913, \"value_uncond\": 0.004488056545781097}, {\"x\": -0.43478260869565233, \"y\": 2.4637681159420293, \"x2\": -0.1449275362318847, \"y2\": 2.753623188405797, \"center_x\": -0.2898550724637685, \"center_y\": 2.608695652173913, \"value_uncond\": 0.005201330499387401}, {\"x\": -0.14492753623188293, \"y\": 2.4637681159420293, \"x2\": 0.1449275362318847, \"y2\": 2.753623188405797, \"center_x\": 8.881784197001252e-16, \"center_y\": 2.608695652173913, \"value_uncond\": 0.005971953192265772}, {\"x\": 0.1449275362318847, \"y\": 2.4637681159420293, \"x2\": 0.43478260869565233, \"y2\": 2.753623188405797, \"center_x\": 0.2898550724637685, \"center_y\": 2.608695652173913, \"value_uncond\": 0.006793039727087407}, {\"x\": 0.43478260869565233, \"y\": 2.4637681159420293, \"x2\": 0.72463768115942, \"y2\": 2.753623188405797, \"center_x\": 0.5797101449275361, \"center_y\": 2.608695652173913, \"value_uncond\": 0.007655220918590051}, {\"x\": 0.72463768115942, \"y\": 2.4637681159420293, \"x2\": 1.0144927536231876, \"y2\": 2.753623188405797, \"center_x\": 0.8695652173913038, \"center_y\": 2.608695652173913, \"value_uncond\": 0.008546673566708152}, {\"x\": 1.0144927536231894, \"y\": 2.4637681159420293, \"x2\": 1.304347826086957, \"y2\": 2.753623188405797, \"center_x\": 1.1594202898550732, \"center_y\": 2.608695652173913, \"value_uncond\": 0.00945327560545279}, {\"x\": 1.304347826086957, \"y\": 2.4637681159420293, \"x2\": 1.5942028985507246, \"y2\": 2.753623188405797, \"center_x\": 1.4492753623188408, \"center_y\": 2.608695652173913, \"value_uncond\": 0.010358892763365544}, {\"x\": 1.5942028985507246, \"y\": 2.4637681159420293, \"x2\": 1.8840579710144922, \"y2\": 2.753623188405797, \"center_x\": 1.7391304347826084, \"center_y\": 2.608695652173913, \"value_uncond\": 0.011245795175755779}, {\"x\": 1.884057971014494, \"y\": 2.4637681159420293, \"x2\": 2.1739130434782616, \"y2\": 2.753623188405797, \"center_x\": 2.028985507246378, \"center_y\": 2.608695652173913, \"value_uncond\": 0.012095193366675175}, {\"x\": 2.1739130434782616, \"y\": 2.4637681159420293, \"x2\": 2.4637681159420293, \"y2\": 2.753623188405797, \"center_x\": 2.3188405797101455, \"center_y\": 2.608695652173913, \"value_uncond\": 0.012887873865860803}, {\"x\": 2.4637681159420293, \"y\": 2.4637681159420293, \"x2\": 2.753623188405797, \"y2\": 2.753623188405797, \"center_x\": 2.608695652173913, \"center_y\": 2.608695652173913, \"value_uncond\": 0.013604906224710313}, {\"x\": 2.753623188405797, \"y\": 2.4637681159420293, \"x2\": 3.0434782608695645, \"y2\": 2.753623188405797, \"center_x\": 2.8985507246376807, \"center_y\": 2.608695652173913, \"value_uncond\": 0.014228386139430085}, {\"x\": 3.0434782608695663, \"y\": 2.4637681159420293, \"x2\": 3.333333333333334, \"y2\": 2.753623188405797, \"center_x\": 3.18840579710145, \"center_y\": 2.608695652173913, \"value_uncond\": 0.014742174501615976}, {\"x\": 3.333333333333334, \"y\": 2.4637681159420293, \"x2\": 3.6231884057971016, \"y2\": 2.753623188405797, \"center_x\": 3.4782608695652177, \"center_y\": 2.608695652173913, \"value_uncond\": 0.01513259004714306}, {\"x\": 3.6231884057971016, \"y\": 2.4637681159420293, \"x2\": 3.913043478260869, \"y2\": 2.753623188405797, \"center_x\": 3.7681159420289854, \"center_y\": 2.608695652173913, \"value_uncond\": 0.015389014211291014}, {\"x\": 3.913043478260871, \"y\": 2.4637681159420293, \"x2\": 4.202898550724639, \"y2\": 2.753623188405797, \"center_x\": 4.057971014492755, \"center_y\": 2.608695652173913, \"value_uncond\": 0.015504370897427292}, {\"x\": 4.202898550724639, \"y\": 2.4637681159420293, \"x2\": 4.492753623188406, \"y2\": 2.753623188405797, \"center_x\": 4.347826086956522, \"center_y\": 2.608695652173913, \"value_uncond\": 0.015475450910674683}, {\"x\": 4.492753623188406, \"y\": 2.4637681159420293, \"x2\": 4.782608695652174, \"y2\": 2.753623188405797, \"center_x\": 4.63768115942029, \"center_y\": 2.608695652173913, \"value_uncond\": 0.015303060296095244}, {\"x\": 4.782608695652174, \"y\": 2.4637681159420293, \"x2\": 5.0724637681159415, \"y2\": 2.753623188405797, \"center_x\": 4.927536231884058, \"center_y\": 2.608695652173913, \"value_uncond\": 0.014991983011760199}, {\"x\": 5.072463768115943, \"y\": 2.4637681159420293, \"x2\": 5.362318840579711, \"y2\": 2.753623188405797, \"center_x\": 5.217391304347827, \"center_y\": 2.608695652173913, \"value_uncond\": 0.014550760349213649}, {\"x\": 5.362318840579711, \"y\": 2.4637681159420293, \"x2\": 5.6521739130434785, \"y2\": 2.753623188405797, \"center_x\": 5.507246376811595, \"center_y\": 2.608695652173913, \"value_uncond\": 0.013991301296120189}, {\"x\": 5.6521739130434785, \"y\": 2.4637681159420293, \"x2\": 5.942028985507246, \"y2\": 2.753623188405797, \"center_x\": 5.797101449275362, \"center_y\": 2.608695652173913, \"value_uncond\": 0.013328348647328502}, {\"x\": 5.942028985507246, \"y\": 2.4637681159420293, \"x2\": 6.231884057971014, \"y2\": 2.753623188405797, \"center_x\": 6.08695652173913, \"center_y\": 2.608695652173913, \"value_uncond\": 0.012578834257875109}, {\"x\": 6.2318840579710155, \"y\": 2.4637681159420293, \"x2\": 6.521739130434783, \"y2\": 2.753623188405797, \"center_x\": 6.376811594202899, \"center_y\": 2.608695652173913, \"value_uncond\": 0.011761162742523812}, {\"x\": 6.521739130434785, \"y\": 2.4637681159420293, \"x2\": 6.8115942028985526, \"y2\": 2.753623188405797, \"center_x\": 6.666666666666669, \"center_y\": 2.608695652173913, \"value_uncond\": 0.010894465770452633}, {\"x\": 6.811594202898551, \"y\": 2.4637681159420293, \"x2\": 7.101449275362318, \"y2\": 2.753623188405797, \"center_x\": 6.956521739130435, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0099978687810239}, {\"x\": 7.10144927536232, \"y\": 2.4637681159420293, \"x2\": 7.391304347826088, \"y2\": 2.753623188405797, \"center_x\": 7.246376811594204, \"center_y\": 2.608695652173913, \"value_uncond\": 0.009089808646205944}, {\"x\": 7.391304347826086, \"y\": 2.4637681159420293, \"x2\": 7.681159420289854, \"y2\": 2.753623188405797, \"center_x\": 7.53623188405797, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0081874349713912}, {\"x\": 7.681159420289855, \"y\": 2.4637681159420293, \"x2\": 7.971014492753623, \"y2\": 2.753623188405797, \"center_x\": 7.826086956521739, \"center_y\": 2.608695652173913, \"value_uncond\": 0.007306119999745298}, {\"x\": 7.971014492753625, \"y\": 2.4637681159420293, \"x2\": 8.260869565217392, \"y2\": 2.753623188405797, \"center_x\": 8.115942028985508, \"center_y\": 2.608695652173913, \"value_uncond\": 0.006459093227042803}, {\"x\": 8.26086956521739, \"y\": 2.4637681159420293, \"x2\": 8.550724637681158, \"y2\": 2.753623188405797, \"center_x\": 8.405797101449274, \"center_y\": 2.608695652173913, \"value_uncond\": 0.005657207642854211}, {\"x\": 8.55072463768116, \"y\": 2.4637681159420293, \"x2\": 8.840579710144928, \"y2\": 2.753623188405797, \"center_x\": 8.695652173913043, \"center_y\": 2.608695652173913, \"value_uncond\": 0.004908835745780014}, {\"x\": 8.84057971014493, \"y\": 2.4637681159420293, \"x2\": 9.130434782608697, \"y2\": 2.753623188405797, \"center_x\": 8.985507246376812, \"center_y\": 2.608695652173913, \"value_uncond\": 0.004219885779634011}, {\"x\": 9.130434782608695, \"y\": 2.4637681159420293, \"x2\": 9.420289855072463, \"y2\": 2.753623188405797, \"center_x\": 9.275362318840578, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0035939224869526204}, {\"x\": 9.420289855072465, \"y\": 2.4637681159420293, \"x2\": 9.710144927536232, \"y2\": 2.753623188405797, \"center_x\": 9.565217391304348, \"center_y\": 2.608695652173913, \"value_uncond\": 0.003032372369244177}, {\"x\": 9.710144927536234, \"y\": 2.4637681159420293, \"x2\": 10.000000000000002, \"y2\": 2.753623188405797, \"center_x\": 9.855072463768117, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0025347910784750617}, {\"x\": 10.0, \"y\": 2.4637681159420293, \"x2\": 10.289855072463768, \"y2\": 2.753623188405797, \"center_x\": 10.144927536231883, \"center_y\": 2.608695652173913, \"value_uncond\": 0.002099170060588627}, {\"x\": -10.0, \"y\": 2.753623188405797, \"x2\": -9.710144927536232, \"y2\": 3.0434782608695645, \"center_x\": -9.855072463768117, \"center_y\": 2.8985507246376807, \"value_uncond\": 3.027696362842212e-07}, {\"x\": -9.710144927536232, \"y\": 2.753623188405797, \"x2\": -9.420289855072465, \"y2\": 3.0434782608695645, \"center_x\": -9.565217391304348, \"center_y\": 2.8985507246376807, \"value_uncond\": 4.7304492121476363e-07}, {\"x\": -9.420289855072463, \"y\": 2.753623188405797, \"x2\": -9.130434782608695, \"y2\": 3.0434782608695645, \"center_x\": -9.275362318840578, \"center_y\": 2.8985507246376807, \"value_uncond\": 7.322143966019667e-07}, {\"x\": -9.130434782608695, \"y\": 2.753623188405797, \"x2\": -8.840579710144928, \"y2\": 3.0434782608695645, \"center_x\": -8.985507246376812, \"center_y\": 2.8985507246376807, \"value_uncond\": 1.1228453832466169e-06}, {\"x\": -8.840579710144928, \"y\": 2.753623188405797, \"x2\": -8.55072463768116, \"y2\": 3.0434782608695645, \"center_x\": -8.695652173913043, \"center_y\": 2.8985507246376807, \"value_uncond\": 1.7058760279322381e-06}, {\"x\": -8.55072463768116, \"y\": 2.753623188405797, \"x2\": -8.260869565217392, \"y2\": 3.0434782608695645, \"center_x\": -8.405797101449277, \"center_y\": 2.8985507246376807, \"value_uncond\": 2.567561112617595e-06}, {\"x\": -8.26086956521739, \"y\": 2.753623188405797, \"x2\": -7.971014492753623, \"y2\": 3.0434782608695645, \"center_x\": -8.115942028985508, \"center_y\": 2.8985507246376807, \"value_uncond\": 3.828599401040885e-06}, {\"x\": -7.971014492753623, \"y\": 2.753623188405797, \"x2\": -7.681159420289855, \"y2\": 3.0434782608695645, \"center_x\": -7.826086956521739, \"center_y\": 2.8985507246376807, \"value_uncond\": 5.65594111476133e-06}, {\"x\": -7.681159420289855, \"y\": 2.753623188405797, \"x2\": -7.391304347826088, \"y2\": 3.0434782608695645, \"center_x\": -7.536231884057972, \"center_y\": 2.8985507246376807, \"value_uncond\": 8.277813663099864e-06}, {\"x\": -7.391304347826087, \"y\": 2.753623188405797, \"x2\": -7.101449275362319, \"y2\": 3.0434782608695645, \"center_x\": -7.246376811594203, \"center_y\": 2.8985507246376807, \"value_uncond\": 1.2002514168987824e-05}, {\"x\": -7.101449275362318, \"y\": 2.753623188405797, \"x2\": -6.811594202898551, \"y2\": 3.0434782608695645, \"center_x\": -6.956521739130435, \"center_y\": 2.8985507246376807, \"value_uncond\": 1.7241483193963902e-05}, {\"x\": -6.811594202898551, \"y\": 2.753623188405797, \"x2\": -6.521739130434783, \"y2\": 3.0434782608695645, \"center_x\": -6.666666666666667, \"center_y\": 2.8985507246376807, \"value_uncond\": 2.4537077438526764e-05}, {\"x\": -6.521739130434782, \"y\": 2.753623188405797, \"x2\": -6.231884057971015, \"y2\": 3.0434782608695645, \"center_x\": -6.3768115942028984, \"center_y\": 2.8985507246376807, \"value_uncond\": 3.459528067694787e-05}, {\"x\": -6.231884057971014, \"y\": 2.753623188405797, \"x2\": -5.942028985507246, \"y2\": 3.0434782608695645, \"center_x\": -6.08695652173913, \"center_y\": 2.8985507246376807, \"value_uncond\": 4.832331260636244e-05}, {\"x\": -5.942028985507246, \"y\": 2.753623188405797, \"x2\": -5.6521739130434785, \"y2\": 3.0434782608695645, \"center_x\": -5.797101449275362, \"center_y\": 2.8985507246376807, \"value_uncond\": 6.687169815402376e-05}, {\"x\": -5.6521739130434785, \"y\": 2.753623188405797, \"x2\": -5.362318840579711, \"y2\": 3.0434782608695645, \"center_x\": -5.507246376811595, \"center_y\": 2.8985507246376807, \"value_uncond\": 9.167983445879034e-05}, {\"x\": -5.36231884057971, \"y\": 2.753623188405797, \"x2\": -5.072463768115942, \"y2\": 3.0434782608695645, \"center_x\": -5.217391304347826, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.00012452343822772443}, {\"x\": -5.0724637681159415, \"y\": 2.753623188405797, \"x2\": -4.782608695652174, \"y2\": 3.0434782608695645, \"center_x\": -4.927536231884058, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.00016756148520500328}, {\"x\": -4.782608695652174, \"y\": 2.753623188405797, \"x2\": -4.492753623188406, \"y2\": 3.0434782608695645, \"center_x\": -4.63768115942029, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.0002233793965085168}, {\"x\": -4.492753623188405, \"y\": 2.753623188405797, \"x2\": -4.202898550724638, \"y2\": 3.0434782608695645, \"center_x\": -4.3478260869565215, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.000295024334917117}, {\"x\": -4.202898550724638, \"y\": 2.753623188405797, \"x2\": -3.91304347826087, \"y2\": 3.0434782608695645, \"center_x\": -4.057971014492754, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.0003860276217674322}, {\"x\": -3.913043478260869, \"y\": 2.753623188405797, \"x2\": -3.6231884057971016, \"y2\": 3.0434782608695645, \"center_x\": -3.7681159420289854, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.0005004085679204973}, {\"x\": -3.6231884057971016, \"y\": 2.753623188405797, \"x2\": -3.333333333333334, \"y2\": 3.0434782608695645, \"center_x\": -3.4782608695652177, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.0006426535446946294}, {\"x\": -3.333333333333333, \"y\": 2.753623188405797, \"x2\": -3.0434782608695654, \"y2\": 3.0434782608695645, \"center_x\": -3.1884057971014492, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.0008176640283809533}, {\"x\": -3.0434782608695645, \"y\": 2.753623188405797, \"x2\": -2.753623188405797, \"y2\": 3.0434782608695645, \"center_x\": -2.8985507246376807, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.001030667760857866}, {\"x\": -2.753623188405797, \"y\": 2.753623188405797, \"x2\": -2.4637681159420293, \"y2\": 3.0434782608695645, \"center_x\": -2.608695652173913, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.001287088190531882}, {\"x\": -2.4637681159420284, \"y\": 2.753623188405797, \"x2\": -2.1739130434782608, \"y2\": 3.0434782608695645, \"center_x\": -2.3188405797101446, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.001592369072576375}, {\"x\": -2.1739130434782608, \"y\": 2.753623188405797, \"x2\": -1.8840579710144931, \"y2\": 3.0434782608695645, \"center_x\": -2.028985507246377, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.00195175354579286}, {\"x\": -1.8840579710144922, \"y\": 2.753623188405797, \"x2\": -1.5942028985507246, \"y2\": 3.0434782608695645, \"center_x\": -1.7391304347826084, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.0023700201291370505}, {\"x\": -1.5942028985507246, \"y\": 2.753623188405797, \"x2\": -1.304347826086957, \"y2\": 3.0434782608695645, \"center_x\": -1.4492753623188408, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.0028511817774572105}, {\"x\": -1.304347826086957, \"y\": 2.753623188405797, \"x2\": -1.0144927536231894, \"y2\": 3.0434782608695645, \"center_x\": -1.1594202898550732, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.0033981581993035538}, {\"x\": -1.0144927536231876, \"y\": 2.753623188405797, \"x2\": -0.72463768115942, \"y2\": 3.0434782608695645, \"center_x\": -0.8695652173913038, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.004012435780324067}, {\"x\": -0.72463768115942, \"y\": 2.753623188405797, \"x2\": -0.43478260869565233, \"y2\": 3.0434782608695645, \"center_x\": -0.5797101449275361, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.004693733311662716}, {\"x\": -0.43478260869565233, \"y\": 2.753623188405797, \"x2\": -0.1449275362318847, \"y2\": 3.0434782608695645, \"center_x\": -0.2898550724637685, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.005439694883722322}, {\"x\": -0.14492753623188293, \"y\": 2.753623188405797, \"x2\": 0.1449275362318847, \"y2\": 3.0434782608695645, \"center_x\": 8.881784197001252e-16, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.006245633348933196}, {\"x\": 0.1449275362318847, \"y\": 2.753623188405797, \"x2\": 0.43478260869565233, \"y2\": 3.0434782608695645, \"center_x\": 0.2898550724637685, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.007104348291790332}, {\"x\": 0.43478260869565233, \"y\": 2.753623188405797, \"x2\": 0.72463768115942, \"y2\": 3.0434782608695645, \"center_x\": 0.5797101449275361, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.008006041159953762}, {\"x\": 0.72463768115942, \"y\": 2.753623188405797, \"x2\": 1.0144927536231876, \"y2\": 3.0434782608695645, \"center_x\": 0.8695652173913038, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.008938346924722965}, {\"x\": 1.0144927536231894, \"y\": 2.753623188405797, \"x2\": 1.304347826086957, \"y2\": 3.0434782608695645, \"center_x\": 1.1594202898550732, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.009886496340014353}, {\"x\": 1.304347826086957, \"y\": 2.753623188405797, \"x2\": 1.5942028985507246, \"y2\": 3.0434782608695645, \"center_x\": 1.4492753623188408, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.010833615739769736}, {\"x\": 1.5942028985507246, \"y\": 2.753623188405797, \"x2\": 1.8840579710144922, \"y2\": 3.0434782608695645, \"center_x\": 1.7391304347826084, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.011761162742523815}, {\"x\": 1.884057971014494, \"y\": 2.753623188405797, \"x2\": 2.1739130434782616, \"y2\": 3.0434782608695645, \"center_x\": 2.028985507246378, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.012649486796134986}, {\"x\": 2.1739130434782616, \"y\": 2.753623188405797, \"x2\": 2.4637681159420293, \"y2\": 3.0434782608695645, \"center_x\": 2.3188405797101455, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.013478493923514094}, {\"x\": 2.4637681159420293, \"y\": 2.753623188405797, \"x2\": 2.753623188405797, \"y2\": 3.0434782608695645, \"center_x\": 2.608695652173913, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.014228386139430085}, {\"x\": 2.753623188405797, \"y\": 2.753623188405797, \"x2\": 3.0434782608695645, \"y2\": 3.0434782608695645, \"center_x\": 2.8985507246376807, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.01488043862919289}, {\"x\": 3.0434782608695663, \"y\": 2.753623188405797, \"x2\": 3.333333333333334, \"y2\": 3.0434782608695645, \"center_x\": 3.18840579710145, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.015417772668133087}, {\"x\": 3.333333333333334, \"y\": 2.753623188405797, \"x2\": 3.6231884057971016, \"y2\": 3.0434782608695645, \"center_x\": 3.4782608695652177, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.015826080012913326}, {\"x\": 3.6231884057971016, \"y\": 2.753623188405797, \"x2\": 3.913043478260869, \"y2\": 3.0434782608695645, \"center_x\": 3.7681159420289854, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.016094255475699756}, {\"x\": 3.913043478260871, \"y\": 2.753623188405797, \"x2\": 4.202898550724639, \"y2\": 3.0434782608695645, \"center_x\": 4.057971014492755, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.01621489867948244}, {\"x\": 4.202898550724639, \"y\": 2.753623188405797, \"x2\": 4.492753623188406, \"y2\": 3.0434782608695645, \"center_x\": 4.347826086956522, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.01618465335975242}, {\"x\": 4.492753623188406, \"y\": 2.753623188405797, \"x2\": 4.782608695652174, \"y2\": 3.0434782608695645, \"center_x\": 4.63768115942029, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.016004362500665503}, {\"x\": 4.782608695652174, \"y\": 2.753623188405797, \"x2\": 5.0724637681159415, \"y2\": 3.0434782608695645, \"center_x\": 4.927536231884058, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.015679029297509334}, {\"x\": 5.072463768115943, \"y\": 2.753623188405797, \"x2\": 5.362318840579711, \"y2\": 3.0434782608695645, \"center_x\": 5.217391304347827, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.01521758646854096}, {\"x\": 5.362318840579711, \"y\": 2.753623188405797, \"x2\": 5.6521739130434785, \"y2\": 3.0434782608695645, \"center_x\": 5.507246376811595, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.014632488761497914}, {\"x\": 5.6521739130434785, \"y\": 2.753623188405797, \"x2\": 5.942028985507246, \"y2\": 3.0434782608695645, \"center_x\": 5.797101449275362, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.013939154597824402}, {\"x\": 5.942028985507246, \"y\": 2.753623188405797, \"x2\": 6.231884057971014, \"y2\": 3.0434782608695645, \"center_x\": 6.08695652173913, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.013155291778481145}, {\"x\": 6.2318840579710155, \"y\": 2.753623188405797, \"x2\": 6.521739130434783, \"y2\": 3.0434782608695645, \"center_x\": 6.376811594202899, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.012300148357168889}, {\"x\": 6.521739130434785, \"y\": 2.753623188405797, \"x2\": 6.8115942028985526, \"y2\": 3.0434782608695645, \"center_x\": 6.666666666666669, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.011393732761146198}, {\"x\": 6.811594202898551, \"y\": 2.753623188405797, \"x2\": 7.101449275362318, \"y2\": 3.0434782608695645, \"center_x\": 6.956521739130435, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.010456046902358577}, {\"x\": 7.10144927536232, \"y\": 2.753623188405797, \"x2\": 7.391304347826088, \"y2\": 3.0434782608695645, \"center_x\": 7.246376811594204, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.00950637256998089}, {\"x\": 7.391304347826086, \"y\": 2.753623188405797, \"x2\": 7.681159420289854, \"y2\": 3.0434782608695645, \"center_x\": 7.53623188405797, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.008562645294301409}, {\"x\": 7.681159420289855, \"y\": 2.753623188405797, \"x2\": 7.971014492753623, \"y2\": 3.0434782608695645, \"center_x\": 7.826086956521739, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.00764094179117375}, {\"x\": 7.971014492753625, \"y\": 2.753623188405797, \"x2\": 8.260869565217392, \"y2\": 3.0434782608695645, \"center_x\": 8.115942028985508, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.0067550978321351445}, {\"x\": 8.26086956521739, \"y\": 2.753623188405797, \"x2\": 8.550724637681158, \"y2\": 3.0434782608695645, \"center_x\": 8.405797101449274, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.005916463772992945}, {\"x\": 8.55072463768116, \"y\": 2.753623188405797, \"x2\": 8.840579710144928, \"y2\": 3.0434782608695645, \"center_x\": 8.695652173913043, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.0051337958036886434}, {\"x\": 8.84057971014493, \"y\": 2.753623188405797, \"x2\": 9.130434782608697, \"y2\": 3.0434782608695645, \"center_x\": 8.985507246376812, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.004413272928546124}, {\"x\": 9.130434782608695, \"y\": 2.753623188405797, \"x2\": 9.420289855072463, \"y2\": 3.0434782608695645, \"center_x\": 9.275362318840578, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.0037586232536219915}, {\"x\": 9.420289855072465, \"y\": 2.753623188405797, \"x2\": 9.710144927536232, \"y2\": 3.0434782608695645, \"center_x\": 9.565217391304348, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.003171338653535138}, {\"x\": 9.710144927536234, \"y\": 2.753623188405797, \"x2\": 10.000000000000002, \"y2\": 3.0434782608695645, \"center_x\": 9.855072463768117, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.002650954416857331}, {\"x\": 10.0, \"y\": 2.753623188405797, \"x2\": 10.289855072463768, \"y2\": 3.0434782608695645, \"center_x\": 10.144927536231883, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.0021953699423622308}, {\"x\": -10.0, \"y\": 3.0434782608695663, \"x2\": -9.710144927536232, \"y2\": 3.333333333333334, \"center_x\": -9.855072463768117, \"center_y\": 3.18840579710145, \"value_uncond\": 3.137026763368097e-07}, {\"x\": -9.710144927536232, \"y\": 3.0434782608695663, \"x2\": -9.420289855072465, \"y2\": 3.333333333333334, \"center_x\": -9.565217391304348, \"center_y\": 3.18840579710145, \"value_uncond\": 4.901266178267039e-07}, {\"x\": -9.420289855072463, \"y\": 3.0434782608695663, \"x2\": -9.130434782608695, \"y2\": 3.333333333333334, \"center_x\": -9.275362318840578, \"center_y\": 3.18840579710145, \"value_uncond\": 7.586547273543421e-07}, {\"x\": -9.130434782608695, \"y\": 3.0434782608695663, \"x2\": -8.840579710144928, \"y2\": 3.333333333333334, \"center_x\": -8.985507246376812, \"center_y\": 3.18840579710145, \"value_uncond\": 1.1633914356796134e-06}, {\"x\": -8.840579710144928, \"y\": 3.0434782608695663, \"x2\": -8.55072463768116, \"y2\": 3.333333333333334, \"center_x\": -8.695652173913043, \"center_y\": 3.18840579710145, \"value_uncond\": 1.7674753717998176e-06}, {\"x\": -8.55072463768116, \"y\": 3.0434782608695663, \"x2\": -8.260869565217392, \"y2\": 3.333333333333334, \"center_x\": -8.405797101449277, \"center_y\": 3.18840579710145, \"value_uncond\": 2.6602759859656123e-06}, {\"x\": -8.26086956521739, \"y\": 3.0434782608695663, \"x2\": -7.971014492753623, \"y2\": 3.333333333333334, \"center_x\": -8.115942028985508, \"center_y\": 3.18840579710145, \"value_uncond\": 3.966850485629838e-06}, {\"x\": -7.971014492753623, \"y\": 3.0434782608695663, \"x2\": -7.681159420289855, \"y2\": 3.333333333333334, \"center_x\": -7.826086956521739, \"center_y\": 3.18840579710145, \"value_uncond\": 5.860177680559899e-06}, {\"x\": -7.681159420289855, \"y\": 3.0434782608695663, \"x2\": -7.391304347826088, \"y2\": 3.333333333333334, \"center_x\": -7.536231884057972, \"center_y\": 3.18840579710145, \"value_uncond\": 8.57672629330027e-06}, {\"x\": -7.391304347826087, \"y\": 3.0434782608695663, \"x2\": -7.101449275362319, \"y2\": 3.333333333333334, \"center_x\": -7.246376811594203, \"center_y\": 3.18840579710145, \"value_uncond\": 1.2435926084897789e-05}, {\"x\": -7.101449275362318, \"y\": 3.0434782608695663, \"x2\": -6.811594202898551, \"y2\": 3.333333333333334, \"center_x\": -6.956521739130435, \"center_y\": 3.18840579710145, \"value_uncond\": 1.7864074774279074e-05}, {\"x\": -6.811594202898551, \"y\": 3.0434782608695663, \"x2\": -6.521739130434783, \"y2\": 3.333333333333334, \"center_x\": -6.666666666666667, \"center_y\": 3.18840579710145, \"value_uncond\": 2.542311361342594e-05}, {\"x\": -6.521739130434782, \"y\": 3.0434782608695663, \"x2\": -6.231884057971015, \"y2\": 3.333333333333334, \"center_x\": -6.3768115942028984, \"center_y\": 3.18840579710145, \"value_uncond\": 3.5844519517121926e-05}, {\"x\": -6.231884057971014, \"y\": 3.0434782608695663, \"x2\": -5.942028985507246, \"y2\": 3.333333333333334, \"center_x\": -6.08695652173913, \"center_y\": 3.18840579710145, \"value_uncond\": 5.006827197112243e-05}, {\"x\": -5.942028985507246, \"y\": 3.0434782608695663, \"x2\": -5.6521739130434785, \"y2\": 3.333333333333334, \"center_x\": -5.797101449275362, \"center_y\": 3.18840579710145, \"value_uncond\": 6.928644146605207e-05}, {\"x\": -5.6521739130434785, \"y\": 3.0434782608695663, \"x2\": -5.362318840579711, \"y2\": 3.333333333333334, \"center_x\": -5.507246376811595, \"center_y\": 3.18840579710145, \"value_uncond\": 9.499040190688058e-05}, {\"x\": -5.36231884057971, \"y\": 3.0434782608695663, \"x2\": -5.072463768115942, \"y2\": 3.333333333333334, \"center_x\": -5.217391304347826, \"center_y\": 3.18840579710145, \"value_uncond\": 0.00012901999129803215}, {\"x\": -5.0724637681159415, \"y\": 3.0434782608695663, \"x2\": -4.782608695652174, \"y2\": 3.333333333333334, \"center_x\": -4.927536231884058, \"center_y\": 3.18840579710145, \"value_uncond\": 0.00017361214620093563}, {\"x\": -4.782608695652174, \"y\": 3.0434782608695663, \"x2\": -4.492753623188406, \"y2\": 3.333333333333334, \"center_x\": -4.63768115942029, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0002314456475332996}, {\"x\": -4.492753623188405, \"y\": 3.0434782608695663, \"x2\": -4.202898550724638, \"y2\": 3.333333333333334, \"center_x\": -4.3478260869565215, \"center_y\": 3.18840579710145, \"value_uncond\": 0.00030567769140861566}, {\"x\": -4.202898550724638, \"y\": 3.0434782608695663, \"x2\": -3.91304347826087, \"y2\": 3.333333333333334, \"center_x\": -4.057971014492754, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0003999671155092253}, {\"x\": -3.913043478260869, \"y\": 3.0434782608695663, \"x2\": -3.6231884057971016, \"y2\": 3.333333333333334, \"center_x\": -3.7681159420289854, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0005184783683895163}, {\"x\": -3.6231884057971016, \"y\": 3.0434782608695663, \"x2\": -3.333333333333334, \"y2\": 3.333333333333334, \"center_x\": -3.4782608695652177, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0006658598246582143}, {\"x\": -3.333333333333333, \"y\": 3.0434782608695663, \"x2\": -3.0434782608695654, \"y2\": 3.333333333333334, \"center_x\": -3.1884057971014492, \"center_y\": 3.18840579710145, \"value_uncond\": 0.000847189953376477}, {\"x\": -3.0434782608695645, \"y\": 3.0434782608695663, \"x2\": -2.753623188405797, \"y2\": 3.333333333333334, \"center_x\": -2.8985507246376807, \"center_y\": 3.18840579710145, \"value_uncond\": 0.001067885270673787}, {\"x\": -2.753623188405797, \"y\": 3.0434782608695663, \"x2\": -2.4637681159420293, \"y2\": 3.333333333333334, \"center_x\": -2.608695652173913, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0013335650661888887}, {\"x\": -2.4637681159420284, \"y\": 3.0434782608695663, \"x2\": -2.1739130434782608, \"y2\": 3.333333333333334, \"center_x\": -2.3188405797101446, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0016498696696066464}, {\"x\": -2.1739130434782608, \"y\": 3.0434782608695663, \"x2\": -1.8840579710144931, \"y2\": 3.333333333333334, \"center_x\": -2.028985507246377, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0020222315499640042}, {\"x\": -1.8840579710144922, \"y\": 3.0434782608695663, \"x2\": -1.5942028985507246, \"y2\": 3.333333333333334, \"center_x\": -1.7391304347826084, \"center_y\": 3.18840579710145, \"value_uncond\": 0.002455601778985758}, {\"x\": -1.5942028985507246, \"y\": 3.0434782608695663, \"x2\": -1.304347826086957, \"y2\": 3.333333333333334, \"center_x\": -1.4492753623188408, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0029541382196973053}, {\"x\": -1.304347826086957, \"y\": 3.0434782608695663, \"x2\": -1.0144927536231894, \"y2\": 3.333333333333334, \"center_x\": -1.1594202898550732, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0035208660115993097}, {\"x\": -1.0144927536231876, \"y\": 3.0434782608695663, \"x2\": -0.72463768115942, \"y2\": 3.333333333333334, \"center_x\": -0.8695652173913038, \"center_y\": 3.18840579710145, \"value_uncond\": 0.004157325213865357}, {\"x\": -0.72463768115942, \"y\": 3.0434782608695663, \"x2\": -0.43478260869565233, \"y2\": 3.333333333333334, \"center_x\": -0.5797101449275361, \"center_y\": 3.18840579710145, \"value_uncond\": 0.004863224463161162}, {\"x\": -0.43478260869565233, \"y\": 3.0434782608695663, \"x2\": -0.1449275362318847, \"y2\": 3.333333333333334, \"center_x\": -0.2898550724637685, \"center_y\": 3.18840579710145, \"value_uncond\": 0.005636122777772336}, {\"x\": -0.14492753623188293, \"y\": 3.0434782608695663, \"x2\": 0.1449275362318847, \"y2\": 3.333333333333334, \"center_x\": 8.881784197001252e-16, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0064711637567894525}, {\"x\": 0.1449275362318847, \"y\": 3.0434782608695663, \"x2\": 0.43478260869565233, \"y2\": 3.333333333333334, \"center_x\": 0.2898550724637685, \"center_y\": 3.18840579710145, \"value_uncond\": 0.007360886977026161}, {\"x\": 0.43478260869565233, \"y\": 3.0434782608695663, \"x2\": 0.72463768115942, \"y2\": 3.333333333333334, \"center_x\": 0.5797101449275361, \"center_y\": 3.18840579710145, \"value_uncond\": 0.008295140059495594}, {\"x\": 0.72463768115942, \"y\": 3.0434782608695663, \"x2\": 1.0144927536231876, \"y2\": 3.333333333333334, \"center_x\": 0.8695652173913038, \"center_y\": 3.18840579710145, \"value_uncond\": 0.009261111473147475}, {\"x\": 1.0144927536231894, \"y\": 3.0434782608695663, \"x2\": 1.304347826086957, \"y2\": 3.333333333333334, \"center_x\": 1.1594202898550732, \"center_y\": 3.18840579710145, \"value_uncond\": 0.010243498653032564}, {\"x\": 1.304347826086957, \"y\": 3.0434782608695663, \"x2\": 1.5942028985507246, \"y2\": 3.333333333333334, \"center_x\": 1.4492753623188408, \"center_y\": 3.18840579710145, \"value_uncond\": 0.01122481862342373}, {\"x\": 1.5942028985507246, \"y\": 3.0434782608695663, \"x2\": 1.8840579710144922, \"y2\": 3.333333333333334, \"center_x\": 1.7391304347826084, \"center_y\": 3.18840579710145, \"value_uncond\": 0.012185859435716389}, {\"x\": 1.884057971014494, \"y\": 3.0434782608695663, \"x2\": 2.1739130434782616, \"y2\": 3.333333333333334, \"center_x\": 2.028985507246378, \"center_y\": 3.18840579710145, \"value_uncond\": 0.013106260954482262}, {\"x\": 2.1739130434782616, \"y\": 3.0434782608695663, \"x2\": 2.4637681159420293, \"y2\": 3.333333333333334, \"center_x\": 2.3188405797101455, \"center_y\": 3.18840579710145, \"value_uncond\": 0.013965203607228947}, {\"x\": 2.4637681159420293, \"y\": 3.0434782608695663, \"x2\": 2.753623188405797, \"y2\": 3.333333333333334, \"center_x\": 2.608695652173913, \"center_y\": 3.18840579710145, \"value_uncond\": 0.014742174501615976}, {\"x\": 2.753623188405797, \"y\": 3.0434782608695663, \"x2\": 3.0434782608695645, \"y2\": 3.333333333333334, \"center_x\": 2.8985507246376807, \"center_y\": 3.18840579710145, \"value_uncond\": 0.015417772668133087}, {\"x\": 3.0434782608695663, \"y\": 3.0434782608695663, \"x2\": 3.333333333333334, \"y2\": 3.333333333333334, \"center_x\": 3.18840579710145, \"center_y\": 3.18840579710145, \"value_uncond\": 0.015974509889774988}, {\"x\": 3.333333333333334, \"y\": 3.0434782608695663, \"x2\": 3.6231884057971016, \"y2\": 3.333333333333334, \"center_x\": 3.4782608695652177, \"center_y\": 3.18840579710145, \"value_uncond\": 0.016397561251191222}, {\"x\": 3.6231884057971016, \"y\": 3.0434782608695663, \"x2\": 3.913043478260869, \"y2\": 3.333333333333334, \"center_x\": 3.7681159420289854, \"center_y\": 3.18840579710145, \"value_uncond\": 0.016675420555170413}, {\"x\": 3.913043478260871, \"y\": 3.0434782608695663, \"x2\": 4.202898550724639, \"y2\": 3.333333333333334, \"center_x\": 4.057971014492755, \"center_y\": 3.18840579710145, \"value_uncond\": 0.016800420196392517}, {\"x\": 4.202898550724639, \"y\": 3.0434782608695663, \"x2\": 4.492753623188406, \"y2\": 3.333333333333334, \"center_x\": 4.347826086956522, \"center_y\": 3.18840579710145, \"value_uncond\": 0.016769082715321383}, {\"x\": 4.492753623188406, \"y\": 3.0434782608695663, \"x2\": 4.782608695652174, \"y2\": 3.333333333333334, \"center_x\": 4.63768115942029, \"center_y\": 3.18840579710145, \"value_uncond\": 0.01658228153635001}, {\"x\": 4.782608695652174, \"y\": 3.0434782608695663, \"x2\": 5.0724637681159415, \"y2\": 3.333333333333334, \"center_x\": 4.927536231884058, \"center_y\": 3.18840579710145, \"value_uncond\": 0.016245200520618588}, {\"x\": 5.072463768115943, \"y\": 3.0434782608695663, \"x2\": 5.362318840579711, \"y2\": 3.333333333333334, \"center_x\": 5.217391304347827, \"center_y\": 3.18840579710145, \"value_uncond\": 0.015767094947680884}, {\"x\": 5.362318840579711, \"y\": 3.0434782608695663, \"x2\": 5.6521739130434785, \"y2\": 3.333333333333334, \"center_x\": 5.507246376811595, \"center_y\": 3.18840579710145, \"value_uncond\": 0.015160869307387047}, {\"x\": 5.6521739130434785, \"y\": 3.0434782608695663, \"x2\": 5.942028985507246, \"y2\": 3.333333333333334, \"center_x\": 5.797101449275362, \"center_y\": 3.18840579710145, \"value_uncond\": 0.01444249878183029}, {\"x\": 5.942028985507246, \"y\": 3.0434782608695663, \"x2\": 6.231884057971014, \"y2\": 3.333333333333334, \"center_x\": 6.08695652173913, \"center_y\": 3.18840579710145, \"value_uncond\": 0.013630330602330078}, {\"x\": 6.2318840579710155, \"y\": 3.0434782608695663, \"x2\": 6.521739130434783, \"y2\": 3.333333333333334, \"center_x\": 6.376811594202899, \"center_y\": 3.18840579710145, \"value_uncond\": 0.012744307871617264}, {\"x\": 6.521739130434785, \"y\": 3.0434782608695663, \"x2\": 6.8115942028985526, \"y2\": 3.333333333333334, \"center_x\": 6.666666666666669, \"center_y\": 3.18840579710145, \"value_uncond\": 0.011805161523141232}, {\"x\": 6.811594202898551, \"y\": 3.0434782608695663, \"x2\": 7.101449275362318, \"y2\": 3.333333333333334, \"center_x\": 6.956521739130435, \"center_y\": 3.18840579710145, \"value_uncond\": 0.010833615739769736}, {\"x\": 7.10144927536232, \"y\": 3.0434782608695663, \"x2\": 7.391304347826088, \"y2\": 3.333333333333334, \"center_x\": 7.246376811594204, \"center_y\": 3.18840579710145, \"value_uncond\": 0.00984964857789889}, {\"x\": 7.391304347826086, \"y\": 3.0434782608695663, \"x2\": 7.681159420289854, \"y2\": 3.333333333333334, \"center_x\": 7.53623188405797, \"center_y\": 3.18840579710145, \"value_uncond\": 0.008871843221503157}, {\"x\": 7.681159420289855, \"y\": 3.0434782608695663, \"x2\": 7.971014492753623, \"y2\": 3.333333333333334, \"center_x\": 7.826086956521739, \"center_y\": 3.18840579710145, \"value_uncond\": 0.007916856918158218}, {\"x\": 7.971014492753625, \"y\": 3.0434782608695663, \"x2\": 8.260869565217392, \"y2\": 3.333333333333334, \"center_x\": 8.115942028985508, \"center_y\": 3.18840579710145, \"value_uncond\": 0.006999025050413267}, {\"x\": 8.26086956521739, \"y\": 3.0434782608695663, \"x2\": 8.550724637681158, \"y2\": 3.333333333333334, \"center_x\": 8.405797101449274, \"center_y\": 3.18840579710145, \"value_uncond\": 0.00613010783649177}, {\"x\": 8.55072463768116, \"y\": 3.0434782608695663, \"x2\": 8.840579710144928, \"y2\": 3.333333333333334, \"center_x\": 8.695652173913043, \"center_y\": 3.18840579710145, \"value_uncond\": 0.005319177653177839}, {\"x\": 8.84057971014493, \"y\": 3.0434782608695663, \"x2\": 9.130434782608697, \"y2\": 3.333333333333334, \"center_x\": 8.985507246376812, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0045726366292228515}, {\"x\": 9.130434782608695, \"y\": 3.0434782608695663, \"x2\": 9.420289855072463, \"y2\": 3.333333333333334, \"center_x\": 9.275362318840578, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0038943474929438796}, {\"x\": 9.420289855072465, \"y\": 3.0434782608695663, \"x2\": 9.710144927536232, \"y2\": 3.333333333333334, \"center_x\": 9.565217391304348, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0032858559906926666}, {\"x\": 9.710144927536234, \"y\": 3.0434782608695663, \"x2\": 10.000000000000002, \"y2\": 3.333333333333334, \"center_x\": 9.855072463768117, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0027466806302675847}, {\"x\": 10.0, \"y\": 3.0434782608695663, \"x2\": 10.289855072463768, \"y2\": 3.333333333333334, \"center_x\": 10.144927536231883, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0022746449575343722}, {\"x\": -10.0, \"y\": 3.333333333333334, \"x2\": -9.710144927536232, \"y2\": 3.6231884057971016, \"center_x\": -9.855072463768117, \"center_y\": 3.4782608695652177, \"value_uncond\": 3.2201043320822097e-07}, {\"x\": -9.710144927536232, \"y\": 3.333333333333334, \"x2\": -9.420289855072465, \"y2\": 3.6231884057971016, \"center_x\": -9.565217391304348, \"center_y\": 3.4782608695652177, \"value_uncond\": 5.031065924468107e-07}, {\"x\": -9.420289855072463, \"y\": 3.333333333333334, \"x2\": -9.130434782608695, \"y2\": 3.6231884057971016, \"center_x\": -9.275362318840578, \"center_y\": 3.4782608695652177, \"value_uncond\": 7.787461052724562e-07}, {\"x\": -9.130434782608695, \"y\": 3.333333333333334, \"x2\": -8.840579710144928, \"y2\": 3.6231884057971016, \"center_x\": -8.985507246376812, \"center_y\": 3.4782608695652177, \"value_uncond\": 1.1942014157115696e-06}, {\"x\": -8.840579710144928, \"y\": 3.333333333333334, \"x2\": -8.55072463768116, \"y2\": 3.6231884057971016, \"center_x\": -8.695652173913043, \"center_y\": 3.4782608695652177, \"value_uncond\": 1.814283246812509e-06}, {\"x\": -8.55072463768116, \"y\": 3.333333333333334, \"x2\": -8.260869565217392, \"y2\": 3.6231884057971016, \"center_x\": -8.405797101449277, \"center_y\": 3.4782608695652177, \"value_uncond\": 2.7307278111152564e-06}, {\"x\": -8.26086956521739, \"y\": 3.333333333333334, \"x2\": -7.971014492753623, \"y2\": 3.6231884057971016, \"center_x\": -8.115942028985508, \"center_y\": 3.4782608695652177, \"value_uncond\": 4.071904193697249e-06}, {\"x\": -7.971014492753623, \"y\": 3.333333333333334, \"x2\": -7.681159420289855, \"y2\": 3.6231884057971016, \"center_x\": -7.826086956521739, \"center_y\": 3.4782608695652177, \"value_uncond\": 6.015372184992783e-06}, {\"x\": -7.681159420289855, \"y\": 3.333333333333334, \"x2\": -7.391304347826088, \"y2\": 3.6231884057971016, \"center_x\": -7.536231884057972, \"center_y\": 3.4782608695652177, \"value_uncond\": 8.803862885277813e-06}, {\"x\": -7.391304347826087, \"y\": 3.333333333333334, \"x2\": -7.101449275362319, \"y2\": 3.6231884057971016, \"center_x\": -7.246376811594203, \"center_y\": 3.4782608695652177, \"value_uncond\": 1.2765265482287069e-05}, {\"x\": -7.101449275362318, \"y\": 3.333333333333334, \"x2\": -6.811594202898551, \"y2\": 3.6231884057971016, \"center_x\": -6.956521739130435, \"center_y\": 3.4782608695652177, \"value_uncond\": 1.833716729516683e-05}, {\"x\": -6.811594202898551, \"y\": 3.333333333333334, \"x2\": -6.521739130434783, \"y2\": 3.6231884057971016, \"center_x\": -6.666666666666667, \"center_y\": 3.4782608695652177, \"value_uncond\": 2.6096391410354376e-05}, {\"x\": -6.521739130434782, \"y\": 3.333333333333334, \"x2\": -6.231884057971015, \"y2\": 3.6231884057971016, \"center_x\": -6.3768115942028984, \"center_y\": 3.4782608695652177, \"value_uncond\": 3.679378637323594e-05}, {\"x\": -6.231884057971014, \"y\": 3.333333333333334, \"x2\": -5.942028985507246, \"y2\": 3.6231884057971016, \"center_x\": -6.08695652173913, \"center_y\": 3.4782608695652177, \"value_uncond\": 5.1394225053082035e-05}, {\"x\": -5.942028985507246, \"y\": 3.333333333333334, \"x2\": -5.6521739130434785, \"y2\": 3.6231884057971016, \"center_x\": -5.797101449275362, \"center_y\": 3.4782608695652177, \"value_uncond\": 7.112134742511759e-05}, {\"x\": -5.6521739130434785, \"y\": 3.333333333333334, \"x2\": -5.362318840579711, \"y2\": 3.6231884057971016, \"center_x\": -5.507246376811595, \"center_y\": 3.4782608695652177, \"value_uncond\": 9.75060233015565e-05}, {\"x\": -5.36231884057971, \"y\": 3.333333333333334, \"x2\": -5.072463768115942, \"y2\": 3.6231884057971016, \"center_x\": -5.217391304347826, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.00013243681493426023}, {\"x\": -5.0724637681159415, \"y\": 3.333333333333334, \"x2\": -4.782608695652174, \"y2\": 3.6231884057971016, \"center_x\": -4.927536231884058, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.00017820989945380452}, {\"x\": -4.782608695652174, \"y\": 3.333333333333334, \"x2\": -4.492753623188406, \"y2\": 3.6231884057971016, \"center_x\": -4.63768115942029, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.00023757499966732003}, {\"x\": -4.492753623188405, \"y\": 3.333333333333334, \"x2\": -4.202898550724638, \"y2\": 3.6231884057971016, \"center_x\": -4.3478260869565215, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.0003137729233999119}, {\"x\": -4.202898550724638, \"y\": 3.333333333333334, \"x2\": -3.91304347826087, \"y2\": 3.6231884057971016, \"center_x\": -4.057971014492754, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.0004105594049694614}, {\"x\": -3.913043478260869, \"y\": 3.333333333333334, \"x2\": -3.6231884057971016, \"y2\": 3.6231884057971016, \"center_x\": -3.7681159420289854, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.0005322091796084853}, {\"x\": -3.6231884057971016, \"y\": 3.333333333333334, \"x2\": -3.333333333333334, \"y2\": 3.6231884057971016, \"center_x\": -3.4782608695652177, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.0006834937243695501}, {\"x\": -3.333333333333333, \"y\": 3.333333333333334, \"x2\": -3.0434782608695654, \"y2\": 3.6231884057971016, \"center_x\": -3.1884057971014492, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.000869626000906391}, {\"x\": -3.0434782608695645, \"y\": 3.333333333333334, \"x2\": -2.753623188405797, \"y2\": 3.6231884057971016, \"center_x\": -2.8985507246376807, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.001096165970408059}, {\"x\": -2.753623188405797, \"y\": 3.333333333333334, \"x2\": -2.4637681159420293, \"y2\": 3.6231884057971016, \"center_x\": -2.608695652173913, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.0013688817376036064}, {\"x\": -2.4637681159420284, \"y\": 3.333333333333334, \"x2\": -2.1739130434782608, \"y2\": 3.6231884057971016, \"center_x\": -2.3188405797101446, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.001693563004469659}, {\"x\": -2.1739130434782608, \"y\": 3.333333333333334, \"x2\": -1.8840579710144931, \"y2\": 3.6231884057971016, \"center_x\": -2.028985507246377, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.002075786107581996}, {\"x\": -1.8840579710144922, \"y\": 3.333333333333334, \"x2\": -1.5942028985507246, \"y2\": 3.6231884057971016, \"center_x\": -1.7391304347826084, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.0025206332374069643}, {\"x\": -1.5942028985507246, \"y\": 3.333333333333334, \"x2\": -1.304347826086957, \"y2\": 3.6231884057971016, \"center_x\": -1.4492753623188408, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.0030323723692441797}, {\"x\": -1.304347826086957, \"y\": 3.333333333333334, \"x2\": -1.0144927536231894, \"y2\": 3.6231884057971016, \"center_x\": -1.1594202898550732, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.0036141087570637355}, {\"x\": -1.0144927536231876, \"y\": 3.333333333333334, \"x2\": -0.72463768115942, \"y2\": 3.6231884057971016, \"center_x\": -0.8695652173913038, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.004267423245273602}, {\"x\": -0.72463768115942, \"y\": 3.333333333333334, \"x2\": -0.43478260869565233, \"y2\": 3.6231884057971016, \"center_x\": -0.5797101449275361, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.004992016754393206}, {\"x\": -0.43478260869565233, \"y\": 3.333333333333334, \"x2\": -0.1449275362318847, \"y2\": 3.6231884057971016, \"center_x\": -0.2898550724637685, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.005785383658431456}, {\"x\": -0.14492753623188293, \"y\": 3.333333333333334, \"x2\": 0.1449275362318847, \"y2\": 3.6231884057971016, \"center_x\": 8.881784197001252e-16, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.00664253894489519}, {\"x\": 0.1449275362318847, \"y\": 3.333333333333334, \"x2\": 0.43478260869565233, \"y2\": 3.6231884057971016, \"center_x\": 0.2898550724637685, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.007555824616950575}, {\"x\": 0.43478260869565233, \"y\": 3.333333333333334, \"x2\": 0.72463768115942, \"y2\": 3.6231884057971016, \"center_x\": 0.5797101449275361, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.008514819431164715}, {\"x\": 0.72463768115942, \"y\": 3.333333333333334, \"x2\": 1.0144927536231876, \"y2\": 3.6231884057971016, \"center_x\": 0.8695652173913038, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.009506372569980895}, {\"x\": 1.0144927536231894, \"y\": 3.333333333333334, \"x2\": 1.304347826086957, \"y2\": 3.6231884057971016, \"center_x\": 1.1594202898550732, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.010514776212139686}, {\"x\": 1.304347826086957, \"y\": 3.333333333333334, \"x2\": 1.5942028985507246, \"y2\": 3.6231884057971016, \"center_x\": 1.4492753623188408, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.011522084382001354}, {\"x\": 1.5942028985507246, \"y\": 3.333333333333334, \"x2\": 1.8840579710144922, \"y2\": 3.6231884057971016, \"center_x\": 1.7391304347826084, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.01250857634283142}, {\"x\": 1.884057971014494, \"y\": 3.333333333333334, \"x2\": 2.1739130434782616, \"y2\": 3.6231884057971016, \"center_x\": 2.028985507246378, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.013453352763753928}, {\"x\": 2.1739130434782616, \"y\": 3.333333333333334, \"x2\": 2.4637681159420293, \"y2\": 3.6231884057971016, \"center_x\": 2.3188405797101455, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.014335042709602577}, {\"x\": 2.4637681159420293, \"y\": 3.333333333333334, \"x2\": 2.753623188405797, \"y2\": 3.6231884057971016, \"center_x\": 2.608695652173913, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.01513259004714306}, {\"x\": 2.753623188405797, \"y\": 3.333333333333334, \"x2\": 3.0434782608695645, \"y2\": 3.6231884057971016, \"center_x\": 2.8985507246376807, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.015826080012913326}, {\"x\": 3.0434782608695663, \"y\": 3.333333333333334, \"x2\": 3.333333333333334, \"y2\": 3.6231884057971016, \"center_x\": 3.18840579710145, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.016397561251191222}, {\"x\": 3.333333333333334, \"y\": 3.333333333333334, \"x2\": 3.6231884057971016, \"y2\": 3.6231884057971016, \"center_x\": 3.4782608695652177, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.01683181623986307}, {\"x\": 3.6231884057971016, \"y\": 3.333333333333334, \"x2\": 3.913043478260869, \"y2\": 3.6231884057971016, \"center_x\": 3.7681159420289854, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.017117034064237667}, {\"x\": 3.913043478260871, \"y\": 3.333333333333334, \"x2\": 4.202898550724639, \"y2\": 3.6231884057971016, \"center_x\": 4.057971014492755, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.017245344058563587}, {\"x\": 4.202898550724639, \"y\": 3.333333333333334, \"x2\": 4.492753623188406, \"y2\": 3.6231884057971016, \"center_x\": 4.347826086956522, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.0172131766700886}, {\"x\": 4.492753623188406, \"y\": 3.333333333333334, \"x2\": 4.782608695652174, \"y2\": 3.6231884057971016, \"center_x\": 4.63768115942029, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.017021428454017287}, {\"x\": 4.782608695652174, \"y\": 3.333333333333334, \"x2\": 5.0724637681159415, \"y2\": 3.6231884057971016, \"center_x\": 4.927536231884058, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.01667542055517041}, {\"x\": 5.072463768115943, \"y\": 3.333333333333334, \"x2\": 5.362318840579711, \"y2\": 3.6231884057971016, \"center_x\": 5.217391304347827, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.016184653359752416}, {\"x\": 5.362318840579711, \"y\": 3.333333333333334, \"x2\": 5.6521739130434785, \"y2\": 3.6231884057971016, \"center_x\": 5.507246376811595, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.01556237310593858}, {\"x\": 5.6521739130434785, \"y\": 3.333333333333334, \"x2\": 5.942028985507246, \"y2\": 3.6231884057971016, \"center_x\": 5.797101449275362, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.014824978044985428}, {\"x\": 5.942028985507246, \"y\": 3.333333333333334, \"x2\": 6.231884057971014, \"y2\": 3.6231884057971016, \"center_x\": 6.08695652173913, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.01399130129612019}, {\"x\": 6.2318840579710155, \"y\": 3.333333333333334, \"x2\": 6.521739130434783, \"y2\": 3.6231884057971016, \"center_x\": 6.376811594202899, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.01308181411328583}, {\"x\": 6.521739130434785, \"y\": 3.333333333333334, \"x2\": 6.8115942028985526, \"y2\": 3.6231884057971016, \"center_x\": 6.666666666666669, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.012117796445186641}, {\"x\": 6.811594202898551, \"y\": 3.333333333333334, \"x2\": 7.101449275362318, \"y2\": 3.6231884057971016, \"center_x\": 6.956521739130435, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.011120521311170306}, {\"x\": 7.10144927536232, \"y\": 3.333333333333334, \"x2\": 7.391304347826088, \"y2\": 3.6231884057971016, \"center_x\": 7.246376811594204, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.010110495844519491}, {\"x\": 7.391304347826086, \"y\": 3.333333333333334, \"x2\": 7.681159420289854, \"y2\": 3.6231884057971016, \"center_x\": 7.53623188405797, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.0091067953658272}, {\"x\": 7.681159420289855, \"y\": 3.333333333333334, \"x2\": 7.971014492753623, \"y2\": 3.6231884057971016, \"center_x\": 7.826086956521739, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.008126518254904964}, {\"x\": 7.971014492753625, \"y\": 3.333333333333334, \"x2\": 8.260869565217392, \"y2\": 3.6231884057971016, \"center_x\": 8.115942028985508, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.007184379536816565}, {\"x\": 8.26086956521739, \"y\": 3.333333333333334, \"x2\": 8.550724637681158, \"y2\": 3.6231884057971016, \"center_x\": 8.405797101449274, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.006292450874478565}, {\"x\": 8.55072463768116, \"y\": 3.333333333333334, \"x2\": 8.840579710144928, \"y2\": 3.6231884057971016, \"center_x\": 8.695652173913043, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.005460044907529852}, {\"x\": 8.84057971014493, \"y\": 3.333333333333334, \"x2\": 9.130434782608697, \"y2\": 3.6231884057971016, \"center_x\": 8.985507246376812, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.00469373331166271}, {\"x\": 9.130434782608695, \"y\": 3.333333333333334, \"x2\": 9.420289855072463, \"y2\": 3.6231884057971016, \"center_x\": 9.275362318840578, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.003997481111445211}, {\"x\": 9.420289855072465, \"y\": 3.333333333333334, \"x2\": 9.710144927536232, \"y2\": 3.6231884057971016, \"center_x\": 9.565217391304348, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.00337287498907646}, {\"x\": 9.710144927536234, \"y\": 3.333333333333334, \"x2\": 10.000000000000002, \"y2\": 3.6231884057971016, \"center_x\": 9.855072463768117, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.002819420701044596}, {\"x\": 10.0, \"y\": 3.333333333333334, \"x2\": 10.289855072463768, \"y2\": 3.6231884057971016, \"center_x\": 10.144927536231883, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.0023348841543963327}, {\"x\": -10.0, \"y\": 3.6231884057971016, \"x2\": -9.710144927536232, \"y2\": 3.913043478260869, \"center_x\": -9.855072463768117, \"center_y\": 3.7681159420289854, \"value_uncond\": 3.2746695161816275e-07}, {\"x\": -9.710144927536232, \"y\": 3.6231884057971016, \"x2\": -9.420289855072465, \"y2\": 3.913043478260869, \"center_x\": -9.565217391304348, \"center_y\": 3.7681159420289854, \"value_uncond\": 5.116318143053023e-07}, {\"x\": -9.420289855072463, \"y\": 3.6231884057971016, \"x2\": -9.130434782608695, \"y2\": 3.913043478260869, \"center_x\": -9.275362318840578, \"center_y\": 3.7681159420289854, \"value_uncond\": 7.919420828616108e-07}, {\"x\": -9.130434782608695, \"y\": 3.6231884057971016, \"x2\": -8.840579710144928, \"y2\": 3.913043478260869, \"center_x\": -8.985507246376812, \"center_y\": 3.7681159420289854, \"value_uncond\": 1.2144373501348344e-06}, {\"x\": -8.840579710144928, \"y\": 3.6231884057971016, \"x2\": -8.55072463768116, \"y2\": 3.913043478260869, \"center_x\": -8.695652173913043, \"center_y\": 3.7681159420289854, \"value_uncond\": 1.8450265672647379e-06}, {\"x\": -8.55072463768116, \"y\": 3.6231884057971016, \"x2\": -8.260869565217392, \"y2\": 3.913043478260869, \"center_x\": -8.405797101449277, \"center_y\": 3.7681159420289854, \"value_uncond\": 2.7770004316183796e-06}, {\"x\": -8.26086956521739, \"y\": 3.6231884057971016, \"x2\": -7.971014492753623, \"y2\": 3.913043478260869, \"center_x\": -8.115942028985508, \"center_y\": 3.7681159420289854, \"value_uncond\": 4.14090326299778e-06}, {\"x\": -7.971014492753623, \"y\": 3.6231884057971016, \"x2\": -7.681159420289855, \"y2\": 3.913043478260869, \"center_x\": -7.826086956521739, \"center_y\": 3.7681159420289854, \"value_uncond\": 6.117303630949506e-06}, {\"x\": -7.681159420289855, \"y\": 3.6231884057971016, \"x2\": -7.391304347826088, \"y2\": 3.913043478260869, \"center_x\": -7.536231884057972, \"center_y\": 3.7681159420289854, \"value_uncond\": 8.953045753154204e-06}, {\"x\": -7.391304347826087, \"y\": 3.6231884057971016, \"x2\": -7.101449275362319, \"y2\": 3.913043478260869, \"center_x\": -7.246376811594203, \"center_y\": 3.7681159420289854, \"value_uncond\": 1.2981574952194378e-05}, {\"x\": -7.101449275362318, \"y\": 3.6231884057971016, \"x2\": -6.811594202898551, \"y2\": 3.913043478260869, \"center_x\": -6.956521739130435, \"center_y\": 3.7681159420289854, \"value_uncond\": 1.8647893534485788e-05}, {\"x\": -6.811594202898551, \"y\": 3.6231884057971016, \"x2\": -6.521739130434783, \"y2\": 3.913043478260869, \"center_x\": -6.666666666666667, \"center_y\": 3.7681159420289854, \"value_uncond\": 2.6538598946131853e-05}, {\"x\": -6.521739130434782, \"y\": 3.6231884057971016, \"x2\": -6.231884057971015, \"y2\": 3.913043478260869, \"center_x\": -6.3768115942028984, \"center_y\": 3.7681159420289854, \"value_uncond\": 3.741726298148362e-05}, {\"x\": -6.231884057971014, \"y\": 3.6231884057971016, \"x2\": -5.942028985507246, \"y2\": 3.913043478260869, \"center_x\": -6.08695652173913, \"center_y\": 3.7681159420289854, \"value_uncond\": 5.2265108435253366e-05}, {\"x\": -5.942028985507246, \"y\": 3.6231884057971016, \"x2\": -5.6521739130434785, \"y2\": 3.913043478260869, \"center_x\": -5.797101449275362, \"center_y\": 3.7681159420289854, \"value_uncond\": 7.232651005819936e-05}, {\"x\": -5.6521739130434785, \"y\": 3.6231884057971016, \"x2\": -5.362318840579711, \"y2\": 3.913043478260869, \"center_x\": -5.507246376811595, \"center_y\": 3.7681159420289854, \"value_uncond\": 9.91582784969064e-05}, {\"x\": -5.36231884057971, \"y\": 3.6231884057971016, \"x2\": -5.072463768115942, \"y2\": 3.913043478260869, \"center_x\": -5.217391304347826, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0001346809779933359}, {\"x\": -5.0724637681159415, \"y\": 3.6231884057971016, \"x2\": -4.782608695652174, \"y2\": 3.913043478260869, \"center_x\": -4.927536231884058, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0001812296947676252}, {\"x\": -4.782608695652174, \"y\": 3.6231884057971016, \"x2\": -4.492753623188406, \"y2\": 3.913043478260869, \"center_x\": -4.63768115942029, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.00024160074612066055}, {\"x\": -4.492753623188405, \"y\": 3.6231884057971016, \"x2\": -4.202898550724638, \"y2\": 3.913043478260869, \"center_x\": -4.3478260869565215, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.00031908985588565455}, {\"x\": -4.202898550724638, \"y\": 3.6231884057971016, \"x2\": -3.91304347826087, \"y2\": 3.913043478260869, \"center_x\": -4.057971014492754, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.00041751639990056063}, {\"x\": -3.913043478260869, \"y\": 3.6231884057971016, \"x2\": -3.6231884057971016, \"y2\": 3.913043478260869, \"center_x\": -3.7681159420289854, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0005412275494716628}, {\"x\": -3.6231884057971016, \"y\": 3.6231884057971016, \"x2\": -3.333333333333334, \"y2\": 3.913043478260869, \"center_x\": -3.4782608695652177, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0006950756350950657}, {\"x\": -3.333333333333333, \"y\": 3.6231884057971016, \"x2\": -3.0434782608695654, \"y2\": 3.913043478260869, \"center_x\": -3.1884057971014492, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0008843619528953801}, {\"x\": -3.0434782608695645, \"y\": 3.6231884057971016, \"x2\": -2.753623188405797, \"y2\": 3.913043478260869, \"center_x\": -2.8985507246376807, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0011147406784952837}, {\"x\": -2.753623188405797, \"y\": 3.6231884057971016, \"x2\": -2.4637681159420293, \"y2\": 3.913043478260869, \"center_x\": -2.608695652173913, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0013920776580831067}, {\"x\": -2.4637681159420284, \"y\": 3.6231884057971016, \"x2\": -2.1739130434782608, \"y2\": 3.913043478260869, \"center_x\": -2.3188405797101446, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0017222607010635757}, {\"x\": -2.1739130434782608, \"y\": 3.6231884057971016, \"x2\": -1.8840579710144931, \"y2\": 3.913043478260869, \"center_x\": -2.028985507246377, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0021109606359296495}, {\"x\": -1.8840579710144922, \"y\": 3.6231884057971016, \"x2\": -1.5942028985507246, \"y2\": 3.913043478260869, \"center_x\": -1.7391304347826084, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.002563345771679817}, {\"x\": -1.5942028985507246, \"y\": 3.6231884057971016, \"x2\": -1.304347826086957, \"y2\": 3.913043478260869, \"center_x\": -1.4492753623188408, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0030837564051393158}, {\"x\": -1.304347826086957, \"y\": 3.6231884057971016, \"x2\": -1.0144927536231894, \"y2\": 3.913043478260869, \"center_x\": -1.1594202898550732, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0036753504093045447}, {\"x\": -1.0144927536231876, \"y\": 3.6231884057971016, \"x2\": -0.72463768115942, \"y2\": 3.913043478260869, \"center_x\": -0.8695652173913038, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.00433973541624538}, {\"x\": -0.72463768115942, \"y\": 3.6231884057971016, \"x2\": -0.43478260869565233, \"y2\": 3.913043478260869, \"center_x\": -0.5797101449275361, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.005076607278531506}, {\"x\": -0.43478260869565233, \"y\": 3.6231884057971016, \"x2\": -0.1449275362318847, \"y2\": 3.913043478260869, \"center_x\": -0.2898550724637685, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.005883417911937755}, {\"x\": -0.14492753623188293, \"y\": 3.6231884057971016, \"x2\": 0.1449275362318847, \"y2\": 3.913043478260869, \"center_x\": 8.881784197001252e-16, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.006755097832135153}, {\"x\": 0.1449275362318847, \"y\": 3.6231884057971016, \"x2\": 0.43478260869565233, \"y2\": 3.913043478260869, \"center_x\": 0.2898550724637685, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.007683859276305922}, {\"x\": 0.43478260869565233, \"y\": 3.6231884057971016, \"x2\": 0.72463768115942, \"y2\": 3.913043478260869, \"center_x\": 0.5797101449275361, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.008659104411376637}, {\"x\": 0.72463768115942, \"y\": 3.6231884057971016, \"x2\": 1.0144927536231876, \"y2\": 3.913043478260869, \"center_x\": 0.8695652173913038, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.00966745957707897}, {\"x\": 1.0144927536231894, \"y\": 3.6231884057971016, \"x2\": 1.304347826086957, \"y2\": 3.913043478260869, \"center_x\": 1.1594202898550732, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.01069295078060424}, {\"x\": 1.304347826086957, \"y\": 3.6231884057971016, \"x2\": 1.5942028985507246, \"y2\": 3.913043478260869, \"center_x\": 1.4492753623188408, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.011717327948878703}, {\"x\": 1.5942028985507246, \"y\": 3.6231884057971016, \"x2\": 1.8840579710144922, \"y2\": 3.913043478260869, \"center_x\": 1.7391304347826084, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.012720536174122625}, {\"x\": 1.884057971014494, \"y\": 3.6231884057971016, \"x2\": 2.1739130434782616, \"y2\": 3.913043478260869, \"center_x\": 2.028985507246378, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.013681321982948132}, {\"x\": 2.1739130434782616, \"y\": 3.6231884057971016, \"x2\": 2.4637681159420293, \"y2\": 3.913043478260869, \"center_x\": 2.3188405797101455, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.014577952306266703}, {\"x\": 2.4637681159420293, \"y\": 3.6231884057971016, \"x2\": 2.753623188405797, \"y2\": 3.913043478260869, \"center_x\": 2.608695652173913, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.015389014211291014}, {\"x\": 2.753623188405797, \"y\": 3.6231884057971016, \"x2\": 3.0434782608695645, \"y2\": 3.913043478260869, \"center_x\": 2.8985507246376807, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.016094255475699756}, {\"x\": 3.0434782608695663, \"y\": 3.6231884057971016, \"x2\": 3.333333333333334, \"y2\": 3.913043478260869, \"center_x\": 3.18840579710145, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.016675420555170413}, {\"x\": 3.333333333333334, \"y\": 3.6231884057971016, \"x2\": 3.6231884057971016, \"y2\": 3.913043478260869, \"center_x\": 3.4782608695652177, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.017117034064237667}, {\"x\": 3.6231884057971016, \"y\": 3.6231884057971016, \"x2\": 3.913043478260869, \"y2\": 3.913043478260869, \"center_x\": 3.7681159420289854, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.017407084950367555}, {\"x\": 3.913043478260871, \"y\": 3.6231884057971016, \"x2\": 4.202898550724639, \"y2\": 3.913043478260869, \"center_x\": 4.057971014492755, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.017537569178115803}, {\"x\": 4.202898550724639, \"y\": 3.6231884057971016, \"x2\": 4.492753623188406, \"y2\": 3.913043478260869, \"center_x\": 4.347826086956522, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.017504856708086578}, {\"x\": 4.492753623188406, \"y\": 3.6231884057971016, \"x2\": 4.782608695652174, \"y2\": 3.913043478260869, \"center_x\": 4.63768115942029, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.01730985928775613}, {\"x\": 4.782608695652174, \"y\": 3.6231884057971016, \"x2\": 5.0724637681159415, \"y2\": 3.913043478260869, \"center_x\": 4.927536231884058, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0169579882295972}, {\"x\": 5.072463768115943, \"y\": 3.6231884057971016, \"x2\": 5.362318840579711, \"y2\": 3.913043478260869, \"center_x\": 5.217391304347827, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.01645890490538141}, {\"x\": 5.362318840579711, \"y\": 3.6231884057971016, \"x2\": 5.6521739130434785, \"y2\": 3.913043478260869, \"center_x\": 5.507246376811595, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.015826080012913323}, {\"x\": 5.6521739130434785, \"y\": 3.6231884057971016, \"x2\": 5.942028985507246, \"y2\": 3.913043478260869, \"center_x\": 5.797101449275362, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.015076189674445703}, {\"x\": 5.942028985507246, \"y\": 3.6231884057971016, \"x2\": 6.231884057971014, \"y2\": 3.913043478260869, \"center_x\": 6.08695652173913, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.014228386139430086}, {\"x\": 6.2318840579710155, \"y\": 3.6231884057971016, \"x2\": 6.521739130434783, \"y2\": 3.913043478260869, \"center_x\": 6.376811594202899, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.013303487550489101}, {\"x\": 6.521739130434785, \"y\": 3.6231884057971016, \"x2\": 6.8115942028985526, \"y2\": 3.913043478260869, \"center_x\": 6.666666666666669, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.012323134448469077}, {\"x\": 6.811594202898551, \"y\": 3.6231884057971016, \"x2\": 7.101449275362318, \"y2\": 3.913043478260869, \"center_x\": 6.956521739130435, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.011308960327440668}, {\"x\": 7.10144927536232, \"y\": 3.6231884057971016, \"x2\": 7.391304347826088, \"y2\": 3.913043478260869, \"center_x\": 7.246376811594204, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.010281819817347378}, {\"x\": 7.391304347826086, \"y\": 3.6231884057971016, \"x2\": 7.681159420289854, \"y2\": 3.913043478260869, \"center_x\": 7.53623188405797, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.009261111473147477}, {\"x\": 7.681159420289855, \"y\": 3.6231884057971016, \"x2\": 7.971014492753623, \"y2\": 3.913043478260869, \"center_x\": 7.826086956521739, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.008264223409439334}, {\"x\": 7.971014492753625, \"y\": 3.6231884057971016, \"x2\": 8.260869565217392, \"y2\": 3.913043478260869, \"center_x\": 8.115942028985508, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0073061199997452924}, {\"x\": 8.26086956521739, \"y\": 3.6231884057971016, \"x2\": 8.550724637681158, \"y2\": 3.913043478260869, \"center_x\": 8.405797101449274, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.006399077463245162}, {\"x\": 8.55072463768116, \"y\": 3.6231884057971016, \"x2\": 8.840579710144928, \"y2\": 3.913043478260869, \"center_x\": 8.695652173913043, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.005552566243749356}, {\"x\": 8.84057971014493, \"y\": 3.6231884057971016, \"x2\": 9.130434782608697, \"y2\": 3.913043478260869, \"center_x\": 8.985507246376812, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.004773269375048221}, {\"x\": 9.130434782608695, \"y\": 3.6231884057971016, \"x2\": 9.420289855072463, \"y2\": 3.913043478260869, \"center_x\": 9.275362318840578, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.004065219069686742}, {\"x\": 9.420289855072465, \"y\": 3.6231884057971016, \"x2\": 9.710144927536232, \"y2\": 3.913043478260869, \"center_x\": 9.565217391304348, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.003430028896448236}, {\"x\": 9.710144927536234, \"y\": 3.6231884057971016, \"x2\": 10.000000000000002, \"y2\": 3.913043478260869, \"center_x\": 9.855072463768117, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0028671962367853064}, {\"x\": 10.0, \"y\": 3.6231884057971016, \"x2\": 10.289855072463768, \"y2\": 3.913043478260869, \"center_x\": 10.144927536231883, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.002374449140681441}, {\"x\": -10.0, \"y\": 3.913043478260871, \"x2\": -9.710144927536232, \"y2\": 4.202898550724639, \"center_x\": -9.855072463768117, \"center_y\": 4.057971014492755, \"value_uncond\": 3.2992165741277494e-07}, {\"x\": -9.710144927536232, \"y\": 3.913043478260871, \"x2\": -9.420289855072465, \"y2\": 4.202898550724639, \"center_x\": -9.565217391304348, \"center_y\": 4.057971014492755, \"value_uncond\": 5.154670275171308e-07}, {\"x\": -9.420289855072463, \"y\": 3.913043478260871, \"x2\": -9.130434782608695, \"y2\": 4.202898550724639, \"center_x\": -9.275362318840578, \"center_y\": 4.057971014492755, \"value_uncond\": 7.978785134241195e-07}, {\"x\": -9.130434782608695, \"y\": 3.913043478260871, \"x2\": -8.840579710144928, \"y2\": 4.202898550724639, \"center_x\": -8.985507246376812, \"center_y\": 4.057971014492755, \"value_uncond\": 1.2235408226710357e-06}, {\"x\": -8.840579710144928, \"y\": 3.913043478260871, \"x2\": -8.55072463768116, \"y2\": 4.202898550724639, \"center_x\": -8.695652173913043, \"center_y\": 4.057971014492755, \"value_uncond\": 1.8588569626176071e-06}, {\"x\": -8.55072463768116, \"y\": 3.913043478260871, \"x2\": -8.260869565217392, \"y2\": 4.202898550724639, \"center_x\": -8.405797101449277, \"center_y\": 4.057971014492755, \"value_uncond\": 2.7978169415515185e-06}, {\"x\": -8.26086956521739, \"y\": 3.913043478260871, \"x2\": -7.971014492753623, \"y2\": 4.202898550724639, \"center_x\": -8.115942028985508, \"center_y\": 4.057971014492755, \"value_uncond\": 4.171943644887863e-06}, {\"x\": -7.971014492753623, \"y\": 3.913043478260871, \"x2\": -7.681159420289855, \"y2\": 4.202898550724639, \"center_x\": -7.826086956521739, \"center_y\": 4.057971014492755, \"value_uncond\": 6.1631591916285006e-06}, {\"x\": -7.681159420289855, \"y\": 3.913043478260871, \"x2\": -7.391304347826088, \"y2\": 4.202898550724639, \"center_x\": -7.536231884057972, \"center_y\": 4.057971014492755, \"value_uncond\": 9.020158153905162e-06}, {\"x\": -7.391304347826087, \"y\": 3.913043478260871, \"x2\": -7.101449275362319, \"y2\": 4.202898550724639, \"center_x\": -7.246376811594203, \"center_y\": 4.057971014492755, \"value_uncond\": 1.3078885374210632e-05}, {\"x\": -7.101449275362318, \"y\": 3.913043478260871, \"x2\": -6.811594202898551, \"y2\": 4.202898550724639, \"center_x\": -6.956521739130435, \"center_y\": 4.057971014492755, \"value_uncond\": 1.878767891462938e-05}, {\"x\": -6.811594202898551, \"y\": 3.913043478260871, \"x2\": -6.521739130434783, \"y2\": 4.202898550724639, \"center_x\": -6.666666666666667, \"center_y\": 4.057971014492755, \"value_uncond\": 2.673753337994889e-05}, {\"x\": -6.521739130434782, \"y\": 3.913043478260871, \"x2\": -6.231884057971015, \"y2\": 4.202898550724639, \"center_x\": -6.3768115942028984, \"center_y\": 4.057971014492755, \"value_uncond\": 3.769774433022827e-05}, {\"x\": -6.231884057971014, \"y\": 3.913043478260871, \"x2\": -5.942028985507246, \"y2\": 4.202898550724639, \"center_x\": -6.08695652173913, \"center_y\": 4.057971014492755, \"value_uncond\": 5.265688984677617e-05}, {\"x\": -5.942028985507246, \"y\": 3.913043478260871, \"x2\": -5.6521739130434785, \"y2\": 4.202898550724639, \"center_x\": -5.797101449275362, \"center_y\": 4.057971014492755, \"value_uncond\": 7.28686725648786e-05}, {\"x\": -5.6521739130434785, \"y\": 3.913043478260871, \"x2\": -5.362318840579711, \"y2\": 4.202898550724639, \"center_x\": -5.507246376811595, \"center_y\": 4.057971014492755, \"value_uncond\": 9.990157304802774e-05}, {\"x\": -5.36231884057971, \"y\": 3.913043478260871, \"x2\": -5.072463768115942, \"y2\": 4.202898550724639, \"center_x\": -5.217391304347826, \"center_y\": 4.057971014492755, \"value_uncond\": 0.00013569055216706725}, {\"x\": -5.0724637681159415, \"y\": 3.913043478260871, \"x2\": -4.782608695652174, \"y2\": 4.202898550724639, \"center_x\": -4.927536231884058, \"center_y\": 4.057971014492755, \"value_uncond\": 0.0001825882000448861}, {\"x\": -4.782608695652174, \"y\": 3.913043478260871, \"x2\": -4.492753623188406, \"y2\": 4.202898550724639, \"center_x\": -4.63768115942029, \"center_y\": 4.057971014492755, \"value_uncond\": 0.00024341179529235364}, {\"x\": -4.492753623188405, \"y\": 3.913043478260871, \"x2\": -4.202898550724638, \"y2\": 4.202898550724639, \"center_x\": -4.3478260869565215, \"center_y\": 4.057971014492755, \"value_uncond\": 0.0003214817666246586}, {\"x\": -4.202898550724638, \"y\": 3.913043478260871, \"x2\": -3.91304347826087, \"y2\": 4.202898550724639, \"center_x\": -4.057971014492754, \"center_y\": 4.057971014492755, \"value_uncond\": 0.0004206461200787862}, {\"x\": -3.913043478260869, \"y\": 3.913043478260871, \"x2\": -3.6231884057971016, \"y2\": 4.202898550724639, \"center_x\": -3.7681159420289854, \"center_y\": 4.057971014492755, \"value_uncond\": 0.0005452846135366828}, {\"x\": -3.6231884057971016, \"y\": 3.913043478260871, \"x2\": -3.333333333333334, \"y2\": 4.202898550724639, \"center_x\": -3.4782608695652177, \"center_y\": 4.057971014492755, \"value_uncond\": 0.0007002859507642661}, {\"x\": -3.333333333333333, \"y\": 3.913043478260871, \"x2\": -3.0434782608695654, \"y2\": 4.202898550724639, \"center_x\": -3.1884057971014492, \"center_y\": 4.057971014492755, \"value_uncond\": 0.000890991166620855}, {\"x\": -3.0434782608695645, \"y\": 3.913043478260871, \"x2\": -2.753623188405797, \"y2\": 4.202898550724639, \"center_x\": -2.8985507246376807, \"center_y\": 4.057971014492755, \"value_uncond\": 0.001123096820663128}, {\"x\": -2.753623188405797, \"y\": 3.913043478260871, \"x2\": -2.4637681159420293, \"y2\": 4.202898550724639, \"center_x\": -2.608695652173913, \"center_y\": 4.057971014492755, \"value_uncond\": 0.0014025127297047182}, {\"x\": -2.4637681159420284, \"y\": 3.913043478260871, \"x2\": -2.1739130434782608, \"y2\": 4.202898550724639, \"center_x\": -2.3188405797101446, \"center_y\": 4.057971014492755, \"value_uncond\": 0.001735170838412833}, {\"x\": -2.1739130434782608, \"y\": 3.913043478260871, \"x2\": -1.8840579710144931, \"y2\": 4.202898550724639, \"center_x\": -2.028985507246377, \"center_y\": 4.057971014492755, \"value_uncond\": 0.002126784484045035}, {\"x\": -1.8840579710144922, \"y\": 3.913043478260871, \"x2\": -1.5942028985507246, \"y2\": 4.202898550724639, \"center_x\": -1.7391304347826084, \"center_y\": 4.057971014492755, \"value_uncond\": 0.002582560717457531}, {\"x\": -1.5942028985507246, \"y\": 3.913043478260871, \"x2\": -1.304347826086957, \"y2\": 4.202898550724639, \"center_x\": -1.4492753623188408, \"center_y\": 4.057971014492755, \"value_uncond\": 0.003106872370519827}, {\"x\": -1.304347826086957, \"y\": 3.913043478260871, \"x2\": -1.0144927536231894, \"y2\": 4.202898550724639, \"center_x\": -1.1594202898550732, \"center_y\": 4.057971014492755, \"value_uncond\": 0.0037029009877747312}, {\"x\": -1.0144927536231876, \"y\": 3.913043478260871, \"x2\": -0.72463768115942, \"y2\": 4.202898550724639, \"center_x\": -0.8695652173913038, \"center_y\": 4.057971014492755, \"value_uncond\": 0.004372266252168516}, {\"x\": -0.72463768115942, \"y\": 3.913043478260871, \"x2\": -0.43478260869565233, \"y2\": 4.202898550724639, \"center_x\": -0.5797101449275361, \"center_y\": 4.057971014492755, \"value_uncond\": 0.005114661736369165}, {\"x\": -0.43478260869565233, \"y\": 3.913043478260871, \"x2\": -0.1449275362318847, \"y2\": 4.202898550724639, \"center_x\": -0.2898550724637685, \"center_y\": 4.057971014492755, \"value_uncond\": 0.005927520255606916}, {\"x\": -0.14492753623188293, \"y\": 3.913043478260871, \"x2\": 0.1449275362318847, \"y2\": 4.202898550724639, \"center_x\": 8.881784197001252e-16, \"center_y\": 4.057971014492755, \"value_uncond\": 0.006805734324488884}, {\"x\": 0.1449275362318847, \"y\": 3.913043478260871, \"x2\": 0.43478260869565233, \"y2\": 4.202898550724639, \"center_x\": 0.2898550724637685, \"center_y\": 4.057971014492755, \"value_uncond\": 0.007741457802805548}, {\"x\": 0.43478260869565233, \"y\": 3.913043478260871, \"x2\": 0.72463768115942, \"y2\": 4.202898550724639, \"center_x\": 0.5797101449275361, \"center_y\": 4.057971014492755, \"value_uncond\": 0.008724013415689048}, {\"x\": 0.72463768115942, \"y\": 3.913043478260871, \"x2\": 1.0144927536231876, \"y2\": 4.202898550724639, \"center_x\": 0.8695652173913038, \"center_y\": 4.057971014492755, \"value_uncond\": 0.009739927253361315}, {\"x\": 1.0144927536231894, \"y\": 3.913043478260871, \"x2\": 1.304347826086957, \"y2\": 4.202898550724639, \"center_x\": 1.1594202898550732, \"center_y\": 4.057971014492755, \"value_uncond\": 0.010773105581303807}, {\"x\": 1.304347826086957, \"y\": 3.913043478260871, \"x2\": 1.5942028985507246, \"y2\": 4.202898550724639, \"center_x\": 1.4492753623188408, \"center_y\": 4.057971014492755, \"value_uncond\": 0.01180516152314124}, {\"x\": 1.5942028985507246, \"y\": 3.913043478260871, \"x2\": 1.8840579710144922, \"y2\": 4.202898550724639, \"center_x\": 1.7391304347826084, \"center_y\": 4.057971014492755, \"value_uncond\": 0.012815889838676837}, {\"x\": 1.884057971014494, \"y\": 3.913043478260871, \"x2\": 2.1739130434782616, \"y2\": 4.202898550724639, \"center_x\": 2.028985507246378, \"center_y\": 4.057971014492755, \"value_uncond\": 0.013783877737608386}, {\"x\": 2.1739130434782616, \"y\": 3.913043478260871, \"x2\": 2.4637681159420293, \"y2\": 4.202898550724639, \"center_x\": 2.3188405797101455, \"center_y\": 4.057971014492755, \"value_uncond\": 0.01468722923886384}, {\"x\": 2.4637681159420293, \"y\": 3.913043478260871, \"x2\": 2.753623188405797, \"y2\": 4.202898550724639, \"center_x\": 2.608695652173913, \"center_y\": 4.057971014492755, \"value_uncond\": 0.015504370897427292}, {\"x\": 2.753623188405797, \"y\": 3.913043478260871, \"x2\": 3.0434782608695645, \"y2\": 4.202898550724639, \"center_x\": 2.8985507246376807, \"center_y\": 4.057971014492755, \"value_uncond\": 0.01621489867948244}, {\"x\": 3.0434782608695663, \"y\": 3.913043478260871, \"x2\": 3.333333333333334, \"y2\": 4.202898550724639, \"center_x\": 3.18840579710145, \"center_y\": 4.057971014492755, \"value_uncond\": 0.016800420196392517}, {\"x\": 3.333333333333334, \"y\": 3.913043478260871, \"x2\": 3.6231884057971016, \"y2\": 4.202898550724639, \"center_x\": 3.4782608695652177, \"center_y\": 4.057971014492755, \"value_uncond\": 0.017245344058563587}, {\"x\": 3.6231884057971016, \"y\": 3.913043478260871, \"x2\": 3.913043478260869, \"y2\": 4.202898550724639, \"center_x\": 3.7681159420289854, \"center_y\": 4.057971014492755, \"value_uncond\": 0.017537569178115803}, {\"x\": 3.913043478260871, \"y\": 3.913043478260871, \"x2\": 4.202898550724639, \"y2\": 4.202898550724639, \"center_x\": 4.057971014492755, \"center_y\": 4.057971014492755, \"value_uncond\": 0.017669031521024604}, {\"x\": 4.202898550724639, \"y\": 3.913043478260871, \"x2\": 4.492753623188406, \"y2\": 4.202898550724639, \"center_x\": 4.347826086956522, \"center_y\": 4.057971014492755, \"value_uncond\": 0.017636073836968927}, {\"x\": 4.492753623188406, \"y\": 3.913043478260871, \"x2\": 4.782608695652174, \"y2\": 4.202898550724639, \"center_x\": 4.63768115942029, \"center_y\": 4.057971014492755, \"value_uncond\": 0.017439614707921755}, {\"x\": 4.782608695652174, \"y\": 3.913043478260871, \"x2\": 5.0724637681159415, \"y2\": 4.202898550724639, \"center_x\": 4.927536231884058, \"center_y\": 4.057971014492755, \"value_uncond\": 0.017085106009777626}, {\"x\": 5.072463768115943, \"y\": 3.913043478260871, \"x2\": 5.362318840579711, \"y2\": 4.202898550724639, \"center_x\": 5.217391304347827, \"center_y\": 4.057971014492755, \"value_uncond\": 0.016582281536350007}, {\"x\": 5.362318840579711, \"y\": 3.913043478260871, \"x2\": 5.6521739130434785, \"y2\": 4.202898550724639, \"center_x\": 5.507246376811595, \"center_y\": 4.057971014492755, \"value_uncond\": 0.015944712962350577}, {\"x\": 5.6521739130434785, \"y\": 3.913043478260871, \"x2\": 5.942028985507246, \"y2\": 4.202898550724639, \"center_x\": 5.797101449275362, \"center_y\": 4.057971014492755, \"value_uncond\": 0.01518920141493328}, {\"x\": 5.942028985507246, \"y\": 3.913043478260871, \"x2\": 6.231884057971014, \"y2\": 4.202898550724639, \"center_x\": 6.08695652173913, \"center_y\": 4.057971014492755, \"value_uncond\": 0.014335042709602576}, {\"x\": 6.2318840579710155, \"y\": 3.913043478260871, \"x2\": 6.521739130434783, \"y2\": 4.202898550724639, \"center_x\": 6.376811594202899, \"center_y\": 4.057971014492755, \"value_uncond\": 0.013403211042638046}, {\"x\": 6.521739130434785, \"y\": 3.913043478260871, \"x2\": 6.8115942028985526, \"y2\": 4.202898550724639, \"center_x\": 6.666666666666669, \"center_y\": 4.057971014492755, \"value_uncond\": 0.012415509173274013}, {\"x\": 6.811594202898551, \"y\": 3.913043478260871, \"x2\": 7.101449275362318, \"y2\": 4.202898550724639, \"center_x\": 6.956521739130435, \"center_y\": 4.057971014492755, \"value_uncond\": 0.011393732761146204}, {\"x\": 7.10144927536232, \"y\": 3.913043478260871, \"x2\": 7.391304347826088, \"y2\": 4.202898550724639, \"center_x\": 7.246376811594204, \"center_y\": 4.057971014492755, \"value_uncond\": 0.010358892763365537}, {\"x\": 7.391304347826086, \"y\": 3.913043478260871, \"x2\": 7.681159420289854, \"y2\": 4.202898550724639, \"center_x\": 7.53623188405797, \"center_y\": 4.057971014492755, \"value_uncond\": 0.009330533147259464}, {\"x\": 7.681159420289855, \"y\": 3.913043478260871, \"x2\": 7.971014492753623, \"y2\": 4.202898550724639, \"center_x\": 7.826086956521739, \"center_y\": 4.057971014492755, \"value_uncond\": 0.008326172369451556}, {\"x\": 7.971014492753625, \"y\": 3.913043478260871, \"x2\": 8.260869565217392, \"y2\": 4.202898550724639, \"center_x\": 8.115942028985508, \"center_y\": 4.057971014492755, \"value_uncond\": 0.007360886977026152}, {\"x\": 8.26086956521739, \"y\": 3.913043478260871, \"x2\": 8.550724637681158, \"y2\": 4.202898550724639, \"center_x\": 8.405797101449274, \"center_y\": 4.057971014492755, \"value_uncond\": 0.006447045212209076}, {\"x\": 8.55072463768116, \"y\": 3.913043478260871, \"x2\": 8.840579710144928, \"y2\": 4.202898550724639, \"center_x\": 8.695652173913043, \"center_y\": 4.057971014492755, \"value_uncond\": 0.005594188509648697}, {\"x\": 8.84057971014493, \"y\": 3.913043478260871, \"x2\": 9.130434782608697, \"y2\": 4.202898550724639, \"center_x\": 8.985507246376812, \"center_y\": 4.057971014492755, \"value_uncond\": 0.004809049999432683}, {\"x\": 9.130434782608695, \"y\": 3.913043478260871, \"x2\": 9.420289855072463, \"y2\": 4.202898550724639, \"center_x\": 9.275362318840578, \"center_y\": 4.057971014492755, \"value_uncond\": 0.004095692119737797}, {\"x\": 9.420289855072465, \"y\": 3.913043478260871, \"x2\": 9.710144927536232, \"y2\": 4.202898550724639, \"center_x\": 9.565217391304348, \"center_y\": 4.057971014492755, \"value_uncond\": 0.003455740534725601}, {\"x\": 9.710144927536234, \"y\": 3.913043478260871, \"x2\": 10.000000000000002, \"y2\": 4.202898550724639, \"center_x\": 9.855072463768117, \"center_y\": 4.057971014492755, \"value_uncond\": 0.0028886888581993076}, {\"x\": 10.0, \"y\": 3.913043478260871, \"x2\": 10.289855072463768, \"y2\": 4.202898550724639, \"center_x\": 10.144927536231883, \"center_y\": 4.057971014492755, \"value_uncond\": 0.002392248109511243}, {\"x\": -10.0, \"y\": 4.202898550724639, \"x2\": -9.710144927536232, \"y2\": 4.492753623188406, \"center_x\": -9.855072463768117, \"center_y\": 4.347826086956522, \"value_uncond\": 3.2930626127546e-07}, {\"x\": -9.710144927536232, \"y\": 4.202898550724639, \"x2\": -9.420289855072465, \"y2\": 4.492753623188406, \"center_x\": -9.565217391304348, \"center_y\": 4.347826086956522, \"value_uncond\": 5.145055373860044e-07}, {\"x\": -9.420289855072463, \"y\": 4.202898550724639, \"x2\": -9.130434782608695, \"y2\": 4.492753623188406, \"center_x\": -9.275362318840578, \"center_y\": 4.347826086956522, \"value_uncond\": 7.963902469094011e-07}, {\"x\": -9.130434782608695, \"y\": 4.202898550724639, \"x2\": -8.840579710144928, \"y2\": 4.492753623188406, \"center_x\": -8.985507246376812, \"center_y\": 4.347826086956522, \"value_uncond\": 1.2212585769342034e-06}, {\"x\": -8.840579710144928, \"y\": 4.202898550724639, \"x2\": -8.55072463768116, \"y2\": 4.492753623188406, \"center_x\": -8.695652173913043, \"center_y\": 4.347826086956522, \"value_uncond\": 1.8553896746451031e-06}, {\"x\": -8.55072463768116, \"y\": 4.202898550724639, \"x2\": -8.260869565217392, \"y2\": 4.492753623188406, \"center_x\": -8.405797101449277, \"center_y\": 4.347826086956522, \"value_uncond\": 2.7925982306846808e-06}, {\"x\": -8.26086956521739, \"y\": 4.202898550724639, \"x2\": -7.971014492753623, \"y2\": 4.492753623188406, \"center_x\": -8.115942028985508, \"center_y\": 4.347826086956522, \"value_uncond\": 4.164161803512874e-06}, {\"x\": -7.971014492753623, \"y\": 4.202898550724639, \"x2\": -7.681159420289855, \"y2\": 4.492753623188406, \"center_x\": -7.826086956521739, \"center_y\": 4.347826086956522, \"value_uncond\": 6.1516631765141e-06}, {\"x\": -7.681159420289855, \"y\": 4.202898550724639, \"x2\": -7.391304347826088, \"y2\": 4.492753623188406, \"center_x\": -7.536231884057972, \"center_y\": 4.347826086956522, \"value_uncond\": 9.003333036907952e-06}, {\"x\": -7.391304347826087, \"y\": 4.202898550724639, \"x2\": -7.101449275362319, \"y2\": 4.492753623188406, \"center_x\": -7.246376811594203, \"center_y\": 4.347826086956522, \"value_uncond\": 1.3054489596125642e-05}, {\"x\": -7.101449275362318, \"y\": 4.202898550724639, \"x2\": -6.811594202898551, \"y2\": 4.492753623188406, \"center_x\": -6.956521739130435, \"center_y\": 4.347826086956522, \"value_uncond\": 1.8752634640410333e-05}, {\"x\": -6.811594202898551, \"y\": 4.202898550724639, \"x2\": -6.521739130434783, \"y2\": 4.492753623188406, \"center_x\": -6.666666666666667, \"center_y\": 4.347826086956522, \"value_uncond\": 2.6687660404369222e-05}, {\"x\": -6.521739130434782, \"y\": 4.202898550724639, \"x2\": -6.231884057971015, \"y2\": 4.492753623188406, \"center_x\": -6.3768115942028984, \"center_y\": 4.347826086956522, \"value_uncond\": 3.762742749674654e-05}, {\"x\": -6.231884057971014, \"y\": 4.202898550724639, \"x2\": -5.942028985507246, \"y2\": 4.492753623188406, \"center_x\": -6.08695652173913, \"center_y\": 4.347826086956522, \"value_uncond\": 5.2558670024322436e-05}, {\"x\": -5.942028985507246, \"y\": 4.202898550724639, \"x2\": -5.6521739130434785, \"y2\": 4.492753623188406, \"center_x\": -5.797101449275362, \"center_y\": 4.347826086956522, \"value_uncond\": 7.273275211643228e-05}, {\"x\": -5.6521739130434785, \"y\": 4.202898550724639, \"x2\": -5.362318840579711, \"y2\": 4.492753623188406, \"center_x\": -5.507246376811595, \"center_y\": 4.347826086956522, \"value_uncond\": 9.971522868176951e-05}, {\"x\": -5.36231884057971, \"y\": 4.202898550724639, \"x2\": -5.072463768115942, \"y2\": 4.492753623188406, \"center_x\": -5.217391304347826, \"center_y\": 4.347826086956522, \"value_uncond\": 0.00013543745134813776}, {\"x\": -5.0724637681159415, \"y\": 4.202898550724639, \"x2\": -4.782608695652174, \"y2\": 4.492753623188406, \"center_x\": -4.927536231884058, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0001822476220000616}, {\"x\": -4.782608695652174, \"y\": 4.202898550724639, \"x2\": -4.492753623188406, \"y2\": 4.492753623188406, \"center_x\": -4.63768115942029, \"center_y\": 4.347826086956522, \"value_uncond\": 0.00024295776423608866}, {\"x\": -4.492753623188405, \"y\": 4.202898550724639, \"x2\": -4.202898550724638, \"y2\": 4.492753623188406, \"center_x\": -4.3478260869565215, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0003208821132434606}, {\"x\": -4.202898550724638, \"y\": 4.202898550724639, \"x2\": -3.91304347826087, \"y2\": 4.492753623188406, \"center_x\": -4.057971014492754, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0004198614974519994}, {\"x\": -3.913043478260869, \"y\": 4.202898550724639, \"x2\": -3.6231884057971016, \"y2\": 4.492753623188406, \"center_x\": -3.7681159420289854, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0005442675052706195}, {\"x\": -3.6231884057971016, \"y\": 4.202898550724639, \"x2\": -3.333333333333334, \"y2\": 4.492753623188406, \"center_x\": -3.4782608695652177, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0006989797216658312}, {\"x\": -3.333333333333333, \"y\": 4.202898550724639, \"x2\": -3.0434782608695654, \"y2\": 4.492753623188406, \"center_x\": -3.1884057971014492, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0008893292189735857}, {\"x\": -3.0434782608695645, \"y\": 4.202898550724639, \"x2\": -2.753623188405797, \"y2\": 4.492753623188406, \"center_x\": -2.8985507246376807, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0011210019310742272}, {\"x\": -2.753623188405797, \"y\": 4.202898550724639, \"x2\": -2.4637681159420293, \"y2\": 4.492753623188406, \"center_x\": -2.608695652173913, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0013998966513206438}, {\"x\": -2.4637681159420284, \"y\": 4.202898550724639, \"x2\": -2.1739130434782608, \"y2\": 4.492753623188406, \"center_x\": -2.3188405797101446, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0017319342596446646}, {\"x\": -2.1739130434782608, \"y\": 4.202898550724639, \"x2\": -1.8840579710144931, \"y2\": 4.492753623188406, \"center_x\": -2.028985507246377, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0021228174363324154}, {\"x\": -1.8840579710144922, \"y\": 4.202898550724639, \"x2\": -1.5942028985507246, \"y2\": 4.492753623188406, \"center_x\": -1.7391304347826084, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0025777435196343624}, {\"x\": -1.5942028985507246, \"y\": 4.202898550724639, \"x2\": -1.304347826086957, \"y2\": 4.492753623188406, \"center_x\": -1.4492753623188408, \"center_y\": 4.347826086956522, \"value_uncond\": 0.003101077184865929}, {\"x\": -1.304347826086957, \"y\": 4.202898550724639, \"x2\": -1.0144927536231894, \"y2\": 4.492753623188406, \"center_x\": -1.1594202898550732, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0036959940420997896}, {\"x\": -1.0144927536231876, \"y\": 4.202898550724639, \"x2\": -0.72463768115942, \"y2\": 4.492753623188406, \"center_x\": -0.8695652173913038, \"center_y\": 4.347826086956522, \"value_uncond\": 0.004364110753120658}, {\"x\": -0.72463768115942, \"y\": 4.202898550724639, \"x2\": -0.43478260869565233, \"y2\": 4.492753623188406, \"center_x\": -0.5797101449275361, \"center_y\": 4.347826086956522, \"value_uncond\": 0.005105121462169169}, {\"x\": -0.43478260869565233, \"y\": 4.202898550724639, \"x2\": -0.1449275362318847, \"y2\": 4.492753623188406, \"center_x\": -0.2898550724637685, \"center_y\": 4.347826086956522, \"value_uncond\": 0.005916463772992943}, {\"x\": -0.14492753623188293, \"y\": 4.202898550724639, \"x2\": 0.1449275362318847, \"y2\": 4.492753623188406, \"center_x\": 8.881784197001252e-16, \"center_y\": 4.347826086956522, \"value_uncond\": 0.006793039727087408}, {\"x\": 0.1449275362318847, \"y\": 4.202898550724639, \"x2\": 0.43478260869565233, \"y2\": 4.492753623188406, \"center_x\": 0.2898550724637685, \"center_y\": 4.347826086956522, \"value_uncond\": 0.007727017819488317}, {\"x\": 0.43478260869565233, \"y\": 4.202898550724639, \"x2\": 0.72463768115942, \"y2\": 4.492753623188406, \"center_x\": 0.5797101449275361, \"center_y\": 4.347826086956522, \"value_uncond\": 0.008707740691430809}, {\"x\": 0.72463768115942, \"y\": 4.202898550724639, \"x2\": 1.0144927536231876, \"y2\": 4.492753623188406, \"center_x\": 0.8695652173913038, \"center_y\": 4.347826086956522, \"value_uncond\": 0.009721759565745862}, {\"x\": 1.0144927536231894, \"y\": 4.202898550724639, \"x2\": 1.304347826086957, \"y2\": 4.492753623188406, \"center_x\": 1.1594202898550732, \"center_y\": 4.347826086956522, \"value_uncond\": 0.010753010727229628}, {\"x\": 1.304347826086957, \"y\": 4.202898550724639, \"x2\": 1.5942028985507246, \"y2\": 4.492753623188406, \"center_x\": 1.4492753623188408, \"center_y\": 4.347826086956522, \"value_uncond\": 0.011783141596172239}, {\"x\": 1.5942028985507246, \"y\": 4.202898550724639, \"x2\": 1.8840579710144922, \"y2\": 4.492753623188406, \"center_x\": 1.7391304347826084, \"center_y\": 4.347826086956522, \"value_uncond\": 0.012791984620799281}, {\"x\": 1.884057971014494, \"y\": 4.202898550724639, \"x2\": 2.1739130434782616, \"y2\": 4.492753623188406, \"center_x\": 2.028985507246378, \"center_y\": 4.347826086956522, \"value_uncond\": 0.013758166951649482}, {\"x\": 2.1739130434782616, \"y\": 4.202898550724639, \"x2\": 2.4637681159420293, \"y2\": 4.492753623188406, \"center_x\": 2.3188405797101455, \"center_y\": 4.347826086956522, \"value_uncond\": 0.014659833449777619}, {\"x\": 2.4637681159420293, \"y\": 4.202898550724639, \"x2\": 2.753623188405797, \"y2\": 4.492753623188406, \"center_x\": 2.608695652173913, \"center_y\": 4.347826086956522, \"value_uncond\": 0.015475450910674683}, {\"x\": 2.753623188405797, \"y\": 4.202898550724639, \"x2\": 3.0434782608695645, \"y2\": 4.492753623188406, \"center_x\": 2.8985507246376807, \"center_y\": 4.347826086956522, \"value_uncond\": 0.01618465335975242}, {\"x\": 3.0434782608695663, \"y\": 4.202898550724639, \"x2\": 3.333333333333334, \"y2\": 4.492753623188406, \"center_x\": 3.18840579710145, \"center_y\": 4.347826086956522, \"value_uncond\": 0.016769082715321383}, {\"x\": 3.333333333333334, \"y\": 4.202898550724639, \"x2\": 3.6231884057971016, \"y2\": 4.492753623188406, \"center_x\": 3.4782608695652177, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0172131766700886}, {\"x\": 3.6231884057971016, \"y\": 4.202898550724639, \"x2\": 3.913043478260869, \"y2\": 4.492753623188406, \"center_x\": 3.7681159420289854, \"center_y\": 4.347826086956522, \"value_uncond\": 0.017504856708086578}, {\"x\": 3.913043478260871, \"y\": 4.202898550724639, \"x2\": 4.202898550724639, \"y2\": 4.492753623188406, \"center_x\": 4.057971014492755, \"center_y\": 4.347826086956522, \"value_uncond\": 0.017636073836968927}, {\"x\": 4.202898550724639, \"y\": 4.202898550724639, \"x2\": 4.492753623188406, \"y2\": 4.492753623188406, \"center_x\": 4.347826086956522, \"center_y\": 4.347826086956522, \"value_uncond\": 0.017603177628208996}, {\"x\": 4.492753623188406, \"y\": 4.202898550724639, \"x2\": 4.782608695652174, \"y2\": 4.492753623188406, \"center_x\": 4.63768115942029, \"center_y\": 4.347826086956522, \"value_uncond\": 0.017407084950367555}, {\"x\": 4.782608695652174, \"y\": 4.202898550724639, \"x2\": 5.0724637681159415, \"y2\": 4.492753623188406, \"center_x\": 4.927536231884058, \"center_y\": 4.347826086956522, \"value_uncond\": 0.017053237510066252}, {\"x\": 5.072463768115943, \"y\": 4.202898550724639, \"x2\": 5.362318840579711, \"y2\": 4.492753623188406, \"center_x\": 5.217391304347827, \"center_y\": 4.347826086956522, \"value_uncond\": 0.016551350944871517}, {\"x\": 5.362318840579711, \"y\": 4.202898550724639, \"x2\": 5.6521739130434785, \"y2\": 4.492753623188406, \"center_x\": 5.507246376811595, \"center_y\": 4.347826086956522, \"value_uncond\": 0.01591497161452705}, {\"x\": 5.6521739130434785, \"y\": 4.202898550724639, \"x2\": 5.942028985507246, \"y2\": 4.492753623188406, \"center_x\": 5.797101449275362, \"center_y\": 4.347826086956522, \"value_uncond\": 0.015160869307387045}, {\"x\": 5.942028985507246, \"y\": 4.202898550724639, \"x2\": 6.231884057971014, \"y2\": 4.492753623188406, \"center_x\": 6.08695652173913, \"center_y\": 4.347826086956522, \"value_uncond\": 0.014308303846864935}, {\"x\": 6.2318840579710155, \"y\": 4.202898550724639, \"x2\": 6.521739130434783, \"y2\": 4.492753623188406, \"center_x\": 6.376811594202899, \"center_y\": 4.347826086956522, \"value_uncond\": 0.013378210306499836}, {\"x\": 6.521739130434785, \"y\": 4.202898550724639, \"x2\": 6.8115942028985526, \"y2\": 4.492753623188406, \"center_x\": 6.666666666666669, \"center_y\": 4.347826086956522, \"value_uncond\": 0.01239235077728404}, {\"x\": 6.811594202898551, \"y\": 4.202898550724639, \"x2\": 7.101449275362318, \"y2\": 4.492753623188406, \"center_x\": 6.956521739130435, \"center_y\": 4.347826086956522, \"value_uncond\": 0.011372480263853986}, {\"x\": 7.10144927536232, \"y\": 4.202898550724639, \"x2\": 7.391304347826088, \"y2\": 4.492753623188406, \"center_x\": 7.246376811594204, \"center_y\": 4.347826086956522, \"value_uncond\": 0.010339570532010896}, {\"x\": 7.391304347826086, \"y\": 4.202898550724639, \"x2\": 7.681159420289854, \"y2\": 4.492753623188406, \"center_x\": 7.53623188405797, \"center_y\": 4.347826086956522, \"value_uncond\": 0.009313129094118662}, {\"x\": 7.681159420289855, \"y\": 4.202898550724639, \"x2\": 7.971014492753623, \"y2\": 4.492753623188406, \"center_x\": 7.826086956521739, \"center_y\": 4.347826086956522, \"value_uncond\": 0.00831064172998108}, {\"x\": 7.971014492753625, \"y\": 4.202898550724639, \"x2\": 8.260869565217392, \"y2\": 4.492753623188406, \"center_x\": 8.115942028985508, \"center_y\": 4.347826086956522, \"value_uncond\": 0.007347156864706769}, {\"x\": 8.26086956521739, \"y\": 4.202898550724639, \"x2\": 8.550724637681158, \"y2\": 4.492753623188406, \"center_x\": 8.405797101449274, \"center_y\": 4.347826086956522, \"value_uncond\": 0.006435019670291634}, {\"x\": 8.55072463768116, \"y\": 4.202898550724639, \"x2\": 8.840579710144928, \"y2\": 4.492753623188406, \"center_x\": 8.695652173913043, \"center_y\": 4.347826086956522, \"value_uncond\": 0.005583753783940638}, {\"x\": 8.84057971014493, \"y\": 4.202898550724639, \"x2\": 9.130434782608697, \"y2\": 4.492753623188406, \"center_x\": 8.985507246376812, \"center_y\": 4.347826086956522, \"value_uncond\": 0.00480007977657125}, {\"x\": 9.130434782608695, \"y\": 4.202898550724639, \"x2\": 9.420289855072463, \"y2\": 4.492753623188406, \"center_x\": 9.275362318840578, \"center_y\": 4.347826086956522, \"value_uncond\": 0.004088052508777171}, {\"x\": 9.420289855072465, \"y\": 4.202898550724639, \"x2\": 9.710144927536232, \"y2\": 4.492753623188406, \"center_x\": 9.565217391304348, \"center_y\": 4.347826086956522, \"value_uncond\": 0.003449294612401767}, {\"x\": 9.710144927536234, \"y\": 4.202898550724639, \"x2\": 10.000000000000002, \"y2\": 4.492753623188406, \"center_x\": 9.855072463768117, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0028833006458000928}, {\"x\": 10.0, \"y\": 4.202898550724639, \"x2\": 10.289855072463768, \"y2\": 4.492753623188406, \"center_x\": 10.144927536231883, \"center_y\": 4.347826086956522, \"value_uncond\": 0.002387785897913383}, {\"x\": -10.0, \"y\": 4.492753623188406, \"x2\": -9.710144927536232, \"y2\": 4.782608695652174, \"center_x\": -9.855072463768117, \"center_y\": 4.63768115942029, \"value_uncond\": 3.256379152547972e-07}, {\"x\": -9.710144927536232, \"y\": 4.492753623188406, \"x2\": -9.420289855072465, \"y2\": 4.782608695652174, \"center_x\": -9.565217391304348, \"center_y\": 4.63768115942029, \"value_uncond\": 5.087741421390123e-07}, {\"x\": -9.420289855072463, \"y\": 4.492753623188406, \"x2\": -9.130434782608695, \"y2\": 4.782608695652174, \"center_x\": -9.275362318840578, \"center_y\": 4.63768115942029, \"value_uncond\": 7.875187636225984e-07}, {\"x\": -9.130434782608695, \"y\": 4.492753623188406, \"x2\": -8.840579710144928, \"y2\": 4.782608695652174, \"center_x\": -8.985507246376812, \"center_y\": 4.63768115942029, \"value_uncond\": 1.2076542226667046e-06}, {\"x\": -8.840579710144928, \"y\": 4.492753623188406, \"x2\": -8.55072463768116, \"y2\": 4.782608695652174, \"center_x\": -8.695652173913043, \"center_y\": 4.63768115942029, \"value_uncond\": 1.834721342061928e-06}, {\"x\": -8.55072463768116, \"y\": 4.492753623188406, \"x2\": -8.260869565217392, \"y2\": 4.782608695652174, \"center_x\": -8.405797101449277, \"center_y\": 4.63768115942029, \"value_uncond\": 2.761489752615771e-06}, {\"x\": -8.26086956521739, \"y\": 4.492753623188406, \"x2\": -7.971014492753623, \"y2\": 4.782608695652174, \"center_x\": -8.115942028985508, \"center_y\": 4.63768115942029, \"value_uncond\": 4.117774630909027e-06}, {\"x\": -7.971014492753623, \"y\": 4.492753623188406, \"x2\": -7.681159420289855, \"y2\": 4.782608695652174, \"center_x\": -7.826086956521739, \"center_y\": 4.63768115942029, \"value_uncond\": 6.08313599744797e-06}, {\"x\": -7.681159420289855, \"y\": 4.492753623188406, \"x2\": -7.391304347826088, \"y2\": 4.782608695652174, \"center_x\": -7.536231884057972, \"center_y\": 4.63768115942029, \"value_uncond\": 8.90303934437165e-06}, {\"x\": -7.391304347826087, \"y\": 4.492753623188406, \"x2\": -7.101449275362319, \"y2\": 4.782608695652174, \"center_x\": -7.246376811594203, \"center_y\": 4.63768115942029, \"value_uncond\": 1.2909067566261262e-05}, {\"x\": -7.101449275362318, \"y\": 4.492753623188406, \"x2\": -6.811594202898551, \"y2\": 4.782608695652174, \"center_x\": -6.956521739130435, \"center_y\": 4.63768115942029, \"value_uncond\": 1.8543737450318508e-05}, {\"x\": -6.811594202898551, \"y\": 4.492753623188406, \"x2\": -6.521739130434783, \"y2\": 4.782608695652174, \"center_x\": -6.666666666666667, \"center_y\": 4.63768115942029, \"value_uncond\": 2.639037005687939e-05}, {\"x\": -6.521739130434782, \"y\": 4.492753623188406, \"x2\": -6.231884057971015, \"y2\": 4.782608695652174, \"center_x\": -6.3768115942028984, \"center_y\": 4.63768115942029, \"value_uncond\": 3.72082723206778e-05}, {\"x\": -6.231884057971014, \"y\": 4.492753623188406, \"x2\": -5.942028985507246, \"y2\": 4.782608695652174, \"center_x\": -6.08695652173913, \"center_y\": 4.63768115942029, \"value_uncond\": 5.197318650728187e-05}, {\"x\": -5.942028985507246, \"y\": 4.492753623188406, \"x2\": -5.6521739130434785, \"y2\": 4.782608695652174, \"center_x\": -5.797101449275362, \"center_y\": 4.63768115942029, \"value_uncond\": 7.192253702740012e-05}, {\"x\": -5.6521739130434785, \"y\": 4.492753623188406, \"x2\": -5.362318840579711, \"y2\": 4.782608695652174, \"center_x\": -5.507246376811595, \"center_y\": 4.63768115942029, \"value_uncond\": 9.860443910577588e-05}, {\"x\": -5.36231884057971, \"y\": 4.492753623188406, \"x2\": -5.072463768115942, \"y2\": 4.782608695652174, \"center_x\": -5.217391304347826, \"center_y\": 4.63768115942029, \"value_uncond\": 0.00013392872985047388}, {\"x\": -5.0724637681159415, \"y\": 4.492753623188406, \"x2\": -4.782608695652174, \"y2\": 4.782608695652174, \"center_x\": -4.927536231884058, \"center_y\": 4.63768115942029, \"value_uncond\": 0.00018021745307357436}, {\"x\": -4.782608695652174, \"y\": 4.492753623188406, \"x2\": -4.492753623188406, \"y2\": 4.782608695652174, \"center_x\": -4.63768115942029, \"center_y\": 4.63768115942029, \"value_uncond\": 0.00024025130750437475}, {\"x\": -4.492753623188405, \"y\": 4.492753623188406, \"x2\": -4.202898550724638, \"y2\": 4.782608695652174, \"center_x\": -4.3478260869565215, \"center_y\": 4.63768115942029, \"value_uncond\": 0.00031730760901551403}, {\"x\": -4.202898550724638, \"y\": 4.492753623188406, \"x2\": -3.91304347826087, \"y2\": 4.782608695652174, \"center_x\": -4.057971014492754, \"center_y\": 4.63768115942029, \"value_uncond\": 0.0004151844006745436}, {\"x\": -3.913043478260869, \"y\": 4.492753623188406, \"x2\": -3.6231884057971016, \"y2\": 4.782608695652174, \"center_x\": -3.7681159420289854, \"center_y\": 4.63768115942029, \"value_uncond\": 0.000538204573064586}, {\"x\": -3.6231884057971016, \"y\": 4.492753623188406, \"x2\": -3.333333333333334, \"y2\": 4.782608695652174, \"center_x\": -3.4782608695652177, \"center_y\": 4.63768115942029, \"value_uncond\": 0.0006911933544386626}, {\"x\": -3.333333333333333, \"y\": 4.492753623188406, \"x2\": -3.0434782608695654, \"y2\": 4.782608695652174, \"center_x\": -3.1884057971014492, \"center_y\": 4.63768115942029, \"value_uncond\": 0.0008794224310223179}, {\"x\": -3.0434782608695645, \"y\": 4.492753623188406, \"x2\": -2.753623188405797, \"y2\": 4.782608695652174, \"center_x\": -2.8985507246376807, \"center_y\": 4.63768115942029, \"value_uncond\": 0.0011085143975633734}, {\"x\": -2.753623188405797, \"y\": 4.492753623188406, \"x2\": -2.4637681159420293, \"y2\": 4.782608695652174, \"center_x\": -2.608695652173913, \"center_y\": 4.63768115942029, \"value_uncond\": 0.0013843023371089397}, {\"x\": -2.4637681159420284, \"y\": 4.492753623188406, \"x2\": -2.1739130434782608, \"y2\": 4.782608695652174, \"center_x\": -2.3188405797101446, \"center_y\": 4.63768115942029, \"value_uncond\": 0.0017126411732490121}, {\"x\": -2.1739130434782608, \"y\": 4.492753623188406, \"x2\": -1.8840579710144931, \"y2\": 4.782608695652174, \"center_x\": -2.028985507246377, \"center_y\": 4.63768115942029, \"value_uncond\": 0.002099170060588626}, {\"x\": -1.8840579710144922, \"y\": 4.492753623188406, \"x2\": -1.5942028985507246, \"y2\": 4.782608695652174, \"center_x\": -1.7391304347826084, \"center_y\": 4.63768115942029, \"value_uncond\": 0.0025490284410144945}, {\"x\": -1.5942028985507246, \"y\": 4.492753623188406, \"x2\": -1.304347826086957, \"y2\": 4.782608695652174, \"center_x\": -1.4492753623188408, \"center_y\": 4.63768115942029, \"value_uncond\": 0.00306653236902547}, {\"x\": -1.304347826086957, \"y\": 4.492753623188406, \"x2\": -1.0144927536231894, \"y2\": 4.782608695652174, \"center_x\": -1.1594202898550732, \"center_y\": 4.63768115942029, \"value_uncond\": 0.003654822079610475}, {\"x\": -1.0144927536231876, \"y\": 4.492753623188406, \"x2\": -0.72463768115942, \"y2\": 4.782608695652174, \"center_x\": -0.8695652173913038, \"center_y\": 4.63768115942029, \"value_uncond\": 0.004315496225559185}, {\"x\": -0.72463768115942, \"y\": 4.492753623188406, \"x2\": -0.43478260869565233, \"y2\": 4.782608695652174, \"center_x\": -0.5797101449275361, \"center_y\": 4.63768115942029, \"value_uncond\": 0.005048252358228621}, {\"x\": -0.43478260869565233, \"y\": 4.492753623188406, \"x2\": -0.1449275362318847, \"y2\": 4.782608695652174, \"center_x\": -0.2898550724637685, \"center_y\": 4.63768115942029, \"value_uncond\": 0.005850556625482321}, {\"x\": -0.14492753623188293, \"y\": 4.492753623188406, \"x2\": 0.1449275362318847, \"y2\": 4.782608695652174, \"center_x\": 8.881784197001252e-16, \"center_y\": 4.63768115942029, \"value_uncond\": 0.0067173678581270435}, {\"x\": 0.1449275362318847, \"y\": 4.492753623188406, \"x2\": 0.43478260869565233, \"y2\": 4.782608695652174, \"center_x\": 0.2898550724637685, \"center_y\": 4.63768115942029, \"value_uncond\": 0.007640941791173754}, {\"x\": 0.43478260869565233, \"y\": 4.492753623188406, \"x2\": 0.72463768115942, \"y2\": 4.782608695652174, \"center_x\": 0.5797101449275361, \"center_y\": 4.63768115942029, \"value_uncond\": 0.008610739784765228}, {\"x\": 0.72463768115942, \"y\": 4.492753623188406, \"x2\": 1.0144927536231876, \"y2\": 4.782608695652174, \"center_x\": 0.8695652173913038, \"center_y\": 4.63768115942029, \"value_uncond\": 0.00961346287597533}, {\"x\": 1.0144927536231894, \"y\": 4.492753623188406, \"x2\": 1.304347826086957, \"y2\": 4.782608695652174, \"center_x\": 1.1594202898550732, \"center_y\": 4.63768115942029, \"value_uncond\": 0.010633226293254413}, {\"x\": 1.304347826086957, \"y\": 4.492753623188406, \"x2\": 1.5942028985507246, \"y2\": 4.782608695652174, \"center_x\": 1.4492753623188408, \"center_y\": 4.63768115942029, \"value_uncond\": 0.011651881897623518}, {\"x\": 1.5942028985507246, \"y\": 4.492753623188406, \"x2\": 1.8840579710144922, \"y2\": 4.782608695652174, \"center_x\": 1.7391304347826084, \"center_y\": 4.63768115942029, \"value_uncond\": 0.012649486796134982}, {\"x\": 1.884057971014494, \"y\": 4.492753623188406, \"x2\": 2.1739130434782616, \"y2\": 4.782608695652174, \"center_x\": 2.028985507246378, \"center_y\": 4.63768115942029, \"value_uncond\": 0.013604906224710316}, {\"x\": 2.1739130434782616, \"y\": 4.492753623188406, \"x2\": 2.4637681159420293, \"y2\": 4.782608695652174, \"center_x\": 2.3188405797101455, \"center_y\": 4.63768115942029, \"value_uncond\": 0.014496528502307806}, {\"x\": 2.4637681159420293, \"y\": 4.492753623188406, \"x2\": 2.753623188405797, \"y2\": 4.782608695652174, \"center_x\": 2.608695652173913, \"center_y\": 4.63768115942029, \"value_uncond\": 0.015303060296095244}, {\"x\": 2.753623188405797, \"y\": 4.492753623188406, \"x2\": 3.0434782608695645, \"y2\": 4.782608695652174, \"center_x\": 2.8985507246376807, \"center_y\": 4.63768115942029, \"value_uncond\": 0.016004362500665503}, {\"x\": 3.0434782608695663, \"y\": 4.492753623188406, \"x2\": 3.333333333333334, \"y2\": 4.782608695652174, \"center_x\": 3.18840579710145, \"center_y\": 4.63768115942029, \"value_uncond\": 0.01658228153635001}, {\"x\": 3.333333333333334, \"y\": 4.492753623188406, \"x2\": 3.6231884057971016, \"y2\": 4.782608695652174, \"center_x\": 3.4782608695652177, \"center_y\": 4.63768115942029, \"value_uncond\": 0.017021428454017287}, {\"x\": 3.6231884057971016, \"y\": 4.492753623188406, \"x2\": 3.913043478260869, \"y2\": 4.782608695652174, \"center_x\": 3.7681159420289854, \"center_y\": 4.63768115942029, \"value_uncond\": 0.01730985928775613}, {\"x\": 3.913043478260871, \"y\": 4.492753623188406, \"x2\": 4.202898550724639, \"y2\": 4.782608695652174, \"center_x\": 4.057971014492755, \"center_y\": 4.63768115942029, \"value_uncond\": 0.017439614707921755}, {\"x\": 4.202898550724639, \"y\": 4.492753623188406, \"x2\": 4.492753623188406, \"y2\": 4.782608695652174, \"center_x\": 4.347826086956522, \"center_y\": 4.63768115942029, \"value_uncond\": 0.017407084950367555}, {\"x\": 4.492753623188406, \"y\": 4.492753623188406, \"x2\": 4.782608695652174, \"y2\": 4.782608695652174, \"center_x\": 4.63768115942029, \"center_y\": 4.63768115942029, \"value_uncond\": 0.017213176670088596}, {\"x\": 4.782608695652174, \"y\": 4.492753623188406, \"x2\": 5.0724637681159415, \"y2\": 4.782608695652174, \"center_x\": 4.927536231884058, \"center_y\": 4.63768115942029, \"value_uncond\": 0.016863270955172423}, {\"x\": 5.072463768115943, \"y\": 4.492753623188406, \"x2\": 5.362318840579711, \"y2\": 4.782608695652174, \"center_x\": 5.217391304347827, \"center_y\": 4.63768115942029, \"value_uncond\": 0.016366975214692422}, {\"x\": 5.362318840579711, \"y\": 4.492753623188406, \"x2\": 5.6521739130434785, \"y2\": 4.782608695652174, \"center_x\": 5.507246376811595, \"center_y\": 4.63768115942029, \"value_uncond\": 0.015737684907116793}, {\"x\": 5.6521739130434785, \"y\": 4.492753623188406, \"x2\": 5.942028985507246, \"y2\": 4.782608695652174, \"center_x\": 5.797101449275362, \"center_y\": 4.63768115942029, \"value_uncond\": 0.014991983011760197}, {\"x\": 5.942028985507246, \"y\": 4.492753623188406, \"x2\": 6.231884057971014, \"y2\": 4.782608695652174, \"center_x\": 6.08695652173913, \"center_y\": 4.63768115942029, \"value_uncond\": 0.014148914804956699}, {\"x\": 6.2318840579710155, \"y\": 4.492753623188406, \"x2\": 6.521739130434783, \"y2\": 4.782608695652174, \"center_x\": 6.376811594202899, \"center_y\": 4.63768115942029, \"value_uncond\": 0.01322918215151925}, {\"x\": 6.521739130434785, \"y\": 4.492753623188406, \"x2\": 6.8115942028985526, \"y2\": 4.782608695652174, \"center_x\": 6.666666666666669, \"center_y\": 4.63768115942029, \"value_uncond\": 0.01225430472105531}, {\"x\": 6.811594202898551, \"y\": 4.492753623188406, \"x2\": 7.101449275362318, \"y2\": 4.782608695652174, \"center_x\": 6.956521739130435, \"center_y\": 4.63768115942029, \"value_uncond\": 0.011245795175755779}, {\"x\": 7.10144927536232, \"y\": 4.492753623188406, \"x2\": 7.391304347826088, \"y2\": 4.782608695652174, \"center_x\": 7.246376811594204, \"center_y\": 4.63768115942029, \"value_uncond\": 0.01022439166395793}, {\"x\": 7.391304347826086, \"y\": 4.492753623188406, \"x2\": 7.681159420289854, \"y2\": 4.782608695652174, \"center_x\": 7.53623188405797, \"center_y\": 4.63768115942029, \"value_uncond\": 0.009209384391785931}, {\"x\": 7.681159420289855, \"y\": 4.492753623188406, \"x2\": 7.971014492753623, \"y2\": 4.782608695652174, \"center_x\": 7.826086956521739, \"center_y\": 4.63768115942029, \"value_uncond\": 0.008218064354132682}, {\"x\": 7.971014492753625, \"y\": 4.492753623188406, \"x2\": 8.260869565217392, \"y2\": 4.782608695652174, \"center_x\": 8.115942028985508, \"center_y\": 4.63768115942029, \"value_uncond\": 0.00726531234239662}, {\"x\": 8.26086956521739, \"y\": 4.492753623188406, \"x2\": 8.550724637681158, \"y2\": 4.782608695652174, \"center_x\": 8.405797101449274, \"center_y\": 4.63768115942029, \"value_uncond\": 0.00636333600807103}, {\"x\": 8.55072463768116, \"y\": 4.492753623188406, \"x2\": 8.840579710144928, \"y2\": 4.782608695652174, \"center_x\": 8.695652173913043, \"center_y\": 4.63768115942029, \"value_uncond\": 0.005521552898678561}, {\"x\": 8.84057971014493, \"y\": 4.492753623188406, \"x2\": 9.130434782608697, \"y2\": 4.782608695652174, \"center_x\": 8.985507246376812, \"center_y\": 4.63768115942029, \"value_uncond\": 0.004746608720542591}, {\"x\": 9.130434782608695, \"y\": 4.492753623188406, \"x2\": 9.420289855072463, \"y2\": 4.782608695652174, \"center_x\": 9.275362318840578, \"center_y\": 4.63768115942029, \"value_uncond\": 0.004042513164657964}, {\"x\": 9.420289855072465, \"y\": 4.492753623188406, \"x2\": 9.710144927536232, \"y2\": 4.782608695652174, \"center_x\": 9.565217391304348, \"center_y\": 4.63768115942029, \"value_uncond\": 0.0034108707873688354}, {\"x\": 9.710144927536234, \"y\": 4.492753623188406, \"x2\": 10.000000000000002, \"y2\": 4.782608695652174, \"center_x\": 9.855072463768117, \"center_y\": 4.63768115942029, \"value_uncond\": 0.002851181777457206}, {\"x\": 10.0, \"y\": 4.492753623188406, \"x2\": 10.289855072463768, \"y2\": 4.782608695652174, \"center_x\": 10.144927536231883, \"center_y\": 4.63768115942029, \"value_uncond\": 0.0023611868746731966}, {\"x\": -10.0, \"y\": 4.782608695652174, \"x2\": -9.710144927536232, \"y2\": 5.0724637681159415, \"center_x\": -9.855072463768117, \"center_y\": 4.927536231884058, \"value_uncond\": 3.1901841847480727e-07}, {\"x\": -9.710144927536232, \"y\": 4.782608695652174, \"x2\": -9.420289855072465, \"y2\": 5.0724637681159415, \"center_x\": -9.565217391304348, \"center_y\": 4.927536231884058, \"value_uncond\": 4.984318919345294e-07}, {\"x\": -9.420289855072463, \"y\": 4.782608695652174, \"x2\": -9.130434782608695, \"y2\": 5.0724637681159415, \"center_x\": -9.275362318840578, \"center_y\": 4.927536231884058, \"value_uncond\": 7.715102533239665e-07}, {\"x\": -9.130434782608695, \"y\": 4.782608695652174, \"x2\": -8.840579710144928, \"y2\": 5.0724637681159415, \"center_x\": -8.985507246376812, \"center_y\": 4.927536231884058, \"value_uncond\": 1.1831052900523056e-06}, {\"x\": -8.840579710144928, \"y\": 4.782608695652174, \"x2\": -8.55072463768116, \"y2\": 5.0724637681159415, \"center_x\": -8.695652173913043, \"center_y\": 4.927536231884058, \"value_uncond\": 1.7974255253065148e-06}, {\"x\": -8.55072463768116, \"y\": 4.782608695652174, \"x2\": -8.260869565217392, \"y2\": 5.0724637681159415, \"center_x\": -8.405797101449277, \"center_y\": 4.927536231884058, \"value_uncond\": 2.705354788997938e-06}, {\"x\": -8.26086956521739, \"y\": 4.782608695652174, \"x2\": -7.971014492753623, \"y2\": 5.0724637681159415, \"center_x\": -8.115942028985508, \"center_y\": 4.927536231884058, \"value_uncond\": 4.034069403006746e-06}, {\"x\": -7.971014492753623, \"y\": 4.782608695652174, \"x2\": -7.681159420289855, \"y2\": 5.0724637681159415, \"center_x\": -7.826086956521739, \"center_y\": 4.927536231884058, \"value_uncond\": 5.9594793307608665e-06}, {\"x\": -7.681159420289855, \"y\": 4.782608695652174, \"x2\": -7.391304347826088, \"y2\": 5.0724637681159415, \"center_x\": -7.536231884057972, \"center_y\": 4.927536231884058, \"value_uncond\": 8.72206029521493e-06}, {\"x\": -7.391304347826087, \"y\": 4.782608695652174, \"x2\": -7.101449275362319, \"y2\": 5.0724637681159415, \"center_x\": -7.246376811594203, \"center_y\": 4.927536231884058, \"value_uncond\": 1.2646654845922255e-05}, {\"x\": -7.101449275362318, \"y\": 4.782608695652174, \"x2\": -6.811594202898551, \"y2\": 5.0724637681159415, \"center_x\": -6.956521739130435, \"center_y\": 4.927536231884058, \"value_uncond\": 1.8166784384993456e-05}, {\"x\": -6.811594202898551, \"y\": 4.782608695652174, \"x2\": -6.521739130434783, \"y2\": 5.0724637681159415, \"center_x\": -6.666666666666667, \"center_y\": 4.927536231884058, \"value_uncond\": 2.585391234900603e-05}, {\"x\": -6.521739130434782, \"y\": 4.782608695652174, \"x2\": -6.231884057971015, \"y2\": 5.0724637681159415, \"center_x\": -6.3768115942028984, \"center_y\": 4.927536231884058, \"value_uncond\": 3.6451910646322456e-05}, {\"x\": -6.231884057971014, \"y\": 4.782608695652174, \"x2\": -5.942028985507246, \"y2\": 5.0724637681159415, \"center_x\": -6.08695652173913, \"center_y\": 4.927536231884058, \"value_uncond\": 5.0916686865765747e-05}, {\"x\": -5.942028985507246, \"y\": 4.782608695652174, \"x2\": -5.6521739130434785, \"y2\": 5.0724637681159415, \"center_x\": -5.797101449275362, \"center_y\": 4.927536231884058, \"value_uncond\": 7.046051132351661e-05}, {\"x\": -5.6521739130434785, \"y\": 4.782608695652174, \"x2\": -5.362318840579711, \"y2\": 5.0724637681159415, \"center_x\": -5.507246376811595, \"center_y\": 4.927536231884058, \"value_uncond\": 9.66000294944361e-05}, {\"x\": -5.36231884057971, \"y\": 4.782608695652174, \"x2\": -5.072463768115942, \"y2\": 5.0724637681159415, \"center_x\": -5.217391304347826, \"center_y\": 4.927536231884058, \"value_uncond\": 0.00013120625573286498}, {\"x\": -5.0724637681159415, \"y\": 4.782608695652174, \"x2\": -4.782608695652174, \"y2\": 5.0724637681159415, \"center_x\": -4.927536231884058, \"center_y\": 4.927536231884058, \"value_uncond\": 0.00017655403184885295}, {\"x\": -4.782608695652174, \"y\": 4.782608695652174, \"x2\": -4.492753623188406, \"y2\": 5.0724637681159415, \"center_x\": -4.63768115942029, \"center_y\": 4.927536231884058, \"value_uncond\": 0.00023536753113217578}, {\"x\": -4.492753623188405, \"y\": 4.782608695652174, \"x2\": -4.202898550724638, \"y2\": 5.0724637681159415, \"center_x\": -4.3478260869565215, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0003108574488905761}, {\"x\": -4.202898550724638, \"y\": 4.782608695652174, \"x2\": -3.91304347826087, \"y2\": 5.0724637681159415, \"center_x\": -4.057971014492754, \"center_y\": 4.927536231884058, \"value_uncond\": 0.00040674462239744533}, {\"x\": -3.913043478260869, \"y\": 4.782608695652174, \"x2\": -3.6231884057971016, \"y2\": 5.0724637681159415, \"center_x\": -3.7681159420289854, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0005272640674554986}, {\"x\": -3.6231884057971016, \"y\": 4.782608695652174, \"x2\": -3.333333333333334, \"y2\": 5.0724637681159415, \"center_x\": -3.4782608695652177, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0006771429261263549}, {\"x\": -3.333333333333333, \"y\": 4.782608695652174, \"x2\": -3.0434782608695654, \"y2\": 5.0724637681159415, \"center_x\": -3.1884057971014492, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0008615457229435064}, {\"x\": -3.0434782608695645, \"y\": 4.782608695652174, \"x2\": -2.753623188405797, \"y2\": 5.0724637681159415, \"center_x\": -2.8985507246376807, \"center_y\": 4.927536231884058, \"value_uncond\": 0.001085980757770534}, {\"x\": -2.753623188405797, \"y\": 4.782608695652174, \"x2\": -2.4637681159420293, \"y2\": 5.0724637681159415, \"center_x\": -2.608695652173913, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0013561625400098994}, {\"x\": -2.4637681159420284, \"y\": 4.782608695652174, \"x2\": -2.1739130434782608, \"y2\": 5.0724637681159415, \"center_x\": -2.3188405797101446, \"center_y\": 4.927536231884058, \"value_uncond\": 0.001677826975637138}, {\"x\": -2.1739130434782608, \"y\": 4.782608695652174, \"x2\": -1.8840579710144931, \"y2\": 5.0724637681159415, \"center_x\": -2.028985507246377, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0020564985877478664}, {\"x\": -1.8840579710144922, \"y\": 4.782608695652174, \"x2\": -1.5942028985507246, \"y2\": 5.0724637681159415, \"center_x\": -1.7391304347826084, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0024972123447709275}, {\"x\": -1.5942028985507246, \"y\": 4.782608695652174, \"x2\": -1.304347826086957, \"y2\": 5.0724637681159415, \"center_x\": -1.4492753623188408, \"center_y\": 4.927536231884058, \"value_uncond\": 0.003004196565387203}, {\"x\": -1.304347826086957, \"y\": 4.782608695652174, \"x2\": -1.0144927536231894, \"y2\": 5.0724637681159415, \"center_x\": -1.1594202898550732, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0035805276505711356}, {\"x\": -1.0144927536231876, \"y\": 4.782608695652174, \"x2\": -0.72463768115942, \"y2\": 5.0724637681159415, \"center_x\": -0.8695652173913038, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0042277717560458795}, {\"x\": -0.72463768115942, \"y\": 4.782608695652174, \"x2\": -0.43478260869565233, \"y2\": 5.0724637681159415, \"center_x\": -0.5797101449275361, \"center_y\": 4.927536231884058, \"value_uncond\": 0.004945632581278748}, {\"x\": -0.43478260869565233, \"y\": 4.782608695652174, \"x2\": -0.1449275362318847, \"y2\": 5.0724637681159415, \"center_x\": -0.2898550724637685, \"center_y\": 4.927536231884058, \"value_uncond\": 0.005731627781728902}, {\"x\": -0.14492753623188293, \"y\": 4.782608695652174, \"x2\": 0.1449275362318847, \"y2\": 5.0724637681159415, \"center_x\": 8.881784197001252e-16, \"center_y\": 4.927536231884058, \"value_uncond\": 0.006580818663995012}, {\"x\": 0.1449275362318847, \"y\": 4.782608695652174, \"x2\": 0.43478260869565233, \"y2\": 5.0724637681159415, \"center_x\": 0.2898550724637685, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0074856183868239065}, {\"x\": 0.43478260869565233, \"y\": 4.782608695652174, \"x2\": 0.72463768115942, \"y2\": 5.0724637681159415, \"center_x\": 0.5797101449275361, \"center_y\": 4.927536231884058, \"value_uncond\": 0.008435702537539325}, {\"x\": 0.72463768115942, \"y\": 4.782608695652174, \"x2\": 1.0144927536231876, \"y2\": 5.0724637681159415, \"center_x\": 0.8695652173913038, \"center_y\": 4.927536231884058, \"value_uncond\": 0.009418042491643623}, {\"x\": 1.0144927536231894, \"y\": 4.782608695652174, \"x2\": 1.304347826086957, \"y2\": 5.0724637681159415, \"center_x\": 1.1594202898550732, \"center_y\": 4.927536231884058, \"value_uncond\": 0.010417076379771448}, {\"x\": 1.304347826086957, \"y\": 4.782608695652174, \"x2\": 1.5942028985507246, \"y2\": 5.0724637681159415, \"center_x\": 1.4492753623188408, \"center_y\": 4.927536231884058, \"value_uncond\": 0.011415024974369399}, {\"x\": 1.5942028985507246, \"y\": 4.782608695652174, \"x2\": 1.8840579710144922, \"y2\": 5.0724637681159415, \"center_x\": 1.7391304347826084, \"center_y\": 4.927536231884058, \"value_uncond\": 0.012392350777284051}, {\"x\": 1.884057971014494, \"y\": 4.782608695652174, \"x2\": 2.1739130434782616, \"y2\": 5.0724637681159415, \"center_x\": 2.028985507246378, \"center_y\": 4.927536231884058, \"value_uncond\": 0.013328348647328505}, {\"x\": 2.1739130434782616, \"y\": 4.782608695652174, \"x2\": 2.4637681159420293, \"y2\": 5.0724637681159415, \"center_x\": 2.3188405797101455, \"center_y\": 4.927536231884058, \"value_uncond\": 0.014201846221017042}, {\"x\": 2.4637681159420293, \"y\": 4.782608695652174, \"x2\": 2.753623188405797, \"y2\": 5.0724637681159415, \"center_x\": 2.608695652173913, \"center_y\": 4.927536231884058, \"value_uncond\": 0.014991983011760199}, {\"x\": 2.753623188405797, \"y\": 4.782608695652174, \"x2\": 3.0434782608695645, \"y2\": 5.0724637681159415, \"center_x\": 2.8985507246376807, \"center_y\": 4.927536231884058, \"value_uncond\": 0.015679029297509334}, {\"x\": 3.0434782608695663, \"y\": 4.782608695652174, \"x2\": 3.333333333333334, \"y2\": 5.0724637681159415, \"center_x\": 3.18840579710145, \"center_y\": 4.927536231884058, \"value_uncond\": 0.016245200520618588}, {\"x\": 3.333333333333334, \"y\": 4.782608695652174, \"x2\": 3.6231884057971016, \"y2\": 5.0724637681159415, \"center_x\": 3.4782608695652177, \"center_y\": 4.927536231884058, \"value_uncond\": 0.01667542055517041}, {\"x\": 3.6231884057971016, \"y\": 4.782608695652174, \"x2\": 3.913043478260869, \"y2\": 5.0724637681159415, \"center_x\": 3.7681159420289854, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0169579882295972}, {\"x\": 3.913043478260871, \"y\": 4.782608695652174, \"x2\": 4.202898550724639, \"y2\": 5.0724637681159415, \"center_x\": 4.057971014492755, \"center_y\": 4.927536231884058, \"value_uncond\": 0.017085106009777626}, {\"x\": 4.202898550724639, \"y\": 4.782608695652174, \"x2\": 4.492753623188406, \"y2\": 5.0724637681159415, \"center_x\": 4.347826086956522, \"center_y\": 4.927536231884058, \"value_uncond\": 0.017053237510066252}, {\"x\": 4.492753623188406, \"y\": 4.782608695652174, \"x2\": 4.782608695652174, \"y2\": 5.0724637681159415, \"center_x\": 4.63768115942029, \"center_y\": 4.927536231884058, \"value_uncond\": 0.016863270955172423}, {\"x\": 4.782608695652174, \"y\": 4.782608695652174, \"x2\": 5.0724637681159415, \"y2\": 5.0724637681159415, \"center_x\": 4.927536231884058, \"center_y\": 4.927536231884058, \"value_uncond\": 0.016520478047594347}, {\"x\": 5.072463768115943, \"y\": 4.782608695652174, \"x2\": 5.362318840579711, \"y2\": 5.0724637681159415, \"center_x\": 5.217391304347827, \"center_y\": 4.927536231884058, \"value_uncond\": 0.01603427089908147}, {\"x\": 5.362318840579711, \"y\": 4.782608695652174, \"x2\": 5.6521739130434785, \"y2\": 5.0724637681159415, \"center_x\": 5.507246376811595, \"center_y\": 4.927536231884058, \"value_uncond\": 0.015417772668133083}, {\"x\": 5.6521739130434785, \"y\": 4.782608695652174, \"x2\": 5.942028985507246, \"y2\": 5.0724637681159415, \"center_x\": 5.797101449275362, \"center_y\": 4.927536231884058, \"value_uncond\": 0.014687229238863838}, {\"x\": 5.942028985507246, \"y\": 4.782608695652174, \"x2\": 6.231884057971014, \"y2\": 5.0724637681159415, \"center_x\": 6.08695652173913, \"center_y\": 4.927536231884058, \"value_uncond\": 0.013861298739369025}, {\"x\": 6.2318840579710155, \"y\": 4.782608695652174, \"x2\": 6.521739130434783, \"y2\": 5.0724637681159415, \"center_x\": 6.376811594202899, \"center_y\": 4.927536231884058, \"value_uncond\": 0.012960262211452207}, {\"x\": 6.521739130434785, \"y\": 4.782608695652174, \"x2\": 6.8115942028985526, \"y2\": 5.0724637681159415, \"center_x\": 6.666666666666669, \"center_y\": 4.927536231884058, \"value_uncond\": 0.012005201877553301}, {\"x\": 6.811594202898551, \"y\": 4.782608695652174, \"x2\": 7.101449275362318, \"y2\": 5.0724637681159415, \"center_x\": 6.956521739130435, \"center_y\": 4.927536231884058, \"value_uncond\": 0.011017193095140902}, {\"x\": 7.10144927536232, \"y\": 4.782608695652174, \"x2\": 7.391304347826088, \"y2\": 5.0724637681159415, \"center_x\": 7.246376811594204, \"center_y\": 4.927536231884058, \"value_uncond\": 0.010016552451979297}, {\"x\": 7.391304347826086, \"y\": 4.782608695652174, \"x2\": 7.681159420289854, \"y2\": 5.0724637681159415, \"center_x\": 7.53623188405797, \"center_y\": 4.927536231884058, \"value_uncond\": 0.009022178027074335}, {\"x\": 7.681159420289855, \"y\": 4.782608695652174, \"x2\": 7.971014492753623, \"y2\": 5.0724637681159415, \"center_x\": 7.826086956521739, \"center_y\": 4.927536231884058, \"value_uncond\": 0.008051009327732077}, {\"x\": 7.971014492753625, \"y\": 4.782608695652174, \"x2\": 8.260869565217392, \"y2\": 5.0724637681159415, \"center_x\": 8.115942028985508, \"center_y\": 4.927536231884058, \"value_uncond\": 0.007117624651857015}, {\"x\": 8.26086956521739, \"y\": 4.782608695652174, \"x2\": 8.550724637681158, \"y2\": 5.0724637681159415, \"center_x\": 8.405797101449274, \"center_y\": 4.927536231884058, \"value_uncond\": 0.00623398349645561}, {\"x\": 8.55072463768116, \"y\": 4.782608695652174, \"x2\": 8.840579710144928, \"y2\": 5.0724637681159415, \"center_x\": 8.695652173913043, \"center_y\": 4.927536231884058, \"value_uncond\": 0.005409311971190908}, {\"x\": 8.84057971014493, \"y\": 4.782608695652174, \"x2\": 9.130434782608697, \"y2\": 5.0724637681159415, \"center_x\": 8.985507246376812, \"center_y\": 4.927536231884058, \"value_uncond\": 0.004650120689912261}, {\"x\": 9.130434782608695, \"y\": 4.782608695652174, \"x2\": 9.420289855072463, \"y2\": 5.0724637681159415, \"center_x\": 9.275362318840578, \"center_y\": 4.927536231884058, \"value_uncond\": 0.003960337835487279}, {\"x\": 9.420289855072465, \"y\": 4.782608695652174, \"x2\": 9.710144927536232, \"y2\": 5.0724637681159415, \"center_x\": 9.565217391304348, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0033415353471874256}, {\"x\": 9.710144927536234, \"y\": 4.782608695652174, \"x2\": 10.000000000000002, \"y2\": 5.0724637681159415, \"center_x\": 9.855072463768117, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0027932235738485287}, {\"x\": 10.0, \"y\": 4.782608695652174, \"x2\": 10.289855072463768, \"y2\": 5.0724637681159415, \"center_x\": 10.144927536231883, \"center_y\": 4.927536231884058, \"value_uncond\": 0.002313189180972133}, {\"x\": -10.0, \"y\": 5.072463768115943, \"x2\": -9.710144927536232, \"y2\": 5.362318840579711, \"center_x\": -9.855072463768117, \"center_y\": 5.217391304347827, \"value_uncond\": 3.096295233639719e-07}, {\"x\": -9.710144927536232, \"y\": 5.072463768115943, \"x2\": -9.420289855072465, \"y2\": 5.362318840579711, \"center_x\": -9.565217391304348, \"center_y\": 5.217391304347827, \"value_uncond\": 4.837627553509998e-07}, {\"x\": -9.420289855072463, \"y\": 5.072463768115943, \"x2\": -9.130434782608695, \"y2\": 5.362318840579711, \"center_x\": -9.275362318840578, \"center_y\": 5.217391304347827, \"value_uncond\": 7.488042638703676e-07}, {\"x\": -9.130434782608695, \"y\": 5.072463768115943, \"x2\": -8.840579710144928, \"y2\": 5.362318840579711, \"center_x\": -8.985507246376812, \"center_y\": 5.217391304347827, \"value_uncond\": 1.1482858224915232e-06}, {\"x\": -8.840579710144928, \"y\": 5.072463768115943, \"x2\": -8.55072463768116, \"y2\": 5.362318840579711, \"center_x\": -8.695652173913043, \"center_y\": 5.217391304347827, \"value_uncond\": 1.7445262607207185e-06}, {\"x\": -8.55072463768116, \"y\": 5.072463768115943, \"x2\": -8.260869565217392, \"y2\": 5.362318840579711, \"center_x\": -8.405797101449277, \"center_y\": 5.217391304347827, \"value_uncond\": 2.625734645205194e-06}, {\"x\": -8.26086956521739, \"y\": 5.072463768115943, \"x2\": -7.971014492753623, \"y2\": 5.362318840579711, \"center_x\": -8.115942028985508, \"center_y\": 5.217391304347827, \"value_uncond\": 3.915344425697475e-06}, {\"x\": -7.971014492753623, \"y\": 5.072463768115943, \"x2\": -7.681159420289855, \"y2\": 5.362318840579711, \"center_x\": -7.826086956521739, \"center_y\": 5.217391304347827, \"value_uncond\": 5.7840884344633715e-06}, {\"x\": -7.681159420289855, \"y\": 5.072463768115943, \"x2\": -7.391304347826088, \"y2\": 5.362318840579711, \"center_x\": -7.536231884057972, \"center_y\": 5.217391304347827, \"value_uncond\": 8.465365055944217e-06}, {\"x\": -7.391304347826087, \"y\": 5.072463768115943, \"x2\": -7.101449275362319, \"y2\": 5.362318840579711, \"center_x\": -7.246376811594203, \"center_y\": 5.217391304347827, \"value_uncond\": 1.227445653706292e-05}, {\"x\": -7.101449275362318, \"y\": 5.072463768115943, \"x2\": -6.811594202898551, \"y2\": 5.362318840579711, \"center_x\": -6.956521739130435, \"center_y\": 5.217391304347827, \"value_uncond\": 1.7632125496308203e-05}, {\"x\": -6.811594202898551, \"y\": 5.072463768115943, \"x2\": -6.521739130434783, \"y2\": 5.362318840579711, \"center_x\": -6.666666666666667, \"center_y\": 5.217391304347827, \"value_uncond\": 2.5093016873409156e-05}, {\"x\": -6.521739130434782, \"y\": 5.072463768115943, \"x2\": -6.231884057971015, \"y2\": 5.362318840579711, \"center_x\": -6.3768115942028984, \"center_y\": 5.217391304347827, \"value_uncond\": 3.537910999962595e-05}, {\"x\": -6.231884057971014, \"y\": 5.072463768115943, \"x2\": -5.942028985507246, \"y2\": 5.362318840579711, \"center_x\": -6.08695652173913, \"center_y\": 5.217391304347827, \"value_uncond\": 4.941817955493573e-05}, {\"x\": -5.942028985507246, \"y\": 5.072463768115943, \"x2\": -5.6521739130434785, \"y2\": 5.362318840579711, \"center_x\": -5.797101449275362, \"center_y\": 5.217391304347827, \"value_uncond\": 6.838681804450433e-05}, {\"x\": -5.6521739130434785, \"y\": 5.072463768115943, \"x2\": -5.362318840579711, \"y2\": 5.362318840579711, \"center_x\": -5.507246376811595, \"center_y\": 5.217391304347827, \"value_uncond\": 9.37570351966053e-05}, {\"x\": -5.36231884057971, \"y\": 5.072463768115943, \"x2\": -5.072463768115942, \"y2\": 5.362318840579711, \"center_x\": -5.217391304347826, \"center_y\": 5.217391304347827, \"value_uncond\": 0.00012734478033952931}, {\"x\": -5.0724637681159415, \"y\": 5.072463768115943, \"x2\": -4.782608695652174, \"y2\": 5.362318840579711, \"center_x\": -4.927536231884058, \"center_y\": 5.217391304347827, \"value_uncond\": 0.00017135794538353534}, {\"x\": -4.782608695652174, \"y\": 5.072463768115943, \"x2\": -4.492753623188406, \"y2\": 5.362318840579711, \"center_x\": -4.63768115942029, \"center_y\": 5.217391304347827, \"value_uncond\": 0.00022844052963533022}, {\"x\": -4.492753623188405, \"y\": 5.072463768115943, \"x2\": -4.202898550724638, \"y2\": 5.362318840579711, \"center_x\": -4.3478260869565215, \"center_y\": 5.217391304347827, \"value_uncond\": 0.00030170873579742915}, {\"x\": -4.202898550724638, \"y\": 5.072463768115943, \"x2\": -3.91304347826087, \"y2\": 5.362318840579711, \"center_x\": -4.057971014492754, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0003947738947672235}, {\"x\": -3.913043478260869, \"y\": 5.072463768115943, \"x2\": -3.6231884057971016, \"y2\": 5.362318840579711, \"center_x\": -3.7681159420289854, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0005117463834022716}, {\"x\": -3.6231884057971016, \"y\": 5.072463768115943, \"x2\": -3.333333333333334, \"y2\": 5.362318840579711, \"center_x\": -3.4782608695652177, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0006572142212608497}, {\"x\": -3.333333333333333, \"y\": 5.072463768115943, \"x2\": -3.0434782608695654, \"y2\": 5.362318840579711, \"center_x\": -3.1884057971014492, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0008361899379559874}, {\"x\": -3.0434782608695645, \"y\": 5.072463768115943, \"x2\": -2.753623188405797, \"y2\": 5.362318840579711, \"center_x\": -2.8985507246376807, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0010540197209255768}, {\"x\": -2.753623188405797, \"y\": 5.072463768115943, \"x2\": -2.4637681159420293, \"y2\": 5.362318840579711, \"center_x\": -2.608695652173913, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0013162498982813378}, {\"x\": -2.4637681159420284, \"y\": 5.072463768115943, \"x2\": -2.1739130434782608, \"y2\": 5.362318840579711, \"center_x\": -2.3188405797101446, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0016284475649946408}, {\"x\": -2.1739130434782608, \"y\": 5.072463768115943, \"x2\": -1.8840579710144931, \"y2\": 5.362318840579711, \"center_x\": -2.028985507246377, \"center_y\": 5.217391304347827, \"value_uncond\": 0.001995974654276386}, {\"x\": -1.8840579710144922, \"y\": 5.072463768115943, \"x2\": -1.5942028985507246, \"y2\": 5.362318840579711, \"center_x\": -1.7391304347826084, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0024237179525454537}, {\"x\": -1.5942028985507246, \"y\": 5.072463768115943, \"x2\": -1.304347826086957, \"y2\": 5.362318840579711, \"center_x\": -1.4492753623188408, \"center_y\": 5.217391304347827, \"value_uncond\": 0.002915781336637707}, {\"x\": -1.304347826086957, \"y\": 5.072463768115943, \"x2\": -1.0144927536231894, \"y2\": 5.362318840579711, \"center_x\": -1.1594202898550732, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0034751506672816477}, {\"x\": -1.0144927536231876, \"y\": 5.072463768115943, \"x2\": -0.72463768115942, \"y2\": 5.362318840579711, \"center_x\": -0.8695652173913038, \"center_y\": 5.217391304347827, \"value_uncond\": 0.004103346007338828}, {\"x\": -0.72463768115942, \"y\": 5.072463768115943, \"x2\": -0.43478260869565233, \"y2\": 5.362318840579711, \"center_x\": -0.5797101449275361, \"center_y\": 5.217391304347827, \"value_uncond\": 0.004800079776571257}, {\"x\": -0.43478260869565233, \"y\": 5.072463768115943, \"x2\": -0.1449275362318847, \"y2\": 5.362318840579711, \"center_x\": -0.2898550724637685, \"center_y\": 5.217391304347827, \"value_uncond\": 0.005562942687262318}, {\"x\": -0.14492753623188293, \"y\": 5.072463768115943, \"x2\": 0.1449275362318847, \"y2\": 5.362318840579711, \"center_x\": 8.881784197001252e-16, \"center_y\": 5.217391304347827, \"value_uncond\": 0.006387141394591343}, {\"x\": 0.1449275362318847, \"y\": 5.072463768115943, \"x2\": 0.43478260869565233, \"y2\": 5.362318840579711, \"center_x\": 0.2898550724637685, \"center_y\": 5.217391304347827, \"value_uncond\": 0.007265312342396628}, {\"x\": 0.43478260869565233, \"y\": 5.072463768115943, \"x2\": 0.72463768115942, \"y2\": 5.362318840579711, \"center_x\": 0.5797101449275361, \"center_y\": 5.217391304347827, \"value_uncond\": 0.008187434971391197}, {\"x\": 0.72463768115942, \"y\": 5.072463768115943, \"x2\": 1.0144927536231876, \"y2\": 5.362318840579711, \"center_x\": 0.8695652173913038, \"center_y\": 5.217391304347827, \"value_uncond\": 0.009140864096972293}, {\"x\": 1.0144927536231894, \"y\": 5.072463768115943, \"x2\": 1.304347826086957, \"y2\": 5.362318840579711, \"center_x\": 1.1594202898550732, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0101104958445195}, {\"x\": 1.304347826086957, \"y\": 5.072463768115943, \"x2\": 1.5942028985507246, \"y2\": 5.362318840579711, \"center_x\": 1.4492753623188408, \"center_y\": 5.217391304347827, \"value_uncond\": 0.01107907423934817}, {\"x\": 1.5942028985507246, \"y\": 5.072463768115943, \"x2\": 1.8840579710144922, \"y2\": 5.362318840579711, \"center_x\": 1.7391304347826084, \"center_y\": 5.217391304347827, \"value_uncond\": 0.012027636783086286}, {\"x\": 1.884057971014494, \"y\": 5.072463768115943, \"x2\": 2.1739130434782616, \"y2\": 5.362318840579711, \"center_x\": 2.028985507246378, \"center_y\": 5.217391304347827, \"value_uncond\": 0.012936087698732852}, {\"x\": 2.1739130434782616, \"y\": 5.072463768115943, \"x2\": 2.4637681159420293, \"y2\": 5.362318840579711, \"center_x\": 2.3188405797101455, \"center_y\": 5.217391304347827, \"value_uncond\": 0.013783877737608382}, {\"x\": 2.4637681159420293, \"y\": 5.072463768115943, \"x2\": 2.753623188405797, \"y2\": 5.362318840579711, \"center_x\": 2.608695652173913, \"center_y\": 5.217391304347827, \"value_uncond\": 0.014550760349213649}, {\"x\": 2.753623188405797, \"y\": 5.072463768115943, \"x2\": 3.0434782608695645, \"y2\": 5.362318840579711, \"center_x\": 2.8985507246376807, \"center_y\": 5.217391304347827, \"value_uncond\": 0.01521758646854096}, {\"x\": 3.0434782608695663, \"y\": 5.072463768115943, \"x2\": 3.333333333333334, \"y2\": 5.362318840579711, \"center_x\": 3.18840579710145, \"center_y\": 5.217391304347827, \"value_uncond\": 0.015767094947680884}, {\"x\": 3.333333333333334, \"y\": 5.072463768115943, \"x2\": 3.6231884057971016, \"y2\": 5.362318840579711, \"center_x\": 3.4782608695652177, \"center_y\": 5.217391304347827, \"value_uncond\": 0.016184653359752416}, {\"x\": 3.6231884057971016, \"y\": 5.072463768115943, \"x2\": 3.913043478260869, \"y2\": 5.362318840579711, \"center_x\": 3.7681159420289854, \"center_y\": 5.217391304347827, \"value_uncond\": 0.01645890490538141}, {\"x\": 3.913043478260871, \"y\": 5.072463768115943, \"x2\": 4.202898550724639, \"y2\": 5.362318840579711, \"center_x\": 4.057971014492755, \"center_y\": 5.217391304347827, \"value_uncond\": 0.016582281536350007}, {\"x\": 4.202898550724639, \"y\": 5.072463768115943, \"x2\": 4.492753623188406, \"y2\": 5.362318840579711, \"center_x\": 4.347826086956522, \"center_y\": 5.217391304347827, \"value_uncond\": 0.016551350944871517}, {\"x\": 4.492753623188406, \"y\": 5.072463768115943, \"x2\": 4.782608695652174, \"y2\": 5.362318840579711, \"center_x\": 4.63768115942029, \"center_y\": 5.217391304347827, \"value_uncond\": 0.016366975214692422}, {\"x\": 4.782608695652174, \"y\": 5.072463768115943, \"x2\": 5.0724637681159415, \"y2\": 5.362318840579711, \"center_x\": 4.927536231884058, \"center_y\": 5.217391304347827, \"value_uncond\": 0.01603427089908147}, {\"x\": 5.072463768115943, \"y\": 5.072463768115943, \"x2\": 5.362318840579711, \"y2\": 5.362318840579711, \"center_x\": 5.217391304347827, \"center_y\": 5.217391304347827, \"value_uncond\": 0.015562373105938575}, {\"x\": 5.362318840579711, \"y\": 5.072463768115943, \"x2\": 5.6521739130434785, \"y2\": 5.362318840579711, \"center_x\": 5.507246376811595, \"center_y\": 5.217391304347827, \"value_uncond\": 0.014964018771678233}, {\"x\": 5.6521739130434785, \"y\": 5.072463768115943, \"x2\": 5.942028985507246, \"y2\": 5.362318840579711, \"center_x\": 5.797101449275362, \"center_y\": 5.217391304347827, \"value_uncond\": 0.014254975654723591}, {\"x\": 5.942028985507246, \"y\": 5.072463768115943, \"x2\": 6.231884057971014, \"y2\": 5.362318840579711, \"center_x\": 6.08695652173913, \"center_y\": 5.217391304347827, \"value_uncond\": 0.013453352763753925}, {\"x\": 6.2318840579710155, \"y\": 5.072463768115943, \"x2\": 6.521739130434783, \"y2\": 5.362318840579711, \"center_x\": 6.376811594202899, \"center_y\": 5.217391304347827, \"value_uncond\": 0.012578834257875104}, {\"x\": 6.521739130434785, \"y\": 5.072463768115943, \"x2\": 6.8115942028985526, \"y2\": 5.362318840579711, \"center_x\": 6.666666666666669, \"center_y\": 5.217391304347827, \"value_uncond\": 0.011651881897623508}, {\"x\": 6.811594202898551, \"y\": 5.072463768115943, \"x2\": 7.101449275362318, \"y2\": 5.362318840579711, \"center_x\": 6.956521739130435, \"center_y\": 5.217391304347827, \"value_uncond\": 0.010692950780604234}, {\"x\": 7.10144927536232, \"y\": 5.072463768115943, \"x2\": 7.391304347826088, \"y2\": 5.362318840579711, \"center_x\": 7.246376811594204, \"center_y\": 5.217391304347827, \"value_uncond\": 0.009721759565745856}, {\"x\": 7.391304347826086, \"y\": 5.072463768115943, \"x2\": 7.681159420289854, \"y2\": 5.362318840579711, \"center_x\": 7.53623188405797, \"center_y\": 5.217391304347827, \"value_uncond\": 0.00875665015074523}, {\"x\": 7.681159420289855, \"y\": 5.072463768115943, \"x2\": 7.971014492753623, \"y2\": 5.362318840579711, \"center_x\": 7.826086956521739, \"center_y\": 5.217391304347827, \"value_uncond\": 0.007814063503488377}, {\"x\": 7.971014492753625, \"y\": 5.072463768115943, \"x2\": 8.260869565217392, \"y2\": 5.362318840579711, \"center_x\": 8.115942028985508, \"center_y\": 5.217391304347827, \"value_uncond\": 0.006908148874207331}, {\"x\": 8.26086956521739, \"y\": 5.072463768115943, \"x2\": 8.550724637681158, \"y2\": 5.362318840579711, \"center_x\": 8.405797101449274, \"center_y\": 5.217391304347827, \"value_uncond\": 0.006050513785049202}, {\"x\": 8.55072463768116, \"y\": 5.072463768115943, \"x2\": 8.840579710144928, \"y2\": 5.362318840579711, \"center_x\": 8.695652173913043, \"center_y\": 5.217391304347827, \"value_uncond\": 0.005250112815975646}, {\"x\": 8.84057971014493, \"y\": 5.072463768115943, \"x2\": 9.130434782608697, \"y2\": 5.362318840579711, \"center_x\": 8.985507246376812, \"center_y\": 5.217391304347827, \"value_uncond\": 0.004513264969734587}, {\"x\": 9.130434782608695, \"y\": 5.072463768115943, \"x2\": 9.420289855072463, \"y2\": 5.362318840579711, \"center_x\": 9.275362318840578, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0038437828205178234}, {\"x\": 9.420289855072465, \"y\": 5.072463768115943, \"x2\": 9.710144927536232, \"y2\": 5.362318840579711, \"center_x\": 9.565217391304348, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0032431920445220664}, {\"x\": 9.710144927536234, \"y\": 5.072463768115943, \"x2\": 10.000000000000002, \"y2\": 5.362318840579711, \"center_x\": 9.855072463768117, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0027110174012978747}, {\"x\": 10.0, \"y\": 5.072463768115943, \"x2\": 10.289855072463768, \"y2\": 5.362318840579711, \"center_x\": 10.144927536231883, \"center_y\": 5.217391304347827, \"value_uncond\": 0.002245110696051106}, {\"x\": -10.0, \"y\": 5.362318840579711, \"x2\": -9.710144927536232, \"y2\": 5.6521739130434785, \"center_x\": -9.855072463768117, \"center_y\": 5.507246376811595, \"value_uncond\": 2.977246444577404e-07}, {\"x\": -9.710144927536232, \"y\": 5.362318840579711, \"x2\": -9.420289855072465, \"y2\": 5.6521739130434785, \"center_x\": -9.565217391304348, \"center_y\": 5.507246376811595, \"value_uncond\": 4.6516266528456056e-07}, {\"x\": -9.420289855072463, \"y\": 5.362318840579711, \"x2\": -9.130434782608695, \"y2\": 5.6521739130434785, \"center_x\": -9.275362318840578, \"center_y\": 5.507246376811595, \"value_uncond\": 7.200136498843506e-07}, {\"x\": -9.130434782608695, \"y\": 5.362318840579711, \"x2\": -8.840579710144928, \"y2\": 5.6521739130434785, \"center_x\": -8.985507246376812, \"center_y\": 5.507246376811595, \"value_uncond\": 1.1041356280333723e-06}, {\"x\": -8.840579710144928, \"y\": 5.362318840579711, \"x2\": -8.55072463768116, \"y2\": 5.6521739130434785, \"center_x\": -8.695652173913043, \"center_y\": 5.507246376811595, \"value_uncond\": 1.6774513459742732e-06}, {\"x\": -8.55072463768116, \"y\": 5.362318840579711, \"x2\": -8.260869565217392, \"y2\": 5.6521739130434785, \"center_x\": -8.405797101449277, \"center_y\": 5.507246376811595, \"value_uncond\": 2.52477833893488e-06}, {\"x\": -8.26086956521739, \"y\": 5.362318840579711, \"x2\": -7.971014492753623, \"y2\": 5.6521739130434785, \"center_x\": -8.115942028985508, \"center_y\": 5.507246376811595, \"value_uncond\": 3.7648041905231814e-06}, {\"x\": -7.971014492753623, \"y\": 5.362318840579711, \"x2\": -7.681159420289855, \"y2\": 5.6521739130434785, \"center_x\": -7.826086956521739, \"center_y\": 5.507246376811595, \"value_uncond\": 5.561697263081826e-06}, {\"x\": -7.681159420289855, \"y\": 5.362318840579711, \"x2\": -7.391304347826088, \"y2\": 5.6521739130434785, \"center_x\": -7.536231884057972, \"center_y\": 5.507246376811595, \"value_uncond\": 8.139882056800119e-06}, {\"x\": -7.391304347826087, \"y\": 5.362318840579711, \"x2\": -7.101449275362319, \"y2\": 5.6521739130434785, \"center_x\": -7.246376811594203, \"center_y\": 5.507246376811595, \"value_uncond\": 1.1802518599343171e-05}, {\"x\": -7.101449275362318, \"y\": 5.362318840579711, \"x2\": -6.811594202898551, \"y2\": 5.6521739130434785, \"center_x\": -6.956521739130435, \"center_y\": 5.507246376811595, \"value_uncond\": 1.6954191697836777e-05}, {\"x\": -6.811594202898551, \"y\": 5.362318840579711, \"x2\": -6.521739130434783, \"y2\": 5.6521739130434785, \"center_x\": -6.666666666666667, \"center_y\": 5.507246376811595, \"value_uncond\": 2.4128220868091493e-05}, {\"x\": -6.521739130434782, \"y\": 5.362318840579711, \"x2\": -6.231884057971015, \"y2\": 5.6521739130434785, \"center_x\": -6.3768115942028984, \"center_y\": 5.507246376811595, \"value_uncond\": 3.4018826213442224e-05}, {\"x\": -6.231884057971014, \"y\": 5.362318840579711, \"x2\": -5.942028985507246, \"y2\": 5.6521739130434785, \"center_x\": -6.08695652173913, \"center_y\": 5.507246376811595, \"value_uncond\": 4.7518110604868697e-05}, {\"x\": -5.942028985507246, \"y\": 5.362318840579711, \"x2\": -5.6521739130434785, \"y2\": 5.6521739130434785, \"center_x\": -5.797101449275362, \"center_y\": 5.507246376811595, \"value_uncond\": 6.575742799552855e-05}, {\"x\": -5.6521739130434785, \"y\": 5.362318840579711, \"x2\": -5.362318840579711, \"y2\": 5.6521739130434785, \"center_x\": -5.507246376811595, \"center_y\": 5.507246376811595, \"value_uncond\": 9.01521911284547e-05}, {\"x\": -5.36231884057971, \"y\": 5.362318840579711, \"x2\": -5.072463768115942, \"y2\": 5.6521739130434785, \"center_x\": -5.217391304347826, \"center_y\": 5.507246376811595, \"value_uncond\": 0.00012244852828703783}, {\"x\": -5.0724637681159415, \"y\": 5.362318840579711, \"x2\": -4.782608695652174, \"y2\": 5.6521739130434785, \"center_x\": -4.927536231884058, \"center_y\": 5.507246376811595, \"value_uncond\": 0.00016476944062065562}, {\"x\": -4.782608695652174, \"y\": 5.362318840579711, \"x2\": -4.492753623188406, \"y2\": 5.6521739130434785, \"center_x\": -4.63768115942029, \"center_y\": 5.507246376811595, \"value_uncond\": 0.00021965726887570545}, {\"x\": -4.492753623188405, \"y\": 5.362318840579711, \"x2\": -4.202898550724638, \"y2\": 5.6521739130434785, \"center_x\": -4.3478260869565215, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0002901084015476537}, {\"x\": -4.202898550724638, \"y\": 5.362318840579711, \"x2\": -3.91304347826087, \"y2\": 5.6521739130434785, \"center_x\": -4.057971014492754, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0003795953182494388}, {\"x\": -3.913043478260869, \"y\": 5.362318840579711, \"x2\": -3.6231884057971016, \"y2\": 5.6521739130434785, \"center_x\": -3.7681159420289854, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0004920703568434459}, {\"x\": -3.6231884057971016, \"y\": 5.362318840579711, \"x2\": -3.333333333333334, \"y2\": 5.6521739130434785, \"center_x\": -3.4782608695652177, \"center_y\": 5.507246376811595, \"value_uncond\": 0.000631945133111376}, {\"x\": -3.333333333333333, \"y\": 5.362318840579711, \"x2\": -3.0434782608695654, \"y2\": 5.6521739130434785, \"center_x\": -3.1884057971014492, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0008040394509939493}, {\"x\": -3.0434782608695645, \"y\": 5.362318840579711, \"x2\": -2.753623188405797, \"y2\": 5.6521739130434785, \"center_x\": -2.8985507246376807, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0010134939435188506}, {\"x\": -2.753623188405797, \"y\": 5.362318840579711, \"x2\": -2.4637681159420293, \"y2\": 5.6521739130434785, \"center_x\": -2.608695652173913, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0012656416892218962}, {\"x\": -2.4637681159420284, \"y\": 5.362318840579711, \"x2\": -2.1739130434782608, \"y2\": 5.6521739130434785, \"center_x\": -2.3188405797101446, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0015658357350380376}, {\"x\": -2.1739130434782608, \"y\": 5.362318840579711, \"x2\": -1.8840579710144931, \"y2\": 5.6521739130434785, \"center_x\": -2.028985507246377, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0019192318543621285}, {\"x\": -1.8840579710144922, \"y\": 5.362318840579711, \"x2\": -1.5942028985507246, \"y2\": 5.6521739130434785, \"center_x\": -1.7391304347826084, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0023305289426137506}, {\"x\": -1.5942028985507246, \"y\": 5.362318840579711, \"x2\": -1.304347826086957, \"y2\": 5.6521739130434785, \"center_x\": -1.4492753623188408, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0028036730875515294}, {\"x\": -1.304347826086957, \"y\": 5.362318840579711, \"x2\": -1.0144927536231894, \"y2\": 5.6521739130434785, \"center_x\": -1.1594202898550732, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0033415353471874256}, {\"x\": -1.0144927536231876, \"y\": 5.362318840579711, \"x2\": -0.72463768115942, \"y2\": 5.6521739130434785, \"center_x\": -0.8695652173913038, \"center_y\": 5.507246376811595, \"value_uncond\": 0.00394557733981317}, {\"x\": -0.72463768115942, \"y\": 5.362318840579711, \"x2\": -0.43478260869565233, \"y2\": 5.6521739130434785, \"center_x\": -0.5797101449275361, \"center_y\": 5.507246376811595, \"value_uncond\": 0.004615522542301451}, {\"x\": -0.43478260869565233, \"y\": 5.362318840579711, \"x2\": -0.1449275362318847, \"y2\": 5.6521739130434785, \"center_x\": -0.2898550724637685, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0053490543011205476}, {\"x\": -0.14492753623188293, \"y\": 5.362318840579711, \"x2\": 0.1449275362318847, \"y2\": 5.6521739130434785, \"center_x\": 8.881784197001252e-16, \"center_y\": 5.507246376811595, \"value_uncond\": 0.006141563569733192}, {\"x\": 0.1449275362318847, \"y\": 5.362318840579711, \"x2\": 0.43478260869565233, \"y2\": 5.6521739130434785, \"center_x\": 0.2898550724637685, \"center_y\": 5.507246376811595, \"value_uncond\": 0.006985969911763776}, {\"x\": 0.43478260869565233, \"y\": 5.362318840579711, \"x2\": 0.72463768115942, \"y2\": 5.6521739130434785, \"center_x\": 0.5797101449275361, \"center_y\": 5.507246376811595, \"value_uncond\": 0.007872638046252756}, {\"x\": 0.72463768115942, \"y\": 5.362318840579711, \"x2\": 1.0144927536231876, \"y2\": 5.6521739130434785, \"center_x\": 0.8695652173913038, \"center_y\": 5.507246376811595, \"value_uncond\": 0.008789408980578704}, {\"x\": 1.0144927536231894, \"y\": 5.362318840579711, \"x2\": 1.304347826086957, \"y2\": 5.6521739130434785, \"center_x\": 1.1594202898550732, \"center_y\": 5.507246376811595, \"value_uncond\": 0.009721759565745867}, {\"x\": 1.304347826086957, \"y\": 5.362318840579711, \"x2\": 1.5942028985507246, \"y2\": 5.6521739130434785, \"center_x\": 1.4492753623188408, \"center_y\": 5.507246376811595, \"value_uncond\": 0.010653097298326468}, {\"x\": 1.5942028985507246, \"y\": 5.362318840579711, \"x2\": 1.8840579710144922, \"y2\": 5.6521739130434785, \"center_x\": 1.7391304347826084, \"center_y\": 5.507246376811595, \"value_uncond\": 0.011565188764967345}, {\"x\": 1.884057971014494, \"y\": 5.362318840579711, \"x2\": 2.1739130434782616, \"y2\": 5.6521739130434785, \"center_x\": 2.028985507246378, \"center_y\": 5.507246376811595, \"value_uncond\": 0.01243871084687245}, {\"x\": 2.1739130434782616, \"y\": 5.362318840579711, \"x2\": 2.4637681159420293, \"y2\": 5.6521739130434785, \"center_x\": 2.3188405797101455, \"center_y\": 5.507246376811595, \"value_uncond\": 0.013253904389002227}, {\"x\": 2.4637681159420293, \"y\": 5.362318840579711, \"x2\": 2.753623188405797, \"y2\": 5.6521739130434785, \"center_x\": 2.608695652173913, \"center_y\": 5.507246376811595, \"value_uncond\": 0.013991301296120189}, {\"x\": 2.753623188405797, \"y\": 5.362318840579711, \"x2\": 3.0434782608695645, \"y2\": 5.6521739130434785, \"center_x\": 2.8985507246376807, \"center_y\": 5.507246376811595, \"value_uncond\": 0.014632488761497914}, {\"x\": 3.0434782608695663, \"y\": 5.362318840579711, \"x2\": 3.333333333333334, \"y2\": 5.6521739130434785, \"center_x\": 3.18840579710145, \"center_y\": 5.507246376811595, \"value_uncond\": 0.015160869307387047}, {\"x\": 3.333333333333334, \"y\": 5.362318840579711, \"x2\": 3.6231884057971016, \"y2\": 5.6521739130434785, \"center_x\": 3.4782608695652177, \"center_y\": 5.507246376811595, \"value_uncond\": 0.01556237310593858}, {\"x\": 3.6231884057971016, \"y\": 5.362318840579711, \"x2\": 3.913043478260869, \"y2\": 5.6521739130434785, \"center_x\": 3.7681159420289854, \"center_y\": 5.507246376811595, \"value_uncond\": 0.015826080012913323}, {\"x\": 3.913043478260871, \"y\": 5.362318840579711, \"x2\": 4.202898550724639, \"y2\": 5.6521739130434785, \"center_x\": 4.057971014492755, \"center_y\": 5.507246376811595, \"value_uncond\": 0.015944712962350577}, {\"x\": 4.202898550724639, \"y\": 5.362318840579711, \"x2\": 4.492753623188406, \"y2\": 5.6521739130434785, \"center_x\": 4.347826086956522, \"center_y\": 5.507246376811595, \"value_uncond\": 0.01591497161452705}, {\"x\": 4.492753623188406, \"y\": 5.362318840579711, \"x2\": 4.782608695652174, \"y2\": 5.6521739130434785, \"center_x\": 4.63768115942029, \"center_y\": 5.507246376811595, \"value_uncond\": 0.015737684907116793}, {\"x\": 4.782608695652174, \"y\": 5.362318840579711, \"x2\": 5.0724637681159415, \"y2\": 5.6521739130434785, \"center_x\": 4.927536231884058, \"center_y\": 5.507246376811595, \"value_uncond\": 0.015417772668133083}, {\"x\": 5.072463768115943, \"y\": 5.362318840579711, \"x2\": 5.362318840579711, \"y2\": 5.6521739130434785, \"center_x\": 5.217391304347827, \"center_y\": 5.507246376811595, \"value_uncond\": 0.014964018771678233}, {\"x\": 5.362318840579711, \"y\": 5.362318840579711, \"x2\": 5.6521739130434785, \"y2\": 5.6521739130434785, \"center_x\": 5.507246376811595, \"center_y\": 5.507246376811595, \"value_uncond\": 0.014388670434439739}, {\"x\": 5.6521739130434785, \"y\": 5.362318840579711, \"x2\": 5.942028985507246, \"y2\": 5.6521739130434785, \"center_x\": 5.797101449275362, \"center_y\": 5.507246376811595, \"value_uncond\": 0.013706889163690632}, {\"x\": 5.942028985507246, \"y\": 5.362318840579711, \"x2\": 6.231884057971014, \"y2\": 5.6521739130434785, \"center_x\": 6.08695652173913, \"center_y\": 5.507246376811595, \"value_uncond\": 0.01293608769873285}, {\"x\": 6.2318840579710155, \"y\": 5.362318840579711, \"x2\": 6.521739130434783, \"y2\": 5.6521739130434785, \"center_x\": 6.376811594202899, \"center_y\": 5.507246376811595, \"value_uncond\": 0.012095193366675168}, {\"x\": 6.521739130434785, \"y\": 5.362318840579711, \"x2\": 6.8115942028985526, \"y2\": 5.6521739130434785, \"center_x\": 6.666666666666669, \"center_y\": 5.507246376811595, \"value_uncond\": 0.011203881198226821}, {\"x\": 6.811594202898551, \"y\": 5.362318840579711, \"x2\": 7.101449275362318, \"y2\": 5.6521739130434785, \"center_x\": 6.956521739130435, \"center_y\": 5.507246376811595, \"value_uncond\": 0.010281819817347382}, {\"x\": 7.10144927536232, \"y\": 5.362318840579711, \"x2\": 7.391304347826088, \"y2\": 5.6521739130434785, \"center_x\": 7.246376811594204, \"center_y\": 5.507246376811595, \"value_uncond\": 0.00934796972449207}, {\"x\": 7.391304347826086, \"y\": 5.362318840579711, \"x2\": 7.681159420289854, \"y2\": 5.6521739130434785, \"center_x\": 7.53623188405797, \"center_y\": 5.507246376811595, \"value_uncond\": 0.008419967593680685}, {\"x\": 7.681159420289855, \"y\": 5.362318840579711, \"x2\": 7.971014492753623, \"y2\": 5.6521739130434785, \"center_x\": 7.826086956521739, \"center_y\": 5.507246376811595, \"value_uncond\": 0.007513622257563381}, {\"x\": 7.971014492753625, \"y\": 5.362318840579711, \"x2\": 8.260869565217392, \"y2\": 5.6521739130434785, \"center_x\": 8.115942028985508, \"center_y\": 5.507246376811595, \"value_uncond\": 0.00664253894489518}, {\"x\": 8.26086956521739, \"y\": 5.362318840579711, \"x2\": 8.550724637681158, \"y2\": 5.6521739130434785, \"center_x\": 8.405797101449274, \"center_y\": 5.507246376811595, \"value_uncond\": 0.005817878882702297}, {\"x\": 8.55072463768116, \"y\": 5.362318840579711, \"x2\": 8.840579710144928, \"y2\": 5.6521739130434785, \"center_x\": 8.695652173913043, \"center_y\": 5.507246376811595, \"value_uncond\": 0.005048252358228618}, {\"x\": 8.84057971014493, \"y\": 5.362318840579711, \"x2\": 9.130434782608697, \"y2\": 5.6521739130434785, \"center_x\": 8.985507246376812, \"center_y\": 5.507246376811595, \"value_uncond\": 0.004339735416245373}, {\"x\": 9.130434782608695, \"y\": 5.362318840579711, \"x2\": 9.420289855072463, \"y2\": 5.6521739130434785, \"center_x\": 9.275362318840578, \"center_y\": 5.507246376811595, \"value_uncond\": 0.003695994042099792}, {\"x\": 9.420289855072465, \"y\": 5.362318840579711, \"x2\": 9.710144927536232, \"y2\": 5.6521739130434785, \"center_x\": 9.565217391304348, \"center_y\": 5.507246376811595, \"value_uncond\": 0.003118495251592849}, {\"x\": 9.710144927536234, \"y\": 5.362318840579711, \"x2\": 10.000000000000002, \"y2\": 5.6521739130434785, \"center_x\": 9.855072463768117, \"center_y\": 5.507246376811595, \"value_uncond\": 0.002606782076692864}, {\"x\": 10.0, \"y\": 5.362318840579711, \"x2\": 10.289855072463768, \"y2\": 5.6521739130434785, \"center_x\": 10.144927536231883, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0021587889180850065}, {\"x\": -10.0, \"y\": 5.6521739130434785, \"x2\": -9.710144927536232, \"y2\": 5.942028985507246, \"center_x\": -9.855072463768117, \"center_y\": 5.797101449275362, \"value_uncond\": 2.8361749763298007e-07}, {\"x\": -9.710144927536232, \"y\": 5.6521739130434785, \"x2\": -9.420289855072465, \"y2\": 5.942028985507246, \"center_x\": -9.565217391304348, \"center_y\": 5.797101449275362, \"value_uncond\": 4.4312176897744417e-07}, {\"x\": -9.420289855072463, \"y\": 5.6521739130434785, \"x2\": -9.130434782608695, \"y2\": 5.942028985507246, \"center_x\": -9.275362318840578, \"center_y\": 5.797101449275362, \"value_uncond\": 6.858970980172719e-07}, {\"x\": -9.130434782608695, \"y\": 5.6521739130434785, \"x2\": -8.840579710144928, \"y2\": 5.942028985507246, \"center_x\": -8.985507246376812, \"center_y\": 5.797101449275362, \"value_uncond\": 1.0518181470687534e-06}, {\"x\": -8.840579710144928, \"y\": 5.6521739130434785, \"x2\": -8.55072463768116, \"y2\": 5.942028985507246, \"center_x\": -8.695652173913043, \"center_y\": 5.797101449275362, \"value_uncond\": 1.5979683308139013e-06}, {\"x\": -8.55072463768116, \"y\": 5.6521739130434785, \"x2\": -8.260869565217392, \"y2\": 5.942028985507246, \"center_x\": -8.405797101449277, \"center_y\": 5.797101449275362, \"value_uncond\": 2.4051462581167118e-06}, {\"x\": -8.26086956521739, \"y\": 5.6521739130434785, \"x2\": -7.971014492753623, \"y2\": 5.942028985507246, \"center_x\": -8.115942028985508, \"center_y\": 5.797101449275362, \"value_uncond\": 3.586415714893573e-06}, {\"x\": -7.971014492753623, \"y\": 5.6521739130434785, \"x2\": -7.681159420289855, \"y2\": 5.942028985507246, \"center_x\": -7.826086956521739, \"center_y\": 5.797101449275362, \"value_uncond\": 5.2981662408916325e-06}, {\"x\": -7.681159420289855, \"y\": 5.6521739130434785, \"x2\": -7.391304347826088, \"y2\": 5.942028985507246, \"center_x\": -7.536231884057972, \"center_y\": 5.797101449275362, \"value_uncond\": 7.754188384982478e-06}, {\"x\": -7.391304347826087, \"y\": 5.6521739130434785, \"x2\": -7.101449275362319, \"y2\": 5.942028985507246, \"center_x\": -7.246376811594203, \"center_y\": 5.797101449275362, \"value_uncond\": 1.1243277482148635e-05}, {\"x\": -7.101449275362318, \"y\": 5.6521739130434785, \"x2\": -6.811594202898551, \"y2\": 5.942028985507246, \"center_x\": -6.956521739130435, \"center_y\": 5.797101449275362, \"value_uncond\": 1.6150847816069353e-05}, {\"x\": -6.811594202898551, \"y\": 5.6521739130434785, \"x2\": -6.521739130434783, \"y2\": 5.942028985507246, \"center_x\": -6.666666666666667, \"center_y\": 5.797101449275362, \"value_uncond\": 2.2984948516464874e-05}, {\"x\": -6.521739130434782, \"y\": 5.6521739130434785, \"x2\": -6.231884057971015, \"y2\": 5.942028985507246, \"center_x\": -6.3768115942028984, \"center_y\": 5.797101449275362, \"value_uncond\": 3.2406905315616995e-05}, {\"x\": -6.231884057971014, \"y\": 5.6521739130434785, \"x2\": -5.942028985507246, \"y2\": 5.942028985507246, \"center_x\": -6.08695652173913, \"center_y\": 5.797101449275362, \"value_uncond\": 4.52665503943964e-05}, {\"x\": -5.942028985507246, \"y\": 5.6521739130434785, \"x2\": -5.6521739130434785, \"y2\": 5.942028985507246, \"center_x\": -5.797101449275362, \"center_y\": 5.797101449275362, \"value_uncond\": 6.26416305336118e-05}, {\"x\": -5.6521739130434785, \"y\": 5.6521739130434785, \"x2\": -5.362318840579711, \"y2\": 5.942028985507246, \"center_x\": -5.507246376811595, \"center_y\": 5.797101449275362, \"value_uncond\": 8.588049168906403e-05}, {\"x\": -5.36231884057971, \"y\": 5.6521739130434785, \"x2\": -5.072463768115942, \"y2\": 5.942028985507246, \"center_x\": -5.217391304347826, \"center_y\": 5.797101449275362, \"value_uncond\": 0.00011664652499581822}, {\"x\": -5.0724637681159415, \"y\": 5.6521739130434785, \"x2\": -4.782608695652174, \"y2\": 5.942028985507246, \"center_x\": -4.927536231884058, \"center_y\": 5.797101449275362, \"value_uncond\": 0.00015696213701197142}, {\"x\": -4.782608695652174, \"y\": 5.6521739130434785, \"x2\": -4.492753623188406, \"y2\": 5.942028985507246, \"center_x\": -4.63768115942029, \"center_y\": 5.797101449275362, \"value_uncond\": 0.00020924920424001095}, {\"x\": -4.492753623188405, \"y\": 5.6521739130434785, \"x2\": -4.202898550724638, \"y2\": 5.942028985507246, \"center_x\": -4.3478260869565215, \"center_y\": 5.797101449275362, \"value_uncond\": 0.0002763621366955009}, {\"x\": -4.202898550724638, \"y\": 5.6521739130434785, \"x2\": -3.91304347826087, \"y2\": 5.942028985507246, \"center_x\": -4.057971014492754, \"center_y\": 5.797101449275362, \"value_uncond\": 0.00036160887679011775}, {\"x\": -3.913043478260869, \"y\": 5.6521739130434785, \"x2\": -3.6231884057971016, \"y2\": 5.942028985507246, \"center_x\": -3.7681159420289854, \"center_y\": 5.797101449275362, \"value_uncond\": 0.0004687544879648525}, {\"x\": -3.6231884057971016, \"y\": 5.6521739130434785, \"x2\": -3.333333333333334, \"y2\": 5.942028985507246, \"center_x\": -3.4782608695652177, \"center_y\": 5.797101449275362, \"value_uncond\": 0.0006020015495218082}, {\"x\": -3.333333333333333, \"y\": 5.6521739130434785, \"x2\": -3.0434782608695654, \"y2\": 5.942028985507246, \"center_x\": -3.1884057971014492, \"center_y\": 5.797101449275362, \"value_uncond\": 0.0007659414876603125}, {\"x\": -3.0434782608695645, \"y\": 5.6521739130434785, \"x2\": -2.753623188405797, \"y2\": 5.942028985507246, \"center_x\": -2.8985507246376807, \"center_y\": 5.797101449275362, \"value_uncond\": 0.0009654713557573767}, {\"x\": -2.753623188405797, \"y\": 5.6521739130434785, \"x2\": -2.4637681159420293, \"y2\": 5.942028985507246, \"center_x\": -2.608695652173913, \"center_y\": 5.797101449275362, \"value_uncond\": 0.001205671534013852}, {\"x\": -2.4637681159420284, \"y\": 5.6521739130434785, \"x2\": -2.1739130434782608, \"y2\": 5.942028985507246, \"center_x\": -2.3188405797101446, \"center_y\": 5.797101449275362, \"value_uncond\": 0.0014916414248630431}, {\"x\": -2.1739130434782608, \"y\": 5.6521739130434785, \"x2\": -1.8840579710144931, \"y2\": 5.942028985507246, \"center_x\": -2.028985507246377, \"center_y\": 5.797101449275362, \"value_uncond\": 0.0018282925046500629}, {\"x\": -1.8840579710144922, \"y\": 5.6521739130434785, \"x2\": -1.5942028985507246, \"y2\": 5.942028985507246, \"center_x\": -1.7391304347826084, \"center_y\": 5.797101449275362, \"value_uncond\": 0.002220101020085922}, {\"x\": -1.5942028985507246, \"y\": 5.6521739130434785, \"x2\": -1.304347826086957, \"y2\": 5.942028985507246, \"center_x\": -1.4492753623188408, \"center_y\": 5.797101449275362, \"value_uncond\": 0.0026708260806577767}, {\"x\": -1.304347826086957, \"y\": 5.6521739130434785, \"x2\": -1.0144927536231894, \"y2\": 5.942028985507246, \"center_x\": -1.1594202898550732, \"center_y\": 5.797101449275362, \"value_uncond\": 0.003183202704457242}, {\"x\": -1.0144927536231876, \"y\": 5.6521739130434785, \"x2\": -0.72463768115942, \"y2\": 5.942028985507246, \"center_x\": -0.8695652173913038, \"center_y\": 5.797101449275362, \"value_uncond\": 0.0037586232536219923}, {\"x\": -0.72463768115942, \"y\": 5.6521739130434785, \"x2\": -0.43478260869565233, \"y2\": 5.942028985507246, \"center_x\": -0.5797101449275361, \"center_y\": 5.797101449275362, \"value_uncond\": 0.004396824307575779}, {\"x\": -0.43478260869565233, \"y\": 5.6521739130434785, \"x2\": -0.1449275362318847, \"y2\": 5.942028985507246, \"center_x\": -0.2898550724637685, \"center_y\": 5.797101449275362, \"value_uncond\": 0.005095598983248022}, {\"x\": -0.14492753623188293, \"y\": 5.6521739130434785, \"x2\": 0.1449275362318847, \"y2\": 5.942028985507246, \"center_x\": 8.881784197001252e-16, \"center_y\": 5.797101449275362, \"value_uncond\": 0.005850556625482325}, {\"x\": 0.1449275362318847, \"y\": 5.6521739130434785, \"x2\": 0.43478260869565233, \"y2\": 5.942028985507246, \"center_x\": 0.2898550724637685, \"center_y\": 5.797101449275362, \"value_uncond\": 0.006654952291646691}, {\"x\": 0.43478260869565233, \"y\": 5.6521739130434785, \"x2\": 0.72463768115942, \"y2\": 5.942028985507246, \"center_x\": 0.5797101449275361, \"center_y\": 5.797101449275362, \"value_uncond\": 0.0074996072512409475}, {\"x\": 0.72463768115942, \"y\": 5.6521739130434785, \"x2\": 1.0144927536231876, \"y2\": 5.942028985507246, \"center_x\": 0.8695652173913038, \"center_y\": 5.797101449275362, \"value_uncond\": 0.008372938643641286}, {\"x\": 1.0144927536231894, \"y\": 5.6521739130434785, \"x2\": 1.304347826086957, \"y2\": 5.942028985507246, \"center_x\": 1.1594202898550732, \"center_y\": 5.797101449275362, \"value_uncond\": 0.009261111473147477}, {\"x\": 1.304347826086957, \"y\": 5.6521739130434785, \"x2\": 1.5942028985507246, \"y2\": 5.942028985507246, \"center_x\": 1.4492753623188408, \"center_y\": 5.797101449275362, \"value_uncond\": 0.010148319442265323}, {\"x\": 1.5942028985507246, \"y\": 5.6521739130434785, \"x2\": 1.8840579710144922, \"y2\": 5.942028985507246, \"center_x\": 1.7391304347826084, \"center_y\": 5.797101449275362, \"value_uncond\": 0.011017193095140902}, {\"x\": 1.884057971014494, \"y\": 5.6521739130434785, \"x2\": 2.1739130434782616, \"y2\": 5.942028985507246, \"center_x\": 2.028985507246378, \"center_y\": 5.797101449275362, \"value_uncond\": 0.011849324904210014}, {\"x\": 2.1739130434782616, \"y\": 5.6521739130434785, \"x2\": 2.4637681159420293, \"y2\": 5.942028985507246, \"center_x\": 2.3188405797101455, \"center_y\": 5.797101449275362, \"value_uncond\": 0.012625891966458132}, {\"x\": 2.4637681159420293, \"y\": 5.6521739130434785, \"x2\": 2.753623188405797, \"y2\": 5.942028985507246, \"center_x\": 2.608695652173913, \"center_y\": 5.797101449275362, \"value_uncond\": 0.013328348647328502}, {\"x\": 2.753623188405797, \"y\": 5.6521739130434785, \"x2\": 3.0434782608695645, \"y2\": 5.942028985507246, \"center_x\": 2.8985507246376807, \"center_y\": 5.797101449275362, \"value_uncond\": 0.013939154597824402}, {\"x\": 3.0434782608695663, \"y\": 5.6521739130434785, \"x2\": 3.333333333333334, \"y2\": 5.942028985507246, \"center_x\": 3.18840579710145, \"center_y\": 5.797101449275362, \"value_uncond\": 0.01444249878183029}, {\"x\": 3.333333333333334, \"y\": 5.6521739130434785, \"x2\": 3.6231884057971016, \"y2\": 5.942028985507246, \"center_x\": 3.4782608695652177, \"center_y\": 5.797101449275362, \"value_uncond\": 0.014824978044985428}, {\"x\": 3.6231884057971016, \"y\": 5.6521739130434785, \"x2\": 3.913043478260869, \"y2\": 5.942028985507246, \"center_x\": 3.7681159420289854, \"center_y\": 5.797101449275362, \"value_uncond\": 0.015076189674445703}, {\"x\": 3.913043478260871, \"y\": 5.6521739130434785, \"x2\": 4.202898550724639, \"y2\": 5.942028985507246, \"center_x\": 4.057971014492755, \"center_y\": 5.797101449275362, \"value_uncond\": 0.01518920141493328}, {\"x\": 4.202898550724639, \"y\": 5.6521739130434785, \"x2\": 4.492753623188406, \"y2\": 5.942028985507246, \"center_x\": 4.347826086956522, \"center_y\": 5.797101449275362, \"value_uncond\": 0.015160869307387045}, {\"x\": 4.492753623188406, \"y\": 5.6521739130434785, \"x2\": 4.782608695652174, \"y2\": 5.942028985507246, \"center_x\": 4.63768115942029, \"center_y\": 5.797101449275362, \"value_uncond\": 0.014991983011760197}, {\"x\": 4.782608695652174, \"y\": 5.6521739130434785, \"x2\": 5.0724637681159415, \"y2\": 5.942028985507246, \"center_x\": 4.927536231884058, \"center_y\": 5.797101449275362, \"value_uncond\": 0.014687229238863838}, {\"x\": 5.072463768115943, \"y\": 5.6521739130434785, \"x2\": 5.362318840579711, \"y2\": 5.942028985507246, \"center_x\": 5.217391304347827, \"center_y\": 5.797101449275362, \"value_uncond\": 0.014254975654723591}, {\"x\": 5.362318840579711, \"y\": 5.6521739130434785, \"x2\": 5.6521739130434785, \"y2\": 5.942028985507246, \"center_x\": 5.507246376811595, \"center_y\": 5.797101449275362, \"value_uncond\": 0.013706889163690632}, {\"x\": 5.6521739130434785, \"y\": 5.6521739130434785, \"x2\": 5.942028985507246, \"y2\": 5.942028985507246, \"center_x\": 5.797101449275362, \"center_y\": 5.797101449275362, \"value_uncond\": 0.013057412872283585}, {\"x\": 5.942028985507246, \"y\": 5.6521739130434785, \"x2\": 6.231884057971014, \"y2\": 5.942028985507246, \"center_x\": 6.08695652173913, \"center_y\": 5.797101449275362, \"value_uncond\": 0.012323134448469086}, {\"x\": 6.2318840579710155, \"y\": 5.6521739130434785, \"x2\": 6.521739130434783, \"y2\": 5.942028985507246, \"center_x\": 6.376811594202899, \"center_y\": 5.797101449275362, \"value_uncond\": 0.011522084382001349}, {\"x\": 6.521739130434785, \"y\": 5.6521739130434785, \"x2\": 6.8115942028985526, \"y2\": 5.942028985507246, \"center_x\": 6.666666666666669, \"center_y\": 5.797101449275362, \"value_uncond\": 0.010673005437644672}, {\"x\": 6.811594202898551, \"y\": 5.6521739130434785, \"x2\": 7.101449275362318, \"y2\": 5.942028985507246, \"center_x\": 6.956521739130435, \"center_y\": 5.797101449275362, \"value_uncond\": 0.009794634276985995}, {\"x\": 7.10144927536232, \"y\": 5.6521739130434785, \"x2\": 7.391304347826088, \"y2\": 5.942028985507246, \"center_x\": 7.246376811594204, \"center_y\": 5.797101449275362, \"value_uncond\": 0.00890503299126662}, {\"x\": 7.391304347826086, \"y\": 5.6521739130434785, \"x2\": 7.681159420289854, \"y2\": 5.942028985507246, \"center_x\": 7.53623188405797, \"center_y\": 5.797101449275362, \"value_uncond\": 0.008021002572427181}, {\"x\": 7.681159420289855, \"y\": 5.6521739130434785, \"x2\": 7.971014492753623, \"y2\": 5.942028985507246, \"center_x\": 7.826086956521739, \"center_y\": 5.797101449275362, \"value_uncond\": 0.007157602780014635}, {\"x\": 7.971014492753625, \"y\": 5.6521739130434785, \"x2\": 8.260869565217392, \"y2\": 5.942028985507246, \"center_x\": 8.115942028985508, \"center_y\": 5.797101449275362, \"value_uncond\": 0.006327794183488224}, {\"x\": 8.26086956521739, \"y\": 5.6521739130434785, \"x2\": 8.550724637681158, \"y2\": 5.942028985507246, \"center_x\": 8.405797101449274, \"center_y\": 5.797101449275362, \"value_uncond\": 0.005542209155204808}, {\"x\": 8.55072463768116, \"y\": 5.6521739130434785, \"x2\": 8.840579710144928, \"y2\": 5.942028985507246, \"center_x\": 8.695652173913043, \"center_y\": 5.797101449275362, \"value_uncond\": 0.004809049999432685}, {\"x\": 8.84057971014493, \"y\": 5.6521739130434785, \"x2\": 9.130434782608697, \"y2\": 5.942028985507246, \"center_x\": 8.985507246376812, \"center_y\": 5.797101449275362, \"value_uncond\": 0.004134104858489265}, {\"x\": 9.130434782608695, \"y\": 5.6521739130434785, \"x2\": 9.420289855072463, \"y2\": 5.942028985507246, \"center_x\": 9.275362318840578, \"center_y\": 5.797101449275362, \"value_uncond\": 0.003520866011599312}, {\"x\": 9.420289855072465, \"y\": 5.6521739130434785, \"x2\": 9.710144927536232, \"y2\": 5.942028985507246, \"center_x\": 9.565217391304348, \"center_y\": 5.797101449275362, \"value_uncond\": 0.002970730962658476}, {\"x\": 9.710144927536234, \"y\": 5.6521739130434785, \"x2\": 10.000000000000002, \"y2\": 5.942028985507246, \"center_x\": 9.855072463768117, \"center_y\": 5.797101449275362, \"value_uncond\": 0.0024832643962434085}, {\"x\": 10.0, \"y\": 5.6521739130434785, \"x2\": 10.289855072463768, \"y2\": 5.942028985507246, \"center_x\": 10.144927536231883, \"center_y\": 5.797101449275362, \"value_uncond\": 0.0020564985877478664}, {\"x\": -10.0, \"y\": 5.942028985507246, \"x2\": -9.710144927536232, \"y2\": 6.231884057971014, \"center_x\": -9.855072463768117, \"center_y\": 6.08695652173913, \"value_uncond\": 2.6766838036410634e-07}, {\"x\": -9.710144927536232, \"y\": 5.942028985507246, \"x2\": -9.420289855072465, \"y2\": 6.231884057971014, \"center_x\": -9.565217391304348, \"center_y\": 6.08695652173913, \"value_uncond\": 4.182029923970312e-07}, {\"x\": -9.420289855072463, \"y\": 5.942028985507246, \"x2\": -9.130434782608695, \"y2\": 6.231884057971014, \"center_x\": -9.275362318840578, \"center_y\": 6.08695652173913, \"value_uncond\": 6.473259472880103e-07}, {\"x\": -9.130434782608695, \"y\": 5.942028985507246, \"x2\": -8.840579710144928, \"y2\": 6.231884057971014, \"center_x\": -8.985507246376812, \"center_y\": 6.08695652173913, \"value_uncond\": 9.926695715642979e-07}, {\"x\": -8.840579710144928, \"y\": 5.942028985507246, \"x2\": -8.55072463768116, \"y2\": 6.231884057971014, \"center_x\": -8.695652173913043, \"center_y\": 6.08695652173913, \"value_uncond\": 1.5081072167683986e-06}, {\"x\": -8.55072463768116, \"y\": 5.942028985507246, \"x2\": -8.260869565217392, \"y2\": 6.231884057971014, \"center_x\": -8.405797101449277, \"center_y\": 6.08695652173913, \"value_uncond\": 2.2698938141044712e-06}, {\"x\": -8.26086956521739, \"y\": 5.942028985507246, \"x2\": -7.971014492753623, \"y2\": 6.231884057971014, \"center_x\": -8.115942028985508, \"center_y\": 6.08695652173913, \"value_uncond\": 3.3847350524198137e-06}, {\"x\": -7.971014492753623, \"y\": 5.942028985507246, \"x2\": -7.681159420289855, \"y2\": 6.231884057971014, \"center_x\": -7.826086956521739, \"center_y\": 6.08695652173913, \"value_uncond\": 5.0002259678435955e-06}, {\"x\": -7.681159420289855, \"y\": 5.942028985507246, \"x2\": -7.391304347826088, \"y2\": 6.231884057971014, \"center_x\": -7.536231884057972, \"center_y\": 6.08695652173913, \"value_uncond\": 7.318134682692684e-06}, {\"x\": -7.391304347826087, \"y\": 5.942028985507246, \"x2\": -7.101449275362319, \"y2\": 6.231884057971014, \"center_x\": -7.246376811594203, \"center_y\": 6.08695652173913, \"value_uncond\": 1.0611016241055063e-05}, {\"x\": -7.101449275362318, \"y\": 5.942028985507246, \"x2\": -6.811594202898551, \"y2\": 6.231884057971014, \"center_x\": -6.956521739130435, \"center_y\": 6.08695652173913, \"value_uncond\": 1.524261130753217e-05}, {\"x\": -6.811594202898551, \"y\": 5.942028985507246, \"x2\": -6.521739130434783, \"y2\": 6.231884057971014, \"center_x\": -6.666666666666667, \"center_y\": 6.08695652173913, \"value_uncond\": 2.1692399070934804e-05}, {\"x\": -6.521739130434782, \"y\": 5.942028985507246, \"x2\": -6.231884057971015, \"y2\": 6.231884057971014, \"center_x\": -6.3768115942028984, \"center_y\": 6.08695652173913, \"value_uncond\": 3.0584515873802894e-05}, {\"x\": -6.231884057971014, \"y\": 5.942028985507246, \"x2\": -5.942028985507246, \"y2\": 6.231884057971014, \"center_x\": -6.08695652173913, \"center_y\": 6.08695652173913, \"value_uncond\": 4.272100392204194e-05}, {\"x\": -5.942028985507246, \"y\": 5.942028985507246, \"x2\": -5.6521739130434785, \"y2\": 6.231884057971014, \"center_x\": -5.797101449275362, \"center_y\": 6.08695652173913, \"value_uncond\": 5.911900333454195e-05}, {\"x\": -5.6521739130434785, \"y\": 5.942028985507246, \"x2\": -5.362318840579711, \"y2\": 6.231884057971014, \"center_x\": -5.507246376811595, \"center_y\": 6.08695652173913, \"value_uncond\": 8.105103636811636e-05}, {\"x\": -5.36231884057971, \"y\": 5.942028985507246, \"x2\": -5.072463768115942, \"y2\": 6.231884057971014, \"center_x\": -5.217391304347826, \"center_y\": 6.08695652173913, \"value_uncond\": 0.00011008695401838697}, {\"x\": -5.0724637681159415, \"y\": 5.942028985507246, \"x2\": -4.782608695652174, \"y2\": 6.231884057971014, \"center_x\": -4.927536231884058, \"center_y\": 6.08695652173913, \"value_uncond\": 0.0001481354336143672}, {\"x\": -4.782608695652174, \"y\": 5.942028985507246, \"x2\": -4.492753623188406, \"y2\": 6.231884057971014, \"center_x\": -4.63768115942029, \"center_y\": 6.08695652173913, \"value_uncond\": 0.00019748215839588857}, {\"x\": -4.492753623188405, \"y\": 5.942028985507246, \"x2\": -4.202898550724638, \"y2\": 6.231884057971014, \"center_x\": -4.3478260869565215, \"center_y\": 6.08695652173913, \"value_uncond\": 0.00026082102176564175}, {\"x\": -4.202898550724638, \"y\": 5.942028985507246, \"x2\": -3.91304347826087, \"y2\": 6.231884057971014, \"center_x\": -4.057971014492754, \"center_y\": 6.08695652173913, \"value_uncond\": 0.0003412739453083699}, {\"x\": -3.913043478260869, \"y\": 5.942028985507246, \"x2\": -3.6231884057971016, \"y2\": 6.231884057971014, \"center_x\": -3.7681159420289854, \"center_y\": 6.08695652173913, \"value_uncond\": 0.00044239426561870794}, {\"x\": -3.6231884057971016, \"y\": 5.942028985507246, \"x2\": -3.333333333333334, \"y2\": 6.231884057971014, \"center_x\": -3.4782608695652177, \"center_y\": 6.08695652173913, \"value_uncond\": 0.0005681482316218242}, {\"x\": -3.333333333333333, \"y\": 5.942028985507246, \"x2\": -3.0434782608695654, \"y2\": 6.231884057971014, \"center_x\": -3.1884057971014492, \"center_y\": 6.08695652173913, \"value_uncond\": 0.0007228690724893748}, {\"x\": -3.0434782608695645, \"y\": 5.942028985507246, \"x2\": -2.753623188405797, \"y2\": 6.231884057971014, \"center_x\": -2.8985507246376807, \"center_y\": 6.08695652173913, \"value_uncond\": 0.0009111784577478195}, {\"x\": -2.753623188405797, \"y\": 5.942028985507246, \"x2\": -2.4637681159420293, \"y2\": 6.231884057971014, \"center_x\": -2.608695652173913, \"center_y\": 6.08695652173913, \"value_uncond\": 0.0011378710744363743}, {\"x\": -2.4637681159420284, \"y\": 5.942028985507246, \"x2\": -2.1739130434782608, \"y2\": 6.231884057971014, \"center_x\": -2.3188405797101446, \"center_y\": 6.08695652173913, \"value_uncond\": 0.0014077595621190266}, {\"x\": -2.1739130434782608, \"y\": 5.942028985507246, \"x2\": -1.8840579710144931, \"y2\": 6.231884057971014, \"center_x\": -2.028985507246377, \"center_y\": 6.08695652173913, \"value_uncond\": 0.0017254792022204579}, {\"x\": -1.8840579710144922, \"y\": 5.942028985507246, \"x2\": -1.5942028985507246, \"y2\": 6.231884057971014, \"center_x\": -1.7391304347826084, \"center_y\": 6.08695652173913, \"value_uncond\": 0.0020952545214967607}, {\"x\": -1.5942028985507246, \"y\": 5.942028985507246, \"x2\": -1.304347826086957, \"y2\": 6.231884057971014, \"center_x\": -1.4492753623188408, \"center_y\": 6.08695652173913, \"value_uncond\": 0.002520633237406963}, {\"x\": -1.304347826086957, \"y\": 5.942028985507246, \"x2\": -1.0144927536231894, \"y2\": 6.231884057971014, \"center_x\": -1.1594202898550732, \"center_y\": 6.08695652173913, \"value_uncond\": 0.003004196565387202}, {\"x\": -1.0144927536231876, \"y\": 5.942028985507246, \"x2\": -0.72463768115942, \"y2\": 6.231884057971014, \"center_x\": -0.8695652173913038, \"center_y\": 6.08695652173913, \"value_uncond\": 0.003547258568643672}, {\"x\": -0.72463768115942, \"y\": 5.942028985507246, \"x2\": -0.43478260869565233, \"y2\": 6.231884057971014, \"center_x\": -0.5797101449275361, \"center_y\": 6.08695652173913, \"value_uncond\": 0.004149570639951542}, {\"x\": -0.43478260869565233, \"y\": 5.942028985507246, \"x2\": -0.1449275362318847, \"y2\": 6.231884057971014, \"center_x\": -0.2898550724637685, \"center_y\": 6.08695652173913, \"value_uncond\": 0.004809049999432688}, {\"x\": -0.14492753623188293, \"y\": 5.942028985507246, \"x2\": 0.1449275362318847, \"y2\": 6.231884057971014, \"center_x\": 8.881784197001252e-16, \"center_y\": 6.08695652173913, \"value_uncond\": 0.005521552898678568}, {\"x\": 0.1449275362318847, \"y\": 5.942028985507246, \"x2\": 0.43478260869565233, \"y2\": 6.231884057971014, \"center_x\": 0.2898550724637685, \"center_y\": 6.08695652173913, \"value_uncond\": 0.006280713694225636}, {\"x\": 0.43478260869565233, \"y\": 5.942028985507246, \"x2\": 0.72463768115942, \"y2\": 6.231884057971014, \"center_x\": 0.5797101449275361, \"center_y\": 6.08695652173913, \"value_uncond\": 0.00707786981783574}, {\"x\": 0.72463768115942, \"y\": 5.942028985507246, \"x2\": 1.0144927536231876, \"y2\": 6.231884057971014, \"center_x\": 0.8695652173913038, \"center_y\": 6.08695652173913, \"value_uncond\": 0.007902089766449183}, {\"x\": 1.0144927536231894, \"y\": 5.942028985507246, \"x2\": 1.304347826086957, \"y2\": 6.231884057971014, \"center_x\": 1.1594202898550732, \"center_y\": 6.08695652173913, \"value_uncond\": 0.008740316549850866}, {\"x\": 1.304347826086957, \"y\": 5.942028985507246, \"x2\": 1.5942028985507246, \"y2\": 6.231884057971014, \"center_x\": 1.4492753623188408, \"center_y\": 6.08695652173913, \"value_uncond\": 0.009577632731404702}, {\"x\": 1.5942028985507246, \"y\": 5.942028985507246, \"x2\": 1.8840579710144922, \"y2\": 6.231884057971014, \"center_x\": 1.7391304347826084, \"center_y\": 6.08695652173913, \"value_uncond\": 0.010397645619704042}, {\"x\": 1.884057971014494, \"y\": 5.942028985507246, \"x2\": 2.1739130434782616, \"y2\": 6.231884057971014, \"center_x\": 2.028985507246378, \"center_y\": 6.08695652173913, \"value_uncond\": 0.011182982827182043}, {\"x\": 2.1739130434782616, \"y\": 5.942028985507246, \"x2\": 2.4637681159420293, \"y2\": 6.231884057971014, \"center_x\": 2.3188405797101455, \"center_y\": 6.08695652173913, \"value_uncond\": 0.011915879949294914}, {\"x\": 2.4637681159420293, \"y\": 5.942028985507246, \"x2\": 2.753623188405797, \"y2\": 6.231884057971014, \"center_x\": 2.608695652173913, \"center_y\": 6.08695652173913, \"value_uncond\": 0.012578834257875109}, {\"x\": 2.753623188405797, \"y\": 5.942028985507246, \"x2\": 3.0434782608695645, \"y2\": 6.231884057971014, \"center_x\": 2.8985507246376807, \"center_y\": 6.08695652173913, \"value_uncond\": 0.013155291778481145}, {\"x\": 3.0434782608695663, \"y\": 5.942028985507246, \"x2\": 3.333333333333334, \"y2\": 6.231884057971014, \"center_x\": 3.18840579710145, \"center_y\": 6.08695652173913, \"value_uncond\": 0.013630330602330078}, {\"x\": 3.333333333333334, \"y\": 5.942028985507246, \"x2\": 3.6231884057971016, \"y2\": 6.231884057971014, \"center_x\": 3.4782608695652177, \"center_y\": 6.08695652173913, \"value_uncond\": 0.01399130129612019}, {\"x\": 3.6231884057971016, \"y\": 5.942028985507246, \"x2\": 3.913043478260869, \"y2\": 6.231884057971014, \"center_x\": 3.7681159420289854, \"center_y\": 6.08695652173913, \"value_uncond\": 0.014228386139430086}, {\"x\": 3.913043478260871, \"y\": 5.942028985507246, \"x2\": 4.202898550724639, \"y2\": 6.231884057971014, \"center_x\": 4.057971014492755, \"center_y\": 6.08695652173913, \"value_uncond\": 0.014335042709602576}, {\"x\": 4.202898550724639, \"y\": 5.942028985507246, \"x2\": 4.492753623188406, \"y2\": 6.231884057971014, \"center_x\": 4.347826086956522, \"center_y\": 6.08695652173913, \"value_uncond\": 0.014308303846864935}, {\"x\": 4.492753623188406, \"y\": 5.942028985507246, \"x2\": 4.782608695652174, \"y2\": 6.231884057971014, \"center_x\": 4.63768115942029, \"center_y\": 6.08695652173913, \"value_uncond\": 0.014148914804956699}, {\"x\": 4.782608695652174, \"y\": 5.942028985507246, \"x2\": 5.0724637681159415, \"y2\": 6.231884057971014, \"center_x\": 4.927536231884058, \"center_y\": 6.08695652173913, \"value_uncond\": 0.013861298739369025}, {\"x\": 5.072463768115943, \"y\": 5.942028985507246, \"x2\": 5.362318840579711, \"y2\": 6.231884057971014, \"center_x\": 5.217391304347827, \"center_y\": 6.08695652173913, \"value_uncond\": 0.013453352763753925}, {\"x\": 5.362318840579711, \"y\": 5.942028985507246, \"x2\": 5.6521739130434785, \"y2\": 6.231884057971014, \"center_x\": 5.507246376811595, \"center_y\": 6.08695652173913, \"value_uncond\": 0.01293608769873285}, {\"x\": 5.6521739130434785, \"y\": 5.942028985507246, \"x2\": 5.942028985507246, \"y2\": 6.231884057971014, \"center_x\": 5.797101449275362, \"center_y\": 6.08695652173913, \"value_uncond\": 0.012323134448469086}, {\"x\": 5.942028985507246, \"y\": 5.942028985507246, \"x2\": 6.231884057971014, \"y2\": 6.231884057971014, \"center_x\": 6.08695652173913, \"center_y\": 6.08695652173913, \"value_uncond\": 0.01163014788001316}, {\"x\": 6.2318840579710155, \"y\": 5.942028985507246, \"x2\": 6.521739130434783, \"y2\": 6.231884057971014, \"center_x\": 6.376811594202899, \"center_y\": 6.08695652173913, \"value_uncond\": 0.010874144545693331}, {\"x\": 6.521739130434785, \"y\": 5.942028985507246, \"x2\": 6.8115942028985526, \"y2\": 6.231884057971014, \"center_x\": 6.666666666666669, \"center_y\": 6.08695652173913, \"value_uncond\": 0.010072813218345815}, {\"x\": 6.811594202898551, \"y\": 5.942028985507246, \"x2\": 7.101449275362318, \"y2\": 6.231884057971014, \"center_x\": 6.956521739130435, \"center_y\": 6.08695652173913, \"value_uncond\": 0.009243836910839224}, {\"x\": 7.10144927536232, \"y\": 5.942028985507246, \"x2\": 7.391304347826088, \"y2\": 6.231884057971014, \"center_x\": 7.246376811594204, \"center_y\": 6.08695652173913, \"value_uncond\": 0.008404261999891829}, {\"x\": 7.391304347826086, \"y\": 5.942028985507246, \"x2\": 7.681159420289854, \"y2\": 6.231884057971014, \"center_x\": 7.53623188405797, \"center_y\": 6.08695652173913, \"value_uncond\": 0.007569944680339263}, {\"x\": 7.681159420289855, \"y\": 5.942028985507246, \"x2\": 7.971014492753623, \"y2\": 6.231884057971014, \"center_x\": 7.826086956521739, \"center_y\": 6.08695652173913, \"value_uncond\": 0.00675509783213515}, {\"x\": 7.971014492753625, \"y\": 5.942028985507246, \"x2\": 8.260869565217392, \"y2\": 6.231884057971014, \"center_x\": 8.115942028985508, \"center_y\": 6.08695652173913, \"value_uncond\": 0.005971953192265764}, {\"x\": 8.26086956521739, \"y\": 5.942028985507246, \"x2\": 8.550724637681158, \"y2\": 6.231884057971014, \"center_x\": 8.405797101449274, \"center_y\": 6.08695652173913, \"value_uncond\": 0.00523054522585382}, {\"x\": 8.55072463768116, \"y\": 5.942028985507246, \"x2\": 8.840579710144928, \"y2\": 6.231884057971014, \"center_x\": 8.695652173913043, \"center_y\": 6.08695652173913, \"value_uncond\": 0.004538614983846707}, {\"x\": 8.84057971014493, \"y\": 5.942028985507246, \"x2\": 9.130434782608697, \"y2\": 6.231884057971014, \"center_x\": 8.985507246376812, \"center_y\": 6.08695652173913, \"value_uncond\": 0.003901625114678845}, {\"x\": 9.130434782608695, \"y\": 5.942028985507246, \"x2\": 9.420289855072463, \"y2\": 6.231884057971014, \"center_x\": 9.275362318840578, \"center_y\": 6.08695652173913, \"value_uncond\": 0.003322871510640635}, {\"x\": 9.420289855072465, \"y\": 5.942028985507246, \"x2\": 9.710144927536232, \"y2\": 6.231884057971014, \"center_x\": 9.565217391304348, \"center_y\": 6.08695652173913, \"value_uncond\": 0.0028036730875515285}, {\"x\": 9.710144927536234, \"y\": 5.942028985507246, \"x2\": 10.000000000000002, \"y2\": 6.231884057971014, \"center_x\": 9.855072463768117, \"center_y\": 6.08695652173913, \"value_uncond\": 0.002343619009778012}, {\"x\": 10.0, \"y\": 5.942028985507246, \"x2\": 10.289855072463768, \"y2\": 6.231884057971014, \"center_x\": 10.144927536231883, \"center_y\": 6.08695652173913, \"value_uncond\": 0.0019408522069250963}, {\"x\": -10.0, \"y\": 6.2318840579710155, \"x2\": -9.710144927536232, \"y2\": 6.521739130434783, \"center_x\": -9.855072463768117, \"center_y\": 6.376811594202899, \"value_uncond\": 2.502689293738903e-07}, {\"x\": -9.710144927536232, \"y\": 6.2318840579710155, \"x2\": -9.420289855072465, \"y2\": 6.521739130434783, \"center_x\": -9.565217391304348, \"center_y\": 6.376811594202899, \"value_uncond\": 3.9101822570820645e-07}, {\"x\": -9.420289855072463, \"y\": 6.2318840579710155, \"x2\": -9.130434782608695, \"y2\": 6.521739130434783, \"center_x\": -9.275362318840578, \"center_y\": 6.376811594202899, \"value_uncond\": 6.052473271715371e-07}, {\"x\": -9.130434782608695, \"y\": 6.2318840579710155, \"x2\": -8.840579710144928, \"y2\": 6.521739130434783, \"center_x\": -8.985507246376812, \"center_y\": 6.376811594202899, \"value_uncond\": 9.281423175927344e-07}, {\"x\": -8.840579710144928, \"y\": 6.2318840579710155, \"x2\": -8.55072463768116, \"y2\": 6.521739130434783, \"center_x\": -8.695652173913043, \"center_y\": 6.376811594202899, \"value_uncond\": 1.4100745781337623e-06}, {\"x\": -8.55072463768116, \"y\": 6.2318840579710155, \"x2\": -8.260869565217392, \"y2\": 6.521739130434783, \"center_x\": -8.405797101449277, \"center_y\": 6.376811594202899, \"value_uncond\": 2.1223421827994186e-06}, {\"x\": -8.26086956521739, \"y\": 6.2318840579710155, \"x2\": -7.971014492753623, \"y2\": 6.521739130434783, \"center_x\": -8.115942028985508, \"center_y\": 6.376811594202899, \"value_uncond\": 3.1647145495149364e-06}, {\"x\": -7.971014492753623, \"y\": 6.2318840579710155, \"x2\": -7.681159420289855, \"y2\": 6.521739130434783, \"center_x\": -7.826086956521739, \"center_y\": 6.376811594202899, \"value_uncond\": 4.675192482195596e-06}, {\"x\": -7.681159420289855, \"y\": 6.2318840579710155, \"x2\": -7.391304347826088, \"y2\": 6.521739130434783, \"center_x\": -7.536231884057972, \"center_y\": 6.376811594202899, \"value_uncond\": 6.842428416685089e-06}, {\"x\": -7.391304347826087, \"y\": 6.2318840579710155, \"x2\": -7.101449275362319, \"y2\": 6.521739130434783, \"center_x\": -7.246376811594203, \"center_y\": 6.376811594202899, \"value_uncond\": 9.921260294568306e-06}, {\"x\": -7.101449275362318, \"y\": 6.2318840579710155, \"x2\": -6.811594202898551, \"y2\": 6.521739130434783, \"center_x\": -6.956521739130435, \"center_y\": 6.376811594202899, \"value_uncond\": 1.4251784269809043e-05}, {\"x\": -6.811594202898551, \"y\": 6.2318840579710155, \"x2\": -6.521739130434783, \"y2\": 6.521739130434783, \"center_x\": -6.666666666666667, \"center_y\": 6.376811594202899, \"value_uncond\": 2.0282311581402006e-05}, {\"x\": -6.521739130434782, \"y\": 6.2318840579710155, \"x2\": -6.231884057971015, \"y2\": 6.521739130434783, \"center_x\": -6.3768115942028984, \"center_y\": 6.376811594202899, \"value_uncond\": 2.8596407363257766e-05}, {\"x\": -6.231884057971014, \"y\": 6.2318840579710155, \"x2\": -5.942028985507246, \"y2\": 6.521739130434783, \"center_x\": -6.08695652173913, \"center_y\": 6.376811594202899, \"value_uncond\": 3.9943978062718354e-05}, {\"x\": -5.942028985507246, \"y\": 6.2318840579710155, \"x2\": -5.6521739130434785, \"y2\": 6.521739130434783, \"center_x\": -5.797101449275362, \"center_y\": 6.376811594202899, \"value_uncond\": 5.5276045867132e-05}, {\"x\": -5.6521739130434785, \"y\": 6.2318840579710155, \"x2\": -5.362318840579711, \"y2\": 6.521739130434783, \"center_x\": -5.507246376811595, \"center_y\": 6.376811594202899, \"value_uncond\": 7.578241430272746e-05}, {\"x\": -5.36231884057971, \"y\": 6.2318840579710155, \"x2\": -5.072463768115942, \"y2\": 6.521739130434783, \"center_x\": -5.217391304347826, \"center_y\": 6.376811594202899, \"value_uncond\": 0.00010293088814874822}, {\"x\": -5.0724637681159415, \"y\": 6.2318840579710155, \"x2\": -4.782608695652174, \"y2\": 6.521739130434783, \"center_x\": -4.927536231884058, \"center_y\": 6.376811594202899, \"value_uncond\": 0.00013850607353238278}, {\"x\": -4.782608695652174, \"y\": 6.2318840579710155, \"x2\": -4.492753623188406, \"y2\": 6.521739130434783, \"center_x\": -4.63768115942029, \"center_y\": 6.376811594202899, \"value_uncond\": 0.00018464507569012695}, {\"x\": -4.492753623188405, \"y\": 6.2318840579710155, \"x2\": -4.202898550724638, \"y2\": 6.521739130434783, \"center_x\": -4.3478260869565215, \"center_y\": 6.376811594202899, \"value_uncond\": 0.00024386667482613364}, {\"x\": -4.202898550724638, \"y\": 6.2318840579710155, \"x2\": -3.91304347826087, \"y2\": 6.521739130434783, \"center_x\": -4.057971014492754, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0003190898558856549}, {\"x\": -3.913043478260869, \"y\": 6.2318840579710155, \"x2\": -3.6231884057971016, \"y2\": 6.521739130434783, \"center_x\": -3.7681159420289854, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0004136369752263406}, {\"x\": -3.6231884057971016, \"y\": 6.2318840579710155, \"x2\": -3.333333333333334, \"y2\": 6.521739130434783, \"center_x\": -3.4782608695652177, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0005312164606825947}, {\"x\": -3.333333333333333, \"y\": 6.2318840579710155, \"x2\": -3.0434782608695654, \"y2\": 6.521739130434783, \"center_x\": -3.1884057971014492, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0006758798652396703}, {\"x\": -3.0434782608695645, \"y\": 6.2318840579710155, \"x2\": -2.753623188405797, \"y2\": 6.521739130434783, \"center_x\": -2.8985507246376807, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0008519484325302061}, {\"x\": -2.753623188405797, \"y\": 6.2318840579710155, \"x2\": -2.4637681159420293, \"y2\": 6.521739130434783, \"center_x\": -2.608695652173913, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0010639051769108295}, {\"x\": -2.4637681159420284, \"y\": 6.2318840579710155, \"x2\": -2.1739130434782608, \"y2\": 6.521739130434783, \"center_x\": -2.3188405797101446, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0013162498982813384}, {\"x\": -2.1739130434782608, \"y\": 6.2318840579710155, \"x2\": -1.8840579710144931, \"y2\": 6.521739130434783, \"center_x\": -2.028985507246377, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0016133165673480364}, {\"x\": -1.8840579710144922, \"y\": 6.2318840579710155, \"x2\": -1.5942028985507246, \"y2\": 6.521739130434783, \"center_x\": -1.7391304347826084, \"center_y\": 6.376811594202899, \"value_uncond\": 0.001959055100746278}, {\"x\": -1.5942028985507246, \"y\": 6.2318840579710155, \"x2\": -1.304347826086957, \"y2\": 6.521739130434783, \"center_x\": -1.4492753623188408, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0023567826009630436}, {\"x\": -1.304347826086957, \"y\": 6.2318840579710155, \"x2\": -1.0144927536231894, \"y2\": 6.521739130434783, \"center_x\": -1.1594202898550732, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0028089124947273613}, {\"x\": -1.0144927536231876, \"y\": 6.2318840579710155, \"x2\": -0.72463768115942, \"y2\": 6.521739130434783, \"center_x\": -0.8695652173913038, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0033166734261969566}, {\"x\": -0.72463768115942, \"y\": 6.2318840579710155, \"x2\": -0.43478260869565233, \"y2\": 6.521739130434783, \"center_x\": -0.5797101449275361, \"center_y\": 6.376811594202899, \"value_uncond\": 0.003879832948551227}, {\"x\": -0.43478260869565233, \"y\": 6.2318840579710155, \"x2\": -0.1449275362318847, \"y2\": 6.521739130434783, \"center_x\": -0.2898550724637685, \"center_y\": 6.376811594202899, \"value_uncond\": 0.004496443670434078}, {\"x\": -0.14492753623188293, \"y\": 6.2318840579710155, \"x2\": 0.1449275362318847, \"y2\": 6.521739130434783, \"center_x\": 8.881784197001252e-16, \"center_y\": 6.376811594202899, \"value_uncond\": 0.005162631202661442}, {\"x\": 0.1449275362318847, \"y\": 6.2318840579710155, \"x2\": 0.43478260869565233, \"y2\": 6.521739130434783, \"center_x\": 0.2898550724637685, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0058724436925257605}, {\"x\": 0.43478260869565233, \"y\": 6.2318840579710155, \"x2\": 0.72463768115942, \"y2\": 6.521739130434783, \"center_x\": 0.5797101449275361, \"center_y\": 6.376811594202899, \"value_uncond\": 0.006617781671290226}, {\"x\": 0.72463768115942, \"y\": 6.2318840579710155, \"x2\": 1.0144927536231876, \"y2\": 6.521739130434783, \"center_x\": 0.8695652173913038, \"center_y\": 6.376811594202899, \"value_uncond\": 0.007388424224689674}, {\"x\": 1.0144927536231894, \"y\": 6.2318840579710155, \"x2\": 1.304347826086957, \"y2\": 6.521739130434783, \"center_x\": 1.1594202898550732, \"center_y\": 6.376811594202899, \"value_uncond\": 0.008172163115959143}, {\"x\": 1.304347826086957, \"y\": 6.2318840579710155, \"x2\": 1.5942028985507246, \"y2\": 6.521739130434783, \"center_x\": 1.4492753623188408, \"center_y\": 6.376811594202899, \"value_uncond\": 0.008955050597924173}, {\"x\": 1.5942028985507246, \"y\": 6.2318840579710155, \"x2\": 1.8840579710144922, \"y2\": 6.521739130434783, \"center_x\": 1.7391304347826084, \"center_y\": 6.376811594202899, \"value_uncond\": 0.00972175956574586}, {\"x\": 1.884057971014494, \"y\": 6.2318840579710155, \"x2\": 2.1739130434782616, \"y2\": 6.521739130434783, \"center_x\": 2.028985507246378, \"center_y\": 6.376811594202899, \"value_uncond\": 0.010456046902358579}, {\"x\": 2.1739130434782616, \"y\": 6.2318840579710155, \"x2\": 2.4637681159420293, \"y2\": 6.521739130434783, \"center_x\": 2.3188405797101455, \"center_y\": 6.376811594202899, \"value_uncond\": 0.011141302956296993}, {\"x\": 2.4637681159420293, \"y\": 6.2318840579710155, \"x2\": 2.753623188405797, \"y2\": 6.521739130434783, \"center_x\": 2.608695652173913, \"center_y\": 6.376811594202899, \"value_uncond\": 0.011761162742523812}, {\"x\": 2.753623188405797, \"y\": 6.2318840579710155, \"x2\": 3.0434782608695645, \"y2\": 6.521739130434783, \"center_x\": 2.8985507246376807, \"center_y\": 6.376811594202899, \"value_uncond\": 0.012300148357168889}, {\"x\": 3.0434782608695663, \"y\": 6.2318840579710155, \"x2\": 3.333333333333334, \"y2\": 6.521739130434783, \"center_x\": 3.18840579710145, \"center_y\": 6.376811594202899, \"value_uncond\": 0.012744307871617264}, {\"x\": 3.333333333333334, \"y\": 6.2318840579710155, \"x2\": 3.6231884057971016, \"y2\": 6.521739130434783, \"center_x\": 3.4782608695652177, \"center_y\": 6.376811594202899, \"value_uncond\": 0.01308181411328583}, {\"x\": 3.6231884057971016, \"y\": 6.2318840579710155, \"x2\": 3.913043478260869, \"y2\": 6.521739130434783, \"center_x\": 3.7681159420289854, \"center_y\": 6.376811594202899, \"value_uncond\": 0.013303487550489101}, {\"x\": 3.913043478260871, \"y\": 6.2318840579710155, \"x2\": 4.202898550724639, \"y2\": 6.521739130434783, \"center_x\": 4.057971014492755, \"center_y\": 6.376811594202899, \"value_uncond\": 0.013403211042638046}, {\"x\": 4.202898550724639, \"y\": 6.2318840579710155, \"x2\": 4.492753623188406, \"y2\": 6.521739130434783, \"center_x\": 4.347826086956522, \"center_y\": 6.376811594202899, \"value_uncond\": 0.013378210306499836}, {\"x\": 4.492753623188406, \"y\": 6.2318840579710155, \"x2\": 4.782608695652174, \"y2\": 6.521739130434783, \"center_x\": 4.63768115942029, \"center_y\": 6.376811594202899, \"value_uncond\": 0.01322918215151925}, {\"x\": 4.782608695652174, \"y\": 6.2318840579710155, \"x2\": 5.0724637681159415, \"y2\": 6.521739130434783, \"center_x\": 4.927536231884058, \"center_y\": 6.376811594202899, \"value_uncond\": 0.012960262211452207}, {\"x\": 5.072463768115943, \"y\": 6.2318840579710155, \"x2\": 5.362318840579711, \"y2\": 6.521739130434783, \"center_x\": 5.217391304347827, \"center_y\": 6.376811594202899, \"value_uncond\": 0.012578834257875104}, {\"x\": 5.362318840579711, \"y\": 6.2318840579710155, \"x2\": 5.6521739130434785, \"y2\": 6.521739130434783, \"center_x\": 5.507246376811595, \"center_y\": 6.376811594202899, \"value_uncond\": 0.012095193366675168}, {\"x\": 5.6521739130434785, \"y\": 6.2318840579710155, \"x2\": 5.942028985507246, \"y2\": 6.521739130434783, \"center_x\": 5.797101449275362, \"center_y\": 6.376811594202899, \"value_uncond\": 0.011522084382001349}, {\"x\": 5.942028985507246, \"y\": 6.2318840579710155, \"x2\": 6.231884057971014, \"y2\": 6.521739130434783, \"center_x\": 6.08695652173913, \"center_y\": 6.376811594202899, \"value_uncond\": 0.010874144545693331}, {\"x\": 6.2318840579710155, \"y\": 6.2318840579710155, \"x2\": 6.521739130434783, \"y2\": 6.521739130434783, \"center_x\": 6.376811594202899, \"center_y\": 6.376811594202899, \"value_uncond\": 0.010167284270206396}, {\"x\": 6.521739130434785, \"y\": 6.2318840579710155, \"x2\": 6.8115942028985526, \"y2\": 6.521739130434783, \"center_x\": 6.666666666666669, \"center_y\": 6.376811594202899, \"value_uncond\": 0.009418042491643618}, {\"x\": 6.811594202898551, \"y\": 6.2318840579710155, \"x2\": 7.101449275362318, \"y2\": 6.521739130434783, \"center_x\": 6.956521739130435, \"center_y\": 6.376811594202899, \"value_uncond\": 0.008642952760560024}, {\"x\": 7.10144927536232, \"y\": 6.2318840579710155, \"x2\": 7.391304347826088, \"y2\": 6.521739130434783, \"center_x\": 7.246376811594204, \"center_y\": 6.376811594202899, \"value_uncond\": 0.007857953375103437}, {\"x\": 7.391304347826086, \"y\": 6.2318840579710155, \"x2\": 7.681159420289854, \"y2\": 6.521739130434783, \"center_x\": 7.53623188405797, \"center_y\": 6.376811594202899, \"value_uncond\": 0.00707786981783574}, {\"x\": 7.681159420289855, \"y\": 6.2318840579710155, \"x2\": 7.971014492753623, \"y2\": 6.521739130434783, \"center_x\": 7.826086956521739, \"center_y\": 6.376811594202899, \"value_uncond\": 0.00631599107808199}, {\"x\": 7.971014492753625, \"y\": 6.2318840579710155, \"x2\": 8.260869565217392, \"y2\": 6.521739130434783, \"center_x\": 8.115942028985508, \"center_y\": 6.376811594202899, \"value_uncond\": 0.005583753783940637}, {\"x\": 8.26086956521739, \"y\": 6.2318840579710155, \"x2\": 8.550724637681158, \"y2\": 6.521739130434783, \"center_x\": 8.405797101449274, \"center_y\": 6.376811594202899, \"value_uncond\": 0.004890540122578068}, {\"x\": 8.55072463768116, \"y\": 6.2318840579710155, \"x2\": 8.840579710144928, \"y2\": 6.521739130434783, \"center_x\": 8.695652173913043, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0042435879475285635}, {\"x\": 8.84057971014493, \"y\": 6.2318840579710155, \"x2\": 9.130434782608697, \"y2\": 6.521739130434783, \"center_x\": 8.985507246376812, \"center_y\": 6.376811594202899, \"value_uncond\": 0.003648004814542142}, {\"x\": 9.130434782608695, \"y\": 6.2318840579710155, \"x2\": 9.420289855072463, \"y2\": 6.521739130434783, \"center_x\": 9.275362318840578, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0031068723705198263}, {\"x\": 9.420289855072465, \"y\": 6.2318840579710155, \"x2\": 9.710144927536232, \"y2\": 6.521739130434783, \"center_x\": 9.565217391304348, \"center_y\": 6.376811594202899, \"value_uncond\": 0.002621423796794503}, {\"x\": 9.710144927536234, \"y\": 6.2318840579710155, \"x2\": 10.000000000000002, \"y2\": 6.521739130434783, \"center_x\": 9.855072463768117, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0021912749635933215}, {\"x\": 10.0, \"y\": 6.2318840579710155, \"x2\": 10.289855072463768, \"y2\": 6.521739130434783, \"center_x\": 10.144927536231883, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0018146895170783953}, {\"x\": -10.0, \"y\": 6.521739130434785, \"x2\": -9.710144927536232, \"y2\": 6.8115942028985526, \"center_x\": -9.855072463768117, \"center_y\": 6.666666666666669, \"value_uncond\": 2.318262525705508e-07}, {\"x\": -9.710144927536232, \"y\": 6.521739130434785, \"x2\": -9.420289855072465, \"y2\": 6.8115942028985526, \"center_x\": -9.565217391304348, \"center_y\": 6.666666666666669, \"value_uncond\": 3.6220353113548075e-07}, {\"x\": -9.420289855072463, \"y\": 6.521739130434785, \"x2\": -9.130434782608695, \"y2\": 6.8115942028985526, \"center_x\": -9.275362318840578, \"center_y\": 6.666666666666669, \"value_uncond\": 5.606457824690636e-07}, {\"x\": -9.130434782608695, \"y\": 6.521739130434785, \"x2\": -8.840579710144928, \"y2\": 6.8115942028985526, \"center_x\": -8.985507246376812, \"center_y\": 6.666666666666669, \"value_uncond\": 8.59746177353957e-07}, {\"x\": -8.840579710144928, \"y\": 6.521739130434785, \"x2\": -8.55072463768116, \"y2\": 6.8115942028985526, \"center_x\": -8.695652173913043, \"center_y\": 6.666666666666669, \"value_uncond\": 1.3061641575386623e-06}, {\"x\": -8.55072463768116, \"y\": 6.521739130434785, \"x2\": -8.260869565217392, \"y2\": 6.8115942028985526, \"center_x\": -8.405797101449277, \"center_y\": 6.666666666666669, \"value_uncond\": 1.965943739567227e-06}, {\"x\": -8.26086956521739, \"y\": 6.521739130434785, \"x2\": -7.971014492753623, \"y2\": 6.8115942028985526, \"center_x\": -8.115942028985508, \"center_y\": 6.666666666666669, \"value_uncond\": 2.931502189684466e-06}, {\"x\": -7.971014492753623, \"y\": 6.521739130434785, \"x2\": -7.681159420289855, \"y2\": 6.8115942028985526, \"center_x\": -7.826086956521739, \"center_y\": 6.666666666666669, \"value_uncond\": 4.330670834389596e-06}, {\"x\": -7.681159420289855, \"y\": 6.521739130434785, \"x2\": -7.391304347826088, \"y2\": 6.8115942028985526, \"center_x\": -7.536231884057972, \"center_y\": 6.666666666666669, \"value_uncond\": 6.338200040615343e-06}, {\"x\": -7.391304347826087, \"y\": 6.521739130434785, \"x2\": -7.101449275362319, \"y2\": 6.8115942028985526, \"center_x\": -7.246376811594203, \"center_y\": 6.666666666666669, \"value_uncond\": 9.190148376072125e-06}, {\"x\": -7.101449275362318, \"y\": 6.521739130434785, \"x2\": -6.811594202898551, \"y2\": 6.8115942028985526, \"center_x\": -6.956521739130435, \"center_y\": 6.666666666666669, \"value_uncond\": 1.3201549820744305e-05}, {\"x\": -6.811594202898551, \"y\": 6.521739130434785, \"x2\": -6.521739130434783, \"y2\": 6.8115942028985526, \"center_x\": -6.666666666666667, \"center_y\": 6.666666666666669, \"value_uncond\": 1.8787678914629364e-05}, {\"x\": -6.521739130434782, \"y\": 6.521739130434785, \"x2\": -6.231884057971015, \"y2\": 6.8115942028985526, \"center_x\": -6.3768115942028984, \"center_y\": 6.666666666666669, \"value_uncond\": 2.6489097038893434e-05}, {\"x\": -6.231884057971014, \"y\": 6.521739130434785, \"x2\": -5.942028985507246, \"y2\": 6.8115942028985526, \"center_x\": -6.08695652173913, \"center_y\": 6.666666666666669, \"value_uncond\": 3.70004489578735e-05}, {\"x\": -5.942028985507246, \"y\": 6.521739130434785, \"x2\": -5.6521739130434785, \"y2\": 6.8115942028985526, \"center_x\": -5.797101449275362, \"center_y\": 6.666666666666669, \"value_uncond\": 5.12026746682202e-05}, {\"x\": -5.6521739130434785, \"y\": 6.521739130434785, \"x2\": -5.362318840579711, \"y2\": 6.8115942028985526, \"center_x\": -5.507246376811595, \"center_y\": 6.666666666666669, \"value_uncond\": 7.019789936570147e-05}, {\"x\": -5.36231884057971, \"y\": 6.521739130434785, \"x2\": -5.072463768115942, \"y2\": 6.8115942028985526, \"center_x\": -5.217391304347826, \"center_y\": 6.666666666666669, \"value_uncond\": 9.534576318754272e-05}, {\"x\": -5.0724637681159415, \"y\": 6.521739130434785, \"x2\": -4.782608695652174, \"y2\": 6.8115942028985526, \"center_x\": -4.927536231884058, \"center_y\": 6.666666666666669, \"value_uncond\": 0.00012829936207264282}, {\"x\": -4.782608695652174, \"y\": 6.521739130434785, \"x2\": -4.492753623188406, \"y2\": 6.8115942028985526, \"center_x\": -4.63768115942029, \"center_y\": 6.666666666666669, \"value_uncond\": 0.00017103831490363806}, {\"x\": -4.492753623188405, \"y\": 6.521739130434785, \"x2\": -4.202898550724638, \"y2\": 6.8115942028985526, \"center_x\": -4.3478260869565215, \"center_y\": 6.666666666666669, \"value_uncond\": 0.00022589578935435225}, {\"x\": -4.202898550724638, \"y\": 6.521739130434785, \"x2\": -3.91304347826087, \"y2\": 6.8115942028985526, \"center_x\": -4.057971014492754, \"center_y\": 6.666666666666669, \"value_uncond\": 0.00029557566617762447}, {\"x\": -3.913043478260869, \"y\": 6.521739130434785, \"x2\": -3.6231884057971016, \"y2\": 6.8115942028985526, \"center_x\": -3.7681159420289854, \"center_y\": 6.666666666666669, \"value_uncond\": 0.00038315547252005096}, {\"x\": -3.6231884057971016, \"y\": 6.521739130434785, \"x2\": -3.333333333333334, \"y2\": 6.8115942028985526, \"center_x\": -3.4782608695652177, \"center_y\": 6.666666666666669, \"value_uncond\": 0.000492070356843445}, {\"x\": -3.333333333333333, \"y\": 6.521739130434785, \"x2\": -3.0434782608695654, \"y2\": 6.8115942028985526, \"center_x\": -3.1884057971014492, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0006260733073753584}, {\"x\": -3.0434782608695645, \"y\": 6.521739130434785, \"x2\": -2.753623188405797, \"y2\": 6.8115942028985526, \"center_x\": -2.8985507246376807, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0007891671290996348}, {\"x\": -2.753623188405797, \"y\": 6.521739130434785, \"x2\": -2.4637681159420293, \"y2\": 6.8115942028985526, \"center_x\": -2.608695652173913, \"center_y\": 6.666666666666669, \"value_uncond\": 0.000985504476607145}, {\"x\": -2.4637681159420284, \"y\": 6.521739130434785, \"x2\": -2.1739130434782608, \"y2\": 6.8115942028985526, \"center_x\": -2.3188405797101446, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0012192535530811497}, {\"x\": -2.1739130434782608, \"y\": 6.521739130434785, \"x2\": -1.8840579710144931, \"y2\": 6.8115942028985526, \"center_x\": -2.028985507246377, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0014944289527028226}, {\"x\": -1.8840579710144922, \"y\": 6.521739130434785, \"x2\": -1.5942028985507246, \"y2\": 6.8115942028985526, \"center_x\": -1.7391304347826084, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0018146895170783953}, {\"x\": -1.5942028985507246, \"y\": 6.521739130434785, \"x2\": -1.304347826086957, \"y2\": 6.8115942028985526, \"center_x\": -1.4492753623188408, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0021831079066490715}, {\"x\": -1.304347826086957, \"y\": 6.521739130434785, \"x2\": -1.0144927536231894, \"y2\": 6.8115942028985526, \"center_x\": -1.1594202898550732, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0026019196992624204}, {\"x\": -1.0144927536231876, \"y\": 6.521739130434785, \"x2\": -0.72463768115942, \"y2\": 6.8115942028985526, \"center_x\": -0.8695652173913038, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0030722629985238}, {\"x\": -0.72463768115942, \"y\": 6.521739130434785, \"x2\": -0.43478260869565233, \"y2\": 6.8115942028985526, \"center_x\": -0.5797101449275361, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0035939224869526182}, {\"x\": -0.43478260869565233, \"y\": 6.521739130434785, \"x2\": -0.1449275362318847, \"y2\": 6.8115942028985526, \"center_x\": -0.2898550724637685, \"center_y\": 6.666666666666669, \"value_uncond\": 0.004165094279258357}, {\"x\": -0.14492753623188293, \"y\": 6.521739130434785, \"x2\": 0.1449275362318847, \"y2\": 6.8115942028985526, \"center_x\": 8.881784197001252e-16, \"center_y\": 6.666666666666669, \"value_uncond\": 0.004782189495559725}, {\"x\": 0.1449275362318847, \"y\": 6.521739130434785, \"x2\": 0.43478260869565233, \"y2\": 6.8115942028985526, \"center_x\": 0.2898550724637685, \"center_y\": 6.666666666666669, \"value_uncond\": 0.005439694883722319}, {\"x\": 0.43478260869565233, \"y\": 6.521739130434785, \"x2\": 0.72463768115942, \"y2\": 6.8115942028985526, \"center_x\": 0.5797101449275361, \"center_y\": 6.666666666666669, \"value_uncond\": 0.006130107836491764}, {\"x\": 0.72463768115942, \"y\": 6.521739130434785, \"x2\": 1.0144927536231876, \"y2\": 6.8115942028985526, \"center_x\": 0.8695652173913038, \"center_y\": 6.666666666666669, \"value_uncond\": 0.006843960633452795}, {\"x\": 1.0144927536231894, \"y\": 6.521739130434785, \"x2\": 1.304347826086957, \"y2\": 6.8115942028985526, \"center_x\": 1.1594202898550732, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0075699446803392575}, {\"x\": 1.304347826086957, \"y\": 6.521739130434785, \"x2\": 1.5942028985507246, \"y2\": 6.8115942028985526, \"center_x\": 1.4492753623188408, \"center_y\": 6.666666666666669, \"value_uncond\": 0.008295140059495587}, {\"x\": 1.5942028985507246, \"y\": 6.521739130434785, \"x2\": 1.8840579710144922, \"y2\": 6.8115942028985526, \"center_x\": 1.7391304347826084, \"center_y\": 6.666666666666669, \"value_uncond\": 0.009005349142448897}, {\"x\": 1.884057971014494, \"y\": 6.521739130434785, \"x2\": 2.1739130434782616, \"y2\": 6.8115942028985526, \"center_x\": 2.028985507246378, \"center_y\": 6.666666666666669, \"value_uncond\": 0.009685525790755987}, {\"x\": 2.1739130434782616, \"y\": 6.521739130434785, \"x2\": 2.4637681159420293, \"y2\": 6.8115942028985526, \"center_x\": 2.3188405797101455, \"center_y\": 6.666666666666669, \"value_uncond\": 0.01032028434202024}, {\"x\": 2.4637681159420293, \"y\": 6.521739130434785, \"x2\": 2.753623188405797, \"y2\": 6.8115942028985526, \"center_x\": 2.608695652173913, \"center_y\": 6.666666666666669, \"value_uncond\": 0.010894465770452633}, {\"x\": 2.753623188405797, \"y\": 6.521739130434785, \"x2\": 3.0434782608695645, \"y2\": 6.8115942028985526, \"center_x\": 2.8985507246376807, \"center_y\": 6.666666666666669, \"value_uncond\": 0.011393732761146198}, {\"x\": 3.0434782608695663, \"y\": 6.521739130434785, \"x2\": 3.333333333333334, \"y2\": 6.8115942028985526, \"center_x\": 3.18840579710145, \"center_y\": 6.666666666666669, \"value_uncond\": 0.011805161523141232}, {\"x\": 3.333333333333334, \"y\": 6.521739130434785, \"x2\": 3.6231884057971016, \"y2\": 6.8115942028985526, \"center_x\": 3.4782608695652177, \"center_y\": 6.666666666666669, \"value_uncond\": 0.012117796445186641}, {\"x\": 3.6231884057971016, \"y\": 6.521739130434785, \"x2\": 3.913043478260869, \"y2\": 6.8115942028985526, \"center_x\": 3.7681159420289854, \"center_y\": 6.666666666666669, \"value_uncond\": 0.012323134448469077}, {\"x\": 3.913043478260871, \"y\": 6.521739130434785, \"x2\": 4.202898550724639, \"y2\": 6.8115942028985526, \"center_x\": 4.057971014492755, \"center_y\": 6.666666666666669, \"value_uncond\": 0.012415509173274013}, {\"x\": 4.202898550724639, \"y\": 6.521739130434785, \"x2\": 4.492753623188406, \"y2\": 6.8115942028985526, \"center_x\": 4.347826086956522, \"center_y\": 6.666666666666669, \"value_uncond\": 0.01239235077728404}, {\"x\": 4.492753623188406, \"y\": 6.521739130434785, \"x2\": 4.782608695652174, \"y2\": 6.8115942028985526, \"center_x\": 4.63768115942029, \"center_y\": 6.666666666666669, \"value_uncond\": 0.01225430472105531}, {\"x\": 4.782608695652174, \"y\": 6.521739130434785, \"x2\": 5.0724637681159415, \"y2\": 6.8115942028985526, \"center_x\": 4.927536231884058, \"center_y\": 6.666666666666669, \"value_uncond\": 0.012005201877553301}, {\"x\": 5.072463768115943, \"y\": 6.521739130434785, \"x2\": 5.362318840579711, \"y2\": 6.8115942028985526, \"center_x\": 5.217391304347827, \"center_y\": 6.666666666666669, \"value_uncond\": 0.011651881897623508}, {\"x\": 5.362318840579711, \"y\": 6.521739130434785, \"x2\": 5.6521739130434785, \"y2\": 6.8115942028985526, \"center_x\": 5.507246376811595, \"center_y\": 6.666666666666669, \"value_uncond\": 0.011203881198226821}, {\"x\": 5.6521739130434785, \"y\": 6.521739130434785, \"x2\": 5.942028985507246, \"y2\": 6.8115942028985526, \"center_x\": 5.797101449275362, \"center_y\": 6.666666666666669, \"value_uncond\": 0.010673005437644672}, {\"x\": 5.942028985507246, \"y\": 6.521739130434785, \"x2\": 6.231884057971014, \"y2\": 6.8115942028985526, \"center_x\": 6.08695652173913, \"center_y\": 6.666666666666669, \"value_uncond\": 0.010072813218345815}, {\"x\": 6.2318840579710155, \"y\": 6.521739130434785, \"x2\": 6.521739130434783, \"y2\": 6.8115942028985526, \"center_x\": 6.376811594202899, \"center_y\": 6.666666666666669, \"value_uncond\": 0.009418042491643618}, {\"x\": 6.521739130434785, \"y\": 6.521739130434785, \"x2\": 6.8115942028985526, \"y2\": 6.8115942028985526, \"center_x\": 6.666666666666669, \"center_y\": 6.666666666666669, \"value_uncond\": 0.008724013415689036}, {\"x\": 6.811594202898551, \"y\": 6.521739130434785, \"x2\": 7.101449275362318, \"y2\": 6.8115942028985526, \"center_x\": 6.956521739130435, \"center_y\": 6.666666666666669, \"value_uncond\": 0.008006041159953757}, {\"x\": 7.10144927536232, \"y\": 6.521739130434785, \"x2\": 7.391304347826088, \"y2\": 6.8115942028985526, \"center_x\": 7.246376811594204, \"center_y\": 6.666666666666669, \"value_uncond\": 0.007278889506506953}, {\"x\": 7.391304347826086, \"y\": 6.521739130434785, \"x2\": 7.681159420289854, \"y2\": 6.8115942028985526, \"center_x\": 7.53623188405797, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0065562914268104434}, {\"x\": 7.681159420289855, \"y\": 6.521739130434785, \"x2\": 7.971014492753623, \"y2\": 6.8115942028985526, \"center_x\": 7.826086956521739, \"center_y\": 6.666666666666669, \"value_uncond\": 0.005850556625482317}, {\"x\": 7.971014492753625, \"y\": 6.521739130434785, \"x2\": 8.260869565217392, \"y2\": 6.8115942028985526, \"center_x\": 8.115942028985508, \"center_y\": 6.666666666666669, \"value_uncond\": 0.005172278949072917}, {\"x\": 8.26086956521739, \"y\": 6.521739130434785, \"x2\": 8.550724637681158, \"y2\": 6.8115942028985526, \"center_x\": 8.405797101449274, \"center_y\": 6.666666666666669, \"value_uncond\": 0.004530149197903092}, {\"x\": 8.55072463768116, \"y\": 6.521739130434785, \"x2\": 8.840579710144928, \"y2\": 6.8115942028985526, \"center_x\": 8.695652173913043, \"center_y\": 6.666666666666669, \"value_uncond\": 0.003930871857686281}, {\"x\": 8.84057971014493, \"y\": 6.521739130434785, \"x2\": 9.130434782608697, \"y2\": 6.8115942028985526, \"center_x\": 8.985507246376812, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0033791781010546027}, {\"x\": 9.130434782608695, \"y\": 6.521739130434785, \"x2\": 9.420289855072463, \"y2\": 6.8115942028985526, \"center_x\": 9.275362318840578, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0028779224839235533}, {\"x\": 9.420289855072465, \"y\": 6.521739130434785, \"x2\": 9.710144927536232, \"y2\": 6.8115942028985526, \"center_x\": 9.565217391304348, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0024282473127226916}, {\"x\": 9.710144927536234, \"y\": 6.521739130434785, \"x2\": 10.000000000000002, \"y2\": 6.8115942028985526, \"center_x\": 9.855072463768117, \"center_y\": 6.666666666666669, \"value_uncond\": 0.002029796764753759}, {\"x\": 10.0, \"y\": 6.521739130434785, \"x2\": 10.289855072463768, \"y2\": 6.8115942028985526, \"center_x\": 10.144927536231883, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0016809624405866655}, {\"x\": -10.0, \"y\": 6.811594202898551, \"x2\": -9.710144927536232, \"y2\": 7.101449275362318, \"center_x\": -9.855072463768117, \"center_y\": 6.956521739130435, \"value_uncond\": 2.1274732529638975e-07}, {\"x\": -9.710144927536232, \"y\": 6.811594202898551, \"x2\": -9.420289855072465, \"y2\": 7.101449275362318, \"center_x\": -9.565217391304348, \"center_y\": 6.956521739130435, \"value_uncond\": 3.32394763783409e-07}, {\"x\": -9.420289855072463, \"y\": 6.811594202898551, \"x2\": -9.130434782608695, \"y2\": 7.101449275362318, \"center_x\": -9.275362318840578, \"center_y\": 6.956521739130435, \"value_uncond\": 5.145055373860044e-07}, {\"x\": -9.130434782608695, \"y\": 6.811594202898551, \"x2\": -8.840579710144928, \"y2\": 7.101449275362318, \"center_x\": -8.985507246376812, \"center_y\": 6.956521739130435, \"value_uncond\": 7.889904514165666e-07}, {\"x\": -8.840579710144928, \"y\": 6.811594202898551, \"x2\": -8.55072463768116, \"y2\": 7.101449275362318, \"center_x\": -8.695652173913043, \"center_y\": 6.956521739130435, \"value_uncond\": 1.198668950703914e-06}, {\"x\": -8.55072463768116, \"y\": 6.811594202898551, \"x2\": -8.260869565217392, \"y2\": 7.101449275362318, \"center_x\": -8.405797101449277, \"center_y\": 6.956521739130435, \"value_uncond\": 1.8041497355819331e-06}, {\"x\": -8.26086956521739, \"y\": 6.811594202898551, \"x2\": -7.971014492753623, \"y2\": 7.101449275362318, \"center_x\": -8.115942028985508, \"center_y\": 6.956521739130435, \"value_uncond\": 2.6902442801040447e-06}, {\"x\": -7.971014492753623, \"y\": 6.811594202898551, \"x2\": -7.681159420289855, \"y2\": 7.101449275362318, \"center_x\": -7.826086956521739, \"center_y\": 6.956521739130435, \"value_uncond\": 3.974263598446794e-06}, {\"x\": -7.681159420289855, \"y\": 6.811594202898551, \"x2\": -7.391304347826088, \"y2\": 7.101449275362318, \"center_x\": -7.536231884057972, \"center_y\": 6.956521739130435, \"value_uncond\": 5.816576383746788e-06}, {\"x\": -7.391304347826087, \"y\": 6.811594202898551, \"x2\": -7.101449275362319, \"y2\": 7.101449275362318, \"center_x\": -7.246376811594203, \"center_y\": 6.956521739130435, \"value_uncond\": 8.433813963719633e-06}, {\"x\": -7.101449275362318, \"y\": 6.811594202898551, \"x2\": -6.811594202898551, \"y2\": 7.101449275362318, \"center_x\": -6.956521739130435, \"center_y\": 6.956521739130435, \"value_uncond\": 1.2115083529099698e-05}, {\"x\": -6.811594202898551, \"y\": 6.811594202898551, \"x2\": -6.521739130434783, \"y2\": 7.101449275362318, \"center_x\": -6.666666666666667, \"center_y\": 6.956521739130435, \"value_uncond\": 1.7241483193963888e-05}, {\"x\": -6.521739130434782, \"y\": 6.811594202898551, \"x2\": -6.231884057971015, \"y2\": 7.101449275362318, \"center_x\": -6.3768115942028984, \"center_y\": 6.956521739130435, \"value_uncond\": 2.4309087008280366e-05}, {\"x\": -6.231884057971014, \"y\": 6.811594202898551, \"x2\": -5.942028985507246, \"y2\": 7.101449275362318, \"center_x\": -6.08695652173913, \"center_y\": 6.956521739130435, \"value_uncond\": 3.3955371590875396e-05}, {\"x\": -5.942028985507246, \"y\": 6.811594202898551, \"x2\": -5.6521739130434785, \"y2\": 7.101449275362318, \"center_x\": -5.797101449275362, \"center_y\": 6.956521739130435, \"value_uncond\": 4.698877699526274e-05}, {\"x\": -5.6521739130434785, \"y\": 6.811594202898551, \"x2\": -5.362318840579711, \"y2\": 7.101449275362318, \"center_x\": -5.507246376811595, \"center_y\": 6.956521739130435, \"value_uncond\": 6.44207252883631e-05}, {\"x\": -5.36231884057971, \"y\": 6.811594202898551, \"x2\": -5.072463768115942, \"y2\": 7.101449275362318, \"center_x\": -5.217391304347826, \"center_y\": 6.956521739130435, \"value_uncond\": 8.74989604135519e-05}, {\"x\": -5.0724637681159415, \"y\": 6.811594202898551, \"x2\": -4.782608695652174, \"y2\": 7.101449275362318, \"center_x\": -4.927536231884058, \"center_y\": 6.956521739130435, \"value_uncond\": 0.00011774053117595541}, {\"x\": -4.782608695652174, \"y\": 6.811594202898551, \"x2\": -4.492753623188406, \"y2\": 7.101449275362318, \"center_x\": -4.63768115942029, \"center_y\": 6.956521739130435, \"value_uncond\": 0.00015696213701197131}, {\"x\": -4.492753623188405, \"y\": 6.811594202898551, \"x2\": -4.202898550724638, \"y2\": 7.101449275362318, \"center_x\": -4.3478260869565215, \"center_y\": 6.956521739130435, \"value_uncond\": 0.00020730492965299356}, {\"x\": -4.202898550724638, \"y\": 6.811594202898551, \"x2\": -3.91304347826087, \"y2\": 7.101449275362318, \"center_x\": -4.057971014492754, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0002712502648199919}, {\"x\": -3.913043478260869, \"y\": 6.811594202898551, \"x2\": -3.6231884057971016, \"y2\": 7.101449275362318, \"center_x\": -3.7681159420289854, \"center_y\": 6.956521739130435, \"value_uncond\": 0.000351622394131174}, {\"x\": -3.6231884057971016, \"y\": 6.811594202898551, \"x2\": -3.333333333333334, \"y2\": 7.101449275362318, \"center_x\": -3.4782608695652177, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0004515737588616033}, {\"x\": -3.333333333333333, \"y\": 6.811594202898551, \"x2\": -3.0434782608695654, \"y2\": 7.101449275362318, \"center_x\": -3.1884057971014492, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0005745484823511837}, {\"x\": -3.0434782608695645, \"y\": 6.811594202898551, \"x2\": -2.753623188405797, \"y2\": 7.101449275362318, \"center_x\": -2.8985507246376807, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0007242199451793485}, {\"x\": -2.753623188405797, \"y\": 6.811594202898551, \"x2\": -2.4637681159420293, \"y2\": 7.101449275362318, \"center_x\": -2.608695652173913, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0009043990451512076}, {\"x\": -2.4637681159420284, \"y\": 6.811594202898551, \"x2\": -2.1739130434782608, \"y2\": 7.101449275362318, \"center_x\": -2.3188405797101446, \"center_y\": 6.956521739130435, \"value_uncond\": 0.001118910949040142}, {\"x\": -2.1739130434782608, \"y\": 6.811594202898551, \"x2\": -1.8840579710144931, \"y2\": 7.101449275362318, \"center_x\": -2.028985507246377, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0013714398563909602}, {\"x\": -1.8840579710144922, \"y\": 6.811594202898551, \"x2\": -1.5942028985507246, \"y2\": 7.101449275362318, \"center_x\": -1.7391304347826084, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0016653434920375757}, {\"x\": -1.5942028985507246, \"y\": 6.811594202898551, \"x2\": -1.304347826086957, \"y2\": 7.101449275362318, \"center_x\": -1.4492753623188408, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0020034416414148196}, {\"x\": -1.304347826086957, \"y\": 6.811594202898551, \"x2\": -1.0144927536231894, \"y2\": 7.101449275362318, \"center_x\": -1.1594202898550732, \"center_y\": 6.956521739130435, \"value_uncond\": 0.002387785897913383}, {\"x\": -1.0144927536231876, \"y\": 6.811594202898551, \"x2\": -0.72463768115942, \"y2\": 7.101449275362318, \"center_x\": -0.8695652173913038, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0028194207010446017}, {\"x\": -0.72463768115942, \"y\": 6.811594202898551, \"x2\": -0.43478260869565233, \"y2\": 7.101449275362318, \"center_x\": -0.5797101449275361, \"center_y\": 6.956521739130435, \"value_uncond\": 0.00329814845360981}, {\"x\": -0.43478260869565233, \"y\": 6.811594202898551, \"x2\": -0.1449275362318847, \"y2\": 7.101449275362318, \"center_x\": -0.2898550724637685, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0038223137271730825}, {\"x\": -0.14492753623188293, \"y\": 6.811594202898551, \"x2\": 0.1449275362318847, \"y2\": 7.101449275362318, \"center_x\": 8.881784197001252e-16, \"center_y\": 6.956521739130435, \"value_uncond\": 0.004388623000888145}, {\"x\": 0.1449275362318847, \"y\": 6.811594202898551, \"x2\": 0.43478260869565233, \"y2\": 7.101449275362318, \"center_x\": 0.2898550724637685, \"center_y\": 6.956521739130435, \"value_uncond\": 0.004992016754393205}, {\"x\": 0.43478260869565233, \"y\": 6.811594202898551, \"x2\": 0.72463768115942, \"y2\": 7.101449275362318, \"center_x\": 0.5797101449275361, \"center_y\": 6.956521739130435, \"value_uncond\": 0.005625609832929387}, {\"x\": 0.72463768115942, \"y\": 6.811594202898551, \"x2\": 1.0144927536231876, \"y2\": 7.101449275362318, \"center_x\": 0.8695652173913038, \"center_y\": 6.956521739130435, \"value_uncond\": 0.006280713694225632}, {\"x\": 1.0144927536231894, \"y\": 6.811594202898551, \"x2\": 1.304347826086957, \"y2\": 7.101449275362318, \"center_x\": 1.1594202898550732, \"center_y\": 6.956521739130435, \"value_uncond\": 0.006946950423113533}, {\"x\": 1.304347826086957, \"y\": 6.811594202898551, \"x2\": 1.5942028985507246, \"y2\": 7.101449275362318, \"center_x\": 1.4492753623188408, \"center_y\": 6.956521739130435, \"value_uncond\": 0.007612463390355489}, {\"x\": 1.5942028985507246, \"y\": 6.811594202898551, \"x2\": 1.8840579710144922, \"y2\": 7.101449275362318, \"center_x\": 1.7391304347826084, \"center_y\": 6.956521739130435, \"value_uncond\": 0.008264223409439334}, {\"x\": 1.884057971014494, \"y\": 6.811594202898551, \"x2\": 2.1739130434782616, \"y2\": 7.101449275362318, \"center_x\": 2.028985507246378, \"center_y\": 6.956521739130435, \"value_uncond\": 0.00888842261488678}, {\"x\": 2.1739130434782616, \"y\": 6.811594202898551, \"x2\": 2.4637681159420293, \"y2\": 7.101449275362318, \"center_x\": 2.3188405797101455, \"center_y\": 6.956521739130435, \"value_uncond\": 0.009470941559540745}, {\"x\": 2.4637681159420293, \"y\": 6.811594202898551, \"x2\": 2.753623188405797, \"y2\": 7.101449275362318, \"center_x\": 2.608695652173913, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0099978687810239}, {\"x\": 2.753623188405797, \"y\": 6.811594202898551, \"x2\": 3.0434782608695645, \"y2\": 7.101449275362318, \"center_x\": 2.8985507246376807, \"center_y\": 6.956521739130435, \"value_uncond\": 0.010456046902358577}, {\"x\": 3.0434782608695663, \"y\": 6.811594202898551, \"x2\": 3.333333333333334, \"y2\": 7.101449275362318, \"center_x\": 3.18840579710145, \"center_y\": 6.956521739130435, \"value_uncond\": 0.010833615739769736}, {\"x\": 3.333333333333334, \"y\": 6.811594202898551, \"x2\": 3.6231884057971016, \"y2\": 7.101449275362318, \"center_x\": 3.4782608695652177, \"center_y\": 6.956521739130435, \"value_uncond\": 0.011120521311170306}, {\"x\": 3.6231884057971016, \"y\": 6.811594202898551, \"x2\": 3.913043478260869, \"y2\": 7.101449275362318, \"center_x\": 3.7681159420289854, \"center_y\": 6.956521739130435, \"value_uncond\": 0.011308960327440668}, {\"x\": 3.913043478260871, \"y\": 6.811594202898551, \"x2\": 4.202898550724639, \"y2\": 7.101449275362318, \"center_x\": 4.057971014492755, \"center_y\": 6.956521739130435, \"value_uncond\": 0.011393732761146204}, {\"x\": 4.202898550724639, \"y\": 6.811594202898551, \"x2\": 4.492753623188406, \"y2\": 7.101449275362318, \"center_x\": 4.347826086956522, \"center_y\": 6.956521739130435, \"value_uncond\": 0.011372480263853986}, {\"x\": 4.492753623188406, \"y\": 6.811594202898551, \"x2\": 4.782608695652174, \"y2\": 7.101449275362318, \"center_x\": 4.63768115942029, \"center_y\": 6.956521739130435, \"value_uncond\": 0.011245795175755779}, {\"x\": 4.782608695652174, \"y\": 6.811594202898551, \"x2\": 5.0724637681159415, \"y2\": 7.101449275362318, \"center_x\": 4.927536231884058, \"center_y\": 6.956521739130435, \"value_uncond\": 0.011017193095140902}, {\"x\": 5.072463768115943, \"y\": 6.811594202898551, \"x2\": 5.362318840579711, \"y2\": 7.101449275362318, \"center_x\": 5.217391304347827, \"center_y\": 6.956521739130435, \"value_uncond\": 0.010692950780604234}, {\"x\": 5.362318840579711, \"y\": 6.811594202898551, \"x2\": 5.6521739130434785, \"y2\": 7.101449275362318, \"center_x\": 5.507246376811595, \"center_y\": 6.956521739130435, \"value_uncond\": 0.010281819817347382}, {\"x\": 5.6521739130434785, \"y\": 6.811594202898551, \"x2\": 5.942028985507246, \"y2\": 7.101449275362318, \"center_x\": 5.797101449275362, \"center_y\": 6.956521739130435, \"value_uncond\": 0.009794634276985995}, {\"x\": 5.942028985507246, \"y\": 6.811594202898551, \"x2\": 6.231884057971014, \"y2\": 7.101449275362318, \"center_x\": 6.08695652173913, \"center_y\": 6.956521739130435, \"value_uncond\": 0.009243836910839224}, {\"x\": 6.2318840579710155, \"y\": 6.811594202898551, \"x2\": 6.521739130434783, \"y2\": 7.101449275362318, \"center_x\": 6.376811594202899, \"center_y\": 6.956521739130435, \"value_uncond\": 0.008642952760560024}, {\"x\": 6.521739130434785, \"y\": 6.811594202898551, \"x2\": 6.8115942028985526, \"y2\": 7.101449275362318, \"center_x\": 6.666666666666669, \"center_y\": 6.956521739130435, \"value_uncond\": 0.008006041159953757}, {\"x\": 6.811594202898551, \"y\": 6.811594202898551, \"x2\": 7.101449275362318, \"y2\": 7.101449275362318, \"center_x\": 6.956521739130435, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0073471568647067755}, {\"x\": 7.10144927536232, \"y\": 6.811594202898551, \"x2\": 7.391304347826088, \"y2\": 7.101449275362318, \"center_x\": 7.246376811594204, \"center_y\": 6.956521739130435, \"value_uncond\": 0.00667984862139824}, {\"x\": 7.391304347826086, \"y\": 6.811594202898551, \"x2\": 7.681159420289854, \"y2\": 7.101449275362318, \"center_x\": 7.53623188405797, \"center_y\": 6.956521739130435, \"value_uncond\": 0.00601671920005302}, {\"x\": 7.681159420289855, \"y\": 6.811594202898551, \"x2\": 7.971014492753623, \"y2\": 7.101449275362318, \"center_x\": 7.826086956521739, \"center_y\": 6.956521739130435, \"value_uncond\": 0.00536906523642159}, {\"x\": 7.971014492753625, \"y\": 6.811594202898551, \"x2\": 8.260869565217392, \"y2\": 7.101449275362318, \"center_x\": 8.115942028985508, \"center_y\": 6.956521739130435, \"value_uncond\": 0.004746608720542592}, {\"x\": 8.26086956521739, \"y\": 6.811594202898551, \"x2\": 8.550724637681158, \"y2\": 7.101449275362318, \"center_x\": 8.405797101449274, \"center_y\": 6.956521739130435, \"value_uncond\": 0.004157325213865356}, {\"x\": 8.55072463768116, \"y\": 6.811594202898551, \"x2\": 8.840579710144928, \"y2\": 7.101449275362318, \"center_x\": 8.695652173913043, \"center_y\": 6.956521739130435, \"value_uncond\": 0.003607367433725416}, {\"x\": 8.84057971014493, \"y\": 6.811594202898551, \"x2\": 9.130434782608697, \"y2\": 7.101449275362318, \"center_x\": 8.985507246376812, \"center_y\": 6.956521739130435, \"value_uncond\": 0.003101077184865926}, {\"x\": 9.130434782608695, \"y\": 6.811594202898551, \"x2\": 9.420289855072463, \"y2\": 7.101449275362318, \"center_x\": 9.275362318840578, \"center_y\": 6.956521739130435, \"value_uncond\": 0.002641074097847261}, {\"x\": 9.420289855072465, \"y\": 6.811594202898551, \"x2\": 9.710144927536232, \"y2\": 7.101449275362318, \"center_x\": 9.565217391304348, \"center_y\": 6.956521739130435, \"value_uncond\": 0.002228406469119295}, {\"x\": 9.710144927536234, \"y\": 6.811594202898551, \"x2\": 10.000000000000002, \"y2\": 7.101449275362318, \"center_x\": 9.855072463768117, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0018627477596188527}, {\"x\": 10.0, \"y\": 6.811594202898551, \"x2\": 10.289855072463768, \"y2\": 7.101449275362318, \"center_x\": 10.144927536231883, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0015426219385989153}, {\"x\": -10.0, \"y\": 7.10144927536232, \"x2\": -9.710144927536232, \"y2\": 7.391304347826088, \"center_x\": -9.855072463768117, \"center_y\": 7.246376811594204, \"value_uncond\": 1.9342447068386744e-07}, {\"x\": -9.710144927536232, \"y\": 7.10144927536232, \"x2\": -9.420289855072465, \"y2\": 7.391304347826088, \"center_x\": -9.565217391304348, \"center_y\": 7.246376811594204, \"value_uncond\": 3.022048862580275e-07}, {\"x\": -9.420289855072463, \"y\": 7.10144927536232, \"x2\": -9.130434782608695, \"y2\": 7.391304347826088, \"center_x\": -9.275362318840578, \"center_y\": 7.246376811594204, \"value_uncond\": 4.677753814021533e-07}, {\"x\": -9.130434782608695, \"y\": 7.10144927536232, \"x2\": -8.840579710144928, \"y2\": 7.391304347826088, \"center_x\": -8.985507246376812, \"center_y\": 7.246376811594204, \"value_uncond\": 7.17330101458459e-07}, {\"x\": -8.840579710144928, \"y\": 7.10144927536232, \"x2\": -8.55072463768116, \"y2\": 7.391304347826088, \"center_x\": -8.695652173913043, \"center_y\": 7.246376811594204, \"value_uncond\": 1.089799399320701e-06}, {\"x\": -8.55072463768116, \"y\": 7.10144927536232, \"x2\": -8.260869565217392, \"y2\": 7.391304347826088, \"center_x\": -8.405797101449277, \"center_y\": 7.246376811594204, \"value_uncond\": 1.6402871676680804e-06}, {\"x\": -8.26086956521739, \"y\": 7.10144927536232, \"x2\": -7.971014492753623, \"y2\": 7.391304347826088, \"center_x\": -8.115942028985508, \"center_y\": 7.246376811594204, \"value_uncond\": 2.445901847012585e-06}, {\"x\": -7.971014492753623, \"y\": 7.10144927536232, \"x2\": -7.681159420289855, \"y2\": 7.391304347826088, \"center_x\": -7.826086956521739, \"center_y\": 7.246376811594204, \"value_uncond\": 3.613299635221212e-06}, {\"x\": -7.681159420289855, \"y\": 7.10144927536232, \"x2\": -7.391304347826088, \"y2\": 7.391304347826088, \"center_x\": -7.536231884057972, \"center_y\": 7.246376811594204, \"value_uncond\": 5.288283679482755e-06}, {\"x\": -7.391304347826087, \"y\": 7.10144927536232, \"x2\": -7.101449275362319, \"y2\": 7.391304347826088, \"center_x\": -7.246376811594203, \"center_y\": 7.246376811594204, \"value_uncond\": 7.66780968694211e-06}, {\"x\": -7.101449275362318, \"y\": 7.10144927536232, \"x2\": -6.811594202898551, \"y2\": 7.391304347826088, \"center_x\": -6.956521739130435, \"center_y\": 7.246376811594204, \"value_uncond\": 1.1014726580662296e-05}, {\"x\": -6.811594202898551, \"y\": 7.10144927536232, \"x2\": -6.521739130434783, \"y2\": 7.391304347826088, \"center_x\": -6.666666666666667, \"center_y\": 7.246376811594204, \"value_uncond\": 1.56755190973668e-05}, {\"x\": -6.521739130434782, \"y\": 7.10144927536232, \"x2\": -6.231884057971015, \"y2\": 7.391304347826088, \"center_x\": -6.3768115942028984, \"center_y\": 7.246376811594204, \"value_uncond\": 2.21012051777109e-05}, {\"x\": -6.231884057971014, \"y\": 7.10144927536232, \"x2\": -5.942028985507246, \"y2\": 7.391304347826088, \"center_x\": -6.08695652173913, \"center_y\": 7.246376811594204, \"value_uncond\": 3.0871362390521965e-05}, {\"x\": -5.942028985507246, \"y\": 7.10144927536232, \"x2\": -5.6521739130434785, \"y2\": 7.391304347826088, \"center_x\": -5.797101449275362, \"center_y\": 7.246376811594204, \"value_uncond\": 4.27210039220419e-05}, {\"x\": -5.6521739130434785, \"y\": 7.10144927536232, \"x2\": -5.362318840579711, \"y2\": 7.391304347826088, \"center_x\": -5.507246376811595, \"center_y\": 7.246376811594204, \"value_uncond\": 5.856968905537602e-05}, {\"x\": -5.36231884057971, \"y\": 7.10144927536232, \"x2\": -5.072463768115942, \"y2\": 7.391304347826088, \"center_x\": -5.217391304347826, \"center_y\": 7.246376811594204, \"value_uncond\": 7.955183492813184e-05}, {\"x\": -5.0724637681159415, \"y\": 7.10144927536232, \"x2\": -4.782608695652174, \"y2\": 7.391304347826088, \"center_x\": -4.927536231884058, \"center_y\": 7.246376811594204, \"value_uncond\": 0.00010704670382586031}, {\"x\": -4.782608695652174, \"y\": 7.10144927536232, \"x2\": -4.492753623188406, \"y2\": 7.391304347826088, \"center_x\": -4.63768115942029, \"center_y\": 7.246376811594204, \"value_uncond\": 0.00014270599278582075}, {\"x\": -4.492753623188405, \"y\": 7.10144927536232, \"x2\": -4.202898550724638, \"y2\": 7.391304347826088, \"center_x\": -4.3478260869565215, \"center_y\": 7.246376811594204, \"value_uncond\": 0.00018847638264041263}, {\"x\": -4.202898550724638, \"y\": 7.10144927536232, \"x2\": -3.91304347826087, \"y2\": 7.391304347826088, \"center_x\": -4.057971014492754, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0002466138590582607}, {\"x\": -3.913043478260869, \"y\": 7.10144927536232, \"x2\": -3.6231884057971016, \"y2\": 7.391304347826088, \"center_x\": -3.7681159420289854, \"center_y\": 7.246376811594204, \"value_uncond\": 0.00031968615995836775}, {\"x\": -3.6231884057971016, \"y\": 7.10144927536232, \"x2\": -3.333333333333334, \"y2\": 7.391304347826088, \"center_x\": -3.4782608695652177, \"center_y\": 7.246376811594204, \"value_uncond\": 0.00041055940496946086}, {\"x\": -3.333333333333333, \"y\": 7.10144927536232, \"x2\": -3.0434782608695654, \"y2\": 7.391304347826088, \"center_x\": -3.1884057971014492, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0005223649036535408}, {\"x\": -3.0434782608695645, \"y\": 7.10144927536232, \"x2\": -2.753623188405797, \"y2\": 7.391304347826088, \"center_x\": -2.8985507246376807, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0006584424004384523}, {\"x\": -2.753623188405797, \"y\": 7.10144927536232, \"x2\": -2.4637681159420293, \"y2\": 7.391304347826088, \"center_x\": -2.608695652173913, \"center_y\": 7.246376811594204, \"value_uncond\": 0.000822256666924762}, {\"x\": -2.4637681159420284, \"y\": 7.10144927536232, \"x2\": -2.1739130434782608, \"y2\": 7.391304347826088, \"center_x\": -2.3188405797101446, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0010172854476969823}, {\"x\": -2.1739130434782608, \"y\": 7.10144927536232, \"x2\": -1.8840579710144931, \"y2\": 7.391304347826088, \"center_x\": -2.028985507246377, \"center_y\": 7.246376811594204, \"value_uncond\": 0.001246878323511795}, {\"x\": -1.8840579710144922, \"y\": 7.10144927536232, \"x2\": -1.5942028985507246, \"y2\": 7.391304347826088, \"center_x\": -1.7391304347826084, \"center_y\": 7.246376811594204, \"value_uncond\": 0.001514088052601515}, {\"x\": -1.5942028985507246, \"y\": 7.10144927536232, \"x2\": -1.304347826086957, \"y2\": 7.391304347826088, \"center_x\": -1.4492753623188408, \"center_y\": 7.246376811594204, \"value_uncond\": 0.001821478312344528}, {\"x\": -1.304347826086957, \"y\": 7.10144927536232, \"x2\": -1.0144927536231894, \"y2\": 7.391304347826088, \"center_x\": -1.1594202898550732, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0021709143594019938}, {\"x\": -1.0144927536231876, \"y\": 7.10144927536232, \"x2\": -0.72463768115942, \"y2\": 7.391304347826088, \"center_x\": -0.8695652173913038, \"center_y\": 7.246376811594204, \"value_uncond\": 0.002563345771679815}, {\"x\": -0.72463768115942, \"y\": 7.10144927536232, \"x2\": -0.43478260869565233, \"y2\": 7.391304347826088, \"center_x\": -0.5797101449275361, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0029985928988180773}, {\"x\": -0.43478260869565233, \"y\": 7.10144927536232, \"x2\": -0.1449275362318847, \"y2\": 7.391304347826088, \"center_x\": -0.2898550724637685, \"center_y\": 7.246376811594204, \"value_uncond\": 0.003475150667281647}, {\"x\": -0.14492753623188293, \"y\": 7.10144927536232, \"x2\": 0.1449275362318847, \"y2\": 7.391304347826088, \"center_x\": 8.881784197001252e-16, \"center_y\": 7.246376811594204, \"value_uncond\": 0.003990024691474892}, {\"x\": 0.1449275362318847, \"y\": 7.10144927536232, \"x2\": 0.43478260869565233, \"y2\": 7.391304347826088, \"center_x\": 0.2898550724637685, \"center_y\": 7.246376811594204, \"value_uncond\": 0.004538614983846708}, {\"x\": 0.43478260869565233, \"y\": 7.10144927536232, \"x2\": 0.72463768115942, \"y2\": 7.391304347826088, \"center_x\": 0.5797101449275361, \"center_y\": 7.246376811594204, \"value_uncond\": 0.005114661736369161}, {\"x\": 0.72463768115942, \"y\": 7.10144927536232, \"x2\": 1.0144927536231876, \"y2\": 7.391304347826088, \"center_x\": 0.8695652173913038, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0057102655468408235}, {\"x\": 1.0144927536231894, \"y\": 7.10144927536232, \"x2\": 1.304347826086957, \"y2\": 7.391304347826088, \"center_x\": 1.1594202898550732, \"center_y\": 7.246376811594204, \"value_uncond\": 0.006315991078081992}, {\"x\": 1.304347826086957, \"y\": 7.10144927536232, \"x2\": 1.5942028985507246, \"y2\": 7.391304347826088, \"center_x\": 1.4492753623188408, \"center_y\": 7.246376811594204, \"value_uncond\": 0.00692105858359676}, {\"x\": 1.5942028985507246, \"y\": 7.10144927536232, \"x2\": 1.8840579710144922, \"y2\": 7.391304347826088, \"center_x\": 1.7391304347826084, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0075136222575633805}, {\"x\": 1.884057971014494, \"y\": 7.10144927536232, \"x2\": 2.1739130434782616, \"y2\": 7.391304347826088, \"center_x\": 2.028985507246378, \"center_y\": 7.246376811594204, \"value_uncond\": 0.008081128338999469}, {\"x\": 2.1739130434782616, \"y\": 7.10144927536232, \"x2\": 2.4637681159420293, \"y2\": 7.391304347826088, \"center_x\": 2.3188405797101455, \"center_y\": 7.246376811594204, \"value_uncond\": 0.008610739784765224}, {\"x\": 2.4637681159420293, \"y\": 7.10144927536232, \"x2\": 2.753623188405797, \"y2\": 7.391304347826088, \"center_x\": 2.608695652173913, \"center_y\": 7.246376811594204, \"value_uncond\": 0.009089808646205944}, {\"x\": 2.753623188405797, \"y\": 7.10144927536232, \"x2\": 3.0434782608695645, \"y2\": 7.391304347826088, \"center_x\": 2.8985507246376807, \"center_y\": 7.246376811594204, \"value_uncond\": 0.00950637256998089}, {\"x\": 3.0434782608695663, \"y\": 7.10144927536232, \"x2\": 3.333333333333334, \"y2\": 7.391304347826088, \"center_x\": 3.18840579710145, \"center_y\": 7.246376811594204, \"value_uncond\": 0.00984964857789889}, {\"x\": 3.333333333333334, \"y\": 7.10144927536232, \"x2\": 3.6231884057971016, \"y2\": 7.391304347826088, \"center_x\": 3.4782608695652177, \"center_y\": 7.246376811594204, \"value_uncond\": 0.010110495844519491}, {\"x\": 3.6231884057971016, \"y\": 7.10144927536232, \"x2\": 3.913043478260869, \"y2\": 7.391304347826088, \"center_x\": 3.7681159420289854, \"center_y\": 7.246376811594204, \"value_uncond\": 0.010281819817347378}, {\"x\": 3.913043478260871, \"y\": 7.10144927536232, \"x2\": 4.202898550724639, \"y2\": 7.391304347826088, \"center_x\": 4.057971014492755, \"center_y\": 7.246376811594204, \"value_uncond\": 0.010358892763365537}, {\"x\": 4.202898550724639, \"y\": 7.10144927536232, \"x2\": 4.492753623188406, \"y2\": 7.391304347826088, \"center_x\": 4.347826086956522, \"center_y\": 7.246376811594204, \"value_uncond\": 0.010339570532010896}, {\"x\": 4.492753623188406, \"y\": 7.10144927536232, \"x2\": 4.782608695652174, \"y2\": 7.391304347826088, \"center_x\": 4.63768115942029, \"center_y\": 7.246376811594204, \"value_uncond\": 0.01022439166395793}, {\"x\": 4.782608695652174, \"y\": 7.10144927536232, \"x2\": 5.0724637681159415, \"y2\": 7.391304347826088, \"center_x\": 4.927536231884058, \"center_y\": 7.246376811594204, \"value_uncond\": 0.010016552451979297}, {\"x\": 5.072463768115943, \"y\": 7.10144927536232, \"x2\": 5.362318840579711, \"y2\": 7.391304347826088, \"center_x\": 5.217391304347827, \"center_y\": 7.246376811594204, \"value_uncond\": 0.009721759565745856}, {\"x\": 5.362318840579711, \"y\": 7.10144927536232, \"x2\": 5.6521739130434785, \"y2\": 7.391304347826088, \"center_x\": 5.507246376811595, \"center_y\": 7.246376811594204, \"value_uncond\": 0.00934796972449207}, {\"x\": 5.6521739130434785, \"y\": 7.10144927536232, \"x2\": 5.942028985507246, \"y2\": 7.391304347826088, \"center_x\": 5.797101449275362, \"center_y\": 7.246376811594204, \"value_uncond\": 0.00890503299126662}, {\"x\": 5.942028985507246, \"y\": 7.10144927536232, \"x2\": 6.231884057971014, \"y2\": 7.391304347826088, \"center_x\": 6.08695652173913, \"center_y\": 7.246376811594204, \"value_uncond\": 0.008404261999891829}, {\"x\": 6.2318840579710155, \"y\": 7.10144927536232, \"x2\": 6.521739130434783, \"y2\": 7.391304347826088, \"center_x\": 6.376811594202899, \"center_y\": 7.246376811594204, \"value_uncond\": 0.007857953375103437}, {\"x\": 6.521739130434785, \"y\": 7.10144927536232, \"x2\": 6.8115942028985526, \"y2\": 7.391304347826088, \"center_x\": 6.666666666666669, \"center_y\": 7.246376811594204, \"value_uncond\": 0.007278889506506953}, {\"x\": 6.811594202898551, \"y\": 7.10144927536232, \"x2\": 7.101449275362318, \"y2\": 7.391304347826088, \"center_x\": 6.956521739130435, \"center_y\": 7.246376811594204, \"value_uncond\": 0.00667984862139824}, {\"x\": 7.10144927536232, \"y\": 7.10144927536232, \"x2\": 7.391304347826088, \"y2\": 7.391304347826088, \"center_x\": 7.246376811594204, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0060731488964305335}, {\"x\": 7.391304347826086, \"y\": 7.10144927536232, \"x2\": 7.681159420289854, \"y2\": 7.391304347826088, \"center_x\": 7.53623188405797, \"center_y\": 7.246376811594204, \"value_uncond\": 0.005470248450373667}, {\"x\": 7.681159420289855, \"y\": 7.10144927536232, \"x2\": 7.971014492753623, \"y2\": 7.391304347826088, \"center_x\": 7.826086956521739, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0048814178978522915}, {\"x\": 7.971014492753625, \"y\": 7.10144927536232, \"x2\": 8.260869565217392, \"y2\": 7.391304347826088, \"center_x\": 8.115942028985508, \"center_y\": 7.246376811594204, \"value_uncond\": 0.004315496225559179}, {\"x\": 8.26086956521739, \"y\": 7.10144927536232, \"x2\": 8.550724637681158, \"y2\": 7.391304347826088, \"center_x\": 8.405797101449274, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0037797346116212206}, {\"x\": 8.55072463768116, \"y\": 7.10144927536232, \"x2\": 8.840579710144928, \"y2\": 7.391304347826088, \"center_x\": 8.695652173913043, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0032797269505432467}, {\"x\": 8.84057971014493, \"y\": 7.10144927536232, \"x2\": 9.130434782608697, \"y2\": 7.391304347826088, \"center_x\": 8.985507246376812, \"center_y\": 7.246376811594204, \"value_uncond\": 0.002819420701044596}, {\"x\": 9.130434782608695, \"y\": 7.10144927536232, \"x2\": 9.420289855072463, \"y2\": 7.391304347826088, \"center_x\": 9.275362318840578, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0024011975647698}, {\"x\": 9.420289855072465, \"y\": 7.10144927536232, \"x2\": 9.710144927536232, \"y2\": 7.391304347826088, \"center_x\": 9.565217391304348, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0020260106262554294}, {\"x\": 9.710144927536234, \"y\": 7.10144927536232, \"x2\": 10.000000000000002, \"y2\": 7.391304347826088, \"center_x\": 9.855072463768117, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0016935630044696544}, {\"x\": 10.0, \"y\": 7.10144927536232, \"x2\": 10.289855072463768, \"y2\": 7.391304347826088, \"center_x\": 10.144927536231883, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0014025127297047169}, {\"x\": -10.0, \"y\": 7.391304347826086, \"x2\": -9.710144927536232, \"y2\": 7.681159420289854, \"center_x\": -9.855072463768117, \"center_y\": 7.53623188405797, \"value_uncond\": 1.7422261977549334e-07}, {\"x\": -9.710144927536232, \"y\": 7.391304347826086, \"x2\": -9.420289855072465, \"y2\": 7.681159420289854, \"center_x\": -9.565217391304348, \"center_y\": 7.53623188405797, \"value_uncond\": 2.7220406397741216e-07}, {\"x\": -9.420289855072463, \"y\": 7.391304347826086, \"x2\": -9.130434782608695, \"y2\": 7.681159420289854, \"center_x\": -9.275362318840578, \"center_y\": 7.53623188405797, \"value_uncond\": 4.213378593009689e-07}, {\"x\": -9.130434782608695, \"y\": 7.391304347826086, \"x2\": -8.840579710144928, \"y2\": 7.681159420289854, \"center_x\": -8.985507246376812, \"center_y\": 7.53623188405797, \"value_uncond\": 6.461185034036994e-07}, {\"x\": -8.840579710144928, \"y\": 7.391304347826086, \"x2\": -8.55072463768116, \"y2\": 7.681159420289854, \"center_x\": -8.695652173913043, \"center_y\": 7.53623188405797, \"value_uncond\": 9.8161161154077e-07}, {\"x\": -8.55072463768116, \"y\": 7.391304347826086, \"x2\": -8.260869565217392, \"y2\": 7.681159420289854, \"center_x\": -8.405797101449277, \"center_y\": 7.53623188405797, \"value_uncond\": 1.4774507409785143e-06}, {\"x\": -8.26086956521739, \"y\": 7.391304347826086, \"x2\": -7.971014492753623, \"y2\": 7.681159420289854, \"center_x\": -8.115942028985508, \"center_y\": 7.53623188405797, \"value_uncond\": 2.2030895366735617e-06}, {\"x\": -7.971014492753623, \"y\": 7.391304347826086, \"x2\": -7.681159420289855, \"y2\": 7.681159420289854, \"center_x\": -7.826086956521739, \"center_y\": 7.53623188405797, \"value_uncond\": 3.2545961028424198e-06}, {\"x\": -7.681159420289855, \"y\": 7.391304347826086, \"x2\": -7.391304347826088, \"y2\": 7.681159420289854, \"center_x\": -7.536231884057972, \"center_y\": 7.53623188405797, \"value_uncond\": 4.763299253181387e-06}, {\"x\": -7.391304347826087, \"y\": 7.391304347826086, \"x2\": -7.101449275362319, \"y2\": 7.681159420289854, \"center_x\": -7.246376811594203, \"center_y\": 7.53623188405797, \"value_uncond\": 6.906602287062016e-06}, {\"x\": -7.101449275362318, \"y\": 7.391304347826086, \"x2\": -6.811594202898551, \"y2\": 7.681159420289854, \"center_x\": -6.956521739130435, \"center_y\": 7.53623188405797, \"value_uncond\": 9.921260294568306e-06}, {\"x\": -6.811594202898551, \"y\": 7.391304347826086, \"x2\": -6.521739130434783, \"y2\": 7.681159420289854, \"center_x\": -6.666666666666667, \"center_y\": 7.53623188405797, \"value_uncond\": 1.4119361391184097e-05}, {\"x\": -6.521739130434782, \"y\": 7.391304347826086, \"x2\": -6.231884057971015, \"y2\": 7.681159420289854, \"center_x\": -6.3768115942028984, \"center_y\": 7.53623188405797, \"value_uncond\": 1.9907149558908627e-05}, {\"x\": -6.231884057971014, \"y\": 7.391304347826086, \"x2\": -5.942028985507246, \"y2\": 7.681159420289854, \"center_x\": -6.08695652173913, \"center_y\": 7.53623188405797, \"value_uncond\": 2.780666589237285e-05}, {\"x\": -5.942028985507246, \"y\": 7.391304347826086, \"x2\": -5.6521739130434785, \"y2\": 7.681159420289854, \"center_x\": -5.797101449275362, \"center_y\": 7.53623188405797, \"value_uncond\": 3.8479956524746164e-05}, {\"x\": -5.6521739130434785, \"y\": 7.391304347826086, \"x2\": -5.362318840579711, \"y2\": 7.681159420289854, \"center_x\": -5.507246376811595, \"center_y\": 7.53623188405797, \"value_uncond\": 5.275529321903279e-05}, {\"x\": -5.36231884057971, \"y\": 7.391304347826086, \"x2\": -5.072463768115942, \"y2\": 7.681159420289854, \"center_x\": -5.217391304347826, \"center_y\": 7.53623188405797, \"value_uncond\": 7.165447598292267e-05}, {\"x\": -5.0724637681159415, \"y\": 7.391304347826086, \"x2\": -4.782608695652174, \"y2\": 7.681159420289854, \"center_x\": -4.927536231884058, \"center_y\": 7.53623188405797, \"value_uncond\": 9.641984343001844e-05}, {\"x\": -4.782608695652174, \"y\": 7.391304347826086, \"x2\": -4.492753623188406, \"y2\": 7.681159420289854, \"center_x\": -4.63768115942029, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0001285391234775238}, {\"x\": -4.492753623188405, \"y\": 7.391304347826086, \"x2\": -4.202898550724638, \"y2\": 7.681159420289854, \"center_x\": -4.3478260869565215, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0001697657438757553}, {\"x\": -4.202898550724638, \"y\": 7.391304347826086, \"x2\": -3.91304347826087, \"y2\": 7.681159420289854, \"center_x\": -4.057971014492754, \"center_y\": 7.53623188405797, \"value_uncond\": 0.00022213173155478084}, {\"x\": -3.913043478260869, \"y\": 7.391304347826086, \"x2\": -3.6231884057971016, \"y2\": 7.681159420289854, \"center_x\": -3.7681159420289854, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0002879499170761312}, {\"x\": -3.6231884057971016, \"y\": 7.391304347826086, \"x2\": -3.333333333333334, \"y2\": 7.681159420289854, \"center_x\": -3.4782608695652177, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0003698018914274478}, {\"x\": -3.333333333333333, \"y\": 7.391304347826086, \"x2\": -3.0434782608695654, \"y2\": 7.681159420289854, \"center_x\": -3.1884057971014492, \"center_y\": 7.53623188405797, \"value_uncond\": 0.00047050810929727627}, {\"x\": -3.0434782608695645, \"y\": 7.391304347826086, \"x2\": -2.753623188405797, \"y2\": 7.681159420289854, \"center_x\": -2.8985507246376807, \"center_y\": 7.53623188405797, \"value_uncond\": 0.000593076768260322}, {\"x\": -2.753623188405797, \"y\": 7.391304347826086, \"x2\": -2.4637681159420293, \"y2\": 7.681159420289854, \"center_x\": -2.608695652173913, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0007406286812263477}, {\"x\": -2.4637681159420284, \"y\": 7.391304347826086, \"x2\": -2.1739130434782608, \"y2\": 7.681159420289854, \"center_x\": -2.3188405797101446, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0009162963462204569}, {\"x\": -2.1739130434782608, \"y\": 7.391304347826086, \"x2\": -1.8840579710144931, \"y2\": 7.681159420289854, \"center_x\": -2.028985507246377, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0011230968206631274}, {\"x\": -1.8840579710144922, \"y\": 7.391304347826086, \"x2\": -1.5942028985507246, \"y2\": 7.681159420289854, \"center_x\": -1.7391304347826084, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0013637798059488858}, {\"x\": -1.5942028985507246, \"y\": 7.391304347826086, \"x2\": -1.304347826086957, \"y2\": 7.681159420289854, \"center_x\": -1.4492753623188408, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0016406544752011858}, {\"x\": -1.304347826086957, \"y\": 7.391304347826086, \"x2\": -1.0144927536231894, \"y2\": 7.681159420289854, \"center_x\": -1.1594202898550732, \"center_y\": 7.53623188405797, \"value_uncond\": 0.001955400915230719}, {\"x\": -1.0144927536231876, \"y\": 7.391304347826086, \"x2\": -0.72463768115942, \"y2\": 7.681159420289854, \"center_x\": -0.8695652173913038, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0023088744363809113}, {\"x\": -0.72463768115942, \"y\": 7.391304347826086, \"x2\": -0.43478260869565233, \"y2\": 7.681159420289854, \"center_x\": -0.5797101449275361, \"center_y\": 7.53623188405797, \"value_uncond\": 0.002700913222743788}, {\"x\": -0.43478260869565233, \"y\": 7.391304347826086, \"x2\": -0.1449275362318847, \"y2\": 7.681159420289854, \"center_x\": -0.2898550724637685, \"center_y\": 7.53623188405797, \"value_uncond\": 0.003130161614131584}, {\"x\": -0.14492753623188293, \"y\": 7.391304347826086, \"x2\": 0.1449275362318847, \"y2\": 7.681159420289854, \"center_x\": 8.881784197001252e-16, \"center_y\": 7.53623188405797, \"value_uncond\": 0.003593922486952622}, {\"x\": 0.1449275362318847, \"y\": 7.391304347826086, \"x2\": 0.43478260869565233, \"y2\": 7.681159420289854, \"center_x\": 0.2898550724637685, \"center_y\": 7.53623188405797, \"value_uncond\": 0.004088052508777173}, {\"x\": 0.43478260869565233, \"y\": 7.391304347826086, \"x2\": 0.72463768115942, \"y2\": 7.681159420289854, \"center_x\": 0.5797101449275361, \"center_y\": 7.53623188405797, \"value_uncond\": 0.004606913302257929}, {\"x\": 0.72463768115942, \"y\": 7.391304347826086, \"x2\": 1.0144927536231876, \"y2\": 7.681159420289854, \"center_x\": 0.8695652173913038, \"center_y\": 7.53623188405797, \"value_uncond\": 0.00514338966350509}, {\"x\": 1.0144927536231894, \"y\": 7.391304347826086, \"x2\": 1.304347826086957, \"y2\": 7.681159420289854, \"center_x\": 1.1594202898550732, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0056889829307097284}, {\"x\": 1.304347826086957, \"y\": 7.391304347826086, \"x2\": 1.5942028985507246, \"y2\": 7.681159420289854, \"center_x\": 1.4492753623188408, \"center_y\": 7.53623188405797, \"value_uncond\": 0.00623398349645561}, {\"x\": 1.5942028985507246, \"y\": 7.391304347826086, \"x2\": 1.8840579710144922, \"y2\": 7.681159420289854, \"center_x\": 1.7391304347826084, \"center_y\": 7.53623188405797, \"value_uncond\": 0.006767721525037255}, {\"x\": 1.884057971014494, \"y\": 7.391304347826086, \"x2\": 2.1739130434782616, \"y2\": 7.681159420289854, \"center_x\": 2.028985507246378, \"center_y\": 7.53623188405797, \"value_uncond\": 0.007278889506506966}, {\"x\": 2.1739130434782616, \"y\": 7.391304347826086, \"x2\": 2.4637681159420293, \"y2\": 7.681159420289854, \"center_x\": 2.3188405797101455, \"center_y\": 7.53623188405797, \"value_uncond\": 0.007755924771063552}, {\"x\": 2.4637681159420293, \"y\": 7.391304347826086, \"x2\": 2.753623188405797, \"y2\": 7.681159420289854, \"center_x\": 2.608695652173913, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0081874349713912}, {\"x\": 2.753623188405797, \"y\": 7.391304347826086, \"x2\": 3.0434782608695645, \"y2\": 7.681159420289854, \"center_x\": 2.8985507246376807, \"center_y\": 7.53623188405797, \"value_uncond\": 0.008562645294301409}, {\"x\": 3.0434782608695663, \"y\": 7.391304347826086, \"x2\": 3.333333333333334, \"y2\": 7.681159420289854, \"center_x\": 3.18840579710145, \"center_y\": 7.53623188405797, \"value_uncond\": 0.008871843221503157}, {\"x\": 3.333333333333334, \"y\": 7.391304347826086, \"x2\": 3.6231884057971016, \"y2\": 7.681159420289854, \"center_x\": 3.4782608695652177, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0091067953658272}, {\"x\": 3.6231884057971016, \"y\": 7.391304347826086, \"x2\": 3.913043478260869, \"y2\": 7.681159420289854, \"center_x\": 3.7681159420289854, \"center_y\": 7.53623188405797, \"value_uncond\": 0.009261111473147477}, {\"x\": 3.913043478260871, \"y\": 7.391304347826086, \"x2\": 4.202898550724639, \"y2\": 7.681159420289854, \"center_x\": 4.057971014492755, \"center_y\": 7.53623188405797, \"value_uncond\": 0.009330533147259464}, {\"x\": 4.202898550724639, \"y\": 7.391304347826086, \"x2\": 4.492753623188406, \"y2\": 7.681159420289854, \"center_x\": 4.347826086956522, \"center_y\": 7.53623188405797, \"value_uncond\": 0.009313129094118662}, {\"x\": 4.492753623188406, \"y\": 7.391304347826086, \"x2\": 4.782608695652174, \"y2\": 7.681159420289854, \"center_x\": 4.63768115942029, \"center_y\": 7.53623188405797, \"value_uncond\": 0.009209384391785931}, {\"x\": 4.782608695652174, \"y\": 7.391304347826086, \"x2\": 5.0724637681159415, \"y2\": 7.681159420289854, \"center_x\": 4.927536231884058, \"center_y\": 7.53623188405797, \"value_uncond\": 0.009022178027074335}, {\"x\": 5.072463768115943, \"y\": 7.391304347826086, \"x2\": 5.362318840579711, \"y2\": 7.681159420289854, \"center_x\": 5.217391304347827, \"center_y\": 7.53623188405797, \"value_uncond\": 0.00875665015074523}, {\"x\": 5.362318840579711, \"y\": 7.391304347826086, \"x2\": 5.6521739130434785, \"y2\": 7.681159420289854, \"center_x\": 5.507246376811595, \"center_y\": 7.53623188405797, \"value_uncond\": 0.008419967593680685}, {\"x\": 5.6521739130434785, \"y\": 7.391304347826086, \"x2\": 5.942028985507246, \"y2\": 7.681159420289854, \"center_x\": 5.797101449275362, \"center_y\": 7.53623188405797, \"value_uncond\": 0.008021002572427181}, {\"x\": 5.942028985507246, \"y\": 7.391304347826086, \"x2\": 6.231884057971014, \"y2\": 7.681159420289854, \"center_x\": 6.08695652173913, \"center_y\": 7.53623188405797, \"value_uncond\": 0.007569944680339263}, {\"x\": 6.2318840579710155, \"y\": 7.391304347826086, \"x2\": 6.521739130434783, \"y2\": 7.681159420289854, \"center_x\": 6.376811594202899, \"center_y\": 7.53623188405797, \"value_uncond\": 0.00707786981783574}, {\"x\": 6.521739130434785, \"y\": 7.391304347826086, \"x2\": 6.8115942028985526, \"y2\": 7.681159420289854, \"center_x\": 6.666666666666669, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0065562914268104434}, {\"x\": 6.811594202898551, \"y\": 7.391304347826086, \"x2\": 7.101449275362318, \"y2\": 7.681159420289854, \"center_x\": 6.956521739130435, \"center_y\": 7.53623188405797, \"value_uncond\": 0.00601671920005302}, {\"x\": 7.10144927536232, \"y\": 7.391304347826086, \"x2\": 7.391304347826088, \"y2\": 7.681159420289854, \"center_x\": 7.246376811594204, \"center_y\": 7.53623188405797, \"value_uncond\": 0.005470248450373667}, {\"x\": 7.391304347826086, \"y\": 7.391304347826086, \"x2\": 7.681159420289854, \"y2\": 7.681159420289854, \"center_x\": 7.53623188405797, \"center_y\": 7.53623188405797, \"value_uncond\": 0.00492719981332962}, {\"x\": 7.681159420289855, \"y\": 7.391304347826086, \"x2\": 7.971014492753623, \"y2\": 7.681159420289854, \"center_x\": 7.826086956521739, \"center_y\": 7.53623188405797, \"value_uncond\": 0.004396824307575778}, {\"x\": 7.971014492753625, \"y\": 7.391304347826086, \"x2\": 8.260869565217392, \"y2\": 7.681159420289854, \"center_x\": 8.115942028985508, \"center_y\": 7.53623188405797, \"value_uncond\": 0.003887083446008268}, {\"x\": 8.26086956521739, \"y\": 7.391304347826086, \"x2\": 8.550724637681158, \"y2\": 7.681159420289854, \"center_x\": 8.405797101449274, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0034045085596694285}, {\"x\": 8.55072463768116, \"y\": 7.391304347826086, \"x2\": 8.840579710144928, \"y2\": 7.681159420289854, \"center_x\": 8.695652173913043, \"center_y\": 7.53623188405797, \"value_uncond\": 0.002954138219697305}, {\"x\": 8.84057971014493, \"y\": 7.391304347826086, \"x2\": 9.130434782608697, \"y2\": 7.681159420289854, \"center_x\": 8.985507246376812, \"center_y\": 7.53623188405797, \"value_uncond\": 0.002539528008263621}, {\"x\": 9.130434782608695, \"y\": 7.391304347826086, \"x2\": 9.420289855072463, \"y2\": 7.681159420289854, \"center_x\": 9.275362318840578, \"center_y\": 7.53623188405797, \"value_uncond\": 0.002162823188057047}, {\"x\": 9.420289855072465, \"y\": 7.391304347826086, \"x2\": 9.710144927536232, \"y2\": 7.681159420289854, \"center_x\": 9.565217391304348, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0018248822279375043}, {\"x\": 9.710144927536234, \"y\": 7.391304347826086, \"x2\": 10.000000000000002, \"y2\": 7.681159420289854, \"center_x\": 9.855072463768117, \"center_y\": 7.53623188405797, \"value_uncond\": 0.001525437719179798}, {\"x\": 10.0, \"y\": 7.391304347826086, \"x2\": 10.289855072463768, \"y2\": 7.681159420289854, \"center_x\": 10.144927536231883, \"center_y\": 7.53623188405797, \"value_uncond\": 0.001263280913597526}, {\"x\": -10.0, \"y\": 7.681159420289855, \"x2\": -9.710144927536232, \"y2\": 7.971014492753623, \"center_x\": -9.855072463768117, \"center_y\": 7.826086956521739, \"value_uncond\": 1.5546888264731634e-07}, {\"x\": -9.710144927536232, \"y\": 7.681159420289855, \"x2\": -9.420289855072465, \"y2\": 7.971014492753623, \"center_x\": -9.565217391304348, \"center_y\": 7.826086956521739, \"value_uncond\": 2.4290337117625886e-07}, {\"x\": -9.420289855072463, \"y\": 7.681159420289855, \"x2\": -9.130434782608695, \"y2\": 7.971014492753623, \"center_x\": -9.275362318840578, \"center_y\": 7.826086956521739, \"value_uncond\": 3.7598405010178783e-07}, {\"x\": -9.130434782608695, \"y\": 7.681159420289855, \"x2\": -8.840579710144928, \"y2\": 7.971014492753623, \"center_x\": -8.985507246376812, \"center_y\": 7.826086956521739, \"value_uncond\": 5.765687711008647e-07}, {\"x\": -8.840579710144928, \"y\": 7.681159420289855, \"x2\": -8.55072463768116, \"y2\": 7.971014492753623, \"center_x\": -8.695652173913043, \"center_y\": 7.826086956521739, \"value_uncond\": 8.759486032096825e-07}, {\"x\": -8.55072463768116, \"y\": 7.681159420289855, \"x2\": -8.260869565217392, \"y2\": 7.971014492753623, \"center_x\": -8.405797101449277, \"center_y\": 7.826086956521739, \"value_uncond\": 1.3184144295520983e-06}, {\"x\": -8.26086956521739, \"y\": 7.681159420289855, \"x2\": -7.971014492753623, \"y2\": 7.971014492753623, \"center_x\": -8.115942028985508, \"center_y\": 7.826086956521739, \"value_uncond\": 1.965943739567227e-06}, {\"x\": -7.971014492753623, \"y\": 7.681159420289855, \"x2\": -7.681159420289855, \"y2\": 7.971014492753623, \"center_x\": -7.826086956521739, \"center_y\": 7.826086956521739, \"value_uncond\": 2.9042636382649264e-06}, {\"x\": -7.681159420289855, \"y\": 7.681159420289855, \"x2\": -7.391304347826088, \"y2\": 7.971014492753623, \"center_x\": -7.536231884057972, \"center_y\": 7.826086956521739, \"value_uncond\": 4.250566393509563e-06}, {\"x\": -7.391304347826087, \"y\": 7.681159420289855, \"x2\": -7.101449275362319, \"y2\": 7.971014492753623, \"center_x\": -7.246376811594203, \"center_y\": 7.826086956521739, \"value_uncond\": 6.163159191628511e-06}, {\"x\": -7.101449275362318, \"y\": 7.681159420289855, \"x2\": -6.811594202898551, \"y2\": 7.971014492753623, \"center_x\": -6.956521739130435, \"center_y\": 7.826086956521739, \"value_uncond\": 8.853312241759115e-06}, {\"x\": -6.811594202898551, \"y\": 7.681159420289855, \"x2\": -6.521739130434783, \"y2\": 7.971014492753623, \"center_x\": -6.666666666666667, \"center_y\": 7.826086956521739, \"value_uncond\": 1.2599519752427816e-05}, {\"x\": -6.521739130434782, \"y\": 7.681159420289855, \"x2\": -6.231884057971015, \"y2\": 7.971014492753623, \"center_x\": -6.3768115942028984, \"center_y\": 7.826086956521739, \"value_uncond\": 1.7764296637283633e-05}, {\"x\": -6.231884057971014, \"y\": 7.681159420289855, \"x2\": -5.942028985507246, \"y2\": 7.971014492753623, \"center_x\": -6.08695652173913, \"center_y\": 7.826086956521739, \"value_uncond\": 2.4813490246015368e-05}, {\"x\": -5.942028985507246, \"y\": 7.681159420289855, \"x2\": -5.6521739130434785, \"y2\": 7.971014492753623, \"center_x\": -5.797101449275362, \"center_y\": 7.826086956521739, \"value_uncond\": 3.43378824915426e-05}, {\"x\": -5.6521739130434785, \"y\": 7.681159420289855, \"x2\": -5.362318840579711, \"y2\": 7.971014492753623, \"center_x\": -5.507246376811595, \"center_y\": 7.826086956521739, \"value_uncond\": 4.707658799450714e-05}, {\"x\": -5.36231884057971, \"y\": 7.681159420289855, \"x2\": -5.072463768115942, \"y2\": 7.971014492753623, \"center_x\": -5.217391304347826, \"center_y\": 7.826086956521739, \"value_uncond\": 6.394141777973048e-05}, {\"x\": -5.0724637681159415, \"y\": 7.681159420289855, \"x2\": -4.782608695652174, \"y2\": 7.971014492753623, \"center_x\": -4.927536231884058, \"center_y\": 7.826086956521739, \"value_uncond\": 8.604098217792227e-05}, {\"x\": -4.782608695652174, \"y\": 7.681159420289855, \"x2\": -4.492753623188406, \"y2\": 7.971014492753623, \"center_x\": -4.63768115942029, \"center_y\": 7.826086956521739, \"value_uncond\": 0.00011470286653516983}, {\"x\": -4.492753623188405, \"y\": 7.681159420289855, \"x2\": -4.202898550724638, \"y2\": 7.971014492753623, \"center_x\": -4.3478260869565215, \"center_y\": 7.826086956521739, \"value_uncond\": 0.00015149175546875064}, {\"x\": -4.202898550724638, \"y\": 7.681159420289855, \"x2\": -3.91304347826087, \"y2\": 7.971014492753623, \"center_x\": -4.057971014492754, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0001982209436974218}, {\"x\": -3.913043478260869, \"y\": 7.681159420289855, \"x2\": -3.6231884057971016, \"y2\": 7.971014492753623, \"center_x\": -3.7681159420289854, \"center_y\": 7.826086956521739, \"value_uncond\": 0.00025695430320070645}, {\"x\": -3.6231884057971016, \"y\": 7.681159420289855, \"x2\": -3.333333333333334, \"y2\": 7.971014492753623, \"center_x\": -3.4782608695652177, \"center_y\": 7.826086956521739, \"value_uncond\": 0.00032999553637280677}, {\"x\": -3.333333333333333, \"y\": 7.681159420289855, \"x2\": -3.0434782608695654, \"y2\": 7.971014492753623, \"center_x\": -3.1884057971014492, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0004198614974519994}, {\"x\": -3.0434782608695645, \"y\": 7.681159420289855, \"x2\": -2.753623188405797, \"y2\": 7.971014492753623, \"center_x\": -2.8985507246376807, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0005292365744719645}, {\"x\": -2.753623188405797, \"y\": 7.681159420289855, \"x2\": -2.4637681159420293, \"y2\": 7.971014492753623, \"center_x\": -2.608695652173913, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0006609056486189536}, {\"x\": -2.4637681159420284, \"y\": 7.681159420289855, \"x2\": -2.1739130434782608, \"y2\": 7.971014492753623, \"center_x\": -2.3188405797101446, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0008176640283809533}, {\"x\": -2.1739130434782608, \"y\": 7.681159420289855, \"x2\": -1.8840579710144931, \"y2\": 7.971014492753623, \"center_x\": -2.028985507246377, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0010022040079425468}, {\"x\": -1.8840579710144922, \"y\": 7.681159420289855, \"x2\": -1.5942028985507246, \"y2\": 7.971014492753623, \"center_x\": -1.7391304347826084, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0012169793043008256}, {\"x\": -1.5942028985507246, \"y\": 7.681159420289855, \"x2\": -1.304347826086957, \"y2\": 7.971014492753623, \"center_x\": -1.4492753623188408, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0014640505256925686}, {\"x\": -1.304347826086957, \"y\": 7.681159420289855, \"x2\": -1.0144927536231894, \"y2\": 7.971014492753623, \"center_x\": -1.1594202898550732, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0017449169103885887}, {\"x\": -1.0144927536231876, \"y\": 7.681159420289855, \"x2\": -0.72463768115942, \"y2\": 7.971014492753623, \"center_x\": -0.8695652173913038, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0020603417010928485}, {\"x\": -0.72463768115942, \"y\": 7.681159420289855, \"x2\": -0.43478260869565233, \"y2\": 7.971014492753623, \"center_x\": -0.5797101449275361, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0024101805001465392}, {\"x\": -0.43478260869565233, \"y\": 7.681159420289855, \"x2\": -0.1449275362318847, \"y2\": 7.971014492753623, \"center_x\": -0.2898550724637685, \"center_y\": 7.826086956521739, \"value_uncond\": 0.002793223573848532}, {\"x\": -0.14492753623188293, \"y\": 7.681159420289855, \"x2\": 0.1449275362318847, \"y2\": 7.971014492753623, \"center_x\": 8.881784197001252e-16, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0032070641234048475}, {\"x\": 0.1449275362318847, \"y\": 7.681159420289855, \"x2\": 0.43478260869565233, \"y2\": 7.971014492753623, \"center_x\": 0.2898550724637685, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0036480048145421467}, {\"x\": 0.43478260869565233, \"y\": 7.681159420289855, \"x2\": 0.72463768115942, \"y2\": 7.971014492753623, \"center_x\": 0.5797101449275361, \"center_y\": 7.826086956521739, \"value_uncond\": 0.004111014198259955}, {\"x\": 0.72463768115942, \"y\": 7.681159420289855, \"x2\": 1.0144927536231876, \"y2\": 7.971014492753623, \"center_x\": 0.8695652173913038, \"center_y\": 7.826086956521739, \"value_uncond\": 0.004589742968136519}, {\"x\": 1.0144927536231894, \"y\": 7.681159420289855, \"x2\": 1.304347826086957, \"y2\": 7.971014492753623, \"center_x\": 1.1594202898550732, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0050766072785315055}, {\"x\": 1.304347826086957, \"y\": 7.681159420289855, \"x2\": 1.5942028985507246, \"y2\": 7.971014492753623, \"center_x\": 1.4492753623188408, \"center_y\": 7.826086956521739, \"value_uncond\": 0.005562942687262318}, {\"x\": 1.5942028985507246, \"y\": 7.681159420289855, \"x2\": 1.8840579710144922, \"y2\": 7.971014492753623, \"center_x\": 1.7391304347826084, \"center_y\": 7.826086956521739, \"value_uncond\": 0.006039227885113773}, {\"x\": 1.884057971014494, \"y\": 7.681159420289855, \"x2\": 2.1739130434782616, \"y2\": 7.971014492753623, \"center_x\": 2.028985507246378, \"center_y\": 7.826086956521739, \"value_uncond\": 0.006495372529400421}, {\"x\": 2.1739130434782616, \"y\": 7.681159420289855, \"x2\": 2.4637681159420293, \"y2\": 7.971014492753623, \"center_x\": 2.3188405797101455, \"center_y\": 7.826086956521739, \"value_uncond\": 0.006921058583596764}, {\"x\": 2.4637681159420293, \"y\": 7.681159420289855, \"x2\": 2.753623188405797, \"y2\": 7.971014492753623, \"center_x\": 2.608695652173913, \"center_y\": 7.826086956521739, \"value_uncond\": 0.007306119999745298}, {\"x\": 2.753623188405797, \"y\": 7.681159420289855, \"x2\": 3.0434782608695645, \"y2\": 7.971014492753623, \"center_x\": 2.8985507246376807, \"center_y\": 7.826086956521739, \"value_uncond\": 0.00764094179117375}, {\"x\": 3.0434782608695663, \"y\": 7.681159420289855, \"x2\": 3.333333333333334, \"y2\": 7.971014492753623, \"center_x\": 3.18840579710145, \"center_y\": 7.826086956521739, \"value_uncond\": 0.007916856918158218}, {\"x\": 3.333333333333334, \"y\": 7.681159420289855, \"x2\": 3.6231884057971016, \"y2\": 7.971014492753623, \"center_x\": 3.4782608695652177, \"center_y\": 7.826086956521739, \"value_uncond\": 0.008126518254904964}, {\"x\": 3.6231884057971016, \"y\": 7.681159420289855, \"x2\": 3.913043478260869, \"y2\": 7.971014492753623, \"center_x\": 3.7681159420289854, \"center_y\": 7.826086956521739, \"value_uncond\": 0.008264223409439334}, {\"x\": 3.913043478260871, \"y\": 7.681159420289855, \"x2\": 4.202898550724639, \"y2\": 7.971014492753623, \"center_x\": 4.057971014492755, \"center_y\": 7.826086956521739, \"value_uncond\": 0.008326172369451556}, {\"x\": 4.202898550724639, \"y\": 7.681159420289855, \"x2\": 4.492753623188406, \"y2\": 7.971014492753623, \"center_x\": 4.347826086956522, \"center_y\": 7.826086956521739, \"value_uncond\": 0.00831064172998108}, {\"x\": 4.492753623188406, \"y\": 7.681159420289855, \"x2\": 4.782608695652174, \"y2\": 7.971014492753623, \"center_x\": 4.63768115942029, \"center_y\": 7.826086956521739, \"value_uncond\": 0.008218064354132682}, {\"x\": 4.782608695652174, \"y\": 7.681159420289855, \"x2\": 5.0724637681159415, \"y2\": 7.971014492753623, \"center_x\": 4.927536231884058, \"center_y\": 7.826086956521739, \"value_uncond\": 0.008051009327732077}, {\"x\": 5.072463768115943, \"y\": 7.681159420289855, \"x2\": 5.362318840579711, \"y2\": 7.971014492753623, \"center_x\": 5.217391304347827, \"center_y\": 7.826086956521739, \"value_uncond\": 0.007814063503488377}, {\"x\": 5.362318840579711, \"y\": 7.681159420289855, \"x2\": 5.6521739130434785, \"y2\": 7.971014492753623, \"center_x\": 5.507246376811595, \"center_y\": 7.826086956521739, \"value_uncond\": 0.007513622257563381}, {\"x\": 5.6521739130434785, \"y\": 7.681159420289855, \"x2\": 5.942028985507246, \"y2\": 7.971014492753623, \"center_x\": 5.797101449275362, \"center_y\": 7.826086956521739, \"value_uncond\": 0.007157602780014635}, {\"x\": 5.942028985507246, \"y\": 7.681159420289855, \"x2\": 6.231884057971014, \"y2\": 7.971014492753623, \"center_x\": 6.08695652173913, \"center_y\": 7.826086956521739, \"value_uncond\": 0.00675509783213515}, {\"x\": 6.2318840579710155, \"y\": 7.681159420289855, \"x2\": 6.521739130434783, \"y2\": 7.971014492753623, \"center_x\": 6.376811594202899, \"center_y\": 7.826086956521739, \"value_uncond\": 0.00631599107808199}, {\"x\": 6.521739130434785, \"y\": 7.681159420289855, \"x2\": 6.8115942028985526, \"y2\": 7.971014492753623, \"center_x\": 6.666666666666669, \"center_y\": 7.826086956521739, \"value_uncond\": 0.005850556625482317}, {\"x\": 6.811594202898551, \"y\": 7.681159420289855, \"x2\": 7.101449275362318, \"y2\": 7.971014492753623, \"center_x\": 6.956521739130435, \"center_y\": 7.826086956521739, \"value_uncond\": 0.00536906523642159}, {\"x\": 7.10144927536232, \"y\": 7.681159420289855, \"x2\": 7.391304347826088, \"y2\": 7.971014492753623, \"center_x\": 7.246376811594204, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0048814178978522915}, {\"x\": 7.391304347826086, \"y\": 7.681159420289855, \"x2\": 7.681159420289854, \"y2\": 7.971014492753623, \"center_x\": 7.53623188405797, \"center_y\": 7.826086956521739, \"value_uncond\": 0.004396824307575778}, {\"x\": 7.681159420289855, \"y\": 7.681159420289855, \"x2\": 7.971014492753623, \"y2\": 7.971014492753623, \"center_x\": 7.826086956521739, \"center_y\": 7.826086956521739, \"value_uncond\": 0.003923539682598204}, {\"x\": 7.971014492753625, \"y\": 7.681159420289855, \"x2\": 8.260869565217392, \"y2\": 7.971014492753623, \"center_x\": 8.115942028985508, \"center_y\": 7.826086956521739, \"value_uncond\": 0.003468668539633514}, {\"x\": 8.26086956521739, \"y\": 7.681159420289855, \"x2\": 8.550724637681158, \"y2\": 7.971014492753623, \"center_x\": 8.405797101449274, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0030380391617178667}, {\"x\": 8.55072463768116, \"y\": 7.681159420289855, \"x2\": 8.840579710144928, \"y2\": 7.971014492753623, \"center_x\": 8.695652173913043, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0026361477562092976}, {\"x\": 8.84057971014493, \"y\": 7.681159420289855, \"x2\": 9.130434782608697, \"y2\": 7.971014492753623, \"center_x\": 8.985507246376812, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0022661671739586946}, {\"x\": 9.130434782608695, \"y\": 7.681159420289855, \"x2\": 9.420289855072463, \"y2\": 7.971014492753623, \"center_x\": 9.275362318840578, \"center_y\": 7.826086956521739, \"value_uncond\": 0.001930011756477064}, {\"x\": 9.420289855072465, \"y\": 7.681159420289855, \"x2\": 9.710144927536232, \"y2\": 7.971014492753623, \"center_x\": 9.565217391304348, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0016284475649946393}, {\"x\": 9.710144927536234, \"y\": 7.681159420289855, \"x2\": 10.000000000000002, \"y2\": 7.971014492753623, \"center_x\": 9.855072463768117, \"center_y\": 7.826086956521739, \"value_uncond\": 0.001361235975297355}, {\"x\": 10.0, \"y\": 7.681159420289855, \"x2\": 10.289855072463768, \"y2\": 7.971014492753623, \"center_x\": 10.144927536231883, \"center_y\": 7.826086956521739, \"value_uncond\": 0.001127298351728233}, {\"x\": -10.0, \"y\": 7.971014492753625, \"x2\": -9.710144927536232, \"y2\": 8.260869565217392, \"center_x\": -9.855072463768117, \"center_y\": 8.115942028985508, \"value_uncond\": 1.3744477328023635e-07}, {\"x\": -9.710144927536232, \"y\": 7.971014492753625, \"x2\": -9.420289855072465, \"y2\": 8.260869565217392, \"center_x\": -9.565217391304348, \"center_y\": 8.115942028985508, \"value_uncond\": 2.1474264310538734e-07}, {\"x\": -9.420289855072463, \"y\": 7.971014492753625, \"x2\": -9.130434782608695, \"y2\": 8.260869565217392, \"center_x\": -9.275362318840578, \"center_y\": 8.115942028985508, \"value_uncond\": 3.32394763783409e-07}, {\"x\": -9.130434782608695, \"y\": 7.971014492753625, \"x2\": -8.840579710144928, \"y2\": 8.260869565217392, \"center_x\": -8.985507246376812, \"center_y\": 8.115942028985508, \"value_uncond\": 5.097249216371772e-07}, {\"x\": -8.840579710144928, \"y\": 7.971014492753625, \"x2\": -8.55072463768116, \"y2\": 8.260869565217392, \"center_x\": -8.695652173913043, \"center_y\": 8.115942028985508, \"value_uncond\": 7.74396490945468e-07}, {\"x\": -8.55072463768116, \"y\": 7.971014492753625, \"x2\": -8.260869565217392, \"y2\": 8.260869565217392, \"center_x\": -8.405797101449277, \"center_y\": 8.115942028985508, \"value_uncond\": 1.165565541306785e-06}, {\"x\": -8.26086956521739, \"y\": 7.971014492753625, \"x2\": -7.971014492753623, \"y2\": 8.260869565217392, \"center_x\": -8.115942028985508, \"center_y\": 8.115942028985508, \"value_uncond\": 1.7380242719019876e-06}, {\"x\": -7.971014492753623, \"y\": 7.971014492753625, \"x2\": -7.681159420289855, \"y2\": 8.260869565217392, \"center_x\": -7.826086956521739, \"center_y\": 8.115942028985508, \"value_uncond\": 2.567561112617595e-06}, {\"x\": -7.681159420289855, \"y\": 7.971014492753625, \"x2\": -7.391304347826088, \"y2\": 8.260869565217392, \"center_x\": -7.536231884057972, \"center_y\": 8.115942028985508, \"value_uncond\": 3.7577817780669465e-06}, {\"x\": -7.391304347826087, \"y\": 7.971014492753625, \"x2\": -7.101449275362319, \"y2\": 8.260869565217392, \"center_x\": -7.246376811594203, \"center_y\": 8.115942028985508, \"value_uncond\": 5.448640289677979e-06}, {\"x\": -7.101449275362318, \"y\": 7.971014492753625, \"x2\": -6.811594202898551, \"y2\": 8.260869565217392, \"center_x\": -6.956521739130435, \"center_y\": 8.115942028985508, \"value_uncond\": 7.826913483440587e-06}, {\"x\": -6.811594202898551, \"y\": 7.971014492753625, \"x2\": -6.521739130434783, \"y2\": 8.260869565217392, \"center_x\": -6.666666666666667, \"center_y\": 8.115942028985508, \"value_uncond\": 1.1138808656268394e-05}, {\"x\": -6.521739130434782, \"y\": 7.971014492753625, \"x2\": -6.231884057971015, \"y2\": 8.260869565217392, \"center_x\": -6.3768115942028984, \"center_y\": 8.115942028985508, \"value_uncond\": 1.5704812964618436e-05}, {\"x\": -6.231884057971014, \"y\": 7.971014492753625, \"x2\": -5.942028985507246, \"y2\": 8.260869565217392, \"center_x\": -6.08695652173913, \"center_y\": 8.115942028985508, \"value_uncond\": 2.1936766271689755e-05}, {\"x\": -5.942028985507246, \"y\": 7.971014492753625, \"x2\": -5.6521739130434785, \"y2\": 8.260869565217392, \"center_x\": -5.797101449275362, \"center_y\": 8.115942028985508, \"value_uncond\": 3.035695885638976e-05}, {\"x\": -5.6521739130434785, \"y\": 7.971014492753625, \"x2\": -5.362318840579711, \"y2\": 8.260869565217392, \"center_x\": -5.507246376811595, \"center_y\": 8.115942028985508, \"value_uncond\": 4.161881692036346e-05}, {\"x\": -5.36231884057971, \"y\": 7.971014492753625, \"x2\": -5.072463768115942, \"y2\": 8.260869565217392, \"center_x\": -5.217391304347826, \"center_y\": 8.115942028985508, \"value_uncond\": 5.652844170681143e-05}, {\"x\": -5.0724637681159415, \"y\": 7.971014492753625, \"x2\": -4.782608695652174, \"y2\": 8.260869565217392, \"center_x\": -4.927536231884058, \"center_y\": 8.115942028985508, \"value_uncond\": 7.606591805950384e-05}, {\"x\": -4.782608695652174, \"y\": 7.971014492753625, \"x2\": -4.492753623188406, \"y2\": 8.260869565217392, \"center_x\": -4.63768115942029, \"center_y\": 8.115942028985508, \"value_uncond\": 0.00010140491921642922}, {\"x\": -4.492753623188405, \"y\": 7.971014492753625, \"x2\": -4.202898550724638, \"y2\": 8.260869565217392, \"center_x\": -4.3478260869565215, \"center_y\": 8.115942028985508, \"value_uncond\": 0.00013392872985047388}, {\"x\": -4.202898550724638, \"y\": 7.971014492753625, \"x2\": -3.91304347826087, \"y2\": 8.260869565217392, \"center_x\": -4.057971014492754, \"center_y\": 8.115942028985508, \"value_uncond\": 0.00017524042240459845}, {\"x\": -3.913043478260869, \"y\": 7.971014492753625, \"x2\": -3.6231884057971016, \"y2\": 8.260869565217392, \"center_x\": -3.7681159420289854, \"center_y\": 8.115942028985508, \"value_uncond\": 0.00022716459619073407}, {\"x\": -3.6231884057971016, \"y\": 7.971014492753625, \"x2\": -3.333333333333334, \"y2\": 8.260869565217392, \"center_x\": -3.4782608695652177, \"center_y\": 8.115942028985508, \"value_uncond\": 0.00029173787646716157}, {\"x\": -3.333333333333333, \"y\": 7.971014492753625, \"x2\": -3.0434782608695654, \"y2\": 8.260869565217392, \"center_x\": -3.1884057971014492, \"center_y\": 8.115942028985508, \"value_uncond\": 0.00037118532881786785}, {\"x\": -3.0434782608695645, \"y\": 7.971014492753625, \"x2\": -2.753623188405797, \"y2\": 8.260869565217392, \"center_x\": -2.8985507246376807, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0004678801297808371}, {\"x\": -2.753623188405797, \"y\": 7.971014492753625, \"x2\": -2.4637681159420293, \"y2\": 8.260869565217392, \"center_x\": -2.608695652173913, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0005842842984864515}, {\"x\": -2.4637681159420284, \"y\": 7.971014492753625, \"x2\": -2.1739130434782608, \"y2\": 8.260869565217392, \"center_x\": -2.3188405797101446, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0007228690724893741}, {\"x\": -2.1739130434782608, \"y\": 7.971014492753625, \"x2\": -1.8840579710144931, \"y2\": 8.260869565217392, \"center_x\": -2.028985507246377, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0008860146178878153}, {\"x\": -1.8840579710144922, \"y\": 7.971014492753625, \"x2\": -1.5942028985507246, \"y2\": 8.260869565217392, \"center_x\": -1.7391304347826084, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0010758901827693436}, {\"x\": -1.5942028985507246, \"y\": 7.971014492753625, \"x2\": -1.304347826086957, \"y2\": 8.260869565217392, \"center_x\": -1.4492753623188408, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0012943174810814762}, {\"x\": -1.304347826086957, \"y\": 7.971014492753625, \"x2\": -1.0144927536231894, \"y2\": 8.260869565217392, \"center_x\": -1.1594202898550732, \"center_y\": 8.115942028985508, \"value_uncond\": 0.001542621938598914}, {\"x\": -1.0144927536231876, \"y\": 7.971014492753625, \"x2\": -0.72463768115942, \"y2\": 8.260869565217392, \"center_x\": -0.8695652173913038, \"center_y\": 8.115942028985508, \"value_uncond\": 0.001821478312344528}, {\"x\": -0.72463768115942, \"y\": 7.971014492753625, \"x2\": -0.43478260869565233, \"y2\": 8.260869565217392, \"center_x\": -0.5797101449275361, \"center_y\": 8.115942028985508, \"value_uncond\": 0.00213075894523904}, {\"x\": -0.43478260869565233, \"y\": 7.971014492753625, \"x2\": -0.1449275362318847, \"y2\": 8.260869565217392, \"center_x\": -0.2898550724637685, \"center_y\": 8.115942028985508, \"value_uncond\": 0.002469394352692033}, {\"x\": -0.14492753623188293, \"y\": 7.971014492753625, \"x2\": 0.1449275362318847, \"y2\": 8.260869565217392, \"center_x\": 8.881784197001252e-16, \"center_y\": 8.115942028985508, \"value_uncond\": 0.002835256765410144}, {\"x\": 0.1449275362318847, \"y\": 7.971014492753625, \"x2\": 0.43478260869565233, \"y2\": 8.260869565217392, \"center_x\": 0.2898550724637685, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0032250774953942927}, {\"x\": 0.43478260869565233, \"y\": 7.971014492753625, \"x2\": 0.72463768115942, \"y2\": 8.260869565217392, \"center_x\": 0.5797101449275361, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0036344084090027774}, {\"x\": 0.72463768115942, \"y\": 7.971014492753625, \"x2\": 1.0144927536231876, \"y2\": 8.260869565217392, \"center_x\": 0.8695652173913038, \"center_y\": 8.115942028985508, \"value_uncond\": 0.004057636299484735}, {\"x\": 1.0144927536231894, \"y\": 7.971014492753625, \"x2\": 1.304347826086957, \"y2\": 8.260869565217392, \"center_x\": 1.1594202898550732, \"center_y\": 8.115942028985508, \"value_uncond\": 0.004488056545781094}, {\"x\": 1.304347826086957, \"y\": 7.971014492753625, \"x2\": 1.5942028985507246, \"y2\": 8.260869565217392, \"center_x\": 1.4492753623188408, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0049180092080305235}, {\"x\": 1.5942028985507246, \"y\": 7.971014492753625, \"x2\": 1.8840579710144922, \"y2\": 8.260869565217392, \"center_x\": 1.7391304347826084, \"center_y\": 8.115942028985508, \"value_uncond\": 0.005339076819251023}, {\"x\": 1.884057971014494, \"y\": 7.971014492753625, \"x2\": 2.1739130434782616, \"y2\": 8.260869565217392, \"center_x\": 2.028985507246378, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0057423388492432005}, {\"x\": 2.1739130434782616, \"y\": 7.971014492753625, \"x2\": 2.4637681159420293, \"y2\": 8.260869565217392, \"center_x\": 2.3188405797101455, \"center_y\": 8.115942028985508, \"value_uncond\": 0.006118673471395866}, {\"x\": 2.4637681159420293, \"y\": 7.971014492753625, \"x2\": 2.753623188405797, \"y2\": 8.260869565217392, \"center_x\": 2.608695652173913, \"center_y\": 8.115942028985508, \"value_uncond\": 0.006459093227042803}, {\"x\": 2.753623188405797, \"y\": 7.971014492753625, \"x2\": 3.0434782608695645, \"y2\": 8.260869565217392, \"center_x\": 2.8985507246376807, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0067550978321351445}, {\"x\": 3.0434782608695663, \"y\": 7.971014492753625, \"x2\": 3.333333333333334, \"y2\": 8.260869565217392, \"center_x\": 3.18840579710145, \"center_y\": 8.115942028985508, \"value_uncond\": 0.006999025050413267}, {\"x\": 3.333333333333334, \"y\": 7.971014492753625, \"x2\": 3.6231884057971016, \"y2\": 8.260869565217392, \"center_x\": 3.4782608695652177, \"center_y\": 8.115942028985508, \"value_uncond\": 0.007184379536816565}, {\"x\": 3.6231884057971016, \"y\": 7.971014492753625, \"x2\": 3.913043478260869, \"y2\": 8.260869565217392, \"center_x\": 3.7681159420289854, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0073061199997452924}, {\"x\": 3.913043478260871, \"y\": 7.971014492753625, \"x2\": 4.202898550724639, \"y2\": 8.260869565217392, \"center_x\": 4.057971014492755, \"center_y\": 8.115942028985508, \"value_uncond\": 0.007360886977026152}, {\"x\": 4.202898550724639, \"y\": 7.971014492753625, \"x2\": 4.492753623188406, \"y2\": 8.260869565217392, \"center_x\": 4.347826086956522, \"center_y\": 8.115942028985508, \"value_uncond\": 0.007347156864706769}, {\"x\": 4.492753623188406, \"y\": 7.971014492753625, \"x2\": 4.782608695652174, \"y2\": 8.260869565217392, \"center_x\": 4.63768115942029, \"center_y\": 8.115942028985508, \"value_uncond\": 0.00726531234239662}, {\"x\": 4.782608695652174, \"y\": 7.971014492753625, \"x2\": 5.0724637681159415, \"y2\": 8.260869565217392, \"center_x\": 4.927536231884058, \"center_y\": 8.115942028985508, \"value_uncond\": 0.007117624651857015}, {\"x\": 5.072463768115943, \"y\": 7.971014492753625, \"x2\": 5.362318840579711, \"y2\": 8.260869565217392, \"center_x\": 5.217391304347827, \"center_y\": 8.115942028985508, \"value_uncond\": 0.006908148874207331}, {\"x\": 5.362318840579711, \"y\": 7.971014492753625, \"x2\": 5.6521739130434785, \"y2\": 8.260869565217392, \"center_x\": 5.507246376811595, \"center_y\": 8.115942028985508, \"value_uncond\": 0.00664253894489518}, {\"x\": 5.6521739130434785, \"y\": 7.971014492753625, \"x2\": 5.942028985507246, \"y2\": 8.260869565217392, \"center_x\": 5.797101449275362, \"center_y\": 8.115942028985508, \"value_uncond\": 0.006327794183488224}, {\"x\": 5.942028985507246, \"y\": 7.971014492753625, \"x2\": 6.231884057971014, \"y2\": 8.260869565217392, \"center_x\": 6.08695652173913, \"center_y\": 8.115942028985508, \"value_uncond\": 0.005971953192265764}, {\"x\": 6.2318840579710155, \"y\": 7.971014492753625, \"x2\": 6.521739130434783, \"y2\": 8.260869565217392, \"center_x\": 6.376811594202899, \"center_y\": 8.115942028985508, \"value_uncond\": 0.005583753783940637}, {\"x\": 6.521739130434785, \"y\": 7.971014492753625, \"x2\": 6.8115942028985526, \"y2\": 8.260869565217392, \"center_x\": 6.666666666666669, \"center_y\": 8.115942028985508, \"value_uncond\": 0.005172278949072917}, {\"x\": 6.811594202898551, \"y\": 7.971014492753625, \"x2\": 7.101449275362318, \"y2\": 8.260869565217392, \"center_x\": 6.956521739130435, \"center_y\": 8.115942028985508, \"value_uncond\": 0.004746608720542592}, {\"x\": 7.10144927536232, \"y\": 7.971014492753625, \"x2\": 7.391304347826088, \"y2\": 8.260869565217392, \"center_x\": 7.246376811594204, \"center_y\": 8.115942028985508, \"value_uncond\": 0.004315496225559179}, {\"x\": 7.391304347826086, \"y\": 7.971014492753625, \"x2\": 7.681159420289854, \"y2\": 8.260869565217392, \"center_x\": 7.53623188405797, \"center_y\": 8.115942028985508, \"value_uncond\": 0.003887083446008268}, {\"x\": 7.681159420289855, \"y\": 7.971014492753625, \"x2\": 7.971014492753623, \"y2\": 8.260869565217392, \"center_x\": 7.826086956521739, \"center_y\": 8.115942028985508, \"value_uncond\": 0.003468668539633514}, {\"x\": 7.971014492753625, \"y\": 7.971014492753625, \"x2\": 8.260869565217392, \"y2\": 8.260869565217392, \"center_x\": 8.115942028985508, \"center_y\": 8.115942028985508, \"value_uncond\": 0.003066532369025466}, {\"x\": 8.26086956521739, \"y\": 7.971014492753625, \"x2\": 8.550724637681158, \"y2\": 8.260869565217392, \"center_x\": 8.405797101449274, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0026858275218073005}, {\"x\": 8.55072463768116, \"y\": 7.971014492753625, \"x2\": 8.840579710144928, \"y2\": 8.260869565217392, \"center_x\": 8.695652173913043, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0023305289426137467}, {\"x\": 8.84057971014493, \"y\": 7.971014492753625, \"x2\": 9.130434782608697, \"y2\": 8.260869565217392, \"center_x\": 8.985507246376812, \"center_y\": 8.115942028985508, \"value_uncond\": 0.002003441641414816}, {\"x\": 9.130434782608695, \"y\": 7.971014492753625, \"x2\": 9.420289855072463, \"y2\": 8.260869565217392, \"center_x\": 9.275362318840578, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0017062580226999524}, {\"x\": 9.420289855072465, \"y\": 7.971014492753625, \"x2\": 9.710144927536232, \"y2\": 8.260869565217392, \"center_x\": 9.565217391304348, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0014396553352556355}, {\"x\": 9.710144927536234, \"y\": 7.971014492753625, \"x2\": 10.000000000000002, \"y2\": 8.260869565217392, \"center_x\": 9.855072463768117, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0012034226194966226}, {\"x\": 10.0, \"y\": 7.971014492753625, \"x2\": 10.289855072463768, \"y2\": 8.260869565217392, \"center_x\": 10.144927536231883, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0009966062901729214}, {\"x\": -10.0, \"y\": 8.26086956521739, \"x2\": -9.710144927536232, \"y2\": 8.550724637681158, \"center_x\": -9.855072463768117, \"center_y\": 8.405797101449274, \"value_uncond\": 1.203812353436658e-07}, {\"x\": -9.710144927536232, \"y\": 8.26086956521739, \"x2\": -9.420289855072465, \"y2\": 8.550724637681158, \"center_x\": -9.565217391304348, \"center_y\": 8.405797101449274, \"value_uncond\": 1.880827043548819e-07}, {\"x\": -9.420289855072463, \"y\": 8.26086956521739, \"x2\": -9.130434782608695, \"y2\": 8.550724637681158, \"center_x\": -9.275362318840578, \"center_y\": 8.405797101449274, \"value_uncond\": 2.911285116999536e-07}, {\"x\": -9.130434782608695, \"y\": 8.26086956521739, \"x2\": -8.840579710144928, \"y2\": 8.550724637681158, \"center_x\": -8.985507246376812, \"center_y\": 8.405797101449274, \"value_uncond\": 4.4644342805984316e-07}, {\"x\": -8.840579710144928, \"y\": 8.26086956521739, \"x2\": -8.55072463768116, \"y2\": 8.550724637681158, \"center_x\": -8.695652173913043, \"center_y\": 8.405797101449274, \"value_uncond\": 6.782564662225695e-07}, {\"x\": -8.55072463768116, \"y\": 8.26086956521739, \"x2\": -8.260869565217392, \"y2\": 8.550724637681158, \"center_x\": -8.405797101449277, \"center_y\": 8.405797101449274, \"value_uncond\": 1.020862535459508e-06}, {\"x\": -8.26086956521739, \"y\": 8.26086956521739, \"x2\": -7.971014492753623, \"y2\": 8.550724637681158, \"center_x\": -8.115942028985508, \"center_y\": 8.405797101449274, \"value_uncond\": 1.5222514753780152e-06}, {\"x\": -7.971014492753623, \"y\": 8.26086956521739, \"x2\": -7.681159420289855, \"y2\": 8.550724637681158, \"center_x\": -7.826086956521739, \"center_y\": 8.405797101449274, \"value_uncond\": 2.248802709485845e-06}, {\"x\": -7.681159420289855, \"y\": 8.26086956521739, \"x2\": -7.391304347826088, \"y2\": 8.550724637681158, \"center_x\": -7.536231884057972, \"center_y\": 8.405797101449274, \"value_uncond\": 3.291259476802988e-06}, {\"x\": -7.391304347826087, \"y\": 8.26086956521739, \"x2\": -7.101449275362319, \"y2\": 8.550724637681158, \"center_x\": -7.246376811594203, \"center_y\": 8.405797101449274, \"value_uncond\": 4.772200741874412e-06}, {\"x\": -7.101449275362318, \"y\": 8.26086956521739, \"x2\": -6.811594202898551, \"y2\": 8.550724637681158, \"center_x\": -6.956521739130435, \"center_y\": 8.405797101449274, \"value_uncond\": 6.855215309959383e-06}, {\"x\": -6.811594202898551, \"y\": 8.26086956521739, \"x2\": -6.521739130434783, \"y2\": 8.550724637681158, \"center_x\": -6.666666666666667, \"center_y\": 8.405797101449274, \"value_uncond\": 9.755944255256153e-06}, {\"x\": -6.521739130434782, \"y\": 8.26086956521739, \"x2\": -6.231884057971015, \"y2\": 8.550724637681158, \"center_x\": -6.3768115942028984, \"center_y\": 8.405797101449274, \"value_uncond\": 1.375508679160399e-05}, {\"x\": -6.231884057971014, \"y\": 8.26086956521739, \"x2\": -5.942028985507246, \"y2\": 8.550724637681158, \"center_x\": -6.08695652173913, \"center_y\": 8.405797101449274, \"value_uncond\": 1.921335355435446e-05}, {\"x\": -5.942028985507246, \"y\": 8.26086956521739, \"x2\": -5.6521739130434785, \"y2\": 8.550724637681158, \"center_x\": -5.797101449275362, \"center_y\": 8.405797101449274, \"value_uncond\": 2.658819336082033e-05}, {\"x\": -5.6521739130434785, \"y\": 8.26086956521739, \"x2\": -5.362318840579711, \"y2\": 8.550724637681158, \"center_x\": -5.507246376811595, \"center_y\": 8.405797101449274, \"value_uncond\": 3.645191064632239e-05}, {\"x\": -5.36231884057971, \"y\": 8.26086956521739, \"x2\": -5.072463768115942, \"y2\": 8.550724637681158, \"center_x\": -5.217391304347826, \"center_y\": 8.405797101449274, \"value_uncond\": 4.9510530537554236e-05}, {\"x\": -5.0724637681159415, \"y\": 8.26086956521739, \"x2\": -4.782608695652174, \"y2\": 8.550724637681158, \"center_x\": -4.927536231884058, \"center_y\": 8.405797101449274, \"value_uncond\": 6.662246198975567e-05}, {\"x\": -4.782608695652174, \"y\": 8.26086956521739, \"x2\": -4.492753623188406, \"y2\": 8.550724637681158, \"center_x\": -4.63768115942029, \"center_y\": 8.405797101449274, \"value_uncond\": 8.881566867813159e-05}, {\"x\": -4.492753623188405, \"y\": 8.26086956521739, \"x2\": -4.202898550724638, \"y2\": 8.550724637681158, \"center_x\": -4.3478260869565215, \"center_y\": 8.405797101449274, \"value_uncond\": 0.00011730170280492166}, {\"x\": -4.202898550724638, \"y\": 8.26086956521739, \"x2\": -3.91304347826087, \"y2\": 8.550724637681158, \"center_x\": -4.057971014492754, \"center_y\": 8.405797101449274, \"value_uncond\": 0.00015348461805964338}, {\"x\": -3.913043478260869, \"y\": 8.26086956521739, \"x2\": -3.6231884057971016, \"y2\": 8.550724637681158, \"center_x\": -3.7681159420289854, \"center_y\": 8.405797101449274, \"value_uncond\": 0.00019896249281177862}, {\"x\": -3.6231884057971016, \"y\": 8.26086956521739, \"x2\": -3.333333333333334, \"y2\": 8.550724637681158, \"center_x\": -3.4782608695652177, \"center_y\": 8.405797101449274, \"value_uncond\": 0.000255519108711751}, {\"x\": -3.333333333333333, \"y\": 8.26086956521739, \"x2\": -3.0434782608695654, \"y2\": 8.550724637681158, \"center_x\": -3.1884057971014492, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0003251032931855033}, {\"x\": -3.0434782608695645, \"y\": 8.26086956521739, \"x2\": -2.753623188405797, \"y2\": 8.550724637681158, \"center_x\": -2.8985507246376807, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0004097935968866038}, {\"x\": -2.753623188405797, \"y\": 8.26086956521739, \"x2\": -2.4637681159420293, \"y2\": 8.550724637681158, \"center_x\": -2.608695652173913, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0005117463834022718}, {\"x\": -2.4637681159420284, \"y\": 8.26086956521739, \"x2\": -2.1739130434782608, \"y2\": 8.550724637681158, \"center_x\": -2.3188405797101446, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0006331260902921042}, {\"x\": -2.1739130434782608, \"y\": 8.26086956521739, \"x2\": -1.8840579710144931, \"y2\": 8.550724637681158, \"center_x\": -2.028985507246377, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0007760173900277234}, {\"x\": -1.8840579710144922, \"y\": 8.26086956521739, \"x2\": -1.5942028985507246, \"y2\": 8.550724637681158, \"center_x\": -1.7391304347826084, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0009423202221871583}, {\"x\": -1.5942028985507246, \"y\": 8.26086956521739, \"x2\": -1.304347826086957, \"y2\": 8.550724637681158, \"center_x\": -1.4492753623188408, \"center_y\": 8.405797101449274, \"value_uncond\": 0.001133630137988626}, {\"x\": -1.304347826086957, \"y\": 8.26086956521739, \"x2\": -1.0144927536231894, \"y2\": 8.550724637681158, \"center_x\": -1.1594202898550732, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0013511080138212909}, {\"x\": -1.0144927536231876, \"y\": 8.26086956521739, \"x2\": -0.72463768115942, \"y2\": 8.550724637681158, \"center_x\": -0.8695652173913038, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0015953448367560417}, {\"x\": -0.72463768115942, \"y\": 8.26086956521739, \"x2\": -0.43478260869565233, \"y2\": 8.550724637681158, \"center_x\": -0.5797101449275361, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0018662287981257527}, {\"x\": -0.43478260869565233, \"y\": 8.26086956521739, \"x2\": -0.1449275362318847, \"y2\": 8.550724637681158, \"center_x\": -0.2898550724637685, \"center_y\": 8.405797101449274, \"value_uncond\": 0.002162823188057046}, {\"x\": -0.14492753623188293, \"y\": 8.26086956521739, \"x2\": 0.1449275362318847, \"y2\": 8.550724637681158, \"center_x\": 8.881784197001252e-16, \"center_y\": 8.405797101449274, \"value_uncond\": 0.002483264396243414}, {\"x\": 0.1449275362318847, \"y\": 8.26086956521739, \"x2\": 0.43478260869565233, \"y2\": 8.550724637681158, \"center_x\": 0.2898550724637685, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0028246895368151965}, {\"x\": 0.43478260869565233, \"y\": 8.26086956521739, \"x2\": 0.72463768115942, \"y2\": 8.550724637681158, \"center_x\": 0.5797101449275361, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0031832027044572447}, {\"x\": 0.72463768115942, \"y\": 8.26086956521739, \"x2\": 1.0144927536231876, \"y2\": 8.550724637681158, \"center_x\": 0.8695652173913038, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0035538875626164724}, {\"x\": 1.0144927536231894, \"y\": 8.26086956521739, \"x2\": 1.304347826086957, \"y2\": 8.550724637681158, \"center_x\": 1.1594202898550732, \"center_y\": 8.405797101449274, \"value_uncond\": 0.003930871857686288}, {\"x\": 1.304347826086957, \"y\": 8.26086956521739, \"x2\": 1.5942028985507246, \"y2\": 8.550724637681158, \"center_x\": 1.4492753623188408, \"center_y\": 8.405797101449274, \"value_uncond\": 0.004307446618483881}, {\"x\": 1.5942028985507246, \"y\": 8.26086956521739, \"x2\": 1.8840579710144922, \"y2\": 8.550724637681158, \"center_x\": 1.7391304347826084, \"center_y\": 8.405797101449274, \"value_uncond\": 0.004676239392426481}, {\"x\": 1.884057971014494, \"y\": 8.26086956521739, \"x2\": 2.1739130434782616, \"y2\": 8.550724637681158, \"center_x\": 2.028985507246378, \"center_y\": 8.405797101449274, \"value_uncond\": 0.005029437118168106}, {\"x\": 2.1739130434782616, \"y\": 8.26086956521739, \"x2\": 2.4637681159420293, \"y2\": 8.550724637681158, \"center_x\": 2.3188405797101455, \"center_y\": 8.405797101449274, \"value_uncond\": 0.005359050428562672}, {\"x\": 2.4637681159420293, \"y\": 8.26086956521739, \"x2\": 2.753623188405797, \"y2\": 8.550724637681158, \"center_x\": 2.608695652173913, \"center_y\": 8.405797101449274, \"value_uncond\": 0.005657207642854211}, {\"x\": 2.753623188405797, \"y\": 8.26086956521739, \"x2\": 3.0434782608695645, \"y2\": 8.550724637681158, \"center_x\": 2.8985507246376807, \"center_y\": 8.405797101449274, \"value_uncond\": 0.005916463772992945}, {\"x\": 3.0434782608695663, \"y\": 8.26086956521739, \"x2\": 3.333333333333334, \"y2\": 8.550724637681158, \"center_x\": 3.18840579710145, \"center_y\": 8.405797101449274, \"value_uncond\": 0.00613010783649177}, {\"x\": 3.333333333333334, \"y\": 8.26086956521739, \"x2\": 3.6231884057971016, \"y2\": 8.550724637681158, \"center_x\": 3.4782608695652177, \"center_y\": 8.405797101449274, \"value_uncond\": 0.006292450874478565}, {\"x\": 3.6231884057971016, \"y\": 8.26086956521739, \"x2\": 3.913043478260869, \"y2\": 8.550724637681158, \"center_x\": 3.7681159420289854, \"center_y\": 8.405797101449274, \"value_uncond\": 0.006399077463245162}, {\"x\": 3.913043478260871, \"y\": 8.26086956521739, \"x2\": 4.202898550724639, \"y2\": 8.550724637681158, \"center_x\": 4.057971014492755, \"center_y\": 8.405797101449274, \"value_uncond\": 0.006447045212209076}, {\"x\": 4.202898550724639, \"y\": 8.26086956521739, \"x2\": 4.492753623188406, \"y2\": 8.550724637681158, \"center_x\": 4.347826086956522, \"center_y\": 8.405797101449274, \"value_uncond\": 0.006435019670291634}, {\"x\": 4.492753623188406, \"y\": 8.26086956521739, \"x2\": 4.782608695652174, \"y2\": 8.550724637681158, \"center_x\": 4.63768115942029, \"center_y\": 8.405797101449274, \"value_uncond\": 0.00636333600807103}, {\"x\": 4.782608695652174, \"y\": 8.26086956521739, \"x2\": 5.0724637681159415, \"y2\": 8.550724637681158, \"center_x\": 4.927536231884058, \"center_y\": 8.405797101449274, \"value_uncond\": 0.00623398349645561}, {\"x\": 5.072463768115943, \"y\": 8.26086956521739, \"x2\": 5.362318840579711, \"y2\": 8.550724637681158, \"center_x\": 5.217391304347827, \"center_y\": 8.405797101449274, \"value_uncond\": 0.006050513785049202}, {\"x\": 5.362318840579711, \"y\": 8.26086956521739, \"x2\": 5.6521739130434785, \"y2\": 8.550724637681158, \"center_x\": 5.507246376811595, \"center_y\": 8.405797101449274, \"value_uncond\": 0.005817878882702297}, {\"x\": 5.6521739130434785, \"y\": 8.26086956521739, \"x2\": 5.942028985507246, \"y2\": 8.550724637681158, \"center_x\": 5.797101449275362, \"center_y\": 8.405797101449274, \"value_uncond\": 0.005542209155204808}, {\"x\": 5.942028985507246, \"y\": 8.26086956521739, \"x2\": 6.231884057971014, \"y2\": 8.550724637681158, \"center_x\": 6.08695652173913, \"center_y\": 8.405797101449274, \"value_uncond\": 0.00523054522585382}, {\"x\": 6.2318840579710155, \"y\": 8.26086956521739, \"x2\": 6.521739130434783, \"y2\": 8.550724637681158, \"center_x\": 6.376811594202899, \"center_y\": 8.405797101449274, \"value_uncond\": 0.004890540122578068}, {\"x\": 6.521739130434785, \"y\": 8.26086956521739, \"x2\": 6.8115942028985526, \"y2\": 8.550724637681158, \"center_x\": 6.666666666666669, \"center_y\": 8.405797101449274, \"value_uncond\": 0.004530149197903092}, {\"x\": 6.811594202898551, \"y\": 8.26086956521739, \"x2\": 7.101449275362318, \"y2\": 8.550724637681158, \"center_x\": 6.956521739130435, \"center_y\": 8.405797101449274, \"value_uncond\": 0.004157325213865356}, {\"x\": 7.10144927536232, \"y\": 8.26086956521739, \"x2\": 7.391304347826088, \"y2\": 8.550724637681158, \"center_x\": 7.246376811594204, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0037797346116212206}, {\"x\": 7.391304347826086, \"y\": 8.26086956521739, \"x2\": 7.681159420289854, \"y2\": 8.550724637681158, \"center_x\": 7.53623188405797, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0034045085596694285}, {\"x\": 7.681159420289855, \"y\": 8.26086956521739, \"x2\": 7.971014492753623, \"y2\": 8.550724637681158, \"center_x\": 7.826086956521739, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0030380391617178667}, {\"x\": 7.971014492753625, \"y\": 8.26086956521739, \"x2\": 8.260869565217392, \"y2\": 8.550724637681158, \"center_x\": 8.115942028985508, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0026858275218073005}, {\"x\": 8.26086956521739, \"y\": 8.26086956521739, \"x2\": 8.550724637681158, \"y2\": 8.550724637681158, \"center_x\": 8.405797101449274, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0023523865424548013}, {\"x\": 8.55072463768116, \"y\": 8.26086956521739, \"x2\": 8.840579710144928, \"y2\": 8.550724637681158, \"center_x\": 8.695652173913043, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0020411976855896304}, {\"x\": 8.84057971014493, \"y\": 8.26086956521739, \"x2\": 9.130434782608697, \"y2\": 8.550724637681158, \"center_x\": 8.985507246376812, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0017547177239015214}, {\"x\": 9.130434782608695, \"y\": 8.26086956521739, \"x2\": 9.420289855072463, \"y2\": 8.550724637681158, \"center_x\": 9.275362318840578, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0014944289527028252}, {\"x\": 9.420289855072465, \"y\": 8.26086956521739, \"x2\": 9.710144927536232, \"y2\": 8.550724637681158, \"center_x\": 9.565217391304348, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0012609245414797678}, {\"x\": 9.710144927536234, \"y\": 8.26086956521739, \"x2\": 10.000000000000002, \"y2\": 8.550724637681158, \"center_x\": 9.855072463768117, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0010540197209255755}, {\"x\": 10.0, \"y\": 8.26086956521739, \"x2\": 10.289855072463768, \"y2\": 8.550724637681158, \"center_x\": 10.144927536231883, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0008728792917986891}, {\"x\": -10.0, \"y\": 8.55072463768116, \"x2\": -9.710144927536232, \"y2\": 8.840579710144928, \"center_x\": -9.855072463768117, \"center_y\": 8.695652173913043, \"value_uncond\": 1.0445642947586815e-07}, {\"x\": -9.710144927536232, \"y\": 8.55072463768116, \"x2\": -9.420289855072465, \"y2\": 8.840579710144928, \"center_x\": -9.565217391304348, \"center_y\": 8.695652173913043, \"value_uncond\": 1.6320191171812923e-07}, {\"x\": -9.420289855072463, \"y\": 8.55072463768116, \"x2\": -9.130434782608695, \"y2\": 8.840579710144928, \"center_x\": -9.275362318840578, \"center_y\": 8.695652173913043, \"value_uncond\": 2.5261615536661616e-07}, {\"x\": -9.130434782608695, \"y\": 8.55072463768116, \"x2\": -8.840579710144928, \"y2\": 8.840579710144928, \"center_x\": -8.985507246376812, \"center_y\": 8.695652173913043, \"value_uncond\": 3.873850133284215e-07}, {\"x\": -8.840579710144928, \"y\": 8.55072463768116, \"x2\": -8.55072463768116, \"y2\": 8.840579710144928, \"center_x\": -8.695652173913043, \"center_y\": 8.695652173913043, \"value_uncond\": 5.885323283838296e-07}, {\"x\": -8.55072463768116, \"y\": 8.55072463768116, \"x2\": -8.260869565217392, \"y2\": 8.840579710144928, \"center_x\": -8.405797101449277, \"center_y\": 8.695652173913043, \"value_uncond\": 8.858162581182798e-07}, {\"x\": -8.26086956521739, \"y\": 8.55072463768116, \"x2\": -7.971014492753623, \"y2\": 8.840579710144928, \"center_x\": -8.115942028985508, \"center_y\": 8.695652173913043, \"value_uncond\": 1.3208782367818309e-06}, {\"x\": -7.971014492753623, \"y\": 8.55072463768116, \"x2\": -7.681159420289855, \"y2\": 8.840579710144928, \"center_x\": -7.826086956521739, \"center_y\": 8.695652173913043, \"value_uncond\": 1.9513165898152533e-06}, {\"x\": -7.681159420289855, \"y\": 8.55072463768116, \"x2\": -7.391304347826088, \"y2\": 8.840579710144928, \"center_x\": -7.536231884057972, \"center_y\": 8.695652173913043, \"value_uncond\": 2.8558704555904338e-06}, {\"x\": -7.391304347826087, \"y\": 8.55072463768116, \"x2\": -7.101449275362319, \"y2\": 8.840579710144928, \"center_x\": -7.246376811594203, \"center_y\": 8.695652173913043, \"value_uncond\": 4.140903262997788e-06}, {\"x\": -7.101449275362318, \"y\": 8.55072463768116, \"x2\": -6.811594202898551, \"y2\": 8.840579710144928, \"center_x\": -6.956521739130435, \"center_y\": 8.695652173913043, \"value_uncond\": 5.948363235535961e-06}, {\"x\": -6.811594202898551, \"y\": 8.55072463768116, \"x2\": -6.521739130434783, \"y2\": 8.840579710144928, \"center_x\": -6.666666666666667, \"center_y\": 8.695652173913043, \"value_uncond\": 8.465365055944217e-06}, {\"x\": -6.521739130434782, \"y\": 8.55072463768116, \"x2\": -6.231884057971015, \"y2\": 8.840579710144928, \"center_x\": -6.3768115942028984, \"center_y\": 8.695652173913043, \"value_uncond\": 1.1935475236483604e-05}, {\"x\": -6.231884057971014, \"y\": 8.55072463768116, \"x2\": -5.942028985507246, \"y2\": 8.840579710144928, \"center_x\": -6.08695652173913, \"center_y\": 8.695652173913043, \"value_uncond\": 1.6671687284283626e-05}, {\"x\": -5.942028985507246, \"y\": 8.55072463768116, \"x2\": -5.6521739130434785, \"y2\": 8.840579710144928, \"center_x\": -5.797101449275362, \"center_y\": 8.695652173913043, \"value_uncond\": 2.3070935738087277e-05}, {\"x\": -5.6521739130434785, \"y\": 8.55072463768116, \"x2\": -5.362318840579711, \"y2\": 8.840579710144928, \"center_x\": -5.507246376811595, \"center_y\": 8.695652173913043, \"value_uncond\": 3.1629816913060714e-05}, {\"x\": -5.36231884057971, \"y\": 8.55072463768116, \"x2\": -5.072463768115942, \"y2\": 8.840579710144928, \"center_x\": -5.217391304347826, \"center_y\": 8.695652173913043, \"value_uncond\": 4.296095838063664e-05}, {\"x\": -5.0724637681159415, \"y\": 8.55072463768116, \"x2\": -4.782608695652174, \"y2\": 8.840579710144928, \"center_x\": -4.927536231884058, \"center_y\": 8.695652173913043, \"value_uncond\": 5.780921322558761e-05}, {\"x\": -4.782608695652174, \"y\": 8.55072463768116, \"x2\": -4.492753623188406, \"y2\": 8.840579710144928, \"center_x\": -4.63768115942029, \"center_y\": 8.695652173913043, \"value_uncond\": 7.706655946123317e-05}, {\"x\": -4.492753623188405, \"y\": 8.55072463768116, \"x2\": -4.202898550724638, \"y2\": 8.840579710144928, \"center_x\": -4.3478260869565215, \"center_y\": 8.695652173913043, \"value_uncond\": 0.00010178427735403919}, {\"x\": -4.202898550724638, \"y\": 8.55072463768116, \"x2\": -3.91304347826087, \"y2\": 8.840579710144928, \"center_x\": -4.057971014492754, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0001331806833200212}, {\"x\": -3.913043478260869, \"y\": 8.55072463768116, \"x2\": -3.6231884057971016, \"y2\": 8.840579710144928, \"center_x\": -3.7681159420289854, \"center_y\": 8.695652173913043, \"value_uncond\": 0.00017264245161968284}, {\"x\": -3.6231884057971016, \"y\": 8.55072463768116, \"x2\": -3.333333333333334, \"y2\": 8.840579710144928, \"center_x\": -3.4782608695652177, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0002217173937673012}, {\"x\": -3.333333333333333, \"y\": 8.55072463768116, \"x2\": -3.0434782608695654, \"y2\": 8.840579710144928, \"center_x\": -3.1884057971014492, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0002820965337334934}, {\"x\": -3.0434782608695645, \"y\": 8.55072463768116, \"x2\": -2.753623188405797, \"y2\": 8.840579710144928, \"center_x\": -2.8985507246376807, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0003555834580916702}, {\"x\": -2.753623188405797, \"y\": 8.55072463768116, \"x2\": -2.4637681159420293, \"y2\": 8.840579710144928, \"center_x\": -2.608695652173913, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0004440492727523974}, {\"x\": -2.4637681159420284, \"y\": 8.55072463768116, \"x2\": -2.1739130434782608, \"y2\": 8.840579710144928, \"center_x\": -2.3188405797101446, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0005493720895215017}, {\"x\": -2.1739130434782608, \"y\": 8.55072463768116, \"x2\": -1.8840579710144931, \"y2\": 8.840579710144928, \"center_x\": -2.028985507246377, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0006733608069568906}, {\"x\": -1.8840579710144922, \"y\": 8.55072463768116, \"x2\": -1.5942028985507246, \"y2\": 8.840579710144928, \"center_x\": -1.7391304347826084, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0008176640283809529}, {\"x\": -1.5942028985507246, \"y\": 8.55072463768116, \"x2\": -1.304347826086957, \"y2\": 8.840579710144928, \"center_x\": -1.4492753623188408, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0009836662352107881}, {\"x\": -1.304347826086957, \"y\": 8.55072463768116, \"x2\": -1.0144927536231894, \"y2\": 8.840579710144928, \"center_x\": -1.1594202898550732, \"center_y\": 8.695652173913043, \"value_uncond\": 0.00117237473562303}, {\"x\": -1.0144927536231876, \"y\": 8.55072463768116, \"x2\": -0.72463768115942, \"y2\": 8.840579710144928, \"center_x\": -0.8695652173913038, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0013843023371089397}, {\"x\": -0.72463768115942, \"y\": 8.55072463768116, \"x2\": -0.43478260869565233, \"y2\": 8.840579710144928, \"center_x\": -0.5797101449275361, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0016193520217726706}, {\"x\": -0.43478260869565233, \"y\": 8.55072463768116, \"x2\": -0.1449275362318847, \"y2\": 8.840579710144928, \"center_x\": -0.2898550724637685, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0018767109937615424}, {\"x\": -0.14492753623188293, \"y\": 8.55072463768116, \"x2\": 0.1449275362318847, \"y2\": 8.840579710144928, \"center_x\": 8.881784197001252e-16, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0021547621731544497}, {\"x\": 0.1449275362318847, \"y\": 8.55072463768116, \"x2\": 0.43478260869565233, \"y2\": 8.840579710144928, \"center_x\": 0.2898550724637685, \"center_y\": 8.695652173913043, \"value_uncond\": 0.002451021395080612}, {\"x\": 0.43478260869565233, \"y\": 8.55072463768116, \"x2\": 0.72463768115942, \"y2\": 8.840579710144928, \"center_x\": 0.5797101449275361, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0027621081296955365}, {\"x\": 0.72463768115942, \"y\": 8.55072463768116, \"x2\": 1.0144927536231876, \"y2\": 8.840579710144928, \"center_x\": 0.8695652173913038, \"center_y\": 8.695652173913043, \"value_uncond\": 0.003083756405139314}, {\"x\": 1.0144927536231894, \"y\": 8.55072463768116, \"x2\": 1.304347826086957, \"y2\": 8.840579710144928, \"center_x\": 1.1594202898550732, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0034108707873688375}, {\"x\": 1.304347826086957, \"y\": 8.55072463768116, \"x2\": 1.5942028985507246, \"y2\": 8.840579710144928, \"center_x\": 1.4492753623188408, \"center_y\": 8.695652173913043, \"value_uncond\": 0.003737629811159793}, {\"x\": 1.5942028985507246, \"y\": 8.55072463768116, \"x2\": 1.8840579710144922, \"y2\": 8.840579710144928, \"center_x\": 1.7391304347826084, \"center_y\": 8.695652173913043, \"value_uncond\": 0.004057636299484736}, {\"x\": 1.884057971014494, \"y\": 8.55072463768116, \"x2\": 2.1739130434782616, \"y2\": 8.840579710144928, \"center_x\": 2.028985507246378, \"center_y\": 8.695652173913043, \"value_uncond\": 0.004364110753120656}, {\"x\": 2.1739130434782616, \"y\": 8.55072463768116, \"x2\": 2.4637681159420293, \"y2\": 8.840579710144928, \"center_x\": 2.3188405797101455, \"center_y\": 8.695652173913043, \"value_uncond\": 0.004650120689912263}, {\"x\": 2.4637681159420293, \"y\": 8.55072463768116, \"x2\": 2.753623188405797, \"y2\": 8.840579710144928, \"center_x\": 2.608695652173913, \"center_y\": 8.695652173913043, \"value_uncond\": 0.004908835745780014}, {\"x\": 2.753623188405797, \"y\": 8.55072463768116, \"x2\": 3.0434782608695645, \"y2\": 8.840579710144928, \"center_x\": 2.8985507246376807, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0051337958036886434}, {\"x\": 3.0434782608695663, \"y\": 8.55072463768116, \"x2\": 3.333333333333334, \"y2\": 8.840579710144928, \"center_x\": 3.18840579710145, \"center_y\": 8.695652173913043, \"value_uncond\": 0.005319177653177839}, {\"x\": 3.333333333333334, \"y\": 8.55072463768116, \"x2\": 3.6231884057971016, \"y2\": 8.840579710144928, \"center_x\": 3.4782608695652177, \"center_y\": 8.695652173913043, \"value_uncond\": 0.005460044907529852}, {\"x\": 3.6231884057971016, \"y\": 8.55072463768116, \"x2\": 3.913043478260869, \"y2\": 8.840579710144928, \"center_x\": 3.7681159420289854, \"center_y\": 8.695652173913043, \"value_uncond\": 0.005552566243749356}, {\"x\": 3.913043478260871, \"y\": 8.55072463768116, \"x2\": 4.202898550724639, \"y2\": 8.840579710144928, \"center_x\": 4.057971014492755, \"center_y\": 8.695652173913043, \"value_uncond\": 0.005594188509648697}, {\"x\": 4.202898550724639, \"y\": 8.55072463768116, \"x2\": 4.492753623188406, \"y2\": 8.840579710144928, \"center_x\": 4.347826086956522, \"center_y\": 8.695652173913043, \"value_uncond\": 0.005583753783940638}, {\"x\": 4.492753623188406, \"y\": 8.55072463768116, \"x2\": 4.782608695652174, \"y2\": 8.840579710144928, \"center_x\": 4.63768115942029, \"center_y\": 8.695652173913043, \"value_uncond\": 0.005521552898678561}, {\"x\": 4.782608695652174, \"y\": 8.55072463768116, \"x2\": 5.0724637681159415, \"y2\": 8.840579710144928, \"center_x\": 4.927536231884058, \"center_y\": 8.695652173913043, \"value_uncond\": 0.005409311971190908}, {\"x\": 5.072463768115943, \"y\": 8.55072463768116, \"x2\": 5.362318840579711, \"y2\": 8.840579710144928, \"center_x\": 5.217391304347827, \"center_y\": 8.695652173913043, \"value_uncond\": 0.005250112815975646}, {\"x\": 5.362318840579711, \"y\": 8.55072463768116, \"x2\": 5.6521739130434785, \"y2\": 8.840579710144928, \"center_x\": 5.507246376811595, \"center_y\": 8.695652173913043, \"value_uncond\": 0.005048252358228618}, {\"x\": 5.6521739130434785, \"y\": 8.55072463768116, \"x2\": 5.942028985507246, \"y2\": 8.840579710144928, \"center_x\": 5.797101449275362, \"center_y\": 8.695652173913043, \"value_uncond\": 0.004809049999432685}, {\"x\": 5.942028985507246, \"y\": 8.55072463768116, \"x2\": 6.231884057971014, \"y2\": 8.840579710144928, \"center_x\": 6.08695652173913, \"center_y\": 8.695652173913043, \"value_uncond\": 0.004538614983846707}, {\"x\": 6.2318840579710155, \"y\": 8.55072463768116, \"x2\": 6.521739130434783, \"y2\": 8.840579710144928, \"center_x\": 6.376811594202899, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0042435879475285635}, {\"x\": 6.521739130434785, \"y\": 8.55072463768116, \"x2\": 6.8115942028985526, \"y2\": 8.840579710144928, \"center_x\": 6.666666666666669, \"center_y\": 8.695652173913043, \"value_uncond\": 0.003930871857686281}, {\"x\": 6.811594202898551, \"y\": 8.55072463768116, \"x2\": 7.101449275362318, \"y2\": 8.840579710144928, \"center_x\": 6.956521739130435, \"center_y\": 8.695652173913043, \"value_uncond\": 0.003607367433725416}, {\"x\": 7.10144927536232, \"y\": 8.55072463768116, \"x2\": 7.391304347826088, \"y2\": 8.840579710144928, \"center_x\": 7.246376811594204, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0032797269505432467}, {\"x\": 7.391304347826086, \"y\": 8.55072463768116, \"x2\": 7.681159420289854, \"y2\": 8.840579710144928, \"center_x\": 7.53623188405797, \"center_y\": 8.695652173913043, \"value_uncond\": 0.002954138219697305}, {\"x\": 7.681159420289855, \"y\": 8.55072463768116, \"x2\": 7.971014492753623, \"y2\": 8.840579710144928, \"center_x\": 7.826086956521739, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0026361477562092976}, {\"x\": 7.971014492753625, \"y\": 8.55072463768116, \"x2\": 8.260869565217392, \"y2\": 8.840579710144928, \"center_x\": 8.115942028985508, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0023305289426137467}, {\"x\": 8.26086956521739, \"y\": 8.55072463768116, \"x2\": 8.550724637681158, \"y2\": 8.840579710144928, \"center_x\": 8.405797101449274, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0020411976855896304}, {\"x\": 8.55072463768116, \"y\": 8.55072463768116, \"x2\": 8.840579710144928, \"y2\": 8.840579710144928, \"center_x\": 8.695652173913043, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0017711748968384177}, {\"x\": 8.84057971014493, \"y\": 8.55072463768116, \"x2\": 9.130434782608697, \"y2\": 8.840579710144928, \"center_x\": 8.985507246376812, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0015225923513204718}, {\"x\": 9.130434782608695, \"y\": 8.55072463768116, \"x2\": 9.420289855072463, \"y2\": 8.840579710144928, \"center_x\": 9.275362318840578, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0012967362567683765}, {\"x\": 9.420289855072465, \"y\": 8.55072463768116, \"x2\": 9.710144927536232, \"y2\": 8.840579710144928, \"center_x\": 9.565217391304348, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0010941213143847602}, {\"x\": 9.710144927536234, \"y\": 8.55072463768116, \"x2\": 10.000000000000002, \"y2\": 8.840579710144928, \"center_x\": 9.855072463768117, \"center_y\": 8.695652173913043, \"value_uncond\": 0.000914587197337893}, {\"x\": 10.0, \"y\": 8.55072463768116, \"x2\": 10.289855072463768, \"y2\": 8.840579710144928, \"center_x\": 10.144927536231883, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0007574091919261327}, {\"x\": -10.0, \"y\": 8.84057971014493, \"x2\": -9.710144927536232, \"y2\": 9.130434782608697, \"center_x\": -9.855072463768117, \"center_y\": 8.985507246376812, \"value_uncond\": 8.979607877804766e-08}, {\"x\": -9.710144927536232, \"y\": 8.84057971014493, \"x2\": -9.420289855072465, \"y2\": 9.130434782608697, \"center_x\": -9.565217391304348, \"center_y\": 8.985507246376812, \"value_uncond\": 1.402966939890929e-07}, {\"x\": -9.420289855072463, \"y\": 8.84057971014493, \"x2\": -9.130434782608695, \"y2\": 9.130434782608697, \"center_x\": -9.275362318840578, \"center_y\": 8.985507246376812, \"value_uncond\": 2.1716174199835867e-07}, {\"x\": -9.130434782608695, \"y\": 8.84057971014493, \"x2\": -8.840579710144928, \"y2\": 9.130434782608697, \"center_x\": -8.985507246376812, \"center_y\": 8.985507246376812, \"value_uncond\": 3.330159316072577e-07}, {\"x\": -8.840579710144928, \"y\": 8.84057971014493, \"x2\": -8.55072463768116, \"y2\": 9.130434782608697, \"center_x\": -8.695652173913043, \"center_y\": 8.985507246376812, \"value_uncond\": 5.059324312362338e-07}, {\"x\": -8.55072463768116, \"y\": 8.84057971014493, \"x2\": -8.260869565217392, \"y2\": 9.130434782608697, \"center_x\": -8.405797101449277, \"center_y\": 8.985507246376812, \"value_uncond\": 7.614928721571976e-07}, {\"x\": -8.26086956521739, \"y\": 8.84057971014493, \"x2\": -7.971014492753623, \"y2\": 9.130434782608697, \"center_x\": -8.115942028985508, \"center_y\": 8.985507246376812, \"value_uncond\": 1.1354943568473354e-06}, {\"x\": -7.971014492753623, \"y\": 8.84057971014493, \"x2\": -7.681159420289855, \"y2\": 9.130434782608697, \"center_x\": -7.826086956521739, \"center_y\": 8.985507246376812, \"value_uncond\": 1.6774513459742732e-06}, {\"x\": -7.681159420289855, \"y\": 8.84057971014493, \"x2\": -7.391304347826088, \"y2\": 9.130434782608697, \"center_x\": -7.536231884057972, \"center_y\": 8.985507246376812, \"value_uncond\": 2.455052022138501e-06}, {\"x\": -7.391304347826087, \"y\": 8.84057971014493, \"x2\": -7.101449275362319, \"y2\": 9.130434782608697, \"center_x\": -7.246376811594203, \"center_y\": 8.985507246376812, \"value_uncond\": 3.559731818157989e-06}, {\"x\": -7.101449275362318, \"y\": 8.84057971014493, \"x2\": -6.811594202898551, \"y2\": 9.130434782608697, \"center_x\": -6.956521739130435, \"center_y\": 8.985507246376812, \"value_uncond\": 5.113516672729353e-06}, {\"x\": -6.811594202898551, \"y\": 8.84057971014493, \"x2\": -6.521739130434783, \"y2\": 9.130434782608697, \"center_x\": -6.666666666666667, \"center_y\": 8.985507246376812, \"value_uncond\": 7.277259918443921e-06}, {\"x\": -6.521739130434782, \"y\": 8.84057971014493, \"x2\": -6.231884057971015, \"y2\": 9.130434782608697, \"center_x\": -6.3768115942028984, \"center_y\": 8.985507246376812, \"value_uncond\": 1.0260343762145541e-05}, {\"x\": -6.231884057971014, \"y\": 8.84057971014493, \"x2\": -5.942028985507246, \"y2\": 9.130434782608697, \"center_x\": -6.08695652173913, \"center_y\": 8.985507246376812, \"value_uncond\": 1.4331833399382685e-05}, {\"x\": -5.942028985507246, \"y\": 8.84057971014493, \"x2\": -5.6521739130434785, \"y2\": 9.130434782608697, \"center_x\": -5.797101449275362, \"center_y\": 8.985507246376812, \"value_uncond\": 1.9832954021266523e-05}, {\"x\": -5.6521739130434785, \"y\": 8.84057971014493, \"x2\": -5.362318840579711, \"y2\": 9.130434782608697, \"center_x\": -5.507246376811595, \"center_y\": 8.985507246376812, \"value_uncond\": 2.719060516917808e-05}, {\"x\": -5.36231884057971, \"y\": 8.84057971014493, \"x2\": -5.072463768115942, \"y2\": 9.130434782608697, \"center_x\": -5.217391304347826, \"center_y\": 8.985507246376812, \"value_uncond\": 3.6931432775225205e-05}, {\"x\": -5.0724637681159415, \"y\": 8.84057971014493, \"x2\": -4.782608695652174, \"y2\": 9.130434782608697, \"center_x\": -4.927536231884058, \"center_y\": 8.985507246376812, \"value_uncond\": 4.9695750572262035e-05}, {\"x\": -4.782608695652174, \"y\": 8.84057971014493, \"x2\": -4.492753623188406, \"y2\": 9.130434782608697, \"center_x\": -4.63768115942029, \"center_y\": 8.985507246376812, \"value_uncond\": 6.625034839174487e-05}, {\"x\": -4.492753623188405, \"y\": 8.84057971014493, \"x2\": -4.202898550724638, \"y2\": 9.130434782608697, \"center_x\": -4.3478260869565215, \"center_y\": 8.985507246376812, \"value_uncond\": 8.74989604135519e-05}, {\"x\": -4.202898550724638, \"y\": 8.84057971014493, \"x2\": -3.91304347826087, \"y2\": 9.130434782608697, \"center_x\": -4.057971014492754, \"center_y\": 8.985507246376812, \"value_uncond\": 0.00011448891361810995}, {\"x\": -3.913043478260869, \"y\": 8.84057971014493, \"x2\": -3.6231884057971016, \"y2\": 9.130434782608697, \"center_x\": -3.7681159420289854, \"center_y\": 8.985507246376812, \"value_uncond\": 0.00014841226398282917}, {\"x\": -3.6231884057971016, \"y\": 8.84057971014493, \"x2\": -3.333333333333334, \"y2\": 9.130434782608697, \"center_x\": -3.4782608695652177, \"center_y\": 8.985507246376812, \"value_uncond\": 0.00019059958929374977}, {\"x\": -3.333333333333333, \"y\": 8.84057971014493, \"x2\": -3.0434782608695654, \"y2\": 9.130434782608697, \"center_x\": -3.1884057971014492, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0002425045800746907}, {\"x\": -3.0434782608695645, \"y\": 8.84057971014493, \"x2\": -2.753623188405797, \"y2\": 9.130434782608697, \"center_x\": -2.8985507246376807, \"center_y\": 8.985507246376812, \"value_uncond\": 0.00030567769140861566}, {\"x\": -2.753623188405797, \"y\": 8.84057971014493, \"x2\": -2.4637681159420293, \"y2\": 9.130434782608697, \"center_x\": -2.608695652173913, \"center_y\": 8.985507246376812, \"value_uncond\": 0.00038172742144724434}, {\"x\": -2.4637681159420284, \"y\": 8.84057971014493, \"x2\": -2.1739130434782608, \"y2\": 9.130434782608697, \"center_x\": -2.3188405797101446, \"center_y\": 8.985507246376812, \"value_uncond\": 0.000472268290967481}, {\"x\": -2.1739130434782608, \"y\": 8.84057971014493, \"x2\": -1.8840579710144931, \"y2\": 9.130434782608697, \"center_x\": -2.028985507246377, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0005788553215053133}, {\"x\": -1.8840579710144922, \"y\": 8.84057971014493, \"x2\": -1.5942028985507246, \"y2\": 9.130434782608697, \"center_x\": -1.7391304347826084, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0007029057366299728}, {\"x\": -1.5942028985507246, \"y\": 8.84057971014493, \"x2\": -1.304347826086957, \"y2\": 9.130434782608697, \"center_x\": -1.4492753623188408, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0008456097072387457}, {\"x\": -1.304347826086957, \"y\": 8.84057971014493, \"x2\": -1.0144927536231894, \"y2\": 9.130434782608697, \"center_x\": -1.1594202898550732, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0010078331668585262}, {\"x\": -1.0144927536231876, \"y\": 8.84057971014493, \"x2\": -0.72463768115942, \"y2\": 9.130434782608697, \"center_x\": -0.8695652173913038, \"center_y\": 8.985507246376812, \"value_uncond\": 0.001190016950985169}, {\"x\": -0.72463768115942, \"y\": 8.84057971014493, \"x2\": -0.43478260869565233, \"y2\": 9.130434782608697, \"center_x\": -0.5797101449275361, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0013920776580831054}, {\"x\": -0.43478260869565233, \"y\": 8.84057971014493, \"x2\": -0.1449275362318847, \"y2\": 9.130434782608697, \"center_x\": -0.2898550724637685, \"center_y\": 8.985507246376812, \"value_uncond\": 0.001613316567348035}, {\"x\": -0.14492753623188293, \"y\": 8.84057971014493, \"x2\": 0.1449275362318847, \"y2\": 9.130434782608697, \"center_x\": 8.881784197001252e-16, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0018523435543355879}, {\"x\": 0.1449275362318847, \"y\": 8.84057971014493, \"x2\": 0.43478260869565233, \"y2\": 9.130434782608697, \"center_x\": 0.2898550724637685, \"center_y\": 8.985507246376812, \"value_uncond\": 0.002107023104118119}, {\"x\": 0.43478260869565233, \"y\": 8.84057971014493, \"x2\": 0.72463768115942, \"y2\": 9.130434782608697, \"center_x\": 0.5797101449275361, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0023744491406814394}, {\"x\": 0.72463768115942, \"y\": 8.84057971014493, \"x2\": 1.0144927536231876, \"y2\": 9.130434782608697, \"center_x\": 0.8695652173913038, \"center_y\": 8.985507246376812, \"value_uncond\": 0.002650954416857332}, {\"x\": 1.0144927536231894, \"y\": 8.84057971014493, \"x2\": 1.304347826086957, \"y2\": 9.130434782608697, \"center_x\": 1.1594202898550732, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0029321586374448324}, {\"x\": 1.304347826086957, \"y\": 8.84057971014493, \"x2\": 1.5942028985507246, \"y2\": 9.130434782608697, \"center_x\": 1.4492753623188408, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0032130573737791934}, {\"x\": 1.5942028985507246, \"y\": 8.84057971014493, \"x2\": 1.8840579710144922, \"y2\": 9.130434782608697, \"center_x\": 1.7391304347826084, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0034881512859423654}, {\"x\": 1.884057971014494, \"y\": 8.84057971014493, \"x2\": 2.1739130434782616, \"y2\": 9.130434782608697, \"center_x\": 2.028985507246378, \"center_y\": 8.985507246376812, \"value_uncond\": 0.003751612370341272}, {\"x\": 2.1739130434782616, \"y\": 8.84057971014493, \"x2\": 2.4637681159420293, \"y2\": 9.130434782608697, \"center_x\": 2.3188405797101455, \"center_y\": 8.985507246376812, \"value_uncond\": 0.003997481111445207}, {\"x\": 2.4637681159420293, \"y\": 8.84057971014493, \"x2\": 2.753623188405797, \"y2\": 9.130434782608697, \"center_x\": 2.608695652173913, \"center_y\": 8.985507246376812, \"value_uncond\": 0.004219885779634011}, {\"x\": 2.753623188405797, \"y\": 8.84057971014493, \"x2\": 3.0434782608695645, \"y2\": 9.130434782608697, \"center_x\": 2.8985507246376807, \"center_y\": 8.985507246376812, \"value_uncond\": 0.004413272928546124}, {\"x\": 3.0434782608695663, \"y\": 8.84057971014493, \"x2\": 3.333333333333334, \"y2\": 9.130434782608697, \"center_x\": 3.18840579710145, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0045726366292228515}, {\"x\": 3.333333333333334, \"y\": 8.84057971014493, \"x2\": 3.6231884057971016, \"y2\": 9.130434782608697, \"center_x\": 3.4782608695652177, \"center_y\": 8.985507246376812, \"value_uncond\": 0.00469373331166271}, {\"x\": 3.6231884057971016, \"y\": 8.84057971014493, \"x2\": 3.913043478260869, \"y2\": 9.130434782608697, \"center_x\": 3.7681159420289854, \"center_y\": 8.985507246376812, \"value_uncond\": 0.004773269375048221}, {\"x\": 3.913043478260871, \"y\": 8.84057971014493, \"x2\": 4.202898550724639, \"y2\": 9.130434782608697, \"center_x\": 4.057971014492755, \"center_y\": 8.985507246376812, \"value_uncond\": 0.004809049999432683}, {\"x\": 4.202898550724639, \"y\": 8.84057971014493, \"x2\": 4.492753623188406, \"y2\": 9.130434782608697, \"center_x\": 4.347826086956522, \"center_y\": 8.985507246376812, \"value_uncond\": 0.00480007977657125}, {\"x\": 4.492753623188406, \"y\": 8.84057971014493, \"x2\": 4.782608695652174, \"y2\": 9.130434782608697, \"center_x\": 4.63768115942029, \"center_y\": 8.985507246376812, \"value_uncond\": 0.004746608720542591}, {\"x\": 4.782608695652174, \"y\": 8.84057971014493, \"x2\": 5.0724637681159415, \"y2\": 9.130434782608697, \"center_x\": 4.927536231884058, \"center_y\": 8.985507246376812, \"value_uncond\": 0.004650120689912261}, {\"x\": 5.072463768115943, \"y\": 8.84057971014493, \"x2\": 5.362318840579711, \"y2\": 9.130434782608697, \"center_x\": 5.217391304347827, \"center_y\": 8.985507246376812, \"value_uncond\": 0.004513264969734587}, {\"x\": 5.362318840579711, \"y\": 8.84057971014493, \"x2\": 5.6521739130434785, \"y2\": 9.130434782608697, \"center_x\": 5.507246376811595, \"center_y\": 8.985507246376812, \"value_uncond\": 0.004339735416245373}, {\"x\": 5.6521739130434785, \"y\": 8.84057971014493, \"x2\": 5.942028985507246, \"y2\": 9.130434782608697, \"center_x\": 5.797101449275362, \"center_y\": 8.985507246376812, \"value_uncond\": 0.004134104858489265}, {\"x\": 5.942028985507246, \"y\": 8.84057971014493, \"x2\": 6.231884057971014, \"y2\": 9.130434782608697, \"center_x\": 6.08695652173913, \"center_y\": 8.985507246376812, \"value_uncond\": 0.003901625114678845}, {\"x\": 6.2318840579710155, \"y\": 8.84057971014493, \"x2\": 6.521739130434783, \"y2\": 9.130434782608697, \"center_x\": 6.376811594202899, \"center_y\": 8.985507246376812, \"value_uncond\": 0.003648004814542142}, {\"x\": 6.521739130434785, \"y\": 8.84057971014493, \"x2\": 6.8115942028985526, \"y2\": 9.130434782608697, \"center_x\": 6.666666666666669, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0033791781010546027}, {\"x\": 6.811594202898551, \"y\": 8.84057971014493, \"x2\": 7.101449275362318, \"y2\": 9.130434782608697, \"center_x\": 6.956521739130435, \"center_y\": 8.985507246376812, \"value_uncond\": 0.003101077184865926}, {\"x\": 7.10144927536232, \"y\": 8.84057971014493, \"x2\": 7.391304347826088, \"y2\": 9.130434782608697, \"center_x\": 7.246376811594204, \"center_y\": 8.985507246376812, \"value_uncond\": 0.002819420701044596}, {\"x\": 7.391304347826086, \"y\": 8.84057971014493, \"x2\": 7.681159420289854, \"y2\": 9.130434782608697, \"center_x\": 7.53623188405797, \"center_y\": 8.985507246376812, \"value_uncond\": 0.002539528008263621}, {\"x\": 7.681159420289855, \"y\": 8.84057971014493, \"x2\": 7.971014492753623, \"y2\": 9.130434782608697, \"center_x\": 7.826086956521739, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0022661671739586946}, {\"x\": 7.971014492753625, \"y\": 8.84057971014493, \"x2\": 8.260869565217392, \"y2\": 9.130434782608697, \"center_x\": 8.115942028985508, \"center_y\": 8.985507246376812, \"value_uncond\": 0.002003441641414816}, {\"x\": 8.26086956521739, \"y\": 8.84057971014493, \"x2\": 8.550724637681158, \"y2\": 9.130434782608697, \"center_x\": 8.405797101449274, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0017547177239015214}, {\"x\": 8.55072463768116, \"y\": 8.84057971014493, \"x2\": 8.840579710144928, \"y2\": 9.130434782608697, \"center_x\": 8.695652173913043, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0015225923513204718}, {\"x\": 8.84057971014493, \"y\": 8.84057971014493, \"x2\": 9.130434782608697, \"y2\": 9.130434782608697, \"center_x\": 8.985507246376812, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0013088981062445}, {\"x\": 9.130434782608695, \"y\": 8.84057971014493, \"x2\": 9.420289855072463, \"y2\": 9.130434782608697, \"center_x\": 9.275362318840578, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0011147406784952822}, {\"x\": 9.420289855072465, \"y\": 8.84057971014493, \"x2\": 9.710144927536232, \"y2\": 9.130434782608697, \"center_x\": 9.565217391304348, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0009405625314996294}, {\"x\": 9.710144927536234, \"y\": 8.84057971014493, \"x2\": 10.000000000000002, \"y2\": 9.130434782608697, \"center_x\": 9.855072463768117, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0007862258401290695}, {\"x\": 10.0, \"y\": 8.84057971014493, \"x2\": 10.289855072463768, \"y2\": 9.130434782608697, \"center_x\": 10.144927536231883, \"center_y\": 8.985507246376812, \"value_uncond\": 0.000651107603492506}, {\"x\": -10.0, \"y\": 9.130434782608695, \"x2\": -9.710144927536232, \"y2\": 9.420289855072463, \"center_x\": -9.855072463768117, \"center_y\": 9.275362318840578, \"value_uncond\": 7.647603836058899e-08}, {\"x\": -9.710144927536232, \"y\": 9.130434782608695, \"x2\": -9.420289855072465, \"y2\": 9.420289855072463, \"center_x\": -9.565217391304348, \"center_y\": 9.275362318840578, \"value_uncond\": 1.1948556660134085e-07}, {\"x\": -9.420289855072463, \"y\": 9.130434782608695, \"x2\": -9.130434782608695, \"y2\": 9.420289855072463, \"center_x\": -9.275362318840578, \"center_y\": 9.275362318840578, \"value_uncond\": 1.8494871866920357e-07}, {\"x\": -9.130434782608695, \"y\": 9.130434782608695, \"x2\": -8.840579710144928, \"y2\": 9.420289855072463, \"center_x\": -8.985507246376812, \"center_y\": 9.275362318840578, \"value_uncond\": 2.836174976329806e-07}, {\"x\": -8.840579710144928, \"y\": 9.130434782608695, \"x2\": -8.55072463768116, \"y2\": 9.420289855072463, \"center_x\": -8.695652173913043, \"center_y\": 9.275362318840578, \"value_uncond\": 4.308841604846021e-07}, {\"x\": -8.55072463768116, \"y\": 9.130434782608695, \"x2\": -8.260869565217392, \"y2\": 9.420289855072463, \"center_x\": -8.405797101449277, \"center_y\": 9.275362318840578, \"value_uncond\": 6.485356476016378e-07}, {\"x\": -8.26086956521739, \"y\": 9.130434782608695, \"x2\": -7.971014492753623, \"y2\": 9.420289855072463, \"center_x\": -8.115942028985508, \"center_y\": 9.275362318840578, \"value_uncond\": 9.670590428244664e-07}, {\"x\": -7.971014492753623, \"y\": 9.130434782608695, \"x2\": -7.681159420289855, \"y2\": 9.420289855072463, \"center_x\": -7.826086956521739, \"center_y\": 9.275362318840578, \"value_uncond\": 1.4286240026119246e-06}, {\"x\": -7.681159420289855, \"y\": 9.130434782608695, \"x2\": -7.391304347826088, \"y2\": 9.420289855072463, \"center_x\": -7.536231884057972, \"center_y\": 9.275362318840578, \"value_uncond\": 2.0908780781662027e-06}, {\"x\": -7.391304347826087, \"y\": 9.130434782608695, \"x2\": -7.101449275362319, \"y2\": 9.420289855072463, \"center_x\": -7.246376811594203, \"center_y\": 9.275362318840578, \"value_uncond\": 3.0316934857673573e-06}, {\"x\": -7.101449275362318, \"y\": 9.130434782608695, \"x2\": -6.811594202898551, \"y2\": 9.420289855072463, \"center_x\": -6.956521739130435, \"center_y\": 9.275362318840578, \"value_uncond\": 4.354995257507432e-06}, {\"x\": -6.811594202898551, \"y\": 9.130434782608695, \"x2\": -6.521739130434783, \"y2\": 9.420289855072463, \"center_x\": -6.666666666666667, \"center_y\": 9.275362318840578, \"value_uncond\": 6.197776297765796e-06}, {\"x\": -6.521739130434782, \"y\": 9.130434782608695, \"x2\": -6.231884057971015, \"y2\": 9.420289855072463, \"center_x\": -6.3768115942028984, \"center_y\": 9.275362318840578, \"value_uncond\": 8.738359779452863e-06}, {\"x\": -6.231884057971014, \"y\": 9.130434782608695, \"x2\": -5.942028985507246, \"y2\": 9.420289855072463, \"center_x\": -6.08695652173913, \"center_y\": 9.275362318840578, \"value_uncond\": 1.2205898695619978e-05}, {\"x\": -5.942028985507246, \"y\": 9.130434782608695, \"x2\": -5.6521739130434785, \"y2\": 9.420289855072463, \"center_x\": -5.797101449275362, \"center_y\": 9.275362318840578, \"value_uncond\": 1.6891002070181413e-05}, {\"x\": -5.6521739130434785, \"y\": 9.130434782608695, \"x2\": -5.362318840579711, \"y2\": 9.420289855072463, \"center_x\": -5.507246376811595, \"center_y\": 9.275362318840578, \"value_uncond\": 2.315724463988563e-05}, {\"x\": -5.36231884057971, \"y\": 9.130434782608695, \"x2\": -5.072463768115942, \"y2\": 9.420289855072463, \"center_x\": -5.217391304347826, \"center_y\": 9.275362318840578, \"value_uncond\": 3.1453151496856975e-05}, {\"x\": -5.0724637681159415, \"y\": 9.130434782608695, \"x2\": -4.782608695652174, \"y2\": 9.420289855072463, \"center_x\": -4.927536231884058, \"center_y\": 9.275362318840578, \"value_uncond\": 4.2324054444699044e-05}, {\"x\": -4.782608695652174, \"y\": 9.130434782608695, \"x2\": -4.492753623188406, \"y2\": 9.420289855072463, \"center_x\": -4.63768115942029, \"center_y\": 9.275362318840578, \"value_uncond\": 5.642300035765128e-05}, {\"x\": -4.492753623188405, \"y\": 9.130434782608695, \"x2\": -4.202898550724638, \"y2\": 9.420289855072463, \"center_x\": -4.3478260869565215, \"center_y\": 9.275362318840578, \"value_uncond\": 7.451966660635891e-05}, {\"x\": -4.202898550724638, \"y\": 9.130434782608695, \"x2\": -3.91304347826087, \"y2\": 9.420289855072463, \"center_x\": -4.057971014492754, \"center_y\": 9.275362318840578, \"value_uncond\": 9.750602330155659e-05}, {\"x\": -3.913043478260869, \"y\": 9.130434782608695, \"x2\": -3.6231884057971016, \"y2\": 9.420289855072463, \"center_x\": -3.7681159420289854, \"center_y\": 9.275362318840578, \"value_uncond\": 0.00012639730095104576}, {\"x\": -3.6231884057971016, \"y\": 9.130434782608695, \"x2\": -3.333333333333334, \"y2\": 9.420289855072463, \"center_x\": -3.4782608695652177, \"center_y\": 9.275362318840578, \"value_uncond\": 0.00016232670402423812}, {\"x\": -3.333333333333333, \"y\": 9.130434782608695, \"x2\": -3.0434782608695654, \"y2\": 9.420289855072463, \"center_x\": -3.1884057971014492, \"center_y\": 9.275362318840578, \"value_uncond\": 0.000206532287609695}, {\"x\": -3.0434782608695645, \"y\": 9.130434782608695, \"x2\": -2.753623188405797, \"y2\": 9.420289855072463, \"center_x\": -2.8985507246376807, \"center_y\": 9.275362318840578, \"value_uncond\": 0.00026033451763437723}, {\"x\": -2.753623188405797, \"y\": 9.130434782608695, \"x2\": -2.4637681159420293, \"y2\": 9.420289855072463, \"center_x\": -2.608695652173913, \"center_y\": 9.275362318840578, \"value_uncond\": 0.00032510329318550315}, {\"x\": -2.4637681159420284, \"y\": 9.130434782608695, \"x2\": -2.1739130434782608, \"y2\": 9.420289855072463, \"center_x\": -2.3188405797101446, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0004022136426000418}, {\"x\": -2.1739130434782608, \"y\": 9.130434782608695, \"x2\": -1.8840579710144931, \"y2\": 9.420289855072463, \"center_x\": -2.028985507246377, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0004929899208860965}, {\"x\": -1.8840579710144922, \"y\": 9.130434782608695, \"x2\": -1.5942028985507246, \"y2\": 9.420289855072463, \"center_x\": -1.7391304347826084, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0005986391255598276}, {\"x\": -1.5942028985507246, \"y\": 9.130434782608695, \"x2\": -1.304347826086957, \"y2\": 9.420289855072463, \"center_x\": -1.4492753623188408, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0007201748816751926}, {\"x\": -1.304347826086957, \"y\": 9.130434782608695, \"x2\": -1.0144927536231894, \"y2\": 9.420289855072463, \"center_x\": -1.1594202898550732, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0008583346731682558}, {\"x\": -1.0144927536231876, \"y\": 9.130434782608695, \"x2\": -0.72463768115942, \"y2\": 9.420289855072463, \"center_x\": -0.8695652173913038, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0010134939435188506}, {\"x\": -0.72463768115942, \"y\": 9.130434782608695, \"x2\": -0.43478260869565233, \"y2\": 9.420289855072463, \"center_x\": -0.5797101449275361, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0011855816626873544}, {\"x\": -0.43478260869565233, \"y\": 9.130434782608695, \"x2\": -0.1449275362318847, \"y2\": 9.420289855072463, \"center_x\": -0.2898550724637685, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0013740027557021192}, {\"x\": -0.14492753623188293, \"y\": 9.130434782608695, \"x2\": 0.1449275362318847, \"y2\": 9.420289855072463, \"center_x\": 8.881784197001252e-16, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0015775733043811879}, {\"x\": 0.1449275362318847, \"y\": 9.130434782608695, \"x2\": 0.43478260869565233, \"y2\": 9.420289855072463, \"center_x\": 0.2898550724637685, \"center_y\": 9.275362318840578, \"value_uncond\": 0.001794474568711094}, {\"x\": 0.43478260869565233, \"y\": 9.130434782608695, \"x2\": 0.72463768115942, \"y2\": 9.420289855072463, \"center_x\": 0.5797101449275361, \"center_y\": 9.275362318840578, \"value_uncond\": 0.002022231549964005}, {\"x\": 0.72463768115942, \"y\": 9.130434782608695, \"x2\": 1.0144927536231876, \"y2\": 9.420289855072463, \"center_x\": 0.8695652173913038, \"center_y\": 9.275362318840578, \"value_uncond\": 0.002257720987760062}, {\"x\": 1.0144927536231894, \"y\": 9.130434782608695, \"x2\": 1.304347826086957, \"y2\": 9.420289855072463, \"center_x\": 1.1594202898550732, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0024972123447709275}, {\"x\": 1.304347826086957, \"y\": 9.130434782608695, \"x2\": 1.5942028985507246, \"y2\": 9.420289855072463, \"center_x\": 1.4492753623188408, \"center_y\": 9.275362318840578, \"value_uncond\": 0.002736443532008462}, {\"x\": 1.5942028985507246, \"y\": 9.130434782608695, \"x2\": 1.8840579710144922, \"y2\": 9.420289855072463, \"center_x\": 1.7391304347826084, \"center_y\": 9.275362318840578, \"value_uncond\": 0.002970730962658479}, {\"x\": 1.884057971014494, \"y\": 9.130434782608695, \"x2\": 2.1739130434782616, \"y2\": 9.420289855072463, \"center_x\": 2.028985507246378, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0031951111390670145}, {\"x\": 2.1739130434782616, \"y\": 9.130434782608695, \"x2\": 2.4637681159420293, \"y2\": 9.420289855072463, \"center_x\": 2.3188405797101455, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0034045085596694277}, {\"x\": 2.4637681159420293, \"y\": 9.130434782608695, \"x2\": 2.753623188405797, \"y2\": 9.420289855072463, \"center_x\": 2.608695652173913, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0035939224869526204}, {\"x\": 2.753623188405797, \"y\": 9.130434782608695, \"x2\": 3.0434782608695645, \"y2\": 9.420289855072463, \"center_x\": 2.8985507246376807, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0037586232536219915}, {\"x\": 3.0434782608695663, \"y\": 9.130434782608695, \"x2\": 3.333333333333334, \"y2\": 9.420289855072463, \"center_x\": 3.18840579710145, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0038943474929438796}, {\"x\": 3.333333333333334, \"y\": 9.130434782608695, \"x2\": 3.6231884057971016, \"y2\": 9.420289855072463, \"center_x\": 3.4782608695652177, \"center_y\": 9.275362318840578, \"value_uncond\": 0.003997481111445211}, {\"x\": 3.6231884057971016, \"y\": 9.130434782608695, \"x2\": 3.913043478260869, \"y2\": 9.420289855072463, \"center_x\": 3.7681159420289854, \"center_y\": 9.275362318840578, \"value_uncond\": 0.004065219069686742}, {\"x\": 3.913043478260871, \"y\": 9.130434782608695, \"x2\": 4.202898550724639, \"y2\": 9.420289855072463, \"center_x\": 4.057971014492755, \"center_y\": 9.275362318840578, \"value_uncond\": 0.004095692119737797}, {\"x\": 4.202898550724639, \"y\": 9.130434782608695, \"x2\": 4.492753623188406, \"y2\": 9.420289855072463, \"center_x\": 4.347826086956522, \"center_y\": 9.275362318840578, \"value_uncond\": 0.004088052508777171}, {\"x\": 4.492753623188406, \"y\": 9.130434782608695, \"x2\": 4.782608695652174, \"y2\": 9.420289855072463, \"center_x\": 4.63768115942029, \"center_y\": 9.275362318840578, \"value_uncond\": 0.004042513164657964}, {\"x\": 4.782608695652174, \"y\": 9.130434782608695, \"x2\": 5.0724637681159415, \"y2\": 9.420289855072463, \"center_x\": 4.927536231884058, \"center_y\": 9.275362318840578, \"value_uncond\": 0.003960337835487279}, {\"x\": 5.072463768115943, \"y\": 9.130434782608695, \"x2\": 5.362318840579711, \"y2\": 9.420289855072463, \"center_x\": 5.217391304347827, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0038437828205178234}, {\"x\": 5.362318840579711, \"y\": 9.130434782608695, \"x2\": 5.6521739130434785, \"y2\": 9.420289855072463, \"center_x\": 5.507246376811595, \"center_y\": 9.275362318840578, \"value_uncond\": 0.003695994042099792}, {\"x\": 5.6521739130434785, \"y\": 9.130434782608695, \"x2\": 5.942028985507246, \"y2\": 9.420289855072463, \"center_x\": 5.797101449275362, \"center_y\": 9.275362318840578, \"value_uncond\": 0.003520866011599312}, {\"x\": 5.942028985507246, \"y\": 9.130434782608695, \"x2\": 6.231884057971014, \"y2\": 9.420289855072463, \"center_x\": 6.08695652173913, \"center_y\": 9.275362318840578, \"value_uncond\": 0.003322871510640635}, {\"x\": 6.2318840579710155, \"y\": 9.130434782608695, \"x2\": 6.521739130434783, \"y2\": 9.420289855072463, \"center_x\": 6.376811594202899, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0031068723705198263}, {\"x\": 6.521739130434785, \"y\": 9.130434782608695, \"x2\": 6.8115942028985526, \"y2\": 9.420289855072463, \"center_x\": 6.666666666666669, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0028779224839235533}, {\"x\": 6.811594202898551, \"y\": 9.130434782608695, \"x2\": 7.101449275362318, \"y2\": 9.420289855072463, \"center_x\": 6.956521739130435, \"center_y\": 9.275362318840578, \"value_uncond\": 0.002641074097847261}, {\"x\": 7.10144927536232, \"y\": 9.130434782608695, \"x2\": 7.391304347826088, \"y2\": 9.420289855072463, \"center_x\": 7.246376811594204, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0024011975647698}, {\"x\": 7.391304347826086, \"y\": 9.130434782608695, \"x2\": 7.681159420289854, \"y2\": 9.420289855072463, \"center_x\": 7.53623188405797, \"center_y\": 9.275362318840578, \"value_uncond\": 0.002162823188057047}, {\"x\": 7.681159420289855, \"y\": 9.130434782608695, \"x2\": 7.971014492753623, \"y2\": 9.420289855072463, \"center_x\": 7.826086956521739, \"center_y\": 9.275362318840578, \"value_uncond\": 0.001930011756477064}, {\"x\": 7.971014492753625, \"y\": 9.130434782608695, \"x2\": 8.260869565217392, \"y2\": 9.420289855072463, \"center_x\": 8.115942028985508, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0017062580226999524}, {\"x\": 8.26086956521739, \"y\": 9.130434782608695, \"x2\": 8.550724637681158, \"y2\": 9.420289855072463, \"center_x\": 8.405797101449274, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0014944289527028252}, {\"x\": 8.55072463768116, \"y\": 9.130434782608695, \"x2\": 8.840579710144928, \"y2\": 9.420289855072463, \"center_x\": 8.695652173913043, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0012967362567683765}, {\"x\": 8.84057971014493, \"y\": 9.130434782608695, \"x2\": 9.130434782608697, \"y2\": 9.420289855072463, \"center_x\": 8.985507246376812, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0011147406784952822}, {\"x\": 9.130434782608695, \"y\": 9.130434782608695, \"x2\": 9.420289855072463, \"y2\": 9.420289855072463, \"center_x\": 9.275362318840578, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0009493838934930793}, {\"x\": 9.420289855072465, \"y\": 9.130434782608695, \"x2\": 9.710144927536232, \"y2\": 9.420289855072463, \"center_x\": 9.565217391304348, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0008010427316908976}, {\"x\": 9.710144927536234, \"y\": 9.130434782608695, \"x2\": 10.000000000000002, \"y2\": 9.420289855072463, \"center_x\": 9.855072463768117, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0006695998124641526}, {\"x\": 10.0, \"y\": 9.130434782608695, \"x2\": 10.289855072463768, \"y2\": 9.420289855072463, \"center_x\": 10.144927536231883, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0005545245487238043}, {\"x\": -10.0, \"y\": 9.420289855072465, \"x2\": -9.710144927536232, \"y2\": 9.710144927536232, \"center_x\": -9.855072463768117, \"center_y\": 9.565217391304348, \"value_uncond\": 6.452666313083046e-08}, {\"x\": -9.710144927536232, \"y\": 9.420289855072465, \"x2\": -9.420289855072465, \"y2\": 9.710144927536232, \"center_x\": -9.565217391304348, \"center_y\": 9.565217391304348, \"value_uncond\": 1.0081595582564033e-07}, {\"x\": -9.420289855072463, \"y\": 9.420289855072465, \"x2\": -9.130434782608695, \"y2\": 9.710144927536232, \"center_x\": -9.275362318840578, \"center_y\": 9.565217391304348, \"value_uncond\": 1.5605049531692952e-07}, {\"x\": -9.130434782608695, \"y\": 9.420289855072465, \"x2\": -8.840579710144928, \"y2\": 9.710144927536232, \"center_x\": -8.985507246376812, \"center_y\": 9.565217391304348, \"value_uncond\": 2.3930228500439113e-07}, {\"x\": -8.840579710144928, \"y\": 9.420289855072465, \"x2\": -8.55072463768116, \"y2\": 9.710144927536232, \"center_x\": -8.695652173913043, \"center_y\": 9.565217391304348, \"value_uncond\": 3.6355854288509836e-07}, {\"x\": -8.55072463768116, \"y\": 9.420289855072465, \"x2\": -8.260869565217392, \"y2\": 9.710144927536232, \"center_x\": -8.405797101449277, \"center_y\": 9.565217391304348, \"value_uncond\": 5.472020015447292e-07}, {\"x\": -8.26086956521739, \"y\": 9.420289855072465, \"x2\": -7.971014492753623, \"y2\": 9.710144927536232, \"center_x\": -8.115942028985508, \"center_y\": 9.565217391304348, \"value_uncond\": 8.15956140271452e-07}, {\"x\": -7.971014492753623, \"y\": 9.420289855072465, \"x2\": -7.681159420289855, \"y2\": 9.710144927536232, \"center_x\": -7.826086956521739, \"center_y\": 9.565217391304348, \"value_uncond\": 1.2054016098807787e-06}, {\"x\": -7.681159420289855, \"y\": 9.420289855072465, \"x2\": -7.391304347826088, \"y2\": 9.710144927536232, \"center_x\": -7.536231884057972, \"center_y\": 9.565217391304348, \"value_uncond\": 1.7641785360445216e-06}, {\"x\": -7.391304347826087, \"y\": 9.420289855072465, \"x2\": -7.101449275362319, \"y2\": 9.710144927536232, \"center_x\": -7.246376811594203, \"center_y\": 9.565217391304348, \"value_uncond\": 2.5579916071182954e-06}, {\"x\": -7.101449275362318, \"y\": 9.420289855072465, \"x2\": -6.811594202898551, \"y2\": 9.710144927536232, \"center_x\": -6.956521739130435, \"center_y\": 9.565217391304348, \"value_uncond\": 3.674527576762701e-06}, {\"x\": -6.811594202898551, \"y\": 9.420289855072465, \"x2\": -6.521739130434783, \"y2\": 9.710144927536232, \"center_x\": -6.666666666666667, \"center_y\": 9.565217391304348, \"value_uncond\": 5.229374218373128e-06}, {\"x\": -6.521739130434782, \"y\": 9.420289855072465, \"x2\": -6.231884057971015, \"y2\": 9.710144927536232, \"center_x\": -6.3768115942028984, \"center_y\": 9.565217391304348, \"value_uncond\": 7.372991722533171e-06}, {\"x\": -6.231884057971014, \"y\": 9.420289855072465, \"x2\": -5.942028985507246, \"y2\": 9.710144927536232, \"center_x\": -6.08695652173913, \"center_y\": 9.565217391304348, \"value_uncond\": 1.0298727944401408e-05}, {\"x\": -5.942028985507246, \"y\": 9.420289855072465, \"x2\": -5.6521739130434785, \"y2\": 9.710144927536232, \"center_x\": -5.797101449275362, \"center_y\": 9.565217391304348, \"value_uncond\": 1.425178426980903e-05}, {\"x\": -5.6521739130434785, \"y\": 9.420289855072465, \"x2\": -5.362318840579711, \"y2\": 9.710144927536232, \"center_x\": -5.507246376811595, \"center_y\": 9.565217391304348, \"value_uncond\": 1.9538926910290582e-05}, {\"x\": -5.36231884057971, \"y\": 9.420289855072465, \"x2\": -5.072463768115942, \"y2\": 9.710144927536232, \"center_x\": -5.217391304347826, \"center_y\": 9.565217391304348, \"value_uncond\": 2.6538598946131802e-05}, {\"x\": -5.0724637681159415, \"y\": 9.420289855072465, \"x2\": -4.782608695652174, \"y2\": 9.710144927536232, \"center_x\": -4.927536231884058, \"center_y\": 9.565217391304348, \"value_uncond\": 3.5710924127725504e-05}, {\"x\": -4.782608695652174, \"y\": 9.420289855072465, \"x2\": -4.492753623188406, \"y2\": 9.710144927536232, \"center_x\": -4.63768115942029, \"center_y\": 9.565217391304348, \"value_uncond\": 4.760691080443206e-05}, {\"x\": -4.492753623188405, \"y\": 9.420289855072465, \"x2\": -4.202898550724638, \"y2\": 9.710144927536232, \"center_x\": -4.3478260869565215, \"center_y\": 9.565217391304348, \"value_uncond\": 6.287597431574483e-05}, {\"x\": -4.202898550724638, \"y\": 9.420289855072465, \"x2\": -3.91304347826087, \"y2\": 9.710144927536232, \"center_x\": -4.057971014492754, \"center_y\": 9.565217391304348, \"value_uncond\": 8.227071450982501e-05}, {\"x\": -3.913043478260869, \"y\": 9.420289855072465, \"x2\": -3.6231884057971016, \"y2\": 9.710144927536232, \"center_x\": -3.7681159420289854, \"center_y\": 9.565217391304348, \"value_uncond\": 0.00010664773220414889}, {\"x\": -3.6231884057971016, \"y\": 9.420289855072465, \"x2\": -3.333333333333334, \"y2\": 9.710144927536232, \"center_x\": -3.4782608695652177, \"center_y\": 9.565217391304348, \"value_uncond\": 0.00013696316875519372}, {\"x\": -3.333333333333333, \"y\": 9.420289855072465, \"x2\": -3.0434782608695654, \"y2\": 9.710144927536232, \"center_x\": -3.1884057971014492, \"center_y\": 9.565217391304348, \"value_uncond\": 0.00017426163323724657}, {\"x\": -3.0434782608695645, \"y\": 9.420289855072465, \"x2\": -2.753623188405797, \"y2\": 9.710144927536232, \"center_x\": -2.8985507246376807, \"center_y\": 9.565217391304348, \"value_uncond\": 0.00021965726887570564}, {\"x\": -2.753623188405797, \"y\": 9.420289855072465, \"x2\": -2.4637681159420293, \"y2\": 9.710144927536232, \"center_x\": -2.608695652173913, \"center_y\": 9.565217391304348, \"value_uncond\": 0.00027430592812866244}, {\"x\": -2.4637681159420284, \"y\": 9.420289855072465, \"x2\": -2.1739130434782608, \"y2\": 9.710144927536232, \"center_x\": -2.3188405797101446, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0003393677912590714}, {\"x\": -2.1739130434782608, \"y\": 9.420289855072465, \"x2\": -1.8840579710144931, \"y2\": 9.710144927536232, \"center_x\": -2.028985507246377, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0004159602829048383}, {\"x\": -1.8840579710144922, \"y\": 9.420289855072465, \"x2\": -1.5942028985507246, \"y2\": 9.710144927536232, \"center_x\": -1.7391304347826084, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0005051018073111961}, {\"x\": -1.5942028985507246, \"y\": 9.420289855072465, \"x2\": -1.304347826086957, \"y2\": 9.710144927536232, \"center_x\": -1.4492753623188408, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0006076476106938192}, {\"x\": -1.304347826086957, \"y\": 9.420289855072465, \"x2\": -1.0144927536231894, \"y2\": 9.710144927536232, \"center_x\": -1.1594202898550732, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0007242199451793476}, {\"x\": -1.0144927536231876, \"y\": 9.420289855072465, \"x2\": -0.72463768115942, \"y2\": 9.710144927536232, \"center_x\": -0.8695652173913038, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0008551355912321872}, {\"x\": -0.72463768115942, \"y\": 9.420289855072465, \"x2\": -0.43478260869565233, \"y2\": 9.710144927536232, \"center_x\": -0.5797101449275361, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0010003346172510537}, {\"x\": -0.43478260869565233, \"y\": 9.420289855072465, \"x2\": -0.1449275362318847, \"y2\": 9.710144927536232, \"center_x\": -0.2898550724637685, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0011593149286837669}, {\"x\": -0.14492753623188293, \"y\": 9.420289855072465, \"x2\": 0.1449275362318847, \"y2\": 9.710144927536232, \"center_x\": 8.881784197001252e-16, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0013310775944750685}, {\"x\": 0.1449275362318847, \"y\": 9.420289855072465, \"x2\": 0.43478260869565233, \"y2\": 9.710144927536232, \"center_x\": 0.2898550724637685, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0015140880526015143}, {\"x\": 0.43478260869565233, \"y\": 9.420289855072465, \"x2\": 0.72463768115942, \"y2\": 9.710144927536232, \"center_x\": 0.5797101449275361, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0017062580226999535}, {\"x\": 0.72463768115942, \"y\": 9.420289855072465, \"x2\": 1.0144927536231876, \"y2\": 9.710144927536232, \"center_x\": 0.8695652173913038, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0019049522535894748}, {\"x\": 1.0144927536231894, \"y\": 9.420289855072465, \"x2\": 1.304347826086957, \"y2\": 9.710144927536232, \"center_x\": 1.1594202898550732, \"center_y\": 9.565217391304348, \"value_uncond\": 0.00210702310411812}, {\"x\": 1.304347826086957, \"y\": 9.420289855072465, \"x2\": 1.5942028985507246, \"y2\": 9.710144927536232, \"center_x\": 1.4492753623188408, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0023088744363809082}, {\"x\": 1.5942028985507246, \"y\": 9.420289855072465, \"x2\": 1.8840579710144922, \"y2\": 9.710144927536232, \"center_x\": 1.7391304347826084, \"center_y\": 9.565217391304348, \"value_uncond\": 0.002506554473650362}, {\"x\": 1.884057971014494, \"y\": 9.420289855072465, \"x2\": 2.1739130434782616, \"y2\": 9.710144927536232, \"center_x\": 2.028985507246378, \"center_y\": 9.565217391304348, \"value_uncond\": 0.002695875264406846}, {\"x\": 2.1739130434782616, \"y\": 9.420289855072465, \"x2\": 2.4637681159420293, \"y2\": 9.710144927536232, \"center_x\": 2.3188405797101455, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0028725543538226468}, {\"x\": 2.4637681159420293, \"y\": 9.420289855072465, \"x2\": 2.753623188405797, \"y2\": 9.710144927536232, \"center_x\": 2.608695652173913, \"center_y\": 9.565217391304348, \"value_uncond\": 0.003032372369244177}, {\"x\": 2.753623188405797, \"y\": 9.420289855072465, \"x2\": 3.0434782608695645, \"y2\": 9.710144927536232, \"center_x\": 2.8985507246376807, \"center_y\": 9.565217391304348, \"value_uncond\": 0.003171338653535138}, {\"x\": 3.0434782608695663, \"y\": 9.420289855072465, \"x2\": 3.333333333333334, \"y2\": 9.710144927536232, \"center_x\": 3.18840579710145, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0032858559906926666}, {\"x\": 3.333333333333334, \"y\": 9.420289855072465, \"x2\": 3.6231884057971016, \"y2\": 9.710144927536232, \"center_x\": 3.4782608695652177, \"center_y\": 9.565217391304348, \"value_uncond\": 0.00337287498907646}, {\"x\": 3.6231884057971016, \"y\": 9.420289855072465, \"x2\": 3.913043478260869, \"y2\": 9.710144927536232, \"center_x\": 3.7681159420289854, \"center_y\": 9.565217391304348, \"value_uncond\": 0.003430028896448236}, {\"x\": 3.913043478260871, \"y\": 9.420289855072465, \"x2\": 4.202898550724639, \"y2\": 9.710144927536232, \"center_x\": 4.057971014492755, \"center_y\": 9.565217391304348, \"value_uncond\": 0.003455740534725601}, {\"x\": 4.202898550724639, \"y\": 9.420289855072465, \"x2\": 4.492753623188406, \"y2\": 9.710144927536232, \"center_x\": 4.347826086956522, \"center_y\": 9.565217391304348, \"value_uncond\": 0.003449294612401767}, {\"x\": 4.492753623188406, \"y\": 9.420289855072465, \"x2\": 4.782608695652174, \"y2\": 9.710144927536232, \"center_x\": 4.63768115942029, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0034108707873688354}, {\"x\": 4.782608695652174, \"y\": 9.420289855072465, \"x2\": 5.0724637681159415, \"y2\": 9.710144927536232, \"center_x\": 4.927536231884058, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0033415353471874256}, {\"x\": 5.072463768115943, \"y\": 9.420289855072465, \"x2\": 5.362318840579711, \"y2\": 9.710144927536232, \"center_x\": 5.217391304347827, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0032431920445220664}, {\"x\": 5.362318840579711, \"y\": 9.420289855072465, \"x2\": 5.6521739130434785, \"y2\": 9.710144927536232, \"center_x\": 5.507246376811595, \"center_y\": 9.565217391304348, \"value_uncond\": 0.003118495251592849}, {\"x\": 5.6521739130434785, \"y\": 9.420289855072465, \"x2\": 5.942028985507246, \"y2\": 9.710144927536232, \"center_x\": 5.797101449275362, \"center_y\": 9.565217391304348, \"value_uncond\": 0.002970730962658476}, {\"x\": 5.942028985507246, \"y\": 9.420289855072465, \"x2\": 6.231884057971014, \"y2\": 9.710144927536232, \"center_x\": 6.08695652173913, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0028036730875515285}, {\"x\": 6.2318840579710155, \"y\": 9.420289855072465, \"x2\": 6.521739130434783, \"y2\": 9.710144927536232, \"center_x\": 6.376811594202899, \"center_y\": 9.565217391304348, \"value_uncond\": 0.002621423796794503}, {\"x\": 6.521739130434785, \"y\": 9.420289855072465, \"x2\": 6.8115942028985526, \"y2\": 9.710144927536232, \"center_x\": 6.666666666666669, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0024282473127226916}, {\"x\": 6.811594202898551, \"y\": 9.420289855072465, \"x2\": 7.101449275362318, \"y2\": 9.710144927536232, \"center_x\": 6.956521739130435, \"center_y\": 9.565217391304348, \"value_uncond\": 0.002228406469119295}, {\"x\": 7.10144927536232, \"y\": 9.420289855072465, \"x2\": 7.391304347826088, \"y2\": 9.710144927536232, \"center_x\": 7.246376811594204, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0020260106262554294}, {\"x\": 7.391304347826086, \"y\": 9.420289855072465, \"x2\": 7.681159420289854, \"y2\": 9.710144927536232, \"center_x\": 7.53623188405797, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0018248822279375043}, {\"x\": 7.681159420289855, \"y\": 9.420289855072465, \"x2\": 7.971014492753623, \"y2\": 9.710144927536232, \"center_x\": 7.826086956521739, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0016284475649946393}, {\"x\": 7.971014492753625, \"y\": 9.420289855072465, \"x2\": 8.260869565217392, \"y2\": 9.710144927536232, \"center_x\": 8.115942028985508, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0014396553352556355}, {\"x\": 8.26086956521739, \"y\": 9.420289855072465, \"x2\": 8.550724637681158, \"y2\": 9.710144927536232, \"center_x\": 8.405797101449274, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0012609245414797678}, {\"x\": 8.55072463768116, \"y\": 9.420289855072465, \"x2\": 8.840579710144928, \"y2\": 9.710144927536232, \"center_x\": 8.695652173913043, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0010941213143847602}, {\"x\": 8.84057971014493, \"y\": 9.420289855072465, \"x2\": 9.130434782608697, \"y2\": 9.710144927536232, \"center_x\": 8.985507246376812, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0009405625314996294}, {\"x\": 9.130434782608695, \"y\": 9.420289855072465, \"x2\": 9.420289855072463, \"y2\": 9.710144927536232, \"center_x\": 9.275362318840578, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0008010427316908976}, {\"x\": 9.420289855072465, \"y\": 9.420289855072465, \"x2\": 9.710144927536232, \"y2\": 9.710144927536232, \"center_x\": 9.565217391304348, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0006758798652396694}, {\"x\": 9.710144927536234, \"y\": 9.420289855072465, \"x2\": 10.000000000000002, \"y2\": 9.710144927536232, \"center_x\": 9.855072463768117, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0005649748922351057}, {\"x\": 10.0, \"y\": 9.420289855072465, \"x2\": 10.289855072463768, \"y2\": 9.710144927536232, \"center_x\": 10.144927536231883, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0004678801297808369}, {\"x\": -10.0, \"y\": 9.710144927536234, \"x2\": -9.710144927536232, \"y2\": 10.000000000000002, \"center_x\": -9.855072463768117, \"center_y\": 9.855072463768117, \"value_uncond\": 5.3938497688053584e-08}, {\"x\": -9.710144927536232, \"y\": 9.710144927536234, \"x2\": -9.420289855072465, \"y2\": 10.000000000000002, \"center_x\": -9.565217391304348, \"center_y\": 9.855072463768117, \"value_uncond\": 8.427308861756474e-08}, {\"x\": -9.420289855072463, \"y\": 9.710144927536234, \"x2\": -9.130434782608695, \"y2\": 10.000000000000002, \"center_x\": -9.275362318840578, \"center_y\": 9.855072463768117, \"value_uncond\": 1.3044420511573268e-07}, {\"x\": -9.130434782608695, \"y\": 9.710144927536234, \"x2\": -8.840579710144928, \"y2\": 10.000000000000002, \"center_x\": -8.985507246376812, \"center_y\": 9.855072463768117, \"value_uncond\": 2.0003522761257018e-07}, {\"x\": -8.840579710144928, \"y\": 9.710144927536234, \"x2\": -8.55072463768116, \"y2\": 10.000000000000002, \"center_x\": -8.695652173913043, \"center_y\": 9.855072463768117, \"value_uncond\": 3.039023044647501e-07}, {\"x\": -8.55072463768116, \"y\": 9.710144927536234, \"x2\": -8.260869565217392, \"y2\": 10.000000000000002, \"center_x\": -8.405797101449277, \"center_y\": 9.855072463768117, \"value_uncond\": 4.5741174985874186e-07}, {\"x\": -8.26086956521739, \"y\": 9.710144927536234, \"x2\": -7.971014492753623, \"y2\": 10.000000000000002, \"center_x\": -8.115942028985508, \"center_y\": 9.855072463768117, \"value_uncond\": 6.820660832305835e-07}, {\"x\": -7.971014492753623, \"y\": 9.710144927536234, \"x2\": -7.681159420289855, \"y2\": 10.000000000000002, \"center_x\": -7.826086956521739, \"center_y\": 9.855072463768117, \"value_uncond\": 1.0076075345149136e-06}, {\"x\": -7.681159420289855, \"y\": 9.710144927536234, \"x2\": -7.391304347826088, \"y2\": 10.000000000000002, \"center_x\": -7.536231884057972, \"center_y\": 9.855072463768117, \"value_uncond\": 1.4746948822507115e-06}, {\"x\": -7.391304347826087, \"y\": 9.710144927536234, \"x2\": -7.101449275362319, \"y2\": 10.000000000000002, \"center_x\": -7.246376811594203, \"center_y\": 9.855072463768117, \"value_uncond\": 2.138251347460231e-06}, {\"x\": -7.101449275362318, \"y\": 9.710144927536234, \"x2\": -6.811594202898551, \"y2\": 10.000000000000002, \"center_x\": -6.956521739130435, \"center_y\": 9.855072463768117, \"value_uncond\": 3.071575184386158e-06}, {\"x\": -6.811594202898551, \"y\": 9.710144927536234, \"x2\": -6.521739130434783, \"y2\": 10.000000000000002, \"center_x\": -6.666666666666667, \"center_y\": 9.855072463768117, \"value_uncond\": 4.371287395038365e-06}, {\"x\": -6.521739130434782, \"y\": 9.710144927536234, \"x2\": -6.231884057971015, \"y2\": 10.000000000000002, \"center_x\": -6.3768115942028984, \"center_y\": 9.855072463768117, \"value_uncond\": 6.1631591916285065e-06}, {\"x\": -6.231884057971014, \"y\": 9.710144927536234, \"x2\": -5.942028985507246, \"y2\": 10.000000000000002, \"center_x\": -6.08695652173913, \"center_y\": 9.855072463768117, \"value_uncond\": 8.608812023840343e-06}, {\"x\": -5.942028985507246, \"y\": 9.710144927536234, \"x2\": -5.6521739130434785, \"y2\": 10.000000000000002, \"center_x\": -5.797101449275362, \"center_y\": 9.855072463768117, \"value_uncond\": 1.191321223800342e-05}, {\"x\": -5.6521739130434785, \"y\": 9.710144927536234, \"x2\": -5.362318840579711, \"y2\": 10.000000000000002, \"center_x\": -5.507246376811595, \"center_y\": 9.855072463768117, \"value_uncond\": 1.6332788847936102e-05}, {\"x\": -5.36231884057971, \"y\": 9.710144927536234, \"x2\": -5.072463768115942, \"y2\": 10.000000000000002, \"center_x\": -5.217391304347826, \"center_y\": 9.855072463768117, \"value_uncond\": 2.2183886295154995e-05}, {\"x\": -5.0724637681159415, \"y\": 9.710144927536234, \"x2\": -4.782608695652174, \"y2\": 10.000000000000002, \"center_x\": -4.927536231884058, \"center_y\": 9.855072463768117, \"value_uncond\": 2.9851126728746904e-05}, {\"x\": -4.782608695652174, \"y\": 9.710144927536234, \"x2\": -4.492753623188406, \"y2\": 10.000000000000002, \"center_x\": -4.63768115942029, \"center_y\": 9.855072463768117, \"value_uncond\": 3.979510366364091e-05}, {\"x\": -4.492753623188405, \"y\": 9.710144927536234, \"x2\": -4.202898550724638, \"y2\": 10.000000000000002, \"center_x\": -4.3478260869565215, \"center_y\": 9.855072463768117, \"value_uncond\": 5.25586700243223e-05}, {\"x\": -4.202898550724638, \"y\": 9.710144927536234, \"x2\": -3.91304347826087, \"y2\": 10.000000000000002, \"center_x\": -4.057971014492754, \"center_y\": 9.855072463768117, \"value_uncond\": 6.877093172144017e-05}, {\"x\": -3.913043478260869, \"y\": 9.710144927536234, \"x2\": -3.6231884057971016, \"y2\": 10.000000000000002, \"center_x\": -3.7681159420289854, \"center_y\": 9.855072463768117, \"value_uncond\": 8.914793013961349e-05}, {\"x\": -3.6231884057971016, \"y\": 9.710144927536234, \"x2\": -3.333333333333334, \"y2\": 10.000000000000002, \"center_x\": -3.4782608695652177, \"center_y\": 9.855072463768117, \"value_uncond\": 0.00011448891361810975}, {\"x\": -3.333333333333333, \"y\": 9.710144927536234, \"x2\": -3.0434782608695654, \"y2\": 10.000000000000002, \"center_x\": -3.1884057971014492, \"center_y\": 9.855072463768117, \"value_uncond\": 0.00014566708156635937}, {\"x\": -3.0434782608695645, \"y\": 9.710144927536234, \"x2\": -2.753623188405797, \"y2\": 10.000000000000002, \"center_x\": -2.8985507246376807, \"center_y\": 9.855072463768117, \"value_uncond\": 0.00018361375770189993}, {\"x\": -2.753623188405797, \"y\": 9.710144927536234, \"x2\": -2.4637681159420293, \"y2\": 10.000000000000002, \"center_x\": -2.608695652173913, \"center_y\": 9.855072463768117, \"value_uncond\": 0.00022929513091647812}, {\"x\": -2.4637681159420284, \"y\": 9.710144927536234, \"x2\": -2.1739130434782608, \"y2\": 10.000000000000002, \"center_x\": -2.3188405797101446, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0002836810077581909}, {\"x\": -2.1739130434782608, \"y\": 9.710144927536234, \"x2\": -1.8840579710144931, \"y2\": 10.000000000000002, \"center_x\": -2.028985507246377, \"center_y\": 9.855072463768117, \"value_uncond\": 0.00034770545491085266}, {\"x\": -1.8840579710144922, \"y\": 9.710144927536234, \"x2\": -1.5942028985507246, \"y2\": 10.000000000000002, \"center_x\": -1.7391304347826084, \"center_y\": 9.855072463768117, \"value_uncond\": 0.00042221976689926533}, {\"x\": -1.5942028985507246, \"y\": 9.710144927536234, \"x2\": -1.304347826086957, \"y2\": 10.000000000000002, \"center_x\": -1.4492753623188408, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0005079388527825467}, {\"x\": -1.304347826086957, \"y\": 9.710144927536234, \"x2\": -1.0144927536231894, \"y2\": 10.000000000000002, \"center_x\": -1.1594202898550732, \"center_y\": 9.855072463768117, \"value_uncond\": 0.000605382859477733}, {\"x\": -1.0144927536231876, \"y\": 9.710144927536234, \"x2\": -0.72463768115942, \"y2\": 10.000000000000002, \"center_x\": -0.8695652173913038, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0007148165870150437}, {\"x\": -0.72463768115942, \"y\": 9.710144927536234, \"x2\": -0.43478260869565233, \"y2\": 10.000000000000002, \"center_x\": -0.5797101449275361, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0008361899379559863}, {\"x\": -0.43478260869565233, \"y\": 9.710144927536234, \"x2\": -0.1449275362318847, \"y2\": 10.000000000000002, \"center_x\": -0.2898550724637685, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0009690832063289839}, {\"x\": -0.14492753623188293, \"y\": 9.710144927536234, \"x2\": 0.1449275362318847, \"y2\": 10.000000000000002, \"center_x\": 8.881784197001252e-16, \"center_y\": 9.855072463768117, \"value_uncond\": 0.001112661375447905}, {\"x\": 0.1449275362318847, \"y\": 9.710144927536234, \"x2\": 0.43478260869565233, \"y2\": 10.000000000000002, \"center_x\": 0.2898550724637685, \"center_y\": 9.855072463768117, \"value_uncond\": 0.001265641689221894}, {\"x\": 0.43478260869565233, \"y\": 9.710144927536234, \"x2\": 0.72463768115942, \"y2\": 10.000000000000002, \"center_x\": 0.5797101449275361, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0014262785327365166}, {\"x\": 0.72463768115942, \"y\": 9.710144927536234, \"x2\": 1.0144927536231876, \"y2\": 10.000000000000002, \"center_x\": 0.8695652173913038, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0015923690725763713}, {\"x\": 1.0144927536231894, \"y\": 9.710144927536234, \"x2\": 1.304347826086957, \"y2\": 10.000000000000002, \"center_x\": 1.1594202898550732, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0017612821633085447}, {\"x\": 1.304347826086957, \"y\": 9.710144927536234, \"x2\": 1.5942028985507246, \"y2\": 10.000000000000002, \"center_x\": 1.4492753623188408, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0019300117564770617}, {\"x\": 1.5942028985507246, \"y\": 9.710144927536234, \"x2\": 1.8840579710144922, \"y2\": 10.000000000000002, \"center_x\": 1.7391304347826084, \"center_y\": 9.855072463768117, \"value_uncond\": 0.002095254521496756}, {\"x\": 1.884057971014494, \"y\": 9.710144927536234, \"x2\": 2.1739130434782616, \"y2\": 10.000000000000002, \"center_x\": 2.028985507246378, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0022535097068581075}, {\"x\": 2.1739130434782616, \"y\": 9.710144927536234, \"x2\": 2.4637681159420293, \"y2\": 10.000000000000002, \"center_x\": 2.3188405797101455, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0024011975647697976}, {\"x\": 2.4637681159420293, \"y\": 9.710144927536234, \"x2\": 2.753623188405797, \"y2\": 10.000000000000002, \"center_x\": 2.608695652173913, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0025347910784750617}, {\"x\": 2.753623188405797, \"y\": 9.710144927536234, \"x2\": 3.0434782608695645, \"y2\": 10.000000000000002, \"center_x\": 2.8985507246376807, \"center_y\": 9.855072463768117, \"value_uncond\": 0.002650954416857331}, {\"x\": 3.0434782608695663, \"y\": 9.710144927536234, \"x2\": 3.333333333333334, \"y2\": 10.000000000000002, \"center_x\": 3.18840579710145, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0027466806302675847}, {\"x\": 3.333333333333334, \"y\": 9.710144927536234, \"x2\": 3.6231884057971016, \"y2\": 10.000000000000002, \"center_x\": 3.4782608695652177, \"center_y\": 9.855072463768117, \"value_uncond\": 0.002819420701044596}, {\"x\": 3.6231884057971016, \"y\": 9.710144927536234, \"x2\": 3.913043478260869, \"y2\": 10.000000000000002, \"center_x\": 3.7681159420289854, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0028671962367853064}, {\"x\": 3.913043478260871, \"y\": 9.710144927536234, \"x2\": 4.202898550724639, \"y2\": 10.000000000000002, \"center_x\": 4.057971014492755, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0028886888581993076}, {\"x\": 4.202898550724639, \"y\": 9.710144927536234, \"x2\": 4.492753623188406, \"y2\": 10.000000000000002, \"center_x\": 4.347826086956522, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0028833006458000928}, {\"x\": 4.492753623188406, \"y\": 9.710144927536234, \"x2\": 4.782608695652174, \"y2\": 10.000000000000002, \"center_x\": 4.63768115942029, \"center_y\": 9.855072463768117, \"value_uncond\": 0.002851181777457206}, {\"x\": 4.782608695652174, \"y\": 9.710144927536234, \"x2\": 5.0724637681159415, \"y2\": 10.000000000000002, \"center_x\": 4.927536231884058, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0027932235738485287}, {\"x\": 5.072463768115943, \"y\": 9.710144927536234, \"x2\": 5.362318840579711, \"y2\": 10.000000000000002, \"center_x\": 5.217391304347827, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0027110174012978747}, {\"x\": 5.362318840579711, \"y\": 9.710144927536234, \"x2\": 5.6521739130434785, \"y2\": 10.000000000000002, \"center_x\": 5.507246376811595, \"center_y\": 9.855072463768117, \"value_uncond\": 0.002606782076692864}, {\"x\": 5.6521739130434785, \"y\": 9.710144927536234, \"x2\": 5.942028985507246, \"y2\": 10.000000000000002, \"center_x\": 5.797101449275362, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0024832643962434085}, {\"x\": 5.942028985507246, \"y\": 9.710144927536234, \"x2\": 6.231884057971014, \"y2\": 10.000000000000002, \"center_x\": 6.08695652173913, \"center_y\": 9.855072463768117, \"value_uncond\": 0.002343619009778012}, {\"x\": 6.2318840579710155, \"y\": 9.710144927536234, \"x2\": 6.521739130434783, \"y2\": 10.000000000000002, \"center_x\": 6.376811594202899, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0021912749635933215}, {\"x\": 6.521739130434785, \"y\": 9.710144927536234, \"x2\": 6.8115942028985526, \"y2\": 10.000000000000002, \"center_x\": 6.666666666666669, \"center_y\": 9.855072463768117, \"value_uncond\": 0.002029796764753759}, {\"x\": 6.811594202898551, \"y\": 9.710144927536234, \"x2\": 7.101449275362318, \"y2\": 10.000000000000002, \"center_x\": 6.956521739130435, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0018627477596188527}, {\"x\": 7.10144927536232, \"y\": 9.710144927536234, \"x2\": 7.391304347826088, \"y2\": 10.000000000000002, \"center_x\": 7.246376811594204, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0016935630044696544}, {\"x\": 7.391304347826086, \"y\": 9.710144927536234, \"x2\": 7.681159420289854, \"y2\": 10.000000000000002, \"center_x\": 7.53623188405797, \"center_y\": 9.855072463768117, \"value_uncond\": 0.001525437719179798}, {\"x\": 7.681159420289855, \"y\": 9.710144927536234, \"x2\": 7.971014492753623, \"y2\": 10.000000000000002, \"center_x\": 7.826086956521739, \"center_y\": 9.855072463768117, \"value_uncond\": 0.001361235975297355}, {\"x\": 7.971014492753625, \"y\": 9.710144927536234, \"x2\": 8.260869565217392, \"y2\": 10.000000000000002, \"center_x\": 8.115942028985508, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0012034226194966226}, {\"x\": 8.26086956521739, \"y\": 9.710144927536234, \"x2\": 8.550724637681158, \"y2\": 10.000000000000002, \"center_x\": 8.405797101449274, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0010540197209255755}, {\"x\": 8.55072463768116, \"y\": 9.710144927536234, \"x2\": 8.840579710144928, \"y2\": 10.000000000000002, \"center_x\": 8.695652173913043, \"center_y\": 9.855072463768117, \"value_uncond\": 0.000914587197337893}, {\"x\": 8.84057971014493, \"y\": 9.710144927536234, \"x2\": 9.130434782608697, \"y2\": 10.000000000000002, \"center_x\": 8.985507246376812, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0007862258401290695}, {\"x\": 9.130434782608695, \"y\": 9.710144927536234, \"x2\": 9.420289855072463, \"y2\": 10.000000000000002, \"center_x\": 9.275362318840578, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0006695998124641526}, {\"x\": 9.420289855072465, \"y\": 9.710144927536234, \"x2\": 9.710144927536232, \"y2\": 10.000000000000002, \"center_x\": 9.565217391304348, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0005649748922351057}, {\"x\": 9.710144927536234, \"y\": 9.710144927536234, \"x2\": 10.000000000000002, \"y2\": 10.000000000000002, \"center_x\": 9.855072463768117, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0004722682909674797}, {\"x\": 10.0, \"y\": 9.710144927536234, \"x2\": 10.289855072463768, \"y2\": 10.000000000000002, \"center_x\": 10.144927536231883, \"center_y\": 9.855072463768117, \"value_uncond\": 0.00039110578594931143}, {\"x\": -10.0, \"y\": 10.0, \"x2\": -9.710144927536232, \"y2\": 10.289855072463768, \"center_x\": -9.855072463768117, \"center_y\": 10.144927536231883, \"value_uncond\": 4.466880147298297e-08}, {\"x\": -9.710144927536232, \"y\": 10.0, \"x2\": -9.420289855072465, \"y2\": 10.289855072463768, \"center_x\": -9.565217391304348, \"center_y\": 10.144927536231883, \"value_uncond\": 6.979018746024219e-08}, {\"x\": -9.420289855072463, \"y\": 10.0, \"x2\": -9.130434782608695, \"y2\": 10.289855072463768, \"center_x\": -9.275362318840578, \"center_y\": 10.144927536231883, \"value_uncond\": 1.080264848182129e-07}, {\"x\": -9.130434782608695, \"y\": 10.0, \"x2\": -8.840579710144928, \"y2\": 10.289855072463768, \"center_x\": -8.985507246376812, \"center_y\": 10.144927536231883, \"value_uncond\": 1.6565781867906704e-07}, {\"x\": -8.840579710144928, \"y\": 10.0, \"x2\": -8.55072463768116, \"y2\": 10.289855072463768, \"center_x\": -8.695652173913043, \"center_y\": 10.144927536231883, \"value_uncond\": 2.5167463476322513e-07}, {\"x\": -8.55072463768116, \"y\": 10.0, \"x2\": -8.260869565217392, \"y2\": 10.289855072463768, \"center_x\": -8.405797101449277, \"center_y\": 10.144927536231883, \"value_uncond\": 3.7880244207052163e-07}, {\"x\": -8.26086956521739, \"y\": 10.0, \"x2\": -7.971014492753623, \"y2\": 10.289855072463768, \"center_x\": -8.115942028985508, \"center_y\": 10.144927536231883, \"value_uncond\": 5.648484064106578e-07}, {\"x\": -7.971014492753623, \"y\": 10.0, \"x2\": -7.681159420289855, \"y2\": 10.289855072463768, \"center_x\": -7.826086956521739, \"center_y\": 10.144927536231883, \"value_uncond\": 8.344433540257313e-07}, {\"x\": -7.681159420289855, \"y\": 10.0, \"x2\": -7.391304347826088, \"y2\": 10.289855072463768, \"center_x\": -7.536231884057972, \"center_y\": 10.144927536231883, \"value_uncond\": 1.221258576934201e-06}, {\"x\": -7.391304347826087, \"y\": 10.0, \"x2\": -7.101449275362319, \"y2\": 10.289855072463768, \"center_x\": -7.246376811594203, \"center_y\": 10.144927536231883, \"value_uncond\": 1.770778368567611e-06}, {\"x\": -7.101449275362318, \"y\": 10.0, \"x2\": -6.811594202898551, \"y2\": 10.289855072463768, \"center_x\": -6.956521739130435, \"center_y\": 10.144927536231883, \"value_uncond\": 2.5437041816438e-06}, {\"x\": -6.811594202898551, \"y\": 10.0, \"x2\": -6.521739130434783, \"y2\": 10.289855072463768, \"center_x\": -6.666666666666667, \"center_y\": 10.144927536231883, \"value_uncond\": 3.6200520444522546e-06}, {\"x\": -6.521739130434782, \"y\": 10.0, \"x2\": -6.231884057971015, \"y2\": 10.289855072463768, \"center_x\": -6.3768115942028984, \"center_y\": 10.144927536231883, \"value_uncond\": 5.103978534393217e-06}, {\"x\": -6.231884057971014, \"y\": 10.0, \"x2\": -5.942028985507246, \"y2\": 10.289855072463768, \"center_x\": -6.08695652173913, \"center_y\": 10.144927536231883, \"value_uncond\": 7.1293293601746525e-06}, {\"x\": -5.942028985507246, \"y\": 10.0, \"x2\": -5.6521739130434785, \"y2\": 10.289855072463768, \"center_x\": -5.797101449275362, \"center_y\": 10.144927536231883, \"value_uncond\": 9.865846013036942e-06}, {\"x\": -5.6521739130434785, \"y\": 10.0, \"x2\": -5.362318840579711, \"y2\": 10.289855072463768, \"center_x\": -5.507246376811595, \"center_y\": 10.144927536231883, \"value_uncond\": 1.3525888443685628e-05}, {\"x\": -5.36231884057971, \"y\": 10.0, \"x2\": -5.072463768115942, \"y2\": 10.289855072463768, \"center_x\": -5.217391304347826, \"center_y\": 10.144927536231883, \"value_uncond\": 1.837143515839854e-05}, {\"x\": -5.0724637681159415, \"y\": 10.0, \"x2\": -4.782608695652174, \"y2\": 10.289855072463768, \"center_x\": -4.927536231884058, \"center_y\": 10.144927536231883, \"value_uncond\": 2.4721008384454473e-05}, {\"x\": -4.782608695652174, \"y\": 10.0, \"x2\": -4.492753623188406, \"y2\": 10.289855072463768, \"center_x\": -4.63768115942029, \"center_y\": 10.144927536231883, \"value_uncond\": 3.29560455211132e-05}, {\"x\": -4.492753623188405, \"y\": 10.0, \"x2\": -4.202898550724638, \"y2\": 10.289855072463768, \"center_x\": -4.3478260869565215, \"center_y\": 10.144927536231883, \"value_uncond\": 4.3526106540421027e-05}, {\"x\": -4.202898550724638, \"y\": 10.0, \"x2\": -3.91304347826087, \"y2\": 10.289855072463768, \"center_x\": -4.057971014492754, \"center_y\": 10.144927536231883, \"value_uncond\": 5.695218124062533e-05}, {\"x\": -3.913043478260869, \"y\": 10.0, \"x2\": -3.6231884057971016, \"y2\": 10.289855072463768, \"center_x\": -3.7681159420289854, \"center_y\": 10.144927536231883, \"value_uncond\": 7.382725444382787e-05}, {\"x\": -3.6231884057971016, \"y\": 10.0, \"x2\": -3.333333333333334, \"y2\": 10.289855072463768, \"center_x\": -3.4782608695652177, \"center_y\": 10.144927536231883, \"value_uncond\": 9.48132182479661e-05}, {\"x\": -3.333333333333333, \"y\": 10.0, \"x2\": -3.0434782608695654, \"y2\": 10.289855072463768, \"center_x\": -3.1884057971014492, \"center_y\": 10.144927536231883, \"value_uncond\": 0.00012063320682877794}, {\"x\": -3.0434782608695645, \"y\": 10.0, \"x2\": -2.753623188405797, \"y2\": 10.289855072463768, \"center_x\": -2.8985507246376807, \"center_y\": 10.144927536231883, \"value_uncond\": 0.00015205848961401678}, {\"x\": -2.753623188405797, \"y\": 10.0, \"x2\": -2.4637681159420293, \"y2\": 10.289855072463768, \"center_x\": -2.608695652173913, \"center_y\": 10.144927536231883, \"value_uncond\": 0.00018988920938927623}, {\"x\": -2.4637681159420284, \"y\": 10.0, \"x2\": -2.1739130434782608, \"y2\": 10.289855072463768, \"center_x\": -2.3188405797101446, \"center_y\": 10.144927536231883, \"value_uncond\": 0.00023492850487774955}, {\"x\": -2.1739130434782608, \"y\": 10.0, \"x2\": -1.8840579710144931, \"y2\": 10.289855072463768, \"center_x\": -2.028985507246377, \"center_y\": 10.144927536231883, \"value_uncond\": 0.00028794991707613093}, {\"x\": -1.8840579710144922, \"y\": 10.0, \"x2\": -1.5942028985507246, \"y2\": 10.289855072463768, \"center_x\": -1.7391304347826084, \"center_y\": 10.144927536231883, \"value_uncond\": 0.00034965843977834024}, {\"x\": -1.5942028985507246, \"y\": 10.0, \"x2\": -1.304347826086957, \"y2\": 10.289855072463768, \"center_x\": -1.4492753623188408, \"center_y\": 10.144927536231883, \"value_uncond\": 0.00042064612007878583}, {\"x\": -1.304347826086957, \"y\": 10.0, \"x2\": -1.0144927536231894, \"y2\": 10.289855072463768, \"center_x\": -1.1594202898550732, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0005013437141232592}, {\"x\": -1.0144927536231876, \"y\": 10.0, \"x2\": -0.72463768115942, \"y2\": 10.289855072463768, \"center_x\": -0.8695652173913038, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0005919705142629914}, {\"x\": -0.72463768115942, \"y\": 10.0, \"x2\": -0.43478260869565233, \"y2\": 10.289855072463768, \"center_x\": -0.5797101449275361, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0006924850326436628}, {\"x\": -0.43478260869565233, \"y\": 10.0, \"x2\": -0.1449275362318847, \"y2\": 10.289855072463768, \"center_x\": -0.2898550724637685, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0008025396926080617}, {\"x\": -0.14492753623188293, \"y\": 10.0, \"x2\": 0.1449275362318847, \"y2\": 10.289855072463768, \"center_x\": 8.881784197001252e-16, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0009214429807440965}, {\"x\": 0.1449275362318847, \"y\": 10.0, \"x2\": 0.43478260869565233, \"y2\": 10.289855072463768, \"center_x\": 0.2898550724637685, \"center_y\": 10.144927536231883, \"value_uncond\": 0.001048132591284704}, {\"x\": 0.43478260869565233, \"y\": 10.0, \"x2\": 0.72463768115942, \"y2\": 10.289855072463768, \"center_x\": 0.5797101449275361, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0011811629050635496}, {\"x\": 0.72463768115942, \"y\": 10.0, \"x2\": 1.0144927536231876, \"y2\": 10.289855072463768, \"center_x\": 0.8695652173913038, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0013187096605099884}, {\"x\": 1.0144927536231894, \"y\": 10.0, \"x2\": 1.304347826086957, \"y2\": 10.289855072463768, \"center_x\": 1.1594202898550732, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0014585938923575234}, {\"x\": 1.304347826086957, \"y\": 10.0, \"x2\": 1.5942028985507246, \"y2\": 10.289855072463768, \"center_x\": 1.4492753623188408, \"center_y\": 10.144927536231883, \"value_uncond\": 0.001598326161940756}, {\"x\": 1.5942028985507246, \"y\": 10.0, \"x2\": 1.8840579710144922, \"y2\": 10.289855072463768, \"center_x\": 1.7391304347826084, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0017351708384128314}, {\"x\": 1.884057971014494, \"y\": 10.0, \"x2\": 2.1739130434782616, \"y2\": 10.289855072463768, \"center_x\": 2.028985507246378, \"center_y\": 10.144927536231883, \"value_uncond\": 0.001866228798125752}, {\"x\": 2.1739130434782616, \"y\": 10.0, \"x2\": 2.4637681159420293, \"y2\": 10.289855072463768, \"center_x\": 2.3188405797101455, \"center_y\": 10.144927536231883, \"value_uncond\": 0.001988535497195876}, {\"x\": 2.4637681159420293, \"y\": 10.0, \"x2\": 2.753623188405797, \"y2\": 10.289855072463768, \"center_x\": 2.608695652173913, \"center_y\": 10.144927536231883, \"value_uncond\": 0.002099170060588627}, {\"x\": 2.753623188405797, \"y\": 10.0, \"x2\": 3.0434782608695645, \"y2\": 10.289855072463768, \"center_x\": 2.8985507246376807, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0021953699423622308}, {\"x\": 3.0434782608695663, \"y\": 10.0, \"x2\": 3.333333333333334, \"y2\": 10.289855072463768, \"center_x\": 3.18840579710145, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0022746449575343722}, {\"x\": 3.333333333333334, \"y\": 10.0, \"x2\": 3.6231884057971016, \"y2\": 10.289855072463768, \"center_x\": 3.4782608695652177, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0023348841543963327}, {\"x\": 3.6231884057971016, \"y\": 10.0, \"x2\": 3.913043478260869, \"y2\": 10.289855072463768, \"center_x\": 3.7681159420289854, \"center_y\": 10.144927536231883, \"value_uncond\": 0.002374449140681441}, {\"x\": 3.913043478260871, \"y\": 10.0, \"x2\": 4.202898550724639, \"y2\": 10.289855072463768, \"center_x\": 4.057971014492755, \"center_y\": 10.144927536231883, \"value_uncond\": 0.002392248109511243}, {\"x\": 4.202898550724639, \"y\": 10.0, \"x2\": 4.492753623188406, \"y2\": 10.289855072463768, \"center_x\": 4.347826086956522, \"center_y\": 10.144927536231883, \"value_uncond\": 0.002387785897913383}, {\"x\": 4.492753623188406, \"y\": 10.0, \"x2\": 4.782608695652174, \"y2\": 10.289855072463768, \"center_x\": 4.63768115942029, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0023611868746731966}, {\"x\": 4.782608695652174, \"y\": 10.0, \"x2\": 5.0724637681159415, \"y2\": 10.289855072463768, \"center_x\": 4.927536231884058, \"center_y\": 10.144927536231883, \"value_uncond\": 0.002313189180972133}, {\"x\": 5.072463768115943, \"y\": 10.0, \"x2\": 5.362318840579711, \"y2\": 10.289855072463768, \"center_x\": 5.217391304347827, \"center_y\": 10.144927536231883, \"value_uncond\": 0.002245110696051106}, {\"x\": 5.362318840579711, \"y\": 10.0, \"x2\": 5.6521739130434785, \"y2\": 10.289855072463768, \"center_x\": 5.507246376811595, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0021587889180850065}, {\"x\": 5.6521739130434785, \"y\": 10.0, \"x2\": 5.942028985507246, \"y2\": 10.289855072463768, \"center_x\": 5.797101449275362, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0020564985877478664}, {\"x\": 5.942028985507246, \"y\": 10.0, \"x2\": 6.231884057971014, \"y2\": 10.289855072463768, \"center_x\": 6.08695652173913, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0019408522069250963}, {\"x\": 6.2318840579710155, \"y\": 10.0, \"x2\": 6.521739130434783, \"y2\": 10.289855072463768, \"center_x\": 6.376811594202899, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0018146895170783953}, {\"x\": 6.521739130434785, \"y\": 10.0, \"x2\": 6.8115942028985526, \"y2\": 10.289855072463768, \"center_x\": 6.666666666666669, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0016809624405866655}, {\"x\": 6.811594202898551, \"y\": 10.0, \"x2\": 7.101449275362318, \"y2\": 10.289855072463768, \"center_x\": 6.956521739130435, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0015426219385989153}, {\"x\": 7.10144927536232, \"y\": 10.0, \"x2\": 7.391304347826088, \"y2\": 10.289855072463768, \"center_x\": 7.246376811594204, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0014025127297047169}, {\"x\": 7.391304347826086, \"y\": 10.0, \"x2\": 7.681159420289854, \"y2\": 10.289855072463768, \"center_x\": 7.53623188405797, \"center_y\": 10.144927536231883, \"value_uncond\": 0.001263280913597526}, {\"x\": 7.681159420289855, \"y\": 10.0, \"x2\": 7.971014492753623, \"y2\": 10.289855072463768, \"center_x\": 7.826086956521739, \"center_y\": 10.144927536231883, \"value_uncond\": 0.001127298351728233}, {\"x\": 7.971014492753625, \"y\": 10.0, \"x2\": 8.260869565217392, \"y2\": 10.289855072463768, \"center_x\": 8.115942028985508, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0009966062901729214}, {\"x\": 8.26086956521739, \"y\": 10.0, \"x2\": 8.550724637681158, \"y2\": 10.289855072463768, \"center_x\": 8.405797101449274, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0008728792917986891}, {\"x\": 8.55072463768116, \"y\": 10.0, \"x2\": 8.840579710144928, \"y2\": 10.289855072463768, \"center_x\": 8.695652173913043, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0007574091919261327}, {\"x\": 8.84057971014493, \"y\": 10.0, \"x2\": 9.130434782608697, \"y2\": 10.289855072463768, \"center_x\": 8.985507246376812, \"center_y\": 10.144927536231883, \"value_uncond\": 0.000651107603492506}, {\"x\": 9.130434782608695, \"y\": 10.0, \"x2\": 9.420289855072463, \"y2\": 10.289855072463768, \"center_x\": 9.275362318840578, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0005545245487238043}, {\"x\": 9.420289855072465, \"y\": 10.0, \"x2\": 9.710144927536232, \"y2\": 10.289855072463768, \"center_x\": 9.565217391304348, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0004678801297808369}, {\"x\": 9.710144927536234, \"y\": 10.0, \"x2\": 10.000000000000002, \"y2\": 10.289855072463768, \"center_x\": 9.855072463768117, \"center_y\": 10.144927536231883, \"value_uncond\": 0.00039110578594931143}, {\"x\": 10.0, \"y\": 10.0, \"x2\": 10.289855072463768, \"y2\": 10.289855072463768, \"center_x\": 10.144927536231883, \"center_y\": 10.144927536231883, \"value_uncond\": 0.00032389160722535483}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 11,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# | label: plot1\n",
    "plot_unconditional(components)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 12,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<style>\n",
       "  #altair-viz-b77b89d535254052bd1f9f32b9ea11bb.vega-embed {\n",
       "    width: 100%;\n",
       "    display: flex;\n",
       "  }\n",
       "\n",
       "  #altair-viz-b77b89d535254052bd1f9f32b9ea11bb.vega-embed details,\n",
       "  #altair-viz-b77b89d535254052bd1f9f32b9ea11bb.vega-embed details summary {\n",
       "    position: relative;\n",
       "  }\n",
       "</style>\n",
       "<div id=\"altair-viz-b77b89d535254052bd1f9f32b9ea11bb\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-b77b89d535254052bd1f9f32b9ea11bb\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-b77b89d535254052bd1f9f32b9ea11bb\");\n",
       "    }\n",
       "\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.20.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function maybeLoadScript(lib, version) {\n",
       "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
       "      return (VEGA_DEBUG[key] == version) ?\n",
       "        Promise.resolve(paths[lib]) :\n",
       "        new Promise(function(resolve, reject) {\n",
       "          var s = document.createElement('script');\n",
       "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "          s.async = true;\n",
       "          s.onload = () => {\n",
       "            VEGA_DEBUG[key] = version;\n",
       "            return resolve(paths[lib]);\n",
       "          };\n",
       "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "          s.src = paths[lib];\n",
       "        });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      let deps = [\"vega-embed\"];\n",
       "      require(deps, displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else {\n",
       "      maybeLoadScript(\"vega\", \"5\")\n",
       "        .then(() => maybeLoadScript(\"vega-lite\", \"5.20.1\"))\n",
       "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}}, \"layer\": [{\"data\": {\"name\": \"data-14fe821a8b2c524d22cd359632b5b9ec\"}, \"mark\": {\"type\": \"rect\"}, \"encoding\": {\"color\": {\"field\": \"value_cond\", \"legend\": null, \"type\": \"quantitative\"}, \"x\": {\"axis\": {\"grid\": false, \"labelFont\": \"Times\", \"labelFontSize\": 12, \"labelFontStyle\": \"normal\", \"titleFont\": \"Times\", \"titleFontSize\": 12, \"titleFontStyle\": \"italic\"}, \"field\": \"x\", \"scale\": {\"domain\": [-10, 10]}, \"title\": \"x\", \"type\": \"quantitative\"}, \"x2\": {\"field\": \"x2\"}, \"y\": {\"axis\": {\"grid\": false, \"labelFont\": \"Times\", \"labelFontSize\": 12, \"labelFontStyle\": \"normal\", \"titleFont\": \"Times\", \"titleFontSize\": 12, \"titleFontStyle\": \"italic\"}, \"field\": \"y\", \"scale\": {\"domain\": [-10, 10]}, \"title\": \"y\", \"type\": \"quantitative\"}, \"y2\": {\"field\": \"y2\"}}, \"transform\": [{\"calculate\": \"datum.value_uncond / (sqrt(2 * PI) * 0.5) * exp(- (pow(d - sqrt(pow(datum.center_x, 2) + pow(datum.center_y, 2)), 2)) / (2 * 0.5 * 0.5))\", \"as\": \"value_cond\"}]}, {\"data\": {\"name\": \"data-8c80cb8577b8cc407d46734c5f0d66d3\"}, \"mark\": {\"type\": \"line\", \"color\": \"gray\", \"strokeWidth\": 1}, \"encoding\": {\"order\": {\"field\": \"theta\", \"type\": \"quantitative\"}, \"x\": {\"axis\": {\"grid\": false, \"labelFont\": \"Times\", \"labelFontSize\": 12, \"labelFontStyle\": \"normal\", \"titleFont\": \"Times\", \"titleFontSize\": 12, \"titleFontStyle\": \"italic\"}, \"field\": \"x_scaled\", \"scale\": {\"domain\": [-10, 10]}, \"type\": \"quantitative\"}, \"y\": {\"axis\": {\"grid\": false, \"labelFont\": \"Times\", \"labelFontSize\": 12, \"labelFontStyle\": \"normal\", \"titleFont\": \"Times\", \"titleFontSize\": 12, \"titleFontStyle\": \"italic\"}, \"field\": \"y_scaled\", \"scale\": {\"domain\": [-10, 10]}, \"type\": \"quantitative\"}}, \"transform\": [{\"calculate\": \"datum.x * d\", \"as\": \"x_scaled\"}, {\"calculate\": \"datum.y * d\", \"as\": \"y_scaled\"}]}], \"height\": 300, \"params\": [{\"name\": \"d\", \"bind\": {\"input\": \"range\", \"max\": 7.656854249492381, \"min\": 3.6568542494923806, \"name\": \"\\ud835\\udc51\", \"step\": 0.1}, \"value\": 5.656854249492381}], \"width\": 300, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.20.1.json\", \"datasets\": {\"data-14fe821a8b2c524d22cd359632b5b9ec\": [{\"x\": -10.0, \"y\": -10.0, \"x2\": -9.710144927536232, \"y2\": -9.710144927536232, \"center_x\": -9.855072463768117, \"center_y\": -9.855072463768117, \"value_uncond\": 6.160399900836236e-12}, {\"x\": -9.710144927536232, \"y\": -10.0, \"x2\": -9.420289855072465, \"y2\": -9.710144927536232, \"center_x\": -9.565217391304348, \"center_y\": -9.855072463768117, \"value_uncond\": 9.624960816767312e-12}, {\"x\": -9.420289855072463, \"y\": -10.0, \"x2\": -9.130434782608695, \"y2\": -9.710144927536232, \"center_x\": -9.275362318840578, \"center_y\": -9.855072463768117, \"value_uncond\": 1.4898236004033224e-11}, {\"x\": -9.130434782608695, \"y\": -10.0, \"x2\": -8.840579710144928, \"y2\": -9.710144927536232, \"center_x\": -8.985507246376812, \"center_y\": -9.855072463768117, \"value_uncond\": 2.284633516259696e-11}, {\"x\": -8.840579710144928, \"y\": -10.0, \"x2\": -8.55072463768116, \"y2\": -9.710144927536232, \"center_x\": -8.695652173913043, \"center_y\": -9.855072463768117, \"value_uncond\": 3.470915591894953e-11}, {\"x\": -8.55072463768116, \"y\": -10.0, \"x2\": -8.260869565217392, \"y2\": -9.710144927536232, \"center_x\": -8.405797101449277, \"center_y\": -9.855072463768117, \"value_uncond\": 5.2241708969495986e-11}, {\"x\": -8.26086956521739, \"y\": -10.0, \"x2\": -7.971014492753623, \"y2\": -9.710144927536232, \"center_x\": -8.115942028985508, \"center_y\": -9.855072463768117, \"value_uncond\": 7.789983057737388e-11}, {\"x\": -7.971014492753623, \"y\": -10.0, \"x2\": -7.681159420289855, \"y2\": -9.710144927536232, \"center_x\": -7.826086956521739, \"center_y\": -9.855072463768117, \"value_uncond\": 1.150804271859119e-10}, {\"x\": -7.681159420289855, \"y\": -10.0, \"x2\": -7.391304347826088, \"y2\": -9.710144927536232, \"center_x\": -7.536231884057972, \"center_y\": -9.855072463768117, \"value_uncond\": 1.6842720127136773e-10}, {\"x\": -7.391304347826087, \"y\": -10.0, \"x2\": -7.101449275362319, \"y2\": -9.710144927536232, \"center_x\": -7.246376811594203, \"center_y\": -9.855072463768117, \"value_uncond\": 2.442130195215731e-10}, {\"x\": -7.101449275362318, \"y\": -10.0, \"x2\": -6.811594202898551, \"y2\": -9.710144927536232, \"center_x\": -6.956521739130435, \"center_y\": -9.855072463768117, \"value_uncond\": 3.508093898116566e-10}, {\"x\": -6.811594202898551, \"y\": -10.0, \"x2\": -6.521739130434783, \"y2\": -9.710144927536232, \"center_x\": -6.666666666666667, \"center_y\": -9.855072463768117, \"value_uncond\": 4.99251547394975e-10}, {\"x\": -6.521739130434782, \"y\": -10.0, \"x2\": -6.231884057971015, \"y2\": -9.710144927536232, \"center_x\": -6.3768115942028984, \"center_y\": -9.855072463768117, \"value_uncond\": 7.039040184716764e-10}, {\"x\": -6.231884057971014, \"y\": -10.0, \"x2\": -5.942028985507246, \"y2\": -9.710144927536232, \"center_x\": -6.08695652173913, \"center_y\": -9.855072463768117, \"value_uncond\": 9.832258407473207e-10}, {\"x\": -5.942028985507246, \"y\": -10.0, \"x2\": -5.6521739130434785, \"y2\": -9.710144927536232, \"center_x\": -5.797101449275362, \"center_y\": -9.855072463768117, \"value_uncond\": 1.360626540139841e-09}, {\"x\": -5.6521739130434785, \"y\": -10.0, \"x2\": -5.362318840579711, \"y2\": -9.710144927536232, \"center_x\": -5.507246376811595, \"center_y\": -9.855072463768117, \"value_uncond\": 1.8653932740416187e-09}, {\"x\": -5.36231884057971, \"y\": -10.0, \"x2\": -5.072463768115942, \"y2\": -9.710144927536232, \"center_x\": -5.217391304347826, \"center_y\": -9.855072463768117, \"value_uncond\": 2.5336562342392283e-09}, {\"x\": -5.0724637681159415, \"y\": -10.0, \"x2\": -4.782608695652174, \"y2\": -9.710144927536232, \"center_x\": -4.927536231884058, \"center_y\": -9.855072463768117, \"value_uncond\": 3.4093437159328184e-09}, {\"x\": -4.782608695652174, \"y\": -10.0, \"x2\": -4.492753623188406, \"y2\": -9.710144927536232, \"center_x\": -4.63768115942029, \"center_y\": -9.855072463768117, \"value_uncond\": 4.5450608224403395e-09}, {\"x\": -4.492753623188405, \"y\": -10.0, \"x2\": -4.202898550724638, \"y2\": -9.710144927536232, \"center_x\": -4.3478260869565215, \"center_y\": -9.855072463768117, \"value_uncond\": 6.002807632471971e-09}, {\"x\": -4.202898550724638, \"y\": -10.0, \"x2\": -3.91304347826087, \"y2\": -9.710144927536232, \"center_x\": -4.057971014492754, \"center_y\": -9.855072463768117, \"value_uncond\": 7.85443531273968e-09}, {\"x\": -3.913043478260869, \"y\": -10.0, \"x2\": -3.6231884057971016, \"y2\": -9.710144927536232, \"center_x\": -3.7681159420289854, \"center_y\": -9.855072463768117, \"value_uncond\": 1.0181724065953475e-08}, {\"x\": -3.6231884057971016, \"y\": -10.0, \"x2\": -3.333333333333334, \"y2\": -9.710144927536232, \"center_x\": -3.4782608695652177, \"center_y\": -9.855072463768117, \"value_uncond\": 1.3075957290817584e-08}, {\"x\": -3.333333333333333, \"y\": -10.0, \"x2\": -3.0434782608695654, \"y2\": -9.710144927536232, \"center_x\": -3.1884057971014492, \"center_y\": -9.855072463768117, \"value_uncond\": 1.663686445303529e-08}, {\"x\": -3.0434782608695645, \"y\": -10.0, \"x2\": -2.753623188405797, \"y2\": -9.710144927536232, \"center_x\": -2.8985507246376807, \"center_y\": -9.855072463768117, \"value_uncond\": 2.097081348614346e-08}, {\"x\": -2.753623188405797, \"y\": -10.0, \"x2\": -2.4637681159420293, \"y2\": -9.710144927536232, \"center_x\": -2.608695652173913, \"center_y\": -9.855072463768117, \"value_uncond\": 2.6188154329573736e-08}, {\"x\": -2.4637681159420284, \"y\": -10.0, \"x2\": -2.1739130434782608, \"y2\": -9.710144927536232, \"center_x\": -2.3188405797101446, \"center_y\": -9.855072463768117, \"value_uncond\": 3.239965010092863e-08}, {\"x\": -2.1739130434782608, \"y\": -10.0, \"x2\": -1.8840579710144931, \"y2\": -9.710144927536232, \"center_x\": -2.028985507246377, \"center_y\": -9.855072463768117, \"value_uncond\": 3.9711982012199266e-08}, {\"x\": -1.8840579710144922, \"y\": -10.0, \"x2\": -1.5942028985507246, \"y2\": -9.710144927536232, \"center_x\": -1.7391304347826084, \"center_y\": -9.855072463768117, \"value_uncond\": 4.822237773806992e-08}, {\"x\": -1.5942028985507246, \"y\": -10.0, \"x2\": -1.304347826086957, \"y2\": -9.710144927536232, \"center_x\": -1.4492753623188408, \"center_y\": -9.855072463768117, \"value_uncond\": 5.801248815659017e-08}, {\"x\": -1.304347826086957, \"y\": -10.0, \"x2\": -1.0144927536231894, \"y2\": -9.710144927536232, \"center_x\": -1.1594202898550732, \"center_y\": -9.855072463768117, \"value_uncond\": 6.914172005796482e-08}, {\"x\": -1.0144927536231876, \"y\": -10.0, \"x2\": -0.72463768115942, \"y2\": -9.710144927536232, \"center_x\": -0.8695652173913038, \"center_y\": -9.855072463768117, \"value_uncond\": 8.164031666641845e-08}, {\"x\": -0.72463768115942, \"y\": -10.0, \"x2\": -0.43478260869565233, \"y2\": -9.710144927536232, \"center_x\": -0.5797101449275361, \"center_y\": -9.855072463768117, \"value_uncond\": 9.550255627540823e-08}, {\"x\": -0.43478260869565233, \"y\": -10.0, \"x2\": -0.1449275362318847, \"y2\": -9.710144927536232, \"center_x\": -0.2898550724637685, \"center_y\": -9.855072463768117, \"value_uncond\": 1.1068050361167863e-07}, {\"x\": -0.14492753623188293, \"y\": -10.0, \"x2\": 0.1449275362318847, \"y2\": -9.710144927536232, \"center_x\": 8.881784197001252e-16, \"center_y\": -9.855072463768117, \"value_uncond\": 1.2707879011787393e-07}, {\"x\": 0.1449275362318847, \"y\": -10.0, \"x2\": 0.43478260869565233, \"y2\": -9.710144927536232, \"center_x\": 0.2898550724637685, \"center_y\": -9.855072463768117, \"value_uncond\": 1.445509102212839e-07}, {\"x\": 0.43478260869565233, \"y\": -10.0, \"x2\": 0.72463768115942, \"y2\": -9.710144927536232, \"center_x\": 0.5797101449275361, \"center_y\": -9.855072463768117, \"value_uncond\": 1.628974945214488e-07}, {\"x\": 0.72463768115942, \"y\": -10.0, \"x2\": 1.0144927536231876, \"y2\": -9.710144927536232, \"center_x\": 0.8695652173913038, \"center_y\": -9.855072463768117, \"value_uncond\": 1.8186695398019615e-07}, {\"x\": 1.0144927536231894, \"y\": -10.0, \"x2\": 1.304347826086957, \"y2\": -9.710144927536232, \"center_x\": 1.1594202898550732, \"center_y\": -9.855072463768117, \"value_uncond\": 2.0115878137617703e-07}, {\"x\": 1.304347826086957, \"y\": -10.0, \"x2\": 1.5942028985507246, \"y2\": -9.710144927536232, \"center_x\": 1.4492753623188408, \"center_y\": -9.855072463768117, \"value_uncond\": 2.2042965122937443e-07}, {\"x\": 1.5942028985507246, \"y\": -10.0, \"x2\": 1.8840579710144922, \"y2\": -9.710144927536232, \"center_x\": 1.7391304347826084, \"center_y\": -9.855072463768117, \"value_uncond\": 2.3930228500439113e-07}, {\"x\": 1.884057971014494, \"y\": -10.0, \"x2\": 2.1739130434782616, \"y2\": -9.710144927536232, \"center_x\": 2.028985507246378, \"center_y\": -9.855072463768117, \"value_uncond\": 2.573768564143178e-07}, {\"x\": 2.1739130434782616, \"y\": -10.0, \"x2\": 2.4637681159420293, \"y2\": -9.710144927536232, \"center_x\": 2.3188405797101455, \"center_y\": -9.855072463768117, \"value_uncond\": 2.742445168837601e-07}, {\"x\": 2.4637681159420293, \"y\": -10.0, \"x2\": 2.753623188405797, \"y2\": -9.710144927536232, \"center_x\": 2.608695652173913, \"center_y\": -9.855072463768117, \"value_uncond\": 2.8950244033097844e-07}, {\"x\": 2.753623188405797, \"y\": -10.0, \"x2\": 3.0434782608695645, \"y2\": -9.710144927536232, \"center_x\": 2.8985507246376807, \"center_y\": -9.855072463768117, \"value_uncond\": 3.027696362842212e-07}, {\"x\": 3.0434782608695663, \"y\": -10.0, \"x2\": 3.333333333333334, \"y2\": -9.710144927536232, \"center_x\": 3.18840579710145, \"center_y\": -9.855072463768117, \"value_uncond\": 3.137026763368097e-07}, {\"x\": 3.333333333333334, \"y\": -10.0, \"x2\": 3.6231884057971016, \"y2\": -9.710144927536232, \"center_x\": 3.4782608695652177, \"center_y\": -9.855072463768117, \"value_uncond\": 3.2201043320822097e-07}, {\"x\": 3.6231884057971016, \"y\": -10.0, \"x2\": 3.913043478260869, \"y2\": -9.710144927536232, \"center_x\": 3.7681159420289854, \"center_y\": -9.855072463768117, \"value_uncond\": 3.2746695161816275e-07}, {\"x\": 3.913043478260871, \"y\": -10.0, \"x2\": 4.202898550724639, \"y2\": -9.710144927536232, \"center_x\": 4.057971014492755, \"center_y\": -9.855072463768117, \"value_uncond\": 3.2992165741277494e-07}, {\"x\": 4.202898550724639, \"y\": -10.0, \"x2\": 4.492753623188406, \"y2\": -9.710144927536232, \"center_x\": 4.347826086956522, \"center_y\": -9.855072463768117, \"value_uncond\": 3.2930626127546e-07}, {\"x\": 4.492753623188406, \"y\": -10.0, \"x2\": 4.782608695652174, \"y2\": -9.710144927536232, \"center_x\": 4.63768115942029, \"center_y\": -9.855072463768117, \"value_uncond\": 3.256379152547972e-07}, {\"x\": 4.782608695652174, \"y\": -10.0, \"x2\": 5.0724637681159415, \"y2\": -9.710144927536232, \"center_x\": 4.927536231884058, \"center_y\": -9.855072463768117, \"value_uncond\": 3.1901841847480727e-07}, {\"x\": 5.072463768115943, \"y\": -10.0, \"x2\": 5.362318840579711, \"y2\": -9.710144927536232, \"center_x\": 5.217391304347827, \"center_y\": -9.855072463768117, \"value_uncond\": 3.096295233639719e-07}, {\"x\": 5.362318840579711, \"y\": -10.0, \"x2\": 5.6521739130434785, \"y2\": -9.710144927536232, \"center_x\": 5.507246376811595, \"center_y\": -9.855072463768117, \"value_uncond\": 2.977246444577404e-07}, {\"x\": 5.6521739130434785, \"y\": -10.0, \"x2\": 5.942028985507246, \"y2\": -9.710144927536232, \"center_x\": 5.797101449275362, \"center_y\": -9.855072463768117, \"value_uncond\": 2.8361749763298007e-07}, {\"x\": 5.942028985507246, \"y\": -10.0, \"x2\": 6.231884057971014, \"y2\": -9.710144927536232, \"center_x\": 6.08695652173913, \"center_y\": -9.855072463768117, \"value_uncond\": 2.6766838036410634e-07}, {\"x\": 6.2318840579710155, \"y\": -10.0, \"x2\": 6.521739130434783, \"y2\": -9.710144927536232, \"center_x\": 6.376811594202899, \"center_y\": -9.855072463768117, \"value_uncond\": 2.502689293738903e-07}, {\"x\": 6.521739130434785, \"y\": -10.0, \"x2\": 6.8115942028985526, \"y2\": -9.710144927536232, \"center_x\": 6.666666666666669, \"center_y\": -9.855072463768117, \"value_uncond\": 2.318262525705508e-07}, {\"x\": 6.811594202898551, \"y\": -10.0, \"x2\": 7.101449275362318, \"y2\": -9.710144927536232, \"center_x\": 6.956521739130435, \"center_y\": -9.855072463768117, \"value_uncond\": 2.1274732529638975e-07}, {\"x\": 7.10144927536232, \"y\": -10.0, \"x2\": 7.391304347826088, \"y2\": -9.710144927536232, \"center_x\": 7.246376811594204, \"center_y\": -9.855072463768117, \"value_uncond\": 1.9342447068386744e-07}, {\"x\": 7.391304347826086, \"y\": -10.0, \"x2\": 7.681159420289854, \"y2\": -9.710144927536232, \"center_x\": 7.53623188405797, \"center_y\": -9.855072463768117, \"value_uncond\": 1.7422261977549334e-07}, {\"x\": 7.681159420289855, \"y\": -10.0, \"x2\": 7.971014492753623, \"y2\": -9.710144927536232, \"center_x\": 7.826086956521739, \"center_y\": -9.855072463768117, \"value_uncond\": 1.5546888264731634e-07}, {\"x\": 7.971014492753625, \"y\": -10.0, \"x2\": 8.260869565217392, \"y2\": -9.710144927536232, \"center_x\": 8.115942028985508, \"center_y\": -9.855072463768117, \"value_uncond\": 1.3744477328023635e-07}, {\"x\": 8.26086956521739, \"y\": -10.0, \"x2\": 8.550724637681158, \"y2\": -9.710144927536232, \"center_x\": 8.405797101449274, \"center_y\": -9.855072463768117, \"value_uncond\": 1.203812353436658e-07}, {\"x\": 8.55072463768116, \"y\": -10.0, \"x2\": 8.840579710144928, \"y2\": -9.710144927536232, \"center_x\": 8.695652173913043, \"center_y\": -9.855072463768117, \"value_uncond\": 1.0445642947586815e-07}, {\"x\": 8.84057971014493, \"y\": -10.0, \"x2\": 9.130434782608697, \"y2\": -9.710144927536232, \"center_x\": 8.985507246376812, \"center_y\": -9.855072463768117, \"value_uncond\": 8.979607877804766e-08}, {\"x\": 9.130434782608695, \"y\": -10.0, \"x2\": 9.420289855072463, \"y2\": -9.710144927536232, \"center_x\": 9.275362318840578, \"center_y\": -9.855072463768117, \"value_uncond\": 7.647603836058899e-08}, {\"x\": 9.420289855072465, \"y\": -10.0, \"x2\": 9.710144927536232, \"y2\": -9.710144927536232, \"center_x\": 9.565217391304348, \"center_y\": -9.855072463768117, \"value_uncond\": 6.452666313083046e-08}, {\"x\": 9.710144927536234, \"y\": -10.0, \"x2\": 10.000000000000002, \"y2\": -9.710144927536232, \"center_x\": 9.855072463768117, \"center_y\": -9.855072463768117, \"value_uncond\": 5.3938497688053584e-08}, {\"x\": 10.0, \"y\": -10.0, \"x2\": 10.289855072463768, \"y2\": -9.710144927536232, \"center_x\": 10.144927536231883, \"center_y\": -9.855072463768117, \"value_uncond\": 4.466880147298297e-08}, {\"x\": -10.0, \"y\": -9.710144927536232, \"x2\": -9.710144927536232, \"y2\": -9.420289855072465, \"center_x\": -9.855072463768117, \"center_y\": -9.565217391304348, \"value_uncond\": 9.624960816767312e-12}, {\"x\": -9.710144927536232, \"y\": -9.710144927536232, \"x2\": -9.420289855072465, \"y2\": -9.420289855072465, \"center_x\": -9.565217391304348, \"center_y\": -9.565217391304348, \"value_uncond\": 1.503796380357231e-11}, {\"x\": -9.420289855072463, \"y\": -9.710144927536232, \"x2\": -9.130434782608695, \"y2\": -9.420289855072465, \"center_x\": -9.275362318840578, \"center_y\": -9.565217391304348, \"value_uncond\": 2.327688787838372e-11}, {\"x\": -9.130434782608695, \"y\": -9.710144927536232, \"x2\": -8.840579710144928, \"y2\": -9.420289855072465, \"center_x\": -8.985507246376812, \"center_y\": -9.565217391304348, \"value_uncond\": 3.56949360896001e-11}, {\"x\": -8.840579710144928, \"y\": -9.710144927536232, \"x2\": -8.55072463768116, \"y2\": -9.420289855072465, \"center_x\": -8.695652173913043, \"center_y\": -9.565217391304348, \"value_uncond\": 5.42293148302932e-11}, {\"x\": -8.55072463768116, \"y\": -9.710144927536232, \"x2\": -8.260869565217392, \"y2\": -9.420289855072465, \"center_x\": -8.405797101449277, \"center_y\": -9.565217391304348, \"value_uncond\": 8.162203914133939e-11}, {\"x\": -8.26086956521739, \"y\": -9.710144927536232, \"x2\": -7.971014492753623, \"y2\": -9.420289855072465, \"center_x\": -8.115942028985508, \"center_y\": -9.565217391304348, \"value_uncond\": 1.2171008846978545e-10}, {\"x\": -7.971014492753623, \"y\": -9.710144927536232, \"x2\": -7.681159420289855, \"y2\": -9.420289855072465, \"center_x\": -7.826086956521739, \"center_y\": -9.565217391304348, \"value_uncond\": 1.7980076298145616e-10}, {\"x\": -7.681159420289855, \"y\": -9.710144927536232, \"x2\": -7.391304347826088, \"y2\": -9.420289855072465, \"center_x\": -7.536231884057972, \"center_y\": -9.565217391304348, \"value_uncond\": 2.6314934725173203e-10}, {\"x\": -7.391304347826087, \"y\": -9.710144927536232, \"x2\": -7.101449275362319, \"y2\": -9.420289855072465, \"center_x\": -7.246376811594203, \"center_y\": -9.565217391304348, \"value_uncond\": 3.815565193292877e-10}, {\"x\": -7.101449275362318, \"y\": -9.710144927536232, \"x2\": -6.811594202898551, \"y2\": -9.420289855072465, \"center_x\": -6.956521739130435, \"center_y\": -9.565217391304348, \"value_uncond\": 5.481018579058321e-10}, {\"x\": -6.811594202898551, \"y\": -9.710144927536232, \"x2\": -6.521739130434783, \"y2\": -9.420289855072465, \"center_x\": -6.666666666666667, \"center_y\": -9.565217391304348, \"value_uncond\": 7.800267285789022e-10}, {\"x\": -6.521739130434782, \"y\": -9.710144927536232, \"x2\": -6.231884057971015, \"y2\": -9.420289855072465, \"center_x\": -6.3768115942028984, \"center_y\": -9.565217391304348, \"value_uncond\": 1.0997741551867875e-09}, {\"x\": -6.231884057971014, \"y\": -9.710144927536232, \"x2\": -5.942028985507246, \"y2\": -9.420289855072465, \"center_x\": -6.08695652173913, \"center_y\": -9.565217391304348, \"value_uncond\": 1.5361843944483886e-09}, {\"x\": -5.942028985507246, \"y\": -9.710144927536232, \"x2\": -5.6521739130434785, \"y2\": -9.420289855072465, \"center_x\": -5.797101449275362, \"center_y\": -9.565217391304348, \"value_uncond\": 2.125832307302315e-09}, {\"x\": -5.6521739130434785, \"y\": -9.710144927536232, \"x2\": -5.362318840579711, \"y2\": -9.420289855072465, \"center_x\": -5.507246376811595, \"center_y\": -9.565217391304348, \"value_uncond\": 2.9144759203172313e-09}, {\"x\": -5.36231884057971, \"y\": -9.710144927536232, \"x2\": -5.072463768115942, \"y2\": -9.420289855072465, \"center_x\": -5.217391304347826, \"center_y\": -9.565217391304348, \"value_uncond\": 3.958564763693418e-09}, {\"x\": -5.0724637681159415, \"y\": -9.710144927536232, \"x2\": -4.782608695652174, \"y2\": -9.420289855072465, \"center_x\": -4.927536231884058, \"center_y\": -9.565217391304348, \"value_uncond\": 5.326732063658852e-09}, {\"x\": -4.782608695652174, \"y\": -9.710144927536232, \"x2\": -4.492753623188406, \"y2\": -9.420289855072465, \"center_x\": -4.63768115942029, \"center_y\": -9.565217391304348, \"value_uncond\": 7.10116762385412e-09}, {\"x\": -4.492753623188405, \"y\": -9.710144927536232, \"x2\": -4.202898550724638, \"y2\": -9.420289855072465, \"center_x\": -4.3478260869565215, \"center_y\": -9.565217391304348, \"value_uncond\": 9.378739884287616e-09}, {\"x\": -4.202898550724638, \"y\": -9.710144927536232, \"x2\": -3.91304347826087, \"y2\": -9.420289855072465, \"center_x\": -4.057971014492754, \"center_y\": -9.565217391304348, \"value_uncond\": 1.2271708548123759e-08}, {\"x\": -3.913043478260869, \"y\": -9.710144927536232, \"x2\": -3.6231884057971016, \"y2\": -9.420289855072465, \"center_x\": -3.7681159420289854, \"center_y\": -9.565217391304348, \"value_uncond\": 1.5907846367024987e-08}, {\"x\": -3.6231884057971016, \"y\": -9.710144927536232, \"x2\": -3.333333333333334, \"y2\": -9.420289855072465, \"center_x\": -3.4782608695652177, \"center_y\": -9.565217391304348, \"value_uncond\": 2.0429773812047134e-08}, {\"x\": -3.333333333333333, \"y\": -9.710144927536232, \"x2\": -3.0434782608695654, \"y2\": -9.420289855072465, \"center_x\": -3.1884057971014492, \"center_y\": -9.565217391304348, \"value_uncond\": 2.5993307423532162e-08}, {\"x\": -3.0434782608695645, \"y\": -9.710144927536232, \"x2\": -2.753623188405797, \"y2\": -9.420289855072465, \"center_x\": -2.8985507246376807, \"center_y\": -9.565217391304348, \"value_uncond\": 3.276463563225292e-08}, {\"x\": -2.753623188405797, \"y\": -9.710144927536232, \"x2\": -2.4637681159420293, \"y2\": -9.420289855072465, \"center_x\": -2.608695652173913, \"center_y\": -9.565217391304348, \"value_uncond\": 4.0916168323973e-08}, {\"x\": -2.4637681159420284, \"y\": -9.710144927536232, \"x2\": -2.1739130434782608, \"y2\": -9.420289855072465, \"center_x\": -2.3188405797101446, \"center_y\": -9.565217391304348, \"value_uncond\": 5.0620960930811905e-08}, {\"x\": -2.1739130434782608, \"y\": -9.710144927536232, \"x2\": -1.8840579710144931, \"y2\": -9.420289855072465, \"center_x\": -2.028985507246377, \"center_y\": -9.565217391304348, \"value_uncond\": 6.204569134735891e-08}, {\"x\": -1.8840579710144922, \"y\": -9.710144927536232, \"x2\": -1.5942028985507246, \"y2\": -9.420289855072465, \"center_x\": -1.7391304347826084, \"center_y\": -9.565217391304348, \"value_uncond\": 7.53422673351565e-08}, {\"x\": -1.5942028985507246, \"y\": -9.710144927536232, \"x2\": -1.304347826086957, \"y2\": -9.420289855072465, \"center_x\": -1.4492753623188408, \"center_y\": -9.565217391304348, \"value_uncond\": 9.063825959002471e-08}, {\"x\": -1.304347826086957, \"y\": -9.710144927536232, \"x2\": -1.0144927536231894, \"y2\": -9.420289855072465, \"center_x\": -1.1594202898550732, \"center_y\": -9.565217391304348, \"value_uncond\": 1.080264848182127e-07}, {\"x\": -1.0144927536231876, \"y\": -9.710144927536232, \"x2\": -0.72463768115942, \"y2\": -9.420289855072465, \"center_x\": -0.8695652173913038, \"center_y\": -9.565217391304348, \"value_uncond\": 1.2755419479766016e-07}, {\"x\": -0.72463768115942, \"y\": -9.710144927536232, \"x2\": -0.43478260869565233, \"y2\": -9.420289855072465, \"center_x\": -0.5797101449275361, \"center_y\": -9.565217391304348, \"value_uncond\": 1.4921244997863546e-07}, {\"x\": -0.43478260869565233, \"y\": -9.710144927536232, \"x2\": -0.1449275362318847, \"y2\": -9.420289855072465, \"center_x\": -0.2898550724637685, \"center_y\": -9.565217391304348, \"value_uncond\": 1.7292635666361052e-07}, {\"x\": -0.14492753623188293, \"y\": -9.710144927536232, \"x2\": 0.1449275362318847, \"y2\": -9.420289855072465, \"center_x\": 8.881784197001252e-16, \"center_y\": -9.565217391304348, \"value_uncond\": 1.98546911761475e-07}, {\"x\": 0.1449275362318847, \"y\": -9.710144927536232, \"x2\": 0.43478260869565233, \"y2\": -9.420289855072465, \"center_x\": 0.2898550724637685, \"center_y\": -9.565217391304348, \"value_uncond\": 2.258452161066759e-07}, {\"x\": 0.43478260869565233, \"y\": -9.710144927536232, \"x2\": 0.72463768115942, \"y2\": -9.420289855072465, \"center_x\": 0.5797101449275361, \"center_y\": -9.565217391304348, \"value_uncond\": 2.545097765009833e-07}, {\"x\": 0.72463768115942, \"y\": -9.710144927536232, \"x2\": 1.0144927536231876, \"y2\": -9.420289855072465, \"center_x\": 0.8695652173913038, \"center_y\": -9.565217391304348, \"value_uncond\": 2.841475121909858e-07}, {\"x\": 1.0144927536231894, \"y\": -9.710144927536232, \"x2\": 1.304347826086957, \"y2\": -9.420289855072465, \"center_x\": 1.1594202898550732, \"center_y\": -9.565217391304348, \"value_uncond\": 3.1428891303493833e-07}, {\"x\": 1.304347826086957, \"y\": -9.710144927536232, \"x2\": 1.5942028985507246, \"y2\": -9.420289855072465, \"center_x\": 1.4492753623188408, \"center_y\": -9.565217391304348, \"value_uncond\": 3.4439756997730165e-07}, {\"x\": 1.5942028985507246, \"y\": -9.710144927536232, \"x2\": 1.8840579710144922, \"y2\": -9.420289855072465, \"center_x\": 1.7391304347826084, \"center_y\": -9.565217391304348, \"value_uncond\": 3.738840259732958e-07}, {\"x\": 1.884057971014494, \"y\": -9.710144927536232, \"x2\": 2.1739130434782616, \"y2\": -9.420289855072465, \"center_x\": 2.028985507246378, \"center_y\": -9.565217391304348, \"value_uncond\": 4.021235955468218e-07}, {\"x\": 2.1739130434782616, \"y\": -9.710144927536232, \"x2\": 2.4637681159420293, \"y2\": -9.420289855072465, \"center_x\": 2.3188405797101455, \"center_y\": -9.565217391304348, \"value_uncond\": 4.284774968685328e-07}, {\"x\": 2.4637681159420293, \"y\": -9.710144927536232, \"x2\": 2.753623188405797, \"y2\": -9.420289855072465, \"center_x\": 2.608695652173913, \"center_y\": -9.565217391304348, \"value_uncond\": 4.523163576062548e-07}, {\"x\": 2.753623188405797, \"y\": -9.710144927536232, \"x2\": 3.0434782608695645, \"y2\": -9.420289855072465, \"center_x\": 2.8985507246376807, \"center_y\": -9.565217391304348, \"value_uncond\": 4.7304492121476363e-07}, {\"x\": 3.0434782608695663, \"y\": -9.710144927536232, \"x2\": 3.333333333333334, \"y2\": -9.420289855072465, \"center_x\": 3.18840579710145, \"center_y\": -9.565217391304348, \"value_uncond\": 4.901266178267039e-07}, {\"x\": 3.333333333333334, \"y\": -9.710144927536232, \"x2\": 3.6231884057971016, \"y2\": -9.420289855072465, \"center_x\": 3.4782608695652177, \"center_y\": -9.565217391304348, \"value_uncond\": 5.031065924468107e-07}, {\"x\": 3.6231884057971016, \"y\": -9.710144927536232, \"x2\": 3.913043478260869, \"y2\": -9.420289855072465, \"center_x\": 3.7681159420289854, \"center_y\": -9.565217391304348, \"value_uncond\": 5.116318143053023e-07}, {\"x\": 3.913043478260871, \"y\": -9.710144927536232, \"x2\": 4.202898550724639, \"y2\": -9.420289855072465, \"center_x\": 4.057971014492755, \"center_y\": -9.565217391304348, \"value_uncond\": 5.154670275171308e-07}, {\"x\": 4.202898550724639, \"y\": -9.710144927536232, \"x2\": 4.492753623188406, \"y2\": -9.420289855072465, \"center_x\": 4.347826086956522, \"center_y\": -9.565217391304348, \"value_uncond\": 5.145055373860044e-07}, {\"x\": 4.492753623188406, \"y\": -9.710144927536232, \"x2\": 4.782608695652174, \"y2\": -9.420289855072465, \"center_x\": 4.63768115942029, \"center_y\": -9.565217391304348, \"value_uncond\": 5.087741421390123e-07}, {\"x\": 4.782608695652174, \"y\": -9.710144927536232, \"x2\": 5.0724637681159415, \"y2\": -9.420289855072465, \"center_x\": 4.927536231884058, \"center_y\": -9.565217391304348, \"value_uncond\": 4.984318919345294e-07}, {\"x\": 5.072463768115943, \"y\": -9.710144927536232, \"x2\": 5.362318840579711, \"y2\": -9.420289855072465, \"center_x\": 5.217391304347827, \"center_y\": -9.565217391304348, \"value_uncond\": 4.837627553509998e-07}, {\"x\": 5.362318840579711, \"y\": -9.710144927536232, \"x2\": 5.6521739130434785, \"y2\": -9.420289855072465, \"center_x\": 5.507246376811595, \"center_y\": -9.565217391304348, \"value_uncond\": 4.6516266528456056e-07}, {\"x\": 5.6521739130434785, \"y\": -9.710144927536232, \"x2\": 5.942028985507246, \"y2\": -9.420289855072465, \"center_x\": 5.797101449275362, \"center_y\": -9.565217391304348, \"value_uncond\": 4.4312176897744417e-07}, {\"x\": 5.942028985507246, \"y\": -9.710144927536232, \"x2\": 6.231884057971014, \"y2\": -9.420289855072465, \"center_x\": 6.08695652173913, \"center_y\": -9.565217391304348, \"value_uncond\": 4.182029923970312e-07}, {\"x\": 6.2318840579710155, \"y\": -9.710144927536232, \"x2\": 6.521739130434783, \"y2\": -9.420289855072465, \"center_x\": 6.376811594202899, \"center_y\": -9.565217391304348, \"value_uncond\": 3.9101822570820645e-07}, {\"x\": 6.521739130434785, \"y\": -9.710144927536232, \"x2\": 6.8115942028985526, \"y2\": -9.420289855072465, \"center_x\": 6.666666666666669, \"center_y\": -9.565217391304348, \"value_uncond\": 3.6220353113548075e-07}, {\"x\": 6.811594202898551, \"y\": -9.710144927536232, \"x2\": 7.101449275362318, \"y2\": -9.420289855072465, \"center_x\": 6.956521739130435, \"center_y\": -9.565217391304348, \"value_uncond\": 3.32394763783409e-07}, {\"x\": 7.10144927536232, \"y\": -9.710144927536232, \"x2\": 7.391304347826088, \"y2\": -9.420289855072465, \"center_x\": 7.246376811594204, \"center_y\": -9.565217391304348, \"value_uncond\": 3.022048862580275e-07}, {\"x\": 7.391304347826086, \"y\": -9.710144927536232, \"x2\": 7.681159420289854, \"y2\": -9.420289855072465, \"center_x\": 7.53623188405797, \"center_y\": -9.565217391304348, \"value_uncond\": 2.7220406397741216e-07}, {\"x\": 7.681159420289855, \"y\": -9.710144927536232, \"x2\": 7.971014492753623, \"y2\": -9.420289855072465, \"center_x\": 7.826086956521739, \"center_y\": -9.565217391304348, \"value_uncond\": 2.4290337117625886e-07}, {\"x\": 7.971014492753625, \"y\": -9.710144927536232, \"x2\": 8.260869565217392, \"y2\": -9.420289855072465, \"center_x\": 8.115942028985508, \"center_y\": -9.565217391304348, \"value_uncond\": 2.1474264310538734e-07}, {\"x\": 8.26086956521739, \"y\": -9.710144927536232, \"x2\": 8.550724637681158, \"y2\": -9.420289855072465, \"center_x\": 8.405797101449274, \"center_y\": -9.565217391304348, \"value_uncond\": 1.880827043548819e-07}, {\"x\": 8.55072463768116, \"y\": -9.710144927536232, \"x2\": 8.840579710144928, \"y2\": -9.420289855072465, \"center_x\": 8.695652173913043, \"center_y\": -9.565217391304348, \"value_uncond\": 1.6320191171812923e-07}, {\"x\": 8.84057971014493, \"y\": -9.710144927536232, \"x2\": 9.130434782608697, \"y2\": -9.420289855072465, \"center_x\": 8.985507246376812, \"center_y\": -9.565217391304348, \"value_uncond\": 1.402966939890929e-07}, {\"x\": 9.130434782608695, \"y\": -9.710144927536232, \"x2\": 9.420289855072463, \"y2\": -9.420289855072465, \"center_x\": 9.275362318840578, \"center_y\": -9.565217391304348, \"value_uncond\": 1.1948556660134085e-07}, {\"x\": 9.420289855072465, \"y\": -9.710144927536232, \"x2\": 9.710144927536232, \"y2\": -9.420289855072465, \"center_x\": 9.565217391304348, \"center_y\": -9.565217391304348, \"value_uncond\": 1.0081595582564033e-07}, {\"x\": 9.710144927536234, \"y\": -9.710144927536232, \"x2\": 10.000000000000002, \"y2\": -9.420289855072465, \"center_x\": 9.855072463768117, \"center_y\": -9.565217391304348, \"value_uncond\": 8.427308861756474e-08}, {\"x\": 10.0, \"y\": -9.710144927536232, \"x2\": 10.289855072463768, \"y2\": -9.420289855072465, \"center_x\": 10.144927536231883, \"center_y\": -9.565217391304348, \"value_uncond\": 6.979018746024219e-08}, {\"x\": -10.0, \"y\": -9.420289855072463, \"x2\": -9.710144927536232, \"y2\": -9.130434782608695, \"center_x\": -9.855072463768117, \"center_y\": -9.275362318840578, \"value_uncond\": 1.4898236004033224e-11}, {\"x\": -9.710144927536232, \"y\": -9.420289855072463, \"x2\": -9.420289855072465, \"y2\": -9.130434782608695, \"center_x\": -9.565217391304348, \"center_y\": -9.275362318840578, \"value_uncond\": 2.327688787838372e-11}, {\"x\": -9.420289855072463, \"y\": -9.420289855072463, \"x2\": -9.130434782608695, \"y2\": -9.130434782608695, \"center_x\": -9.275362318840578, \"center_y\": -9.275362318840578, \"value_uncond\": 3.6029712292174674e-11}, {\"x\": -9.130434782608695, \"y\": -9.420289855072463, \"x2\": -8.840579710144928, \"y2\": -9.130434782608695, \"center_x\": -8.985507246376812, \"center_y\": -9.275362318840578, \"value_uncond\": 5.52512983829845e-11}, {\"x\": -8.840579710144928, \"y\": -9.420289855072463, \"x2\": -8.55072463768116, \"y2\": -9.130434782608695, \"center_x\": -8.695652173913043, \"center_y\": -9.275362318840578, \"value_uncond\": 8.394019945216559e-11}, {\"x\": -8.55072463768116, \"y\": -9.420289855072463, \"x2\": -8.260869565217392, \"y2\": -9.130434782608695, \"center_x\": -8.405797101449277, \"center_y\": -9.275362318840578, \"value_uncond\": 1.2634071196837675e-10}, {\"x\": -8.26086956521739, \"y\": -9.420289855072463, \"x2\": -7.971014492753623, \"y2\": -9.130434782608695, \"center_x\": -8.115942028985508, \"center_y\": -9.275362318840578, \"value_uncond\": 1.883920004054249e-10}, {\"x\": -7.971014492753623, \"y\": -9.420289855072463, \"x2\": -7.681159420289855, \"y2\": -9.130434782608695, \"center_x\": -7.826086956521739, \"center_y\": -9.275362318840578, \"value_uncond\": 2.783091018860542e-10}, {\"x\": -7.681159420289855, \"y\": -9.420289855072463, \"x2\": -7.391304347826088, \"y2\": -9.130434782608695, \"center_x\": -7.536231884057972, \"center_y\": -9.275362318840578, \"value_uncond\": 4.0732228985637995e-10}, {\"x\": -7.391304347826087, \"y\": -9.420289855072463, \"x2\": -7.101449275362319, \"y2\": -9.130434782608695, \"center_x\": -7.246376811594203, \"center_y\": -9.275362318840578, \"value_uncond\": 5.906017886267534e-10}, {\"x\": -7.101449275362318, \"y\": -9.420289855072463, \"x2\": -6.811594202898551, \"y2\": -9.130434782608695, \"center_x\": -6.956521739130435, \"center_y\": -9.275362318840578, \"value_uncond\": 8.48393150765341e-10}, {\"x\": -6.811594202898551, \"y\": -9.420289855072463, \"x2\": -6.521739130434783, \"y2\": -9.130434782608695, \"center_x\": -6.666666666666667, \"center_y\": -9.275362318840578, \"value_uncond\": 1.207383854651945e-09}, {\"x\": -6.521739130434782, \"y\": -9.420289855072463, \"x2\": -6.231884057971015, \"y2\": -9.130434782608695, \"center_x\": -6.3768115942028984, \"center_y\": -9.275362318840578, \"value_uncond\": 1.7023128952967586e-09}, {\"x\": -6.231884057971014, \"y\": -9.420289855072463, \"x2\": -5.942028985507246, \"y2\": -9.130434782608695, \"center_x\": -6.08695652173913, \"center_y\": -9.275362318840578, \"value_uncond\": 2.3778213844086803e-09}, {\"x\": -5.942028985507246, \"y\": -9.420289855072463, \"x2\": -5.6521739130434785, \"y2\": -9.130434782608695, \"center_x\": -5.797101449275362, \"center_y\": -9.275362318840578, \"value_uncond\": 3.290522634026223e-09}, {\"x\": -5.6521739130434785, \"y\": -9.420289855072463, \"x2\": -5.362318840579711, \"y2\": -9.130434782608695, \"center_x\": -5.507246376811595, \"center_y\": -9.275362318840578, \"value_uncond\": 4.511244348477409e-09}, {\"x\": -5.36231884057971, \"y\": -9.420289855072463, \"x2\": -5.072463768115942, \"y2\": -9.130434782608695, \"center_x\": -5.217391304347826, \"center_y\": -9.275362318840578, \"value_uncond\": 6.127363343029421e-09}, {\"x\": -5.0724637681159415, \"y\": -9.420289855072463, \"x2\": -4.782608695652174, \"y2\": -9.130434782608695, \"center_x\": -4.927536231884058, \"center_y\": -9.275362318840578, \"value_uncond\": 8.245115271159551e-09}, {\"x\": -4.782608695652174, \"y\": -9.420289855072463, \"x2\": -4.492753623188406, \"y2\": -9.130434782608695, \"center_x\": -4.63768115942029, \"center_y\": -9.275362318840578, \"value_uncond\": 1.0991719673297463e-08}, {\"x\": -4.492753623188405, \"y\": -9.420289855072463, \"x2\": -4.202898550724638, \"y2\": -9.130434782608695, \"center_x\": -4.3478260869565215, \"center_y\": -9.275362318840578, \"value_uncond\": 1.451711678380478e-08}, {\"x\": -4.202898550724638, \"y\": -9.420289855072463, \"x2\": -3.91304347826087, \"y2\": -9.130434782608695, \"center_x\": -4.057971014492754, \"center_y\": -9.275362318840578, \"value_uncond\": 1.8995070588148614e-08}, {\"x\": -3.913043478260869, \"y\": -9.420289855072463, \"x2\": -3.6231884057971016, \"y2\": -9.130434782608695, \"center_x\": -3.7681159420289854, \"center_y\": -9.275362318840578, \"value_uncond\": 2.4623357331384997e-08}, {\"x\": -3.6231884057971016, \"y\": -9.420289855072463, \"x2\": -3.333333333333334, \"y2\": -9.130434782608695, \"center_x\": -3.4782608695652177, \"center_y\": -9.275362318840578, \"value_uncond\": 3.16227356718863e-08}, {\"x\": -3.333333333333333, \"y\": -9.420289855072463, \"x2\": -3.0434782608695654, \"y2\": -9.130434782608695, \"center_x\": -3.1884057971014492, \"center_y\": -9.275362318840578, \"value_uncond\": 4.0234390133469245e-08}, {\"x\": -3.0434782608695645, \"y\": -9.420289855072463, \"x2\": -2.753623188405797, \"y2\": -9.130434782608695, \"center_x\": -2.8985507246376807, \"center_y\": -9.275362318840578, \"value_uncond\": 5.071555962961394e-08}, {\"x\": -2.753623188405797, \"y\": -9.420289855072463, \"x2\": -2.4637681159420293, \"y2\": -9.130434782608695, \"center_x\": -2.608695652173913, \"center_y\": -9.275362318840578, \"value_uncond\": 6.333311310830191e-08}, {\"x\": -2.4637681159420284, \"y\": -9.420289855072463, \"x2\": -2.1739130434782608, \"y2\": -9.130434782608695, \"center_x\": -2.3188405797101446, \"center_y\": -9.275362318840578, \"value_uncond\": 7.835491874256564e-08}, {\"x\": -2.1739130434782608, \"y\": -9.420289855072463, \"x2\": -1.8840579710144931, \"y2\": -9.130434782608695, \"center_x\": -2.028985507246377, \"center_y\": -9.275362318840578, \"value_uncond\": 9.603897307467887e-08}, {\"x\": -1.8840579710144922, \"y\": -9.420289855072463, \"x2\": -1.5942028985507246, \"y2\": -9.130434782608695, \"center_x\": -1.7391304347826084, \"center_y\": -9.275362318840578, \"value_uncond\": 1.1662041032756351e-07}, {\"x\": -1.5942028985507246, \"y\": -9.420289855072463, \"x2\": -1.304347826086957, \"y2\": -9.130434782608695, \"center_x\": -1.4492753623188408, \"center_y\": -9.275362318840578, \"value_uncond\": 1.4029669398909313e-07}, {\"x\": -1.304347826086957, \"y\": -9.420289855072463, \"x2\": -1.0144927536231894, \"y2\": -9.130434782608695, \"center_x\": -1.1594202898550732, \"center_y\": -9.275362318840578, \"value_uncond\": 1.6721149271632956e-07}, {\"x\": -1.0144927536231876, \"y\": -9.420289855072463, \"x2\": -0.72463768115942, \"y2\": -9.130434782608695, \"center_x\": -0.8695652173913038, \"center_y\": -9.275362318840578, \"value_uncond\": 1.9743794635396995e-07}, {\"x\": -0.72463768115942, \"y\": -9.420289855072463, \"x2\": -0.43478260869565233, \"y2\": -9.130434782608695, \"center_x\": -0.5797101449275361, \"center_y\": -9.275362318840578, \"value_uncond\": 2.3096221759667814e-07}, {\"x\": -0.43478260869565233, \"y\": -9.420289855072463, \"x2\": -0.1449275362318847, \"y2\": -9.130434782608695, \"center_x\": -0.2898550724637685, \"center_y\": -9.275362318840578, \"value_uncond\": 2.6766838036410634e-07}, {\"x\": -0.14492753623188293, \"y\": -9.420289855072463, \"x2\": 0.1449275362318847, \"y2\": -9.130434782608695, \"center_x\": 8.881784197001252e-16, \"center_y\": -9.275362318840578, \"value_uncond\": 3.073257965000113e-07}, {\"x\": 0.1449275362318847, \"y\": -9.420289855072463, \"x2\": 0.43478260869565233, \"y2\": -9.130434782608695, \"center_x\": 0.2898550724637685, \"center_y\": -9.275362318840578, \"value_uncond\": 3.4958015871375006e-07}, {\"x\": 0.43478260869565233, \"y\": -9.420289855072463, \"x2\": 0.72463768115942, \"y2\": -9.130434782608695, \"center_x\": 0.5797101449275361, \"center_y\": -9.275362318840578, \"value_uncond\": 3.9394931447823936e-07}, {\"x\": 0.72463768115942, \"y\": -9.420289855072463, \"x2\": 1.0144927536231876, \"y2\": -9.130434782608695, \"center_x\": 0.8695652173913038, \"center_y\": -9.275362318840578, \"value_uncond\": 4.398248239312864e-07}, {\"x\": 1.0144927536231894, \"y\": -9.420289855072463, \"x2\": 1.304347826086957, \"y2\": -9.130434782608695, \"center_x\": 1.1594202898550732, \"center_y\": -9.275362318840578, \"value_uncond\": 4.864799440729798e-07}, {\"x\": 1.304347826086957, \"y\": -9.420289855072463, \"x2\": 1.5942028985507246, \"y2\": -9.130434782608695, \"center_x\": 1.4492753623188408, \"center_y\": -9.275362318840578, \"value_uncond\": 5.330843807487501e-07}, {\"x\": 1.5942028985507246, \"y\": -9.420289855072463, \"x2\": 1.8840579710144922, \"y2\": -9.130434782608695, \"center_x\": 1.7391304347826084, \"center_y\": -9.275362318840578, \"value_uncond\": 5.787257281488953e-07}, {\"x\": 1.884057971014494, \"y\": -9.420289855072463, \"x2\": 2.1739130434782616, \"y2\": -9.130434782608695, \"center_x\": 2.028985507246378, \"center_y\": -9.275362318840578, \"value_uncond\": 6.224370512563913e-07}, {\"x\": 2.1739130434782616, \"y\": -9.420289855072463, \"x2\": 2.4637681159420293, \"y2\": -9.130434782608695, \"center_x\": 2.3188405797101455, \"center_y\": -9.275362318840578, \"value_uncond\": 6.632295956617537e-07}, {\"x\": 2.4637681159420293, \"y\": -9.420289855072463, \"x2\": 2.753623188405797, \"y2\": -9.130434782608695, \"center_x\": 2.608695652173913, \"center_y\": -9.275362318840578, \"value_uncond\": 7.001291716807186e-07}, {\"x\": 2.753623188405797, \"y\": -9.420289855072463, \"x2\": 3.0434782608695645, \"y2\": -9.130434782608695, \"center_x\": 2.8985507246376807, \"center_y\": -9.275362318840578, \"value_uncond\": 7.322143966019667e-07}, {\"x\": 3.0434782608695663, \"y\": -9.420289855072463, \"x2\": 3.333333333333334, \"y2\": -9.130434782608695, \"center_x\": 3.18840579710145, \"center_y\": -9.275362318840578, \"value_uncond\": 7.586547273543421e-07}, {\"x\": 3.333333333333334, \"y\": -9.420289855072463, \"x2\": 3.6231884057971016, \"y2\": -9.130434782608695, \"center_x\": 3.4782608695652177, \"center_y\": -9.275362318840578, \"value_uncond\": 7.787461052724562e-07}, {\"x\": 3.6231884057971016, \"y\": -9.420289855072463, \"x2\": 3.913043478260869, \"y2\": -9.130434782608695, \"center_x\": 3.7681159420289854, \"center_y\": -9.275362318840578, \"value_uncond\": 7.919420828616108e-07}, {\"x\": 3.913043478260871, \"y\": -9.420289855072463, \"x2\": 4.202898550724639, \"y2\": -9.130434782608695, \"center_x\": 4.057971014492755, \"center_y\": -9.275362318840578, \"value_uncond\": 7.978785134241195e-07}, {\"x\": 4.202898550724639, \"y\": -9.420289855072463, \"x2\": 4.492753623188406, \"y2\": -9.130434782608695, \"center_x\": 4.347826086956522, \"center_y\": -9.275362318840578, \"value_uncond\": 7.963902469094011e-07}, {\"x\": 4.492753623188406, \"y\": -9.420289855072463, \"x2\": 4.782608695652174, \"y2\": -9.130434782608695, \"center_x\": 4.63768115942029, \"center_y\": -9.275362318840578, \"value_uncond\": 7.875187636225984e-07}, {\"x\": 4.782608695652174, \"y\": -9.420289855072463, \"x2\": 5.0724637681159415, \"y2\": -9.130434782608695, \"center_x\": 4.927536231884058, \"center_y\": -9.275362318840578, \"value_uncond\": 7.715102533239665e-07}, {\"x\": 5.072463768115943, \"y\": -9.420289855072463, \"x2\": 5.362318840579711, \"y2\": -9.130434782608695, \"center_x\": 5.217391304347827, \"center_y\": -9.275362318840578, \"value_uncond\": 7.488042638703676e-07}, {\"x\": 5.362318840579711, \"y\": -9.420289855072463, \"x2\": 5.6521739130434785, \"y2\": -9.130434782608695, \"center_x\": 5.507246376811595, \"center_y\": -9.275362318840578, \"value_uncond\": 7.200136498843506e-07}, {\"x\": 5.6521739130434785, \"y\": -9.420289855072463, \"x2\": 5.942028985507246, \"y2\": -9.130434782608695, \"center_x\": 5.797101449275362, \"center_y\": -9.275362318840578, \"value_uncond\": 6.858970980172719e-07}, {\"x\": 5.942028985507246, \"y\": -9.420289855072463, \"x2\": 6.231884057971014, \"y2\": -9.130434782608695, \"center_x\": 6.08695652173913, \"center_y\": -9.275362318840578, \"value_uncond\": 6.473259472880103e-07}, {\"x\": 6.2318840579710155, \"y\": -9.420289855072463, \"x2\": 6.521739130434783, \"y2\": -9.130434782608695, \"center_x\": 6.376811594202899, \"center_y\": -9.275362318840578, \"value_uncond\": 6.052473271715371e-07}, {\"x\": 6.521739130434785, \"y\": -9.420289855072463, \"x2\": 6.8115942028985526, \"y2\": -9.130434782608695, \"center_x\": 6.666666666666669, \"center_y\": -9.275362318840578, \"value_uncond\": 5.606457824690636e-07}, {\"x\": 6.811594202898551, \"y\": -9.420289855072463, \"x2\": 7.101449275362318, \"y2\": -9.130434782608695, \"center_x\": 6.956521739130435, \"center_y\": -9.275362318840578, \"value_uncond\": 5.145055373860044e-07}, {\"x\": 7.10144927536232, \"y\": -9.420289855072463, \"x2\": 7.391304347826088, \"y2\": -9.130434782608695, \"center_x\": 7.246376811594204, \"center_y\": -9.275362318840578, \"value_uncond\": 4.677753814021533e-07}, {\"x\": 7.391304347826086, \"y\": -9.420289855072463, \"x2\": 7.681159420289854, \"y2\": -9.130434782608695, \"center_x\": 7.53623188405797, \"center_y\": -9.275362318840578, \"value_uncond\": 4.213378593009689e-07}, {\"x\": 7.681159420289855, \"y\": -9.420289855072463, \"x2\": 7.971014492753623, \"y2\": -9.130434782608695, \"center_x\": 7.826086956521739, \"center_y\": -9.275362318840578, \"value_uncond\": 3.7598405010178783e-07}, {\"x\": 7.971014492753625, \"y\": -9.420289855072463, \"x2\": 8.260869565217392, \"y2\": -9.130434782608695, \"center_x\": 8.115942028985508, \"center_y\": -9.275362318840578, \"value_uncond\": 3.32394763783409e-07}, {\"x\": 8.26086956521739, \"y\": -9.420289855072463, \"x2\": 8.550724637681158, \"y2\": -9.130434782608695, \"center_x\": 8.405797101449274, \"center_y\": -9.275362318840578, \"value_uncond\": 2.911285116999536e-07}, {\"x\": 8.55072463768116, \"y\": -9.420289855072463, \"x2\": 8.840579710144928, \"y2\": -9.130434782608695, \"center_x\": 8.695652173913043, \"center_y\": -9.275362318840578, \"value_uncond\": 2.5261615536661616e-07}, {\"x\": 8.84057971014493, \"y\": -9.420289855072463, \"x2\": 9.130434782608697, \"y2\": -9.130434782608695, \"center_x\": 8.985507246376812, \"center_y\": -9.275362318840578, \"value_uncond\": 2.1716174199835867e-07}, {\"x\": 9.130434782608695, \"y\": -9.420289855072463, \"x2\": 9.420289855072463, \"y2\": -9.130434782608695, \"center_x\": 9.275362318840578, \"center_y\": -9.275362318840578, \"value_uncond\": 1.8494871866920357e-07}, {\"x\": 9.420289855072465, \"y\": -9.420289855072463, \"x2\": 9.710144927536232, \"y2\": -9.130434782608695, \"center_x\": 9.565217391304348, \"center_y\": -9.275362318840578, \"value_uncond\": 1.5605049531692952e-07}, {\"x\": 9.710144927536234, \"y\": -9.420289855072463, \"x2\": 10.000000000000002, \"y2\": -9.130434782608695, \"center_x\": 9.855072463768117, \"center_y\": -9.275362318840578, \"value_uncond\": 1.3044420511573268e-07}, {\"x\": 10.0, \"y\": -9.420289855072463, \"x2\": 10.289855072463768, \"y2\": -9.130434782608695, \"center_x\": 10.144927536231883, \"center_y\": -9.275362318840578, \"value_uncond\": 1.080264848182129e-07}, {\"x\": -10.0, \"y\": -9.130434782608695, \"x2\": -9.710144927536232, \"y2\": -8.840579710144928, \"center_x\": -9.855072463768117, \"center_y\": -8.985507246376812, \"value_uncond\": 2.284633516259696e-11}, {\"x\": -9.710144927536232, \"y\": -9.130434782608695, \"x2\": -9.420289855072465, \"y2\": -8.840579710144928, \"center_x\": -9.565217391304348, \"center_y\": -8.985507246376812, \"value_uncond\": 3.56949360896001e-11}, {\"x\": -9.420289855072463, \"y\": -9.130434782608695, \"x2\": -9.130434782608695, \"y2\": -8.840579710144928, \"center_x\": -9.275362318840578, \"center_y\": -8.985507246376812, \"value_uncond\": 5.52512983829845e-11}, {\"x\": -9.130434782608695, \"y\": -9.130434782608695, \"x2\": -8.840579710144928, \"y2\": -8.840579710144928, \"center_x\": -8.985507246376812, \"center_y\": -8.985507246376812, \"value_uncond\": 8.472745905519222e-11}, {\"x\": -8.840579710144928, \"y\": -9.130434782608695, \"x2\": -8.55072463768116, \"y2\": -8.840579710144928, \"center_x\": -8.695652173913043, \"center_y\": -8.985507246376812, \"value_uncond\": 1.2872167750465555e-10}, {\"x\": -8.55072463768116, \"y\": -9.130434782608695, \"x2\": -8.260869565217392, \"y2\": -8.840579710144928, \"center_x\": -8.405797101449277, \"center_y\": -8.985507246376812, \"value_uncond\": 1.9374255109995932e-10}, {\"x\": -8.26086956521739, \"y\": -9.130434782608695, \"x2\": -7.971014492753623, \"y2\": -8.840579710144928, \"center_x\": -8.115942028985508, \"center_y\": -8.985507246376812, \"value_uncond\": 2.888977448101407e-10}, {\"x\": -7.971014492753623, \"y\": -9.130434782608695, \"x2\": -7.681159420289855, \"y2\": -8.840579710144928, \"center_x\": -7.826086956521739, \"center_y\": -8.985507246376812, \"value_uncond\": 4.267849575459015e-10}, {\"x\": -7.681159420289855, \"y\": -9.130434782608695, \"x2\": -7.391304347826088, \"y2\": -8.840579710144928, \"center_x\": -7.536231884057972, \"center_y\": -8.985507246376812, \"value_uncond\": 6.246257309077444e-10}, {\"x\": -7.391304347826087, \"y\": -9.130434782608695, \"x2\": -7.101449275362319, \"y2\": -8.840579710144928, \"center_x\": -7.246376811594203, \"center_y\": -8.985507246376812, \"value_uncond\": 9.056834921223715e-10}, {\"x\": -7.101449275362318, \"y\": -9.130434782608695, \"x2\": -6.811594202898551, \"y2\": -8.840579710144928, \"center_x\": -6.956521739130435, \"center_y\": -8.985507246376812, \"value_uncond\": 1.3010046469118486e-09}, {\"x\": -6.811594202898551, \"y\": -9.130434782608695, \"x2\": -6.521739130434783, \"y2\": -8.840579710144928, \"center_x\": -6.666666666666667, \"center_y\": -8.985507246376812, \"value_uncond\": 1.85151424677519e-09}, {\"x\": -6.521739130434782, \"y\": -9.130434782608695, \"x2\": -6.231884057971015, \"y2\": -8.840579710144928, \"center_x\": -6.3768115942028984, \"center_y\": -8.985507246376812, \"value_uncond\": 2.6104842846516803e-09}, {\"x\": -6.231884057971014, \"y\": -9.130434782608695, \"x2\": -5.942028985507246, \"y2\": -8.840579710144928, \"center_x\": -6.08695652173913, \"center_y\": -8.985507246376812, \"value_uncond\": 3.6463715764929747e-09}, {\"x\": -5.942028985507246, \"y\": -9.130434782608695, \"x2\": -5.6521739130434785, \"y2\": -8.840579710144928, \"center_x\": -5.797101449275362, \"center_y\": -8.985507246376812, \"value_uncond\": 5.045992219261586e-09}, {\"x\": -5.6521739130434785, \"y\": -9.130434782608695, \"x2\": -5.362318840579711, \"y2\": -8.840579710144928, \"center_x\": -5.507246376811595, \"center_y\": -8.985507246376812, \"value_uncond\": 6.917959975784015e-09}, {\"x\": -5.36231884057971, \"y\": -9.130434782608695, \"x2\": -5.072463768115942, \"y2\": -8.840579710144928, \"center_x\": -5.217391304347826, \"center_y\": -8.985507246376812, \"value_uncond\": 9.396266548601021e-09}, {\"x\": -5.0724637681159415, \"y\": -9.130434782608695, \"x2\": -4.782608695652174, \"y2\": -8.840579710144928, \"center_x\": -4.927536231884058, \"center_y\": -8.985507246376812, \"value_uncond\": 1.2643823529722732e-08}, {\"x\": -4.782608695652174, \"y\": -9.130434782608695, \"x2\": -4.492753623188406, \"y2\": -8.840579710144928, \"center_x\": -4.63768115942029, \"center_y\": -8.985507246376812, \"value_uncond\": 1.68557211472205e-08}, {\"x\": -4.492753623188405, \"y\": -9.130434782608695, \"x2\": -4.202898550724638, \"y2\": -8.840579710144928, \"center_x\": -4.3478260869565215, \"center_y\": -8.985507246376812, \"value_uncond\": 2.2261891645935698e-08}, {\"x\": -4.202898550724638, \"y\": -9.130434782608695, \"x2\": -3.91304347826087, \"y2\": -8.840579710144928, \"center_x\": -4.057971014492754, \"center_y\": -8.985507246376812, \"value_uncond\": 2.912880081752954e-08}, {\"x\": -3.913043478260869, \"y\": -9.130434782608695, \"x2\": -3.6231884057971016, \"y2\": -8.840579710144928, \"center_x\": -3.7681159420289854, \"center_y\": -8.985507246376812, \"value_uncond\": 3.775973707685375e-08}, {\"x\": -3.6231884057971016, \"y\": -9.130434782608695, \"x2\": -3.333333333333334, \"y2\": -8.840579710144928, \"center_x\": -3.4782608695652177, \"center_y\": -8.985507246376812, \"value_uncond\": 4.8493232200278026e-08}, {\"x\": -3.333333333333333, \"y\": -9.130434782608695, \"x2\": -3.0434782608695654, \"y2\": -8.840579710144928, \"center_x\": -3.1884057971014492, \"center_y\": -8.985507246376812, \"value_uncond\": 6.169914087836146e-08}, {\"x\": -3.0434782608695645, \"y\": -9.130434782608695, \"x2\": -2.753623188405797, \"y2\": -8.840579710144928, \"center_x\": -2.8985507246376807, \"center_y\": -8.985507246376812, \"value_uncond\": 7.777193708994542e-08}, {\"x\": -2.753623188405797, \"y\": -9.130434782608695, \"x2\": -2.4637681159420293, \"y2\": -8.840579710144928, \"center_x\": -2.608695652173913, \"center_y\": -8.985507246376812, \"value_uncond\": 9.71208624008385e-08}, {\"x\": -2.4637681159420284, \"y\": -9.130434782608695, \"x2\": -2.1739130434782608, \"y2\": -8.840579710144928, \"center_x\": -2.3188405797101446, \"center_y\": -8.985507246376812, \"value_uncond\": 1.2015669068110387e-07}, {\"x\": -2.1739130434782608, \"y\": -9.130434782608695, \"x2\": -1.8840579710144931, \"y2\": -8.840579710144928, \"center_x\": -2.028985507246377, \"center_y\": -8.985507246376812, \"value_uncond\": 1.4727505772775686e-07}, {\"x\": -1.8840579710144922, \"y\": -9.130434782608695, \"x2\": -1.5942028985507246, \"y2\": -8.840579710144928, \"center_x\": -1.7391304347826084, \"center_y\": -8.985507246376812, \"value_uncond\": 1.7883654013950458e-07}, {\"x\": -1.5942028985507246, \"y\": -9.130434782608695, \"x2\": -1.304347826086957, \"y2\": -8.840579710144928, \"center_x\": -1.4492753623188408, \"center_y\": -8.985507246376812, \"value_uncond\": 2.1514394672036343e-07}, {\"x\": -1.304347826086957, \"y\": -9.130434782608695, \"x2\": -1.0144927536231894, \"y2\": -8.840579710144928, \"center_x\": -1.1594202898550732, \"center_y\": -8.985507246376812, \"value_uncond\": 2.564175922975858e-07}, {\"x\": -1.0144927536231876, \"y\": -9.130434782608695, \"x2\": -0.72463768115942, \"y2\": -8.840579710144928, \"center_x\": -0.8695652173913038, \"center_y\": -8.985507246376812, \"value_uncond\": 3.0276963628422175e-07}, {\"x\": -0.72463768115942, \"y\": -9.130434782608695, \"x2\": -0.43478260869565233, \"y2\": -8.840579710144928, \"center_x\": -0.5797101449275361, \"center_y\": -8.985507246376812, \"value_uncond\": 3.5417885927447224e-07}, {\"x\": -0.43478260869565233, \"y\": -9.130434782608695, \"x2\": -0.1449275362318847, \"y2\": -8.840579710144928, \"center_x\": -0.2898550724637685, \"center_y\": -8.985507246376812, \"value_uncond\": 4.1046748947810695e-07}, {\"x\": -0.14492753623188293, \"y\": -9.130434782608695, \"x2\": 0.1449275362318847, \"y2\": -8.840579710144928, \"center_x\": 8.881784197001252e-16, \"center_y\": -8.985507246376812, \"value_uncond\": 4.7128184498154966e-07}, {\"x\": 0.1449275362318847, \"y\": -9.130434782608695, \"x2\": 0.43478260869565233, \"y2\": -8.840579710144928, \"center_x\": 0.2898550724637685, \"center_y\": -8.985507246376812, \"value_uncond\": 5.360785981646451e-07}, {\"x\": 0.43478260869565233, \"y\": -9.130434782608695, \"x2\": 0.72463768115942, \"y2\": -8.840579710144928, \"center_x\": 0.5797101449275361, \"center_y\": -8.985507246376812, \"value_uncond\": 6.04118371678944e-07}, {\"x\": 0.72463768115942, \"y\": -9.130434782608695, \"x2\": 1.0144927536231876, \"y2\": -8.840579710144928, \"center_x\": 0.8695652173913038, \"center_y\": -8.985507246376812, \"value_uncond\": 6.744681274779165e-07}, {\"x\": 1.0144927536231894, \"y\": -9.130434782608695, \"x2\": 1.304347826086957, \"y2\": -8.840579710144928, \"center_x\": 1.1594202898550732, \"center_y\": -8.985507246376812, \"value_uncond\": 7.460134105248357e-07}, {\"x\": 1.304347826086957, \"y\": -9.130434782608695, \"x2\": 1.5942028985507246, \"y2\": -8.840579710144928, \"center_x\": 1.4492753623188408, \"center_y\": -8.985507246376812, \"value_uncond\": 8.17480970850127e-07}, {\"x\": 1.5942028985507246, \"y\": -9.130434782608695, \"x2\": 1.8840579710144922, \"y2\": -8.840579710144928, \"center_x\": 1.7391304347826084, \"center_y\": -8.985507246376812, \"value_uncond\": 8.874716408659564e-07}, {\"x\": 1.884057971014494, \"y\": -9.130434782608695, \"x2\": 2.1739130434782616, \"y2\": -8.840579710144928, \"center_x\": 2.028985507246378, \"center_y\": -8.985507246376812, \"value_uncond\": 9.54502632846757e-07}, {\"x\": 2.1739130434782616, \"y\": -9.130434782608695, \"x2\": 2.4637681159420293, \"y2\": -8.840579710144928, \"center_x\": 2.3188405797101455, \"center_y\": -8.985507246376812, \"value_uncond\": 1.0170576991893582e-06}, {\"x\": 2.4637681159420293, \"y\": -9.130434782608695, \"x2\": 2.753623188405797, \"y2\": -8.840579710144928, \"center_x\": 2.608695652173913, \"center_y\": -8.985507246376812, \"value_uncond\": 1.0736429271894232e-06}, {\"x\": 2.753623188405797, \"y\": -9.130434782608695, \"x2\": 3.0434782608695645, \"y2\": -8.840579710144928, \"center_x\": 2.8985507246376807, \"center_y\": -8.985507246376812, \"value_uncond\": 1.1228453832466169e-06}, {\"x\": 3.0434782608695663, \"y\": -9.130434782608695, \"x2\": 3.333333333333334, \"y2\": -8.840579710144928, \"center_x\": 3.18840579710145, \"center_y\": -8.985507246376812, \"value_uncond\": 1.1633914356796134e-06}, {\"x\": 3.333333333333334, \"y\": -9.130434782608695, \"x2\": 3.6231884057971016, \"y2\": -8.840579710144928, \"center_x\": 3.4782608695652177, \"center_y\": -8.985507246376812, \"value_uncond\": 1.1942014157115696e-06}, {\"x\": 3.6231884057971016, \"y\": -9.130434782608695, \"x2\": 3.913043478260869, \"y2\": -8.840579710144928, \"center_x\": 3.7681159420289854, \"center_y\": -8.985507246376812, \"value_uncond\": 1.2144373501348344e-06}, {\"x\": 3.913043478260871, \"y\": -9.130434782608695, \"x2\": 4.202898550724639, \"y2\": -8.840579710144928, \"center_x\": 4.057971014492755, \"center_y\": -8.985507246376812, \"value_uncond\": 1.2235408226710357e-06}, {\"x\": 4.202898550724639, \"y\": -9.130434782608695, \"x2\": 4.492753623188406, \"y2\": -8.840579710144928, \"center_x\": 4.347826086956522, \"center_y\": -8.985507246376812, \"value_uncond\": 1.2212585769342034e-06}, {\"x\": 4.492753623188406, \"y\": -9.130434782608695, \"x2\": 4.782608695652174, \"y2\": -8.840579710144928, \"center_x\": 4.63768115942029, \"center_y\": -8.985507246376812, \"value_uncond\": 1.2076542226667046e-06}, {\"x\": 4.782608695652174, \"y\": -9.130434782608695, \"x2\": 5.0724637681159415, \"y2\": -8.840579710144928, \"center_x\": 4.927536231884058, \"center_y\": -8.985507246376812, \"value_uncond\": 1.1831052900523056e-06}, {\"x\": 5.072463768115943, \"y\": -9.130434782608695, \"x2\": 5.362318840579711, \"y2\": -8.840579710144928, \"center_x\": 5.217391304347827, \"center_y\": -8.985507246376812, \"value_uncond\": 1.1482858224915232e-06}, {\"x\": 5.362318840579711, \"y\": -9.130434782608695, \"x2\": 5.6521739130434785, \"y2\": -8.840579710144928, \"center_x\": 5.507246376811595, \"center_y\": -8.985507246376812, \"value_uncond\": 1.1041356280333723e-06}, {\"x\": 5.6521739130434785, \"y\": -9.130434782608695, \"x2\": 5.942028985507246, \"y2\": -8.840579710144928, \"center_x\": 5.797101449275362, \"center_y\": -8.985507246376812, \"value_uncond\": 1.0518181470687534e-06}, {\"x\": 5.942028985507246, \"y\": -9.130434782608695, \"x2\": 6.231884057971014, \"y2\": -8.840579710144928, \"center_x\": 6.08695652173913, \"center_y\": -8.985507246376812, \"value_uncond\": 9.926695715642979e-07}, {\"x\": 6.2318840579710155, \"y\": -9.130434782608695, \"x2\": 6.521739130434783, \"y2\": -8.840579710144928, \"center_x\": 6.376811594202899, \"center_y\": -8.985507246376812, \"value_uncond\": 9.281423175927344e-07}, {\"x\": 6.521739130434785, \"y\": -9.130434782608695, \"x2\": 6.8115942028985526, \"y2\": -8.840579710144928, \"center_x\": 6.666666666666669, \"center_y\": -8.985507246376812, \"value_uncond\": 8.59746177353957e-07}, {\"x\": 6.811594202898551, \"y\": -9.130434782608695, \"x2\": 7.101449275362318, \"y2\": -8.840579710144928, \"center_x\": 6.956521739130435, \"center_y\": -8.985507246376812, \"value_uncond\": 7.889904514165666e-07}, {\"x\": 7.10144927536232, \"y\": -9.130434782608695, \"x2\": 7.391304347826088, \"y2\": -8.840579710144928, \"center_x\": 7.246376811594204, \"center_y\": -8.985507246376812, \"value_uncond\": 7.17330101458459e-07}, {\"x\": 7.391304347826086, \"y\": -9.130434782608695, \"x2\": 7.681159420289854, \"y2\": -8.840579710144928, \"center_x\": 7.53623188405797, \"center_y\": -8.985507246376812, \"value_uncond\": 6.461185034036994e-07}, {\"x\": 7.681159420289855, \"y\": -9.130434782608695, \"x2\": 7.971014492753623, \"y2\": -8.840579710144928, \"center_x\": 7.826086956521739, \"center_y\": -8.985507246376812, \"value_uncond\": 5.765687711008647e-07}, {\"x\": 7.971014492753625, \"y\": -9.130434782608695, \"x2\": 8.260869565217392, \"y2\": -8.840579710144928, \"center_x\": 8.115942028985508, \"center_y\": -8.985507246376812, \"value_uncond\": 5.097249216371772e-07}, {\"x\": 8.26086956521739, \"y\": -9.130434782608695, \"x2\": 8.550724637681158, \"y2\": -8.840579710144928, \"center_x\": 8.405797101449274, \"center_y\": -8.985507246376812, \"value_uncond\": 4.4644342805984316e-07}, {\"x\": 8.55072463768116, \"y\": -9.130434782608695, \"x2\": 8.840579710144928, \"y2\": -8.840579710144928, \"center_x\": 8.695652173913043, \"center_y\": -8.985507246376812, \"value_uncond\": 3.873850133284215e-07}, {\"x\": 8.84057971014493, \"y\": -9.130434782608695, \"x2\": 9.130434782608697, \"y2\": -8.840579710144928, \"center_x\": 8.985507246376812, \"center_y\": -8.985507246376812, \"value_uncond\": 3.330159316072577e-07}, {\"x\": 9.130434782608695, \"y\": -9.130434782608695, \"x2\": 9.420289855072463, \"y2\": -8.840579710144928, \"center_x\": 9.275362318840578, \"center_y\": -8.985507246376812, \"value_uncond\": 2.836174976329806e-07}, {\"x\": 9.420289855072465, \"y\": -9.130434782608695, \"x2\": 9.710144927536232, \"y2\": -8.840579710144928, \"center_x\": 9.565217391304348, \"center_y\": -8.985507246376812, \"value_uncond\": 2.3930228500439113e-07}, {\"x\": 9.710144927536234, \"y\": -9.130434782608695, \"x2\": 10.000000000000002, \"y2\": -8.840579710144928, \"center_x\": 9.855072463768117, \"center_y\": -8.985507246376812, \"value_uncond\": 2.0003522761257018e-07}, {\"x\": 10.0, \"y\": -9.130434782608695, \"x2\": 10.289855072463768, \"y2\": -8.840579710144928, \"center_x\": 10.144927536231883, \"center_y\": -8.985507246376812, \"value_uncond\": 1.6565781867906704e-07}, {\"x\": -10.0, \"y\": -8.840579710144928, \"x2\": -9.710144927536232, \"y2\": -8.55072463768116, \"center_x\": -9.855072463768117, \"center_y\": -8.695652173913043, \"value_uncond\": 3.470915591894953e-11}, {\"x\": -9.710144927536232, \"y\": -8.840579710144928, \"x2\": -9.420289855072465, \"y2\": -8.55072463768116, \"center_x\": -9.565217391304348, \"center_y\": -8.695652173913043, \"value_uncond\": 5.42293148302932e-11}, {\"x\": -9.420289855072463, \"y\": -8.840579710144928, \"x2\": -9.130434782608695, \"y2\": -8.55072463768116, \"center_x\": -9.275362318840578, \"center_y\": -8.695652173913043, \"value_uncond\": 8.394019945216559e-11}, {\"x\": -9.130434782608695, \"y\": -8.840579710144928, \"x2\": -8.840579710144928, \"y2\": -8.55072463768116, \"center_x\": -8.985507246376812, \"center_y\": -8.695652173913043, \"value_uncond\": 1.2872167750465555e-10}, {\"x\": -8.840579710144928, \"y\": -8.840579710144928, \"x2\": -8.55072463768116, \"y2\": -8.55072463768116, \"center_x\": -8.695652173913043, \"center_y\": -8.695652173913043, \"value_uncond\": 1.9555962664735687e-10}, {\"x\": -8.55072463768116, \"y\": -8.840579710144928, \"x2\": -8.260869565217392, \"y2\": -8.55072463768116, \"center_x\": -8.405797101449277, \"center_y\": -8.695652173913043, \"value_uncond\": 2.9434219389693743e-10}, {\"x\": -8.26086956521739, \"y\": -8.840579710144928, \"x2\": -7.971014492753623, \"y2\": -8.55072463768116, \"center_x\": -8.115942028985508, \"center_y\": -8.695652173913043, \"value_uncond\": 4.3890614393438853e-10}, {\"x\": -7.971014492753623, \"y\": -8.840579710144928, \"x2\": -7.681159420289855, \"y2\": -8.55072463768116, \"center_x\": -7.826086956521739, \"center_y\": -8.695652173913043, \"value_uncond\": 6.483904543068586e-10}, {\"x\": -7.681159420289855, \"y\": -8.840579710144928, \"x2\": -7.391304347826088, \"y2\": -8.55072463768116, \"center_x\": -7.536231884057972, \"center_y\": -8.695652173913043, \"value_uncond\": 9.4895884748109e-10}, {\"x\": -7.391304347826087, \"y\": -8.840579710144928, \"x2\": -7.101449275362319, \"y2\": -8.55072463768116, \"center_x\": -7.246376811594203, \"center_y\": -8.695652173913043, \"value_uncond\": 1.3759541439608688e-09}, {\"x\": -7.101449275362318, \"y\": -8.840579710144928, \"x2\": -6.811594202898551, \"y2\": -8.55072463768116, \"center_x\": -6.956521739130435, \"center_y\": -8.695652173913043, \"value_uncond\": 1.976543407052434e-09}, {\"x\": -6.811594202898551, \"y\": -8.840579710144928, \"x2\": -6.521739130434783, \"y2\": -8.55072463768116, \"center_x\": -6.666666666666667, \"center_y\": -8.695652173913043, \"value_uncond\": 2.8129017726522515e-09}, {\"x\": -6.521739130434782, \"y\": -8.840579710144928, \"x2\": -6.231884057971015, \"y2\": -8.55072463768116, \"center_x\": -6.3768115942028984, \"center_y\": -8.695652173913043, \"value_uncond\": 3.965962392440151e-09}, {\"x\": -6.231884057971014, \"y\": -8.840579710144928, \"x2\": -5.942028985507246, \"y2\": -8.55072463768116, \"center_x\": -6.08695652173913, \"center_y\": -8.695652173913043, \"value_uncond\": 5.539727868219475e-09}, {\"x\": -5.942028985507246, \"y\": -8.840579710144928, \"x2\": -5.6521739130434785, \"y2\": -8.55072463768116, \"center_x\": -5.797101449275362, \"center_y\": -8.695652173913043, \"value_uncond\": 7.666093027948395e-09}, {\"x\": -5.6521739130434785, \"y\": -8.840579710144928, \"x2\": -5.362318840579711, \"y2\": -8.55072463768116, \"center_x\": -5.507246376811595, \"center_y\": -8.695652173913043, \"value_uncond\": 1.05100686710422e-08}, {\"x\": -5.36231884057971, \"y\": -8.840579710144928, \"x2\": -5.072463768115942, \"y2\": -8.55072463768116, \"center_x\": -5.217391304347826, \"center_y\": -8.695652173913043, \"value_uncond\": 1.4275220877672309e-08}, {\"x\": -5.0724637681159415, \"y\": -8.840579710144928, \"x2\": -4.782608695652174, \"y2\": -8.55072463768116, \"center_x\": -4.927536231884058, \"center_y\": -8.695652173913043, \"value_uncond\": 1.9209052094416735e-08}, {\"x\": -4.782608695652174, \"y\": -8.840579710144928, \"x2\": -4.492753623188406, \"y2\": -8.55072463768116, \"center_x\": -4.63768115942029, \"center_y\": -8.695652173913043, \"value_uncond\": 2.560795196522492e-08}, {\"x\": -4.492753623188405, \"y\": -8.840579710144928, \"x2\": -4.202898550724638, \"y2\": -8.55072463768116, \"center_x\": -4.3478260869565215, \"center_y\": -8.695652173913043, \"value_uncond\": 3.382124365638135e-08}, {\"x\": -4.202898550724638, \"y\": -8.840579710144928, \"x2\": -3.91304347826087, \"y2\": -8.55072463768116, \"center_x\": -4.057971014492754, \"center_y\": -8.695652173913043, \"value_uncond\": 4.425375370325845e-08}, {\"x\": -3.913043478260869, \"y\": -8.840579710144928, \"x2\": -3.6231884057971016, \"y2\": -8.55072463768116, \"center_x\": -3.7681159420289854, \"center_y\": -8.695652173913043, \"value_uncond\": 5.736625118783737e-08}, {\"x\": -3.6231884057971016, \"y\": -8.840579710144928, \"x2\": -3.333333333333334, \"y2\": -8.55072463768116, \"center_x\": -3.4782608695652177, \"center_y\": -8.695652173913043, \"value_uncond\": 7.36730484550044e-08}, {\"x\": -3.333333333333333, \"y\": -8.840579710144928, \"x2\": -3.0434782608695654, \"y2\": -8.55072463768116, \"center_x\": -3.1884057971014492, \"center_y\": -8.695652173913043, \"value_uncond\": 9.373604499676155e-08}, {\"x\": -3.0434782608695645, \"y\": -8.840579710144928, \"x2\": -2.753623188405797, \"y2\": -8.55072463768116, \"center_x\": -2.8985507246376807, \"center_y\": -8.695652173913043, \"value_uncond\": 1.1815454300928705e-07}, {\"x\": -2.753623188405797, \"y\": -8.840579710144928, \"x2\": -2.4637681159420293, \"y2\": -8.55072463768116, \"center_x\": -2.608695652173913, \"center_y\": -8.695652173913043, \"value_uncond\": 1.475502802555563e-07}, {\"x\": -2.4637681159420284, \"y\": -8.840579710144928, \"x2\": -2.1739130434782608, \"y2\": -8.55072463768116, \"center_x\": -2.3188405797101446, \"center_y\": -8.695652173913043, \"value_uncond\": 1.8254732244247453e-07}, {\"x\": -2.1739130434782608, \"y\": -8.840579710144928, \"x2\": -1.8840579710144931, \"y2\": -8.55072463768116, \"center_x\": -2.028985507246377, \"center_y\": -8.695652173913043, \"value_uncond\": 2.2374673685142385e-07}, {\"x\": -1.8840579710144922, \"y\": -8.840579710144928, \"x2\": -1.5942028985507246, \"y2\": -8.55072463768116, \"center_x\": -1.7391304347826084, \"center_y\": -8.695652173913043, \"value_uncond\": 2.7169632728971814e-07}, {\"x\": -1.5942028985507246, \"y\": -8.840579710144928, \"x2\": -1.304347826086957, \"y2\": -8.55072463768116, \"center_x\": -1.4492753623188408, \"center_y\": -8.695652173913043, \"value_uncond\": 3.268561341934916e-07}, {\"x\": -1.304347826086957, \"y\": -8.840579710144928, \"x2\": -1.0144927536231894, \"y2\": -8.55072463768116, \"center_x\": -1.1594202898550732, \"center_y\": -8.695652173913043, \"value_uncond\": 3.895608695257747e-07}, {\"x\": -1.0144927536231876, \"y\": -8.840579710144928, \"x2\": -0.72463768115942, \"y2\": -8.55072463768116, \"center_x\": -0.8695652173913038, \"center_y\": -8.695652173913043, \"value_uncond\": 4.5998093079354775e-07}, {\"x\": -0.72463768115942, \"y\": -8.840579710144928, \"x2\": -0.43478260869565233, \"y2\": -8.55072463768116, \"center_x\": -0.5797101449275361, \"center_y\": -8.695652173913043, \"value_uncond\": 5.380840805434449e-07}, {\"x\": -0.43478260869565233, \"y\": -8.840579710144928, \"x2\": -0.1449275362318847, \"y2\": -8.55072463768116, \"center_x\": -0.2898550724637685, \"center_y\": -8.695652173913043, \"value_uncond\": 6.236002400630083e-07}, {\"x\": -0.14492753623188293, \"y\": -8.840579710144928, \"x2\": 0.1449275362318847, \"y2\": -8.55072463768116, \"center_x\": 8.881784197001252e-16, \"center_y\": -8.695652173913043, \"value_uncond\": 7.159920802534279e-07}, {\"x\": 0.1449275362318847, \"y\": -8.840579710144928, \"x2\": 0.43478260869565233, \"y2\": -8.55072463768116, \"center_x\": 0.2898550724637685, \"center_y\": -8.695652173913043, \"value_uncond\": 8.144341539281496e-07}, {\"x\": 0.43478260869565233, \"y\": -8.840579710144928, \"x2\": 0.72463768115942, \"y2\": -8.55072463768116, \"center_x\": 0.5797101449275361, \"center_y\": -8.695652173913043, \"value_uncond\": 9.178031665417845e-07}, {\"x\": 0.72463768115942, \"y\": -8.840579710144928, \"x2\": 1.0144927536231876, \"y2\": -8.55072463768116, \"center_x\": 0.8695652173913038, \"center_y\": -8.695652173913043, \"value_uncond\": 1.024681605709748e-06}, {\"x\": 1.0144927536231894, \"y\": -8.840579710144928, \"x2\": 1.304347826086957, \"y2\": -8.55072463768116, \"center_x\": 1.1594202898550732, \"center_y\": -8.695652173913043, \"value_uncond\": 1.1333763423870968e-06}, {\"x\": 1.304347826086957, \"y\": -8.840579710144928, \"x2\": 1.5942028985507246, \"y2\": -8.55072463768116, \"center_x\": 1.4492753623188408, \"center_y\": -8.695652173913043, \"value_uncond\": 1.241952999291727e-06}, {\"x\": 1.5942028985507246, \"y\": -8.840579710144928, \"x2\": 1.8840579710144922, \"y2\": -8.55072463768116, \"center_x\": 1.7391304347826084, \"center_y\": -8.695652173913043, \"value_uncond\": 1.3482858995648677e-06}, {\"x\": 1.884057971014494, \"y\": -8.840579710144928, \"x2\": 2.1739130434782616, \"y2\": -8.55072463768116, \"center_x\": 2.028985507246378, \"center_y\": -8.695652173913043, \"value_uncond\": 1.4501223269614357e-06}, {\"x\": 2.1739130434782616, \"y\": -8.840579710144928, \"x2\": 2.4637681159420293, \"y2\": -8.55072463768116, \"center_x\": 2.3188405797101455, \"center_y\": -8.695652173913043, \"value_uncond\": 1.5451587315205457e-06}, {\"x\": 2.4637681159420293, \"y\": -8.840579710144928, \"x2\": 2.753623188405797, \"y2\": -8.55072463768116, \"center_x\": 2.608695652173913, \"center_y\": -8.695652173913043, \"value_uncond\": 1.6311254954406947e-06}, {\"x\": 2.753623188405797, \"y\": -8.840579710144928, \"x2\": 3.0434782608695645, \"y2\": -8.55072463768116, \"center_x\": 2.8985507246376807, \"center_y\": -8.695652173913043, \"value_uncond\": 1.7058760279322381e-06}, {\"x\": 3.0434782608695663, \"y\": -8.840579710144928, \"x2\": 3.333333333333334, \"y2\": -8.55072463768116, \"center_x\": 3.18840579710145, \"center_y\": -8.695652173913043, \"value_uncond\": 1.7674753717998176e-06}, {\"x\": 3.333333333333334, \"y\": -8.840579710144928, \"x2\": 3.6231884057971016, \"y2\": -8.55072463768116, \"center_x\": 3.4782608695652177, \"center_y\": -8.695652173913043, \"value_uncond\": 1.814283246812509e-06}, {\"x\": 3.6231884057971016, \"y\": -8.840579710144928, \"x2\": 3.913043478260869, \"y2\": -8.55072463768116, \"center_x\": 3.7681159420289854, \"center_y\": -8.695652173913043, \"value_uncond\": 1.8450265672647379e-06}, {\"x\": 3.913043478260871, \"y\": -8.840579710144928, \"x2\": 4.202898550724639, \"y2\": -8.55072463768116, \"center_x\": 4.057971014492755, \"center_y\": -8.695652173913043, \"value_uncond\": 1.8588569626176071e-06}, {\"x\": 4.202898550724639, \"y\": -8.840579710144928, \"x2\": 4.492753623188406, \"y2\": -8.55072463768116, \"center_x\": 4.347826086956522, \"center_y\": -8.695652173913043, \"value_uncond\": 1.8553896746451031e-06}, {\"x\": 4.492753623188406, \"y\": -8.840579710144928, \"x2\": 4.782608695652174, \"y2\": -8.55072463768116, \"center_x\": 4.63768115942029, \"center_y\": -8.695652173913043, \"value_uncond\": 1.834721342061928e-06}, {\"x\": 4.782608695652174, \"y\": -8.840579710144928, \"x2\": 5.0724637681159415, \"y2\": -8.55072463768116, \"center_x\": 4.927536231884058, \"center_y\": -8.695652173913043, \"value_uncond\": 1.7974255253065148e-06}, {\"x\": 5.072463768115943, \"y\": -8.840579710144928, \"x2\": 5.362318840579711, \"y2\": -8.55072463768116, \"center_x\": 5.217391304347827, \"center_y\": -8.695652173913043, \"value_uncond\": 1.7445262607207185e-06}, {\"x\": 5.362318840579711, \"y\": -8.840579710144928, \"x2\": 5.6521739130434785, \"y2\": -8.55072463768116, \"center_x\": 5.507246376811595, \"center_y\": -8.695652173913043, \"value_uncond\": 1.6774513459742732e-06}, {\"x\": 5.6521739130434785, \"y\": -8.840579710144928, \"x2\": 5.942028985507246, \"y2\": -8.55072463768116, \"center_x\": 5.797101449275362, \"center_y\": -8.695652173913043, \"value_uncond\": 1.5979683308139013e-06}, {\"x\": 5.942028985507246, \"y\": -8.840579710144928, \"x2\": 6.231884057971014, \"y2\": -8.55072463768116, \"center_x\": 6.08695652173913, \"center_y\": -8.695652173913043, \"value_uncond\": 1.5081072167683986e-06}, {\"x\": 6.2318840579710155, \"y\": -8.840579710144928, \"x2\": 6.521739130434783, \"y2\": -8.55072463768116, \"center_x\": 6.376811594202899, \"center_y\": -8.695652173913043, \"value_uncond\": 1.4100745781337623e-06}, {\"x\": 6.521739130434785, \"y\": -8.840579710144928, \"x2\": 6.8115942028985526, \"y2\": -8.55072463768116, \"center_x\": 6.666666666666669, \"center_y\": -8.695652173913043, \"value_uncond\": 1.3061641575386623e-06}, {\"x\": 6.811594202898551, \"y\": -8.840579710144928, \"x2\": 7.101449275362318, \"y2\": -8.55072463768116, \"center_x\": 6.956521739130435, \"center_y\": -8.695652173913043, \"value_uncond\": 1.198668950703914e-06}, {\"x\": 7.10144927536232, \"y\": -8.840579710144928, \"x2\": 7.391304347826088, \"y2\": -8.55072463768116, \"center_x\": 7.246376811594204, \"center_y\": -8.695652173913043, \"value_uncond\": 1.089799399320701e-06}, {\"x\": 7.391304347826086, \"y\": -8.840579710144928, \"x2\": 7.681159420289854, \"y2\": -8.55072463768116, \"center_x\": 7.53623188405797, \"center_y\": -8.695652173913043, \"value_uncond\": 9.8161161154077e-07}, {\"x\": 7.681159420289855, \"y\": -8.840579710144928, \"x2\": 7.971014492753623, \"y2\": -8.55072463768116, \"center_x\": 7.826086956521739, \"center_y\": -8.695652173913043, \"value_uncond\": 8.759486032096825e-07}, {\"x\": 7.971014492753625, \"y\": -8.840579710144928, \"x2\": 8.260869565217392, \"y2\": -8.55072463768116, \"center_x\": 8.115942028985508, \"center_y\": -8.695652173913043, \"value_uncond\": 7.74396490945468e-07}, {\"x\": 8.26086956521739, \"y\": -8.840579710144928, \"x2\": 8.550724637681158, \"y2\": -8.55072463768116, \"center_x\": 8.405797101449274, \"center_y\": -8.695652173913043, \"value_uncond\": 6.782564662225695e-07}, {\"x\": 8.55072463768116, \"y\": -8.840579710144928, \"x2\": 8.840579710144928, \"y2\": -8.55072463768116, \"center_x\": 8.695652173913043, \"center_y\": -8.695652173913043, \"value_uncond\": 5.885323283838296e-07}, {\"x\": 8.84057971014493, \"y\": -8.840579710144928, \"x2\": 9.130434782608697, \"y2\": -8.55072463768116, \"center_x\": 8.985507246376812, \"center_y\": -8.695652173913043, \"value_uncond\": 5.059324312362338e-07}, {\"x\": 9.130434782608695, \"y\": -8.840579710144928, \"x2\": 9.420289855072463, \"y2\": -8.55072463768116, \"center_x\": 9.275362318840578, \"center_y\": -8.695652173913043, \"value_uncond\": 4.308841604846021e-07}, {\"x\": 9.420289855072465, \"y\": -8.840579710144928, \"x2\": 9.710144927536232, \"y2\": -8.55072463768116, \"center_x\": 9.565217391304348, \"center_y\": -8.695652173913043, \"value_uncond\": 3.6355854288509836e-07}, {\"x\": 9.710144927536234, \"y\": -8.840579710144928, \"x2\": 10.000000000000002, \"y2\": -8.55072463768116, \"center_x\": 9.855072463768117, \"center_y\": -8.695652173913043, \"value_uncond\": 3.039023044647501e-07}, {\"x\": 10.0, \"y\": -8.840579710144928, \"x2\": 10.289855072463768, \"y2\": -8.55072463768116, \"center_x\": 10.144927536231883, \"center_y\": -8.695652173913043, \"value_uncond\": 2.5167463476322513e-07}, {\"x\": -10.0, \"y\": -8.55072463768116, \"x2\": -9.710144927536232, \"y2\": -8.260869565217392, \"center_x\": -9.855072463768117, \"center_y\": -8.405797101449277, \"value_uncond\": 5.2241708969495986e-11}, {\"x\": -9.710144927536232, \"y\": -8.55072463768116, \"x2\": -9.420289855072465, \"y2\": -8.260869565217392, \"center_x\": -9.565217391304348, \"center_y\": -8.405797101449277, \"value_uncond\": 8.162203914133939e-11}, {\"x\": -9.420289855072463, \"y\": -8.55072463768116, \"x2\": -9.130434782608695, \"y2\": -8.260869565217392, \"center_x\": -9.275362318840578, \"center_y\": -8.405797101449277, \"value_uncond\": 1.2634071196837675e-10}, {\"x\": -9.130434782608695, \"y\": -8.55072463768116, \"x2\": -8.840579710144928, \"y2\": -8.260869565217392, \"center_x\": -8.985507246376812, \"center_y\": -8.405797101449277, \"value_uncond\": 1.9374255109995932e-10}, {\"x\": -8.840579710144928, \"y\": -8.55072463768116, \"x2\": -8.55072463768116, \"y2\": -8.260869565217392, \"center_x\": -8.695652173913043, \"center_y\": -8.405797101449277, \"value_uncond\": 2.9434219389693743e-10}, {\"x\": -8.55072463768116, \"y\": -8.55072463768116, \"x2\": -8.260869565217392, \"y2\": -8.260869565217392, \"center_x\": -8.405797101449277, \"center_y\": -8.405797101449277, \"value_uncond\": 4.430225634675171e-10}, {\"x\": -8.26086956521739, \"y\": -8.55072463768116, \"x2\": -7.971014492753623, \"y2\": -8.260869565217392, \"center_x\": -8.115942028985508, \"center_y\": -8.405797101449277, \"value_uncond\": 6.606097563964613e-10}, {\"x\": -7.971014492753623, \"y\": -8.55072463768116, \"x2\": -7.681159420289855, \"y2\": -8.260869565217392, \"center_x\": -7.826086956521739, \"center_y\": -8.405797101449277, \"value_uncond\": 9.75910376259108e-10}, {\"x\": -7.681159420289855, \"y\": -8.55072463768116, \"x2\": -7.391304347826088, \"y2\": -8.260869565217392, \"center_x\": -7.536231884057972, \"center_y\": -8.405797101449277, \"value_uncond\": 1.4283041641778947e-09}, {\"x\": -7.391304347826087, \"y\": -8.55072463768116, \"x2\": -7.101449275362319, \"y2\": -8.260869565217392, \"center_x\": -7.246376811594203, \"center_y\": -8.405797101449277, \"value_uncond\": 2.07098657518581e-09}, {\"x\": -7.101449275362318, \"y\": -8.55072463768116, \"x2\": -6.811594202898551, \"y2\": -8.260869565217392, \"center_x\": -6.956521739130435, \"center_y\": -8.405797101449277, \"value_uncond\": 2.974950058651102e-09}, {\"x\": -6.811594202898551, \"y\": -8.55072463768116, \"x2\": -6.521739130434783, \"y2\": -8.260869565217392, \"center_x\": -6.666666666666667, \"center_y\": -8.405797101449277, \"value_uncond\": 4.233776128403348e-09}, {\"x\": -6.521739130434782, \"y\": -8.55072463768116, \"x2\": -6.231884057971015, \"y2\": -8.260869565217392, \"center_x\": -6.3768115942028984, \"center_y\": -8.405797101449277, \"value_uncond\": 5.969279505777591e-09}, {\"x\": -6.231884057971014, \"y\": -8.55072463768116, \"x2\": -5.942028985507246, \"y2\": -8.260869565217392, \"center_x\": -6.08695652173913, \"center_y\": -8.405797101449277, \"value_uncond\": 8.33799737848785e-09}, {\"x\": -5.942028985507246, \"y\": -8.55072463768116, \"x2\": -5.6521739130434785, \"y2\": -8.260869565217392, \"center_x\": -5.797101449275362, \"center_y\": -8.405797101449277, \"value_uncond\": 1.153844829399938e-08}, {\"x\": -5.6521739130434785, \"y\": -8.55072463768116, \"x2\": -5.362318840579711, \"y2\": -8.260869565217392, \"center_x\": -5.507246376811595, \"center_y\": -8.405797101449277, \"value_uncond\": 1.5818994562821986e-08}, {\"x\": -5.36231884057971, \"y\": -8.55072463768116, \"x2\": -5.072463768115942, \"y2\": -8.260869565217392, \"center_x\": -5.217391304347826, \"center_y\": -8.405797101449277, \"value_uncond\": 2.1486029113127425e-08}, {\"x\": -5.0724637681159415, \"y\": -8.55072463768116, \"x2\": -4.782608695652174, \"y2\": -8.260869565217392, \"center_x\": -4.927536231884058, \"center_y\": -8.405797101449277, \"value_uncond\": 2.8912074711345388e-08}, {\"x\": -4.782608695652174, \"y\": -8.55072463768116, \"x2\": -4.492753623188406, \"y2\": -8.260869565217392, \"center_x\": -4.63768115942029, \"center_y\": -8.405797101449277, \"value_uncond\": 3.854323559455201e-08}, {\"x\": -4.492753623188405, \"y\": -8.55072463768116, \"x2\": -4.202898550724638, \"y2\": -8.260869565217392, \"center_x\": -4.3478260869565215, \"center_y\": -8.405797101449277, \"value_uncond\": 5.0905287705900384e-08}, {\"x\": -4.202898550724638, \"y\": -8.55072463768116, \"x2\": -3.91304347826087, \"y2\": -8.260869565217392, \"center_x\": -4.057971014492754, \"center_y\": -8.405797101449277, \"value_uncond\": 6.660754664192793e-08}, {\"x\": -3.913043478260869, \"y\": -8.55072463768116, \"x2\": -3.6231884057971016, \"y2\": -8.260869565217392, \"center_x\": -3.7681159420289854, \"center_y\": -8.405797101449277, \"value_uncond\": 8.634352867076865e-08}, {\"x\": -3.6231884057971016, \"y\": -8.55072463768116, \"x2\": -3.333333333333334, \"y2\": -8.260869565217392, \"center_x\": -3.4782608695652177, \"center_y\": -8.405797101449277, \"value_uncond\": 1.1088733950400234e-07}, {\"x\": -3.333333333333333, \"y\": -8.55072463768116, \"x2\": -3.0434782608695654, \"y2\": -8.260869565217392, \"center_x\": -3.1884057971014492, \"center_y\": -8.405797101449277, \"value_uncond\": 1.41084709582318e-07}, {\"x\": -3.0434782608695645, \"y\": -8.55072463768116, \"x2\": -2.753623188405797, \"y2\": -8.260869565217392, \"center_x\": -2.8985507246376807, \"center_y\": -8.405797101449277, \"value_uncond\": 1.7783766518923127e-07}, {\"x\": -2.753623188405797, \"y\": -8.55072463768116, \"x2\": -2.4637681159420293, \"y2\": -8.260869565217392, \"center_x\": -2.608695652173913, \"center_y\": -8.405797101449277, \"value_uncond\": 2.2208200099933804e-07}, {\"x\": -2.4637681159420284, \"y\": -8.55072463768116, \"x2\": -2.1739130434782608, \"y2\": -8.260869565217392, \"center_x\": -2.3188405797101446, \"center_y\": -8.405797101449277, \"value_uncond\": 2.747570155399246e-07}, {\"x\": -2.1739130434782608, \"y\": -8.55072463768116, \"x2\": -1.8840579710144931, \"y2\": -8.260869565217392, \"center_x\": -2.028985507246377, \"center_y\": -8.405797101449277, \"value_uncond\": 3.3676739177298414e-07}, {\"x\": -1.8840579710144922, \"y\": -8.55072463768116, \"x2\": -1.5942028985507246, \"y2\": -8.260869565217392, \"center_x\": -1.7391304347826084, \"center_y\": -8.405797101449277, \"value_uncond\": 4.089376443349696e-07}, {\"x\": -1.5942028985507246, \"y\": -8.55072463768116, \"x2\": -1.304347826086957, \"y2\": -8.260869565217392, \"center_x\": -1.4492753623188408, \"center_y\": -8.405797101449277, \"value_uncond\": 4.919601927890292e-07}, {\"x\": -1.304347826086957, \"y\": -8.55072463768116, \"x2\": -1.0144927536231894, \"y2\": -8.260869565217392, \"center_x\": -1.1594202898550732, \"center_y\": -8.405797101449277, \"value_uncond\": 5.863388213528535e-07}, {\"x\": -1.0144927536231876, \"y\": -8.55072463768116, \"x2\": -0.72463768115942, \"y2\": -8.260869565217392, \"center_x\": -0.8695652173913038, \"center_y\": -8.405797101449277, \"value_uncond\": 6.923300000192465e-07}, {\"x\": -0.72463768115942, \"y\": -8.55072463768116, \"x2\": -0.43478260869565233, \"y2\": -8.260869565217392, \"center_x\": -0.5797101449275361, \"center_y\": -8.405797101449277, \"value_uncond\": 8.098852073070005e-07}, {\"x\": -0.43478260869565233, \"y\": -8.55072463768116, \"x2\": -0.1449275362318847, \"y2\": -8.260869565217392, \"center_x\": -0.2898550724637685, \"center_y\": -8.405797101449277, \"value_uncond\": 9.385979402885297e-07}, {\"x\": -0.14492753623188293, \"y\": -8.55072463768116, \"x2\": 0.1449275362318847, \"y2\": -8.260869565217392, \"center_x\": 8.881784197001252e-16, \"center_y\": -8.405797101449277, \"value_uncond\": 1.077659450100381e-06}, {\"x\": 0.1449275362318847, \"y\": -8.55072463768116, \"x2\": 0.43478260869565233, \"y2\": -8.260869565217392, \"center_x\": 0.2898550724637685, \"center_y\": -8.405797101449277, \"value_uncond\": 1.2258273333896651e-06}, {\"x\": 0.43478260869565233, \"y\": -8.55072463768116, \"x2\": 0.72463768115942, \"y2\": -8.260869565217392, \"center_x\": 0.5797101449275361, \"center_y\": -8.405797101449277, \"value_uncond\": 1.3814108885194928e-06}, {\"x\": 0.72463768115942, \"y\": -8.55072463768116, \"x2\": 1.0144927536231876, \"y2\": -8.260869565217392, \"center_x\": 0.8695652173913038, \"center_y\": -8.405797101449277, \"value_uncond\": 1.5422765784592037e-06}, {\"x\": 1.0144927536231894, \"y\": -8.55072463768116, \"x2\": 1.304347826086957, \"y2\": -8.260869565217392, \"center_x\": 1.1594202898550732, \"center_y\": -8.405797101449277, \"value_uncond\": 1.705876027932241e-06}, {\"x\": 1.304347826086957, \"y\": -8.55072463768116, \"x2\": 1.5942028985507246, \"y2\": -8.260869565217392, \"center_x\": 1.4492753623188408, \"center_y\": -8.405797101449277, \"value_uncond\": 1.8692977522789205e-06}, {\"x\": 1.5942028985507246, \"y\": -8.55072463768116, \"x2\": 1.8840579710144922, \"y2\": -8.260869565217392, \"center_x\": 1.7391304347826084, \"center_y\": -8.405797101449277, \"value_uncond\": 2.0293423365645064e-06}, {\"x\": 1.884057971014494, \"y\": -8.55072463768116, \"x2\": 2.1739130434782616, \"y2\": -8.260869565217392, \"center_x\": 2.028985507246378, \"center_y\": -8.405797101449277, \"value_uncond\": 2.1826191553660887e-06}, {\"x\": 2.1739130434782616, \"y\": -8.55072463768116, \"x2\": 2.4637681159420293, \"y2\": -8.260869565217392, \"center_x\": 2.3188405797101455, \"center_y\": -8.405797101449277, \"value_uncond\": 2.325661072031476e-06}, {\"x\": 2.4637681159420293, \"y\": -8.55072463768116, \"x2\": 2.753623188405797, \"y2\": -8.260869565217392, \"center_x\": 2.608695652173913, \"center_y\": -8.405797101449277, \"value_uncond\": 2.455052022138501e-06}, {\"x\": 2.753623188405797, \"y\": -8.55072463768116, \"x2\": 3.0434782608695645, \"y2\": -8.260869565217392, \"center_x\": 2.8985507246376807, \"center_y\": -8.405797101449277, \"value_uncond\": 2.567561112617595e-06}, {\"x\": 3.0434782608695663, \"y\": -8.55072463768116, \"x2\": 3.333333333333334, \"y2\": -8.260869565217392, \"center_x\": 3.18840579710145, \"center_y\": -8.405797101449277, \"value_uncond\": 2.6602759859656123e-06}, {\"x\": 3.333333333333334, \"y\": -8.55072463768116, \"x2\": 3.6231884057971016, \"y2\": -8.260869565217392, \"center_x\": 3.4782608695652177, \"center_y\": -8.405797101449277, \"value_uncond\": 2.7307278111152564e-06}, {\"x\": 3.6231884057971016, \"y\": -8.55072463768116, \"x2\": 3.913043478260869, \"y2\": -8.260869565217392, \"center_x\": 3.7681159420289854, \"center_y\": -8.405797101449277, \"value_uncond\": 2.7770004316183796e-06}, {\"x\": 3.913043478260871, \"y\": -8.55072463768116, \"x2\": 4.202898550724639, \"y2\": -8.260869565217392, \"center_x\": 4.057971014492755, \"center_y\": -8.405797101449277, \"value_uncond\": 2.7978169415515185e-06}, {\"x\": 4.202898550724639, \"y\": -8.55072463768116, \"x2\": 4.492753623188406, \"y2\": -8.260869565217392, \"center_x\": 4.347826086956522, \"center_y\": -8.405797101449277, \"value_uncond\": 2.7925982306846808e-06}, {\"x\": 4.492753623188406, \"y\": -8.55072463768116, \"x2\": 4.782608695652174, \"y2\": -8.260869565217392, \"center_x\": 4.63768115942029, \"center_y\": -8.405797101449277, \"value_uncond\": 2.761489752615771e-06}, {\"x\": 4.782608695652174, \"y\": -8.55072463768116, \"x2\": 5.0724637681159415, \"y2\": -8.260869565217392, \"center_x\": 4.927536231884058, \"center_y\": -8.405797101449277, \"value_uncond\": 2.705354788997938e-06}, {\"x\": 5.072463768115943, \"y\": -8.55072463768116, \"x2\": 5.362318840579711, \"y2\": -8.260869565217392, \"center_x\": 5.217391304347827, \"center_y\": -8.405797101449277, \"value_uncond\": 2.625734645205194e-06}, {\"x\": 5.362318840579711, \"y\": -8.55072463768116, \"x2\": 5.6521739130434785, \"y2\": -8.260869565217392, \"center_x\": 5.507246376811595, \"center_y\": -8.405797101449277, \"value_uncond\": 2.52477833893488e-06}, {\"x\": 5.6521739130434785, \"y\": -8.55072463768116, \"x2\": 5.942028985507246, \"y2\": -8.260869565217392, \"center_x\": 5.797101449275362, \"center_y\": -8.405797101449277, \"value_uncond\": 2.4051462581167118e-06}, {\"x\": 5.942028985507246, \"y\": -8.55072463768116, \"x2\": 6.231884057971014, \"y2\": -8.260869565217392, \"center_x\": 6.08695652173913, \"center_y\": -8.405797101449277, \"value_uncond\": 2.2698938141044712e-06}, {\"x\": 6.2318840579710155, \"y\": -8.55072463768116, \"x2\": 6.521739130434783, \"y2\": -8.260869565217392, \"center_x\": 6.376811594202899, \"center_y\": -8.405797101449277, \"value_uncond\": 2.1223421827994186e-06}, {\"x\": 6.521739130434785, \"y\": -8.55072463768116, \"x2\": 6.8115942028985526, \"y2\": -8.260869565217392, \"center_x\": 6.666666666666669, \"center_y\": -8.405797101449277, \"value_uncond\": 1.965943739567227e-06}, {\"x\": 6.811594202898551, \"y\": -8.55072463768116, \"x2\": 7.101449275362318, \"y2\": -8.260869565217392, \"center_x\": 6.956521739130435, \"center_y\": -8.405797101449277, \"value_uncond\": 1.8041497355819331e-06}, {\"x\": 7.10144927536232, \"y\": -8.55072463768116, \"x2\": 7.391304347826088, \"y2\": -8.260869565217392, \"center_x\": 7.246376811594204, \"center_y\": -8.405797101449277, \"value_uncond\": 1.6402871676680804e-06}, {\"x\": 7.391304347826086, \"y\": -8.55072463768116, \"x2\": 7.681159420289854, \"y2\": -8.260869565217392, \"center_x\": 7.53623188405797, \"center_y\": -8.405797101449277, \"value_uncond\": 1.4774507409785143e-06}, {\"x\": 7.681159420289855, \"y\": -8.55072463768116, \"x2\": 7.971014492753623, \"y2\": -8.260869565217392, \"center_x\": 7.826086956521739, \"center_y\": -8.405797101449277, \"value_uncond\": 1.3184144295520983e-06}, {\"x\": 7.971014492753625, \"y\": -8.55072463768116, \"x2\": 8.260869565217392, \"y2\": -8.260869565217392, \"center_x\": 8.115942028985508, \"center_y\": -8.405797101449277, \"value_uncond\": 1.165565541306785e-06}, {\"x\": 8.26086956521739, \"y\": -8.55072463768116, \"x2\": 8.550724637681158, \"y2\": -8.260869565217392, \"center_x\": 8.405797101449274, \"center_y\": -8.405797101449277, \"value_uncond\": 1.020862535459508e-06}, {\"x\": 8.55072463768116, \"y\": -8.55072463768116, \"x2\": 8.840579710144928, \"y2\": -8.260869565217392, \"center_x\": 8.695652173913043, \"center_y\": -8.405797101449277, \"value_uncond\": 8.858162581182798e-07}, {\"x\": 8.84057971014493, \"y\": -8.55072463768116, \"x2\": 9.130434782608697, \"y2\": -8.260869565217392, \"center_x\": 8.985507246376812, \"center_y\": -8.405797101449277, \"value_uncond\": 7.614928721571976e-07}, {\"x\": 9.130434782608695, \"y\": -8.55072463768116, \"x2\": 9.420289855072463, \"y2\": -8.260869565217392, \"center_x\": 9.275362318840578, \"center_y\": -8.405797101449277, \"value_uncond\": 6.485356476016378e-07}, {\"x\": 9.420289855072465, \"y\": -8.55072463768116, \"x2\": 9.710144927536232, \"y2\": -8.260869565217392, \"center_x\": 9.565217391304348, \"center_y\": -8.405797101449277, \"value_uncond\": 5.472020015447292e-07}, {\"x\": 9.710144927536234, \"y\": -8.55072463768116, \"x2\": 10.000000000000002, \"y2\": -8.260869565217392, \"center_x\": 9.855072463768117, \"center_y\": -8.405797101449277, \"value_uncond\": 4.5741174985874186e-07}, {\"x\": 10.0, \"y\": -8.55072463768116, \"x2\": 10.289855072463768, \"y2\": -8.260869565217392, \"center_x\": 10.144927536231883, \"center_y\": -8.405797101449277, \"value_uncond\": 3.7880244207052163e-07}, {\"x\": -10.0, \"y\": -8.26086956521739, \"x2\": -9.710144927536232, \"y2\": -7.971014492753623, \"center_x\": -9.855072463768117, \"center_y\": -8.115942028985508, \"value_uncond\": 7.789983057737388e-11}, {\"x\": -9.710144927536232, \"y\": -8.26086956521739, \"x2\": -9.420289855072465, \"y2\": -7.971014492753623, \"center_x\": -9.565217391304348, \"center_y\": -8.115942028985508, \"value_uncond\": 1.2171008846978545e-10}, {\"x\": -9.420289855072463, \"y\": -8.26086956521739, \"x2\": -9.130434782608695, \"y2\": -7.971014492753623, \"center_x\": -9.275362318840578, \"center_y\": -8.115942028985508, \"value_uncond\": 1.883920004054249e-10}, {\"x\": -9.130434782608695, \"y\": -8.26086956521739, \"x2\": -8.840579710144928, \"y2\": -7.971014492753623, \"center_x\": -8.985507246376812, \"center_y\": -8.115942028985508, \"value_uncond\": 2.888977448101407e-10}, {\"x\": -8.840579710144928, \"y\": -8.26086956521739, \"x2\": -8.55072463768116, \"y2\": -7.971014492753623, \"center_x\": -8.695652173913043, \"center_y\": -8.115942028985508, \"value_uncond\": 4.3890614393438853e-10}, {\"x\": -8.55072463768116, \"y\": -8.26086956521739, \"x2\": -8.260869565217392, \"y2\": -7.971014492753623, \"center_x\": -8.405797101449277, \"center_y\": -8.115942028985508, \"value_uncond\": 6.606097563964613e-10}, {\"x\": -8.26086956521739, \"y\": -8.26086956521739, \"x2\": -7.971014492753623, \"y2\": -7.971014492753623, \"center_x\": -8.115942028985508, \"center_y\": -8.115942028985508, \"value_uncond\": 9.850632591497524e-10}, {\"x\": -7.971014492753623, \"y\": -8.26086956521739, \"x2\": -7.681159420289855, \"y2\": -7.971014492753623, \"center_x\": -7.826086956521739, \"center_y\": -8.115942028985508, \"value_uncond\": 1.4552214019965556e-09}, {\"x\": -7.681159420289855, \"y\": -8.26086956521739, \"x2\": -7.391304347826088, \"y2\": -7.971014492753623, \"center_x\": -7.536231884057972, \"center_y\": -8.115942028985508, \"value_uncond\": 2.129804989101398e-09}, {\"x\": -7.391304347826087, \"y\": -8.26086956521739, \"x2\": -7.101449275362319, \"y2\": -7.971014492753623, \"center_x\": -7.246376811594203, \"center_y\": -8.115942028985508, \"value_uncond\": 3.0881360222957336e-09}, {\"x\": -7.101449275362318, \"y\": -8.26086956521739, \"x2\": -6.811594202898551, \"y2\": -7.971014492753623, \"center_x\": -6.956521739130435, \"center_y\": -8.115942028985508, \"value_uncond\": 4.4360743573757856e-09}, {\"x\": -6.811594202898551, \"y\": -8.26086956521739, \"x2\": -6.521739130434783, \"y2\": -7.971014492753623, \"center_x\": -6.666666666666667, \"center_y\": -8.115942028985508, \"value_uncond\": 6.313163363352597e-09}, {\"x\": -6.521739130434782, \"y\": -8.26086956521739, \"x2\": -6.231884057971015, \"y2\": -7.971014492753623, \"center_x\": -6.3768115942028984, \"center_y\": -8.115942028985508, \"value_uncond\": 8.901046143811682e-09}, {\"x\": -6.231884057971014, \"y\": -8.26086956521739, \"x2\": -5.942028985507246, \"y2\": -7.971014492753623, \"center_x\": -6.08695652173913, \"center_y\": -8.115942028985508, \"value_uncond\": 1.2433141946371896e-08}, {\"x\": -5.942028985507246, \"y\": -8.26086956521739, \"x2\": -5.6521739130434785, \"y2\": -7.971014492753623, \"center_x\": -5.797101449275362, \"center_y\": -8.115942028985508, \"value_uncond\": 1.720547020682608e-08}, {\"x\": -5.6521739130434785, \"y\": -8.26086956521739, \"x2\": -5.362318840579711, \"y2\": -7.971014492753623, \"center_x\": -5.507246376811595, \"center_y\": -8.115942028985508, \"value_uncond\": 2.358837451255229e-08}, {\"x\": -5.36231884057971, \"y\": -8.26086956521739, \"x2\": -5.072463768115942, \"y2\": -7.971014492753623, \"center_x\": -5.217391304347826, \"center_y\": -8.115942028985508, \"value_uncond\": 3.203873036907085e-08}, {\"x\": -5.0724637681159415, \"y\": -8.26086956521739, \"x2\": -4.782608695652174, \"y2\": -7.971014492753623, \"center_x\": -4.927536231884058, \"center_y\": -8.115942028985508, \"value_uncond\": 4.311202229179132e-08}, {\"x\": -4.782608695652174, \"y\": -8.26086956521739, \"x2\": -4.492753623188406, \"y2\": -7.971014492753623, \"center_x\": -4.63768115942029, \"center_y\": -8.115942028985508, \"value_uncond\": 5.747345525148468e-08}, {\"x\": -4.492753623188405, \"y\": -8.26086956521739, \"x2\": -4.202898550724638, \"y2\": -7.971014492753623, \"center_x\": -4.3478260869565215, \"center_y\": -8.115942028985508, \"value_uncond\": 7.59070360829428e-08}, {\"x\": -4.202898550724638, \"y\": -8.26086956521739, \"x2\": -3.91304347826087, \"y2\": -7.971014492753623, \"center_x\": -4.057971014492754, \"center_y\": -8.115942028985508, \"value_uncond\": 9.932134114545186e-08}, {\"x\": -3.913043478260869, \"y\": -8.26086956521739, \"x2\": -3.6231884057971016, \"y2\": -7.971014492753623, \"center_x\": -3.7681159420289854, \"center_y\": -8.115942028985508, \"value_uncond\": 1.287505019951189e-07}, {\"x\": -3.6231884057971016, \"y\": -8.26086956521739, \"x2\": -3.333333333333334, \"y2\": -7.971014492753623, \"center_x\": -3.4782608695652177, \"center_y\": -8.115942028985508, \"value_uncond\": 1.6534882052923152e-07}, {\"x\": -3.333333333333333, \"y\": -8.26086956521739, \"x2\": -3.0434782608695654, \"y2\": -7.971014492753623, \"center_x\": -3.1884057971014492, \"center_y\": -8.115942028985508, \"value_uncond\": 2.1037740132004386e-07}, {\"x\": -3.0434782608695645, \"y\": -8.26086956521739, \"x2\": -2.753623188405797, \"y2\": -7.971014492753623, \"center_x\": -2.8985507246376807, \"center_y\": -8.115942028985508, \"value_uncond\": 2.651812940615314e-07}, {\"x\": -2.753623188405797, \"y\": -8.26086956521739, \"x2\": -2.4637681159420293, \"y2\": -7.971014492753623, \"center_x\": -2.608695652173913, \"center_y\": -8.115942028985508, \"value_uncond\": 3.3115590192951433e-07}, {\"x\": -2.4637681159420284, \"y\": -8.26086956521739, \"x2\": -2.1739130434782608, \"y2\": -7.971014492753623, \"center_x\": -2.3188405797101446, \"center_y\": -8.115942028985508, \"value_uncond\": 4.0970185284334017e-07}, {\"x\": -2.1739130434782608, \"y\": -8.26086956521739, \"x2\": -1.8840579710144931, \"y2\": -7.971014492753623, \"center_x\": -2.028985507246377, \"center_y\": -8.115942028985508, \"value_uncond\": 5.021681579830735e-07}, {\"x\": -1.8840579710144922, \"y\": -8.26086956521739, \"x2\": -1.5942028985507246, \"y2\": -7.971014492753623, \"center_x\": -1.7391304347826084, \"center_y\": -8.115942028985508, \"value_uncond\": 6.09784286134387e-07}, {\"x\": -1.5942028985507246, \"y\": -8.26086956521739, \"x2\": -1.304347826086957, \"y2\": -7.971014492753623, \"center_x\": -1.4492753623188408, \"center_y\": -8.115942028985508, \"value_uncond\": 7.33582733510017e-07}, {\"x\": -1.304347826086957, \"y\": -8.26086956521739, \"x2\": -1.0144927536231894, \"y2\": -7.971014492753623, \"center_x\": -1.1594202898550732, \"center_y\": -8.115942028985508, \"value_uncond\": 8.743147141490828e-07}, {\"x\": -1.0144927536231876, \"y\": -8.26086956521739, \"x2\": -0.72463768115942, \"y2\": -7.971014492753623, \"center_x\": -0.8695652173913038, \"center_y\": -8.115942028985508, \"value_uncond\": 1.032362661348308e-06}, {\"x\": -0.72463768115942, \"y\": -8.26086956521739, \"x2\": -0.43478260869565233, \"y2\": -7.971014492753623, \"center_x\": -0.5797101449275361, \"center_y\": -8.115942028985508, \"value_uncond\": 1.2076542226667024e-06}, {\"x\": -0.43478260869565233, \"y\": -8.26086956521739, \"x2\": -0.1449275362318847, \"y2\": -7.971014492753623, \"center_x\": -0.2898550724637685, \"center_y\": -8.115942028985508, \"value_uncond\": 1.3995832443276615e-06}, {\"x\": -0.14492753623188293, \"y\": -8.26086956521739, \"x2\": 0.1449275362318847, \"y2\": -7.971014492753623, \"center_x\": 8.881784197001252e-16, \"center_y\": -8.115942028985508, \"value_uncond\": 1.6069437665590913e-06}, {\"x\": 0.1449275362318847, \"y\": -8.26086956521739, \"x2\": 0.43478260869565233, \"y2\": -7.971014492753623, \"center_x\": 0.2898550724637685, \"center_y\": -8.115942028985508, \"value_uncond\": 1.8278831889654851e-06}, {\"x\": 0.43478260869565233, \"y\": -8.26086956521739, \"x2\": 0.72463768115942, \"y2\": -7.971014492753623, \"center_x\": 0.5797101449275361, \"center_y\": -8.115942028985508, \"value_uncond\": 2.0598804345440314e-06}, {\"x\": 0.72463768115942, \"y\": -8.26086956521739, \"x2\": 1.0144927536231876, \"y2\": -7.971014492753623, \"center_x\": 0.8695652173913038, \"center_y\": -8.115942028985508, \"value_uncond\": 2.2997540956322e-06}, {\"x\": 1.0144927536231894, \"y\": -8.26086956521739, \"x2\": 1.304347826086957, \"y2\": -7.971014492753623, \"center_x\": 1.1594202898550732, \"center_y\": -8.115942028985508, \"value_uncond\": 2.5437041816438e-06}, {\"x\": 1.304347826086957, \"y\": -8.26086956521739, \"x2\": 1.5942028985507246, \"y2\": -7.971014492753623, \"center_x\": 1.4492753623188408, \"center_y\": -8.115942028985508, \"value_uncond\": 2.7873892541727638e-06}, {\"x\": 1.5942028985507246, \"y\": -8.26086956521739, \"x2\": 1.8840579710144922, \"y2\": -7.971014492753623, \"center_x\": 1.7391304347826084, \"center_y\": -8.115942028985508, \"value_uncond\": 3.0260385297535673e-06}, {\"x\": 1.884057971014494, \"y\": -8.26086956521739, \"x2\": 2.1739130434782616, \"y2\": -7.971014492753623, \"center_x\": 2.028985507246378, \"center_y\": -8.115942028985508, \"value_uncond\": 3.2545961028424198e-06}, {\"x\": 2.1739130434782616, \"y\": -8.26086956521739, \"x2\": 2.4637681159420293, \"y2\": -7.971014492753623, \"center_x\": 2.3188405797101455, \"center_y\": -8.115942028985508, \"value_uncond\": 3.4678919787526597e-06}, {\"x\": 2.4637681159420293, \"y\": -8.26086956521739, \"x2\": 2.753623188405797, \"y2\": -7.971014492753623, \"center_x\": 2.608695652173913, \"center_y\": -8.115942028985508, \"value_uncond\": 3.660832318768493e-06}, {\"x\": 2.753623188405797, \"y\": -8.26086956521739, \"x2\": 3.0434782608695645, \"y2\": -7.971014492753623, \"center_x\": 2.8985507246376807, \"center_y\": -8.115942028985508, \"value_uncond\": 3.828599401040885e-06}, {\"x\": 3.0434782608695663, \"y\": -8.26086956521739, \"x2\": 3.333333333333334, \"y2\": -7.971014492753623, \"center_x\": 3.18840579710145, \"center_y\": -8.115942028985508, \"value_uncond\": 3.966850485629838e-06}, {\"x\": 3.333333333333334, \"y\": -8.26086956521739, \"x2\": 3.6231884057971016, \"y2\": -7.971014492753623, \"center_x\": 3.4782608695652177, \"center_y\": -8.115942028985508, \"value_uncond\": 4.071904193697249e-06}, {\"x\": 3.6231884057971016, \"y\": -8.26086956521739, \"x2\": 3.913043478260869, \"y2\": -7.971014492753623, \"center_x\": 3.7681159420289854, \"center_y\": -8.115942028985508, \"value_uncond\": 4.14090326299778e-06}, {\"x\": 3.913043478260871, \"y\": -8.26086956521739, \"x2\": 4.202898550724639, \"y2\": -7.971014492753623, \"center_x\": 4.057971014492755, \"center_y\": -8.115942028985508, \"value_uncond\": 4.171943644887863e-06}, {\"x\": 4.202898550724639, \"y\": -8.26086956521739, \"x2\": 4.492753623188406, \"y2\": -7.971014492753623, \"center_x\": 4.347826086956522, \"center_y\": -8.115942028985508, \"value_uncond\": 4.164161803512874e-06}, {\"x\": 4.492753623188406, \"y\": -8.26086956521739, \"x2\": 4.782608695652174, \"y2\": -7.971014492753623, \"center_x\": 4.63768115942029, \"center_y\": -8.115942028985508, \"value_uncond\": 4.117774630909027e-06}, {\"x\": 4.782608695652174, \"y\": -8.26086956521739, \"x2\": 5.0724637681159415, \"y2\": -7.971014492753623, \"center_x\": 4.927536231884058, \"center_y\": -8.115942028985508, \"value_uncond\": 4.034069403006746e-06}, {\"x\": 5.072463768115943, \"y\": -8.26086956521739, \"x2\": 5.362318840579711, \"y2\": -7.971014492753623, \"center_x\": 5.217391304347827, \"center_y\": -8.115942028985508, \"value_uncond\": 3.915344425697475e-06}, {\"x\": 5.362318840579711, \"y\": -8.26086956521739, \"x2\": 5.6521739130434785, \"y2\": -7.971014492753623, \"center_x\": 5.507246376811595, \"center_y\": -8.115942028985508, \"value_uncond\": 3.7648041905231814e-06}, {\"x\": 5.6521739130434785, \"y\": -8.26086956521739, \"x2\": 5.942028985507246, \"y2\": -7.971014492753623, \"center_x\": 5.797101449275362, \"center_y\": -8.115942028985508, \"value_uncond\": 3.586415714893573e-06}, {\"x\": 5.942028985507246, \"y\": -8.26086956521739, \"x2\": 6.231884057971014, \"y2\": -7.971014492753623, \"center_x\": 6.08695652173913, \"center_y\": -8.115942028985508, \"value_uncond\": 3.3847350524198137e-06}, {\"x\": 6.2318840579710155, \"y\": -8.26086956521739, \"x2\": 6.521739130434783, \"y2\": -7.971014492753623, \"center_x\": 6.376811594202899, \"center_y\": -8.115942028985508, \"value_uncond\": 3.1647145495149364e-06}, {\"x\": 6.521739130434785, \"y\": -8.26086956521739, \"x2\": 6.8115942028985526, \"y2\": -7.971014492753623, \"center_x\": 6.666666666666669, \"center_y\": -8.115942028985508, \"value_uncond\": 2.931502189684466e-06}, {\"x\": 6.811594202898551, \"y\": -8.26086956521739, \"x2\": 7.101449275362318, \"y2\": -7.971014492753623, \"center_x\": 6.956521739130435, \"center_y\": -8.115942028985508, \"value_uncond\": 2.6902442801040447e-06}, {\"x\": 7.10144927536232, \"y\": -8.26086956521739, \"x2\": 7.391304347826088, \"y2\": -7.971014492753623, \"center_x\": 7.246376811594204, \"center_y\": -8.115942028985508, \"value_uncond\": 2.445901847012585e-06}, {\"x\": 7.391304347826086, \"y\": -8.26086956521739, \"x2\": 7.681159420289854, \"y2\": -7.971014492753623, \"center_x\": 7.53623188405797, \"center_y\": -8.115942028985508, \"value_uncond\": 2.2030895366735617e-06}, {\"x\": 7.681159420289855, \"y\": -8.26086956521739, \"x2\": 7.971014492753623, \"y2\": -7.971014492753623, \"center_x\": 7.826086956521739, \"center_y\": -8.115942028985508, \"value_uncond\": 1.965943739567227e-06}, {\"x\": 7.971014492753625, \"y\": -8.26086956521739, \"x2\": 8.260869565217392, \"y2\": -7.971014492753623, \"center_x\": 8.115942028985508, \"center_y\": -8.115942028985508, \"value_uncond\": 1.7380242719019876e-06}, {\"x\": 8.26086956521739, \"y\": -8.26086956521739, \"x2\": 8.550724637681158, \"y2\": -7.971014492753623, \"center_x\": 8.405797101449274, \"center_y\": -8.115942028985508, \"value_uncond\": 1.5222514753780152e-06}, {\"x\": 8.55072463768116, \"y\": -8.26086956521739, \"x2\": 8.840579710144928, \"y2\": -7.971014492753623, \"center_x\": 8.695652173913043, \"center_y\": -8.115942028985508, \"value_uncond\": 1.3208782367818309e-06}, {\"x\": 8.84057971014493, \"y\": -8.26086956521739, \"x2\": 9.130434782608697, \"y2\": -7.971014492753623, \"center_x\": 8.985507246376812, \"center_y\": -8.115942028985508, \"value_uncond\": 1.1354943568473354e-06}, {\"x\": 9.130434782608695, \"y\": -8.26086956521739, \"x2\": 9.420289855072463, \"y2\": -7.971014492753623, \"center_x\": 9.275362318840578, \"center_y\": -8.115942028985508, \"value_uncond\": 9.670590428244664e-07}, {\"x\": 9.420289855072465, \"y\": -8.26086956521739, \"x2\": 9.710144927536232, \"y2\": -7.971014492753623, \"center_x\": 9.565217391304348, \"center_y\": -8.115942028985508, \"value_uncond\": 8.15956140271452e-07}, {\"x\": 9.710144927536234, \"y\": -8.26086956521739, \"x2\": 10.000000000000002, \"y2\": -7.971014492753623, \"center_x\": 9.855072463768117, \"center_y\": -8.115942028985508, \"value_uncond\": 6.820660832305835e-07}, {\"x\": 10.0, \"y\": -8.26086956521739, \"x2\": 10.289855072463768, \"y2\": -7.971014492753623, \"center_x\": 10.144927536231883, \"center_y\": -8.115942028985508, \"value_uncond\": 5.648484064106578e-07}, {\"x\": -10.0, \"y\": -7.971014492753623, \"x2\": -9.710144927536232, \"y2\": -7.681159420289855, \"center_x\": -9.855072463768117, \"center_y\": -7.826086956521739, \"value_uncond\": 1.150804271859119e-10}, {\"x\": -9.710144927536232, \"y\": -7.971014492753623, \"x2\": -9.420289855072465, \"y2\": -7.681159420289855, \"center_x\": -9.565217391304348, \"center_y\": -7.826086956521739, \"value_uncond\": 1.7980076298145616e-10}, {\"x\": -9.420289855072463, \"y\": -7.971014492753623, \"x2\": -9.130434782608695, \"y2\": -7.681159420289855, \"center_x\": -9.275362318840578, \"center_y\": -7.826086956521739, \"value_uncond\": 2.783091018860542e-10}, {\"x\": -9.130434782608695, \"y\": -7.971014492753623, \"x2\": -8.840579710144928, \"y2\": -7.681159420289855, \"center_x\": -8.985507246376812, \"center_y\": -7.826086956521739, \"value_uncond\": 4.267849575459015e-10}, {\"x\": -8.840579710144928, \"y\": -7.971014492753623, \"x2\": -8.55072463768116, \"y2\": -7.681159420289855, \"center_x\": -8.695652173913043, \"center_y\": -7.826086956521739, \"value_uncond\": 6.483904543068586e-10}, {\"x\": -8.55072463768116, \"y\": -7.971014492753623, \"x2\": -8.260869565217392, \"y2\": -7.681159420289855, \"center_x\": -8.405797101449277, \"center_y\": -7.826086956521739, \"value_uncond\": 9.75910376259108e-10}, {\"x\": -8.26086956521739, \"y\": -7.971014492753623, \"x2\": -7.971014492753623, \"y2\": -7.681159420289855, \"center_x\": -8.115942028985508, \"center_y\": -7.826086956521739, \"value_uncond\": 1.4552214019965556e-09}, {\"x\": -7.971014492753623, \"y\": -7.971014492753623, \"x2\": -7.681159420289855, \"y2\": -7.681159420289855, \"center_x\": -7.826086956521739, \"center_y\": -7.826086956521739, \"value_uncond\": 2.1497800361132766e-09}, {\"x\": -7.681159420289855, \"y\": -7.971014492753623, \"x2\": -7.391304347826088, \"y2\": -7.681159420289855, \"center_x\": -7.536231884057972, \"center_y\": -7.826086956521739, \"value_uncond\": 3.146333774436529e-09}, {\"x\": -7.391304347826087, \"y\": -7.971014492753623, \"x2\": -7.101449275362319, \"y2\": -7.681159420289855, \"center_x\": -7.246376811594203, \"center_y\": -7.826086956521739, \"value_uncond\": 4.5620639996259195e-09}, {\"x\": -7.101449275362318, \"y\": -7.971014492753623, \"x2\": -6.811594202898551, \"y2\": -7.681159420289855, \"center_x\": -6.956521739130435, \"center_y\": -7.826086956521739, \"value_uncond\": 6.553356127882929e-09}, {\"x\": -6.811594202898551, \"y\": -7.971014492753623, \"x2\": -6.521739130434783, \"y2\": -7.681159420289855, \"center_x\": -6.666666666666667, \"center_y\": -7.826086956521739, \"value_uncond\": 9.326355800317806e-09}, {\"x\": -6.521739130434782, \"y\": -7.971014492753623, \"x2\": -6.231884057971015, \"y2\": -7.681159420289855, \"center_x\": -6.3768115942028984, \"center_y\": -7.826086956521739, \"value_uncond\": 1.314940205953262e-08}, {\"x\": -6.231884057971014, \"y\": -7.971014492753623, \"x2\": -5.942028985507246, \"y2\": -7.681159420289855, \"center_x\": -6.08695652173913, \"center_y\": -7.826086956521739, \"value_uncond\": 1.836732218602715e-08}, {\"x\": -5.942028985507246, \"y\": -7.971014492753623, \"x2\": -5.6521739130434785, \"y2\": -7.681159420289855, \"center_x\": -5.797101449275362, \"center_y\": -7.826086956521739, \"value_uncond\": 2.5417421920698242e-08}, {\"x\": -5.6521739130434785, \"y\": -7.971014492753623, \"x2\": -5.362318840579711, \"y2\": -7.681159420289855, \"center_x\": -5.507246376811595, \"center_y\": -7.826086956521739, \"value_uncond\": 3.484680512661137e-08}, {\"x\": -5.36231884057971, \"y\": -7.971014492753623, \"x2\": -5.072463768115942, \"y2\": -7.681159420289855, \"center_x\": -5.217391304347826, \"center_y\": -7.826086956521739, \"value_uncond\": 4.7330408166995674e-08}, {\"x\": -5.0724637681159415, \"y\": -7.971014492753623, \"x2\": -4.782608695652174, \"y2\": -7.681159420289855, \"center_x\": -4.927536231884058, \"center_y\": -7.826086956521739, \"value_uncond\": 6.368884123900681e-08}, {\"x\": -4.782608695652174, \"y\": -7.971014492753623, \"x2\": -4.492753623188406, \"y2\": -7.681159420289855, \"center_x\": -4.63768115942029, \"center_y\": -7.826086956521739, \"value_uncond\": 8.490480317055164e-08}, {\"x\": -4.492753623188405, \"y\": -7.971014492753623, \"x2\": -4.202898550724638, \"y2\": -7.681159420289855, \"center_x\": -4.3478260869565215, \"center_y\": -7.826086956521739, \"value_uncond\": 1.1213649726959334e-07}, {\"x\": -4.202898550724638, \"y\": -7.971014492753623, \"x2\": -3.91304347826087, \"y2\": -7.681159420289855, \"center_x\": -4.057971014492754, \"center_y\": -7.826086956521739, \"value_uncond\": 1.467261518154846e-07}, {\"x\": -3.913043478260869, \"y\": -7.971014492753623, \"x2\": -3.6231884057971016, \"y2\": -7.681159420289855, \"center_x\": -3.7681159420289854, \"center_y\": -7.826086956521739, \"value_uncond\": 1.902014761801341e-07}, {\"x\": -3.6231884057971016, \"y\": -7.971014492753623, \"x2\": -3.333333333333334, \"y2\": -7.681159420289855, \"center_x\": -3.4782608695652177, \"center_y\": -7.826086956521739, \"value_uncond\": 2.442677058493814e-07}, {\"x\": -3.333333333333333, \"y\": -7.971014492753623, \"x2\": -3.0434782608695654, \"y2\": -7.681159420289855, \"center_x\": -3.1884057971014492, \"center_y\": -7.826086956521739, \"value_uncond\": 3.1078785454001425e-07}, {\"x\": -3.0434782608695645, \"y\": -7.971014492753623, \"x2\": -2.753623188405797, \"y2\": -7.681159420289855, \"center_x\": -2.8985507246376807, \"center_y\": -7.826086956521739, \"value_uncond\": 3.917489470275911e-07}, {\"x\": -2.753623188405797, \"y\": -7.971014492753623, \"x2\": -2.4637681159420293, \"y2\": -7.681159420289855, \"center_x\": -2.608695652173913, \"center_y\": -7.826086956521739, \"value_uncond\": 4.892123946448407e-07}, {\"x\": -2.4637681159420284, \"y\": -7.971014492753623, \"x2\": -2.1739130434782608, \"y2\": -7.681159420289855, \"center_x\": -2.3188405797101446, \"center_y\": -7.826086956521739, \"value_uncond\": 6.052473271715371e-07}, {\"x\": -2.1739130434782608, \"y\": -7.971014492753623, \"x2\": -1.8840579710144931, \"y2\": -7.681159420289855, \"center_x\": -2.028985507246377, \"center_y\": -7.826086956521739, \"value_uncond\": 7.418466216361657e-07}, {\"x\": -1.8840579710144922, \"y\": -7.971014492753623, \"x2\": -1.5942028985507246, \"y2\": -7.681159420289855, \"center_x\": -1.7391304347826084, \"center_y\": -7.826086956521739, \"value_uncond\": 9.008265566110717e-07}, {\"x\": -1.5942028985507246, \"y\": -7.971014492753623, \"x2\": -1.304347826086957, \"y2\": -7.681159420289855, \"center_x\": -1.4492753623188408, \"center_y\": -7.826086956521739, \"value_uncond\": 1.0837124255962345e-06}, {\"x\": -1.304347826086957, \"y\": -7.971014492753623, \"x2\": -1.0144927536231894, \"y2\": -7.681159420289855, \"center_x\": -1.1594202898550732, \"center_y\": -7.826086956521739, \"value_uncond\": 1.291613987520393e-06}, {\"x\": -1.0144927536231876, \"y\": -7.971014492753623, \"x2\": -0.72463768115942, \"y2\": -7.681159420289855, \"center_x\": -0.8695652173913038, \"center_y\": -7.826086956521739, \"value_uncond\": 1.5250962062201841e-06}, {\"x\": -0.72463768115942, \"y\": -7.971014492753623, \"x2\": -0.43478260869565233, \"y2\": -7.681159420289855, \"center_x\": -0.5797101449275361, \"center_y\": -7.826086956521739, \"value_uncond\": 1.7840521963563896e-06}, {\"x\": -0.43478260869565233, \"y\": -7.971014492753623, \"x2\": -0.1449275362318847, \"y2\": -7.681159420289855, \"center_x\": -0.2898550724637685, \"center_y\": -7.826086956521739, \"value_uncond\": 2.067586494677862e-06}, {\"x\": -0.14492753623188293, \"y\": -7.971014492753623, \"x2\": 0.1449275362318847, \"y2\": -7.681159420289855, \"center_x\": 8.881784197001252e-16, \"center_y\": -7.826086956521739, \"value_uncond\": 2.373917552178486e-06}, {\"x\": 0.1449275362318847, \"y\": -7.971014492753623, \"x2\": 0.43478260869565233, \"y2\": -7.681159420289855, \"center_x\": 0.2898550724637685, \"center_y\": -7.826086956521739, \"value_uncond\": 2.7003085458980758e-06}, {\"x\": 0.43478260869565233, \"y\": -7.971014492753623, \"x2\": 0.72463768115942, \"y2\": -7.681159420289855, \"center_x\": 0.5797101449275361, \"center_y\": -7.826086956521739, \"value_uncond\": 3.043035120901547e-06}, {\"x\": 0.72463768115942, \"y\": -7.971014492753623, \"x2\": 1.0144927536231876, \"y2\": -7.681159420289855, \"center_x\": 0.8695652173913038, \"center_y\": -7.826086956521739, \"value_uncond\": 3.3973974241835387e-06}, {\"x\": 1.0144927536231894, \"y\": -7.971014492753623, \"x2\": 1.304347826086957, \"y2\": -7.681159420289855, \"center_x\": 1.1594202898550732, \"center_y\": -7.826086956521739, \"value_uncond\": 3.757781778066953e-06}, {\"x\": 1.304347826086957, \"y\": -7.971014492753623, \"x2\": 1.5942028985507246, \"y2\": -7.681159420289855, \"center_x\": 1.4492753623188408, \"center_y\": -7.826086956521739, \"value_uncond\": 4.117774630909027e-06}, {\"x\": 1.5942028985507246, \"y\": -7.971014492753623, \"x2\": 1.8840579710144922, \"y2\": -7.681159420289855, \"center_x\": 1.7391304347826084, \"center_y\": -7.826086956521739, \"value_uncond\": 4.470328165080958e-06}, {\"x\": 1.884057971014494, \"y\": -7.971014492753623, \"x2\": 2.1739130434782616, \"y2\": -7.681159420289855, \"center_x\": 2.028985507246378, \"center_y\": -7.826086956521739, \"value_uncond\": 4.807973355740461e-06}, {\"x\": 2.1739130434782616, \"y\": -7.971014492753623, \"x2\": 2.4637681159420293, \"y2\": -7.681159420289855, \"center_x\": 2.3188405797101455, \"center_y\": -7.826086956521739, \"value_uncond\": 5.123072635608127e-06}, {\"x\": 2.4637681159420293, \"y\": -7.971014492753623, \"x2\": 2.753623188405797, \"y2\": -7.681159420289855, \"center_x\": 2.608695652173913, \"center_y\": -7.826086956521739, \"value_uncond\": 5.4081009416499825e-06}, {\"x\": 2.753623188405797, \"y\": -7.971014492753623, \"x2\": 3.0434782608695645, \"y2\": -7.681159420289855, \"center_x\": 2.8985507246376807, \"center_y\": -7.826086956521739, \"value_uncond\": 5.65594111476133e-06}, {\"x\": 3.0434782608695663, \"y\": -7.971014492753623, \"x2\": 3.333333333333334, \"y2\": -7.681159420289855, \"center_x\": 3.18840579710145, \"center_y\": -7.826086956521739, \"value_uncond\": 5.860177680559899e-06}, {\"x\": 3.333333333333334, \"y\": -7.971014492753623, \"x2\": 3.6231884057971016, \"y2\": -7.681159420289855, \"center_x\": 3.4782608695652177, \"center_y\": -7.826086956521739, \"value_uncond\": 6.015372184992783e-06}, {\"x\": 3.6231884057971016, \"y\": -7.971014492753623, \"x2\": 3.913043478260869, \"y2\": -7.681159420289855, \"center_x\": 3.7681159420289854, \"center_y\": -7.826086956521739, \"value_uncond\": 6.117303630949506e-06}, {\"x\": 3.913043478260871, \"y\": -7.971014492753623, \"x2\": 4.202898550724639, \"y2\": -7.681159420289855, \"center_x\": 4.057971014492755, \"center_y\": -7.826086956521739, \"value_uncond\": 6.1631591916285006e-06}, {\"x\": 4.202898550724639, \"y\": -7.971014492753623, \"x2\": 4.492753623188406, \"y2\": -7.681159420289855, \"center_x\": 4.347826086956522, \"center_y\": -7.826086956521739, \"value_uncond\": 6.1516631765141e-06}, {\"x\": 4.492753623188406, \"y\": -7.971014492753623, \"x2\": 4.782608695652174, \"y2\": -7.681159420289855, \"center_x\": 4.63768115942029, \"center_y\": -7.826086956521739, \"value_uncond\": 6.08313599744797e-06}, {\"x\": 4.782608695652174, \"y\": -7.971014492753623, \"x2\": 5.0724637681159415, \"y2\": -7.681159420289855, \"center_x\": 4.927536231884058, \"center_y\": -7.826086956521739, \"value_uncond\": 5.9594793307608665e-06}, {\"x\": 5.072463768115943, \"y\": -7.971014492753623, \"x2\": 5.362318840579711, \"y2\": -7.681159420289855, \"center_x\": 5.217391304347827, \"center_y\": -7.826086956521739, \"value_uncond\": 5.7840884344633715e-06}, {\"x\": 5.362318840579711, \"y\": -7.971014492753623, \"x2\": 5.6521739130434785, \"y2\": -7.681159420289855, \"center_x\": 5.507246376811595, \"center_y\": -7.826086956521739, \"value_uncond\": 5.561697263081826e-06}, {\"x\": 5.6521739130434785, \"y\": -7.971014492753623, \"x2\": 5.942028985507246, \"y2\": -7.681159420289855, \"center_x\": 5.797101449275362, \"center_y\": -7.826086956521739, \"value_uncond\": 5.2981662408916325e-06}, {\"x\": 5.942028985507246, \"y\": -7.971014492753623, \"x2\": 6.231884057971014, \"y2\": -7.681159420289855, \"center_x\": 6.08695652173913, \"center_y\": -7.826086956521739, \"value_uncond\": 5.0002259678435955e-06}, {\"x\": 6.2318840579710155, \"y\": -7.971014492753623, \"x2\": 6.521739130434783, \"y2\": -7.681159420289855, \"center_x\": 6.376811594202899, \"center_y\": -7.826086956521739, \"value_uncond\": 4.675192482195596e-06}, {\"x\": 6.521739130434785, \"y\": -7.971014492753623, \"x2\": 6.8115942028985526, \"y2\": -7.681159420289855, \"center_x\": 6.666666666666669, \"center_y\": -7.826086956521739, \"value_uncond\": 4.330670834389596e-06}, {\"x\": 6.811594202898551, \"y\": -7.971014492753623, \"x2\": 7.101449275362318, \"y2\": -7.681159420289855, \"center_x\": 6.956521739130435, \"center_y\": -7.826086956521739, \"value_uncond\": 3.974263598446794e-06}, {\"x\": 7.10144927536232, \"y\": -7.971014492753623, \"x2\": 7.391304347826088, \"y2\": -7.681159420289855, \"center_x\": 7.246376811594204, \"center_y\": -7.826086956521739, \"value_uncond\": 3.613299635221212e-06}, {\"x\": 7.391304347826086, \"y\": -7.971014492753623, \"x2\": 7.681159420289854, \"y2\": -7.681159420289855, \"center_x\": 7.53623188405797, \"center_y\": -7.826086956521739, \"value_uncond\": 3.2545961028424198e-06}, {\"x\": 7.681159420289855, \"y\": -7.971014492753623, \"x2\": 7.971014492753623, \"y2\": -7.681159420289855, \"center_x\": 7.826086956521739, \"center_y\": -7.826086956521739, \"value_uncond\": 2.9042636382649264e-06}, {\"x\": 7.971014492753625, \"y\": -7.971014492753623, \"x2\": 8.260869565217392, \"y2\": -7.681159420289855, \"center_x\": 8.115942028985508, \"center_y\": -7.826086956521739, \"value_uncond\": 2.567561112617595e-06}, {\"x\": 8.26086956521739, \"y\": -7.971014492753623, \"x2\": 8.550724637681158, \"y2\": -7.681159420289855, \"center_x\": 8.405797101449274, \"center_y\": -7.826086956521739, \"value_uncond\": 2.248802709485845e-06}, {\"x\": 8.55072463768116, \"y\": -7.971014492753623, \"x2\": 8.840579710144928, \"y2\": -7.681159420289855, \"center_x\": 8.695652173913043, \"center_y\": -7.826086956521739, \"value_uncond\": 1.9513165898152533e-06}, {\"x\": 8.84057971014493, \"y\": -7.971014492753623, \"x2\": 9.130434782608697, \"y2\": -7.681159420289855, \"center_x\": 8.985507246376812, \"center_y\": -7.826086956521739, \"value_uncond\": 1.6774513459742732e-06}, {\"x\": 9.130434782608695, \"y\": -7.971014492753623, \"x2\": 9.420289855072463, \"y2\": -7.681159420289855, \"center_x\": 9.275362318840578, \"center_y\": -7.826086956521739, \"value_uncond\": 1.4286240026119246e-06}, {\"x\": 9.420289855072465, \"y\": -7.971014492753623, \"x2\": 9.710144927536232, \"y2\": -7.681159420289855, \"center_x\": 9.565217391304348, \"center_y\": -7.826086956521739, \"value_uncond\": 1.2054016098807787e-06}, {\"x\": 9.710144927536234, \"y\": -7.971014492753623, \"x2\": 10.000000000000002, \"y2\": -7.681159420289855, \"center_x\": 9.855072463768117, \"center_y\": -7.826086956521739, \"value_uncond\": 1.0076075345149136e-06}, {\"x\": 10.0, \"y\": -7.971014492753623, \"x2\": 10.289855072463768, \"y2\": -7.681159420289855, \"center_x\": 10.144927536231883, \"center_y\": -7.826086956521739, \"value_uncond\": 8.344433540257313e-07}, {\"x\": -10.0, \"y\": -7.681159420289855, \"x2\": -9.710144927536232, \"y2\": -7.391304347826088, \"center_x\": -9.855072463768117, \"center_y\": -7.536231884057972, \"value_uncond\": 1.6842720127136773e-10}, {\"x\": -9.710144927536232, \"y\": -7.681159420289855, \"x2\": -9.420289855072465, \"y2\": -7.391304347826088, \"center_x\": -9.565217391304348, \"center_y\": -7.536231884057972, \"value_uncond\": 2.6314934725173203e-10}, {\"x\": -9.420289855072463, \"y\": -7.681159420289855, \"x2\": -9.130434782608695, \"y2\": -7.391304347826088, \"center_x\": -9.275362318840578, \"center_y\": -7.536231884057972, \"value_uncond\": 4.0732228985637995e-10}, {\"x\": -9.130434782608695, \"y\": -7.681159420289855, \"x2\": -8.840579710144928, \"y2\": -7.391304347826088, \"center_x\": -8.985507246376812, \"center_y\": -7.536231884057972, \"value_uncond\": 6.246257309077444e-10}, {\"x\": -8.840579710144928, \"y\": -7.681159420289855, \"x2\": -8.55072463768116, \"y2\": -7.391304347826088, \"center_x\": -8.695652173913043, \"center_y\": -7.536231884057972, \"value_uncond\": 9.4895884748109e-10}, {\"x\": -8.55072463768116, \"y\": -7.681159420289855, \"x2\": -8.260869565217392, \"y2\": -7.391304347826088, \"center_x\": -8.405797101449277, \"center_y\": -7.536231884057972, \"value_uncond\": 1.4283041641778947e-09}, {\"x\": -8.26086956521739, \"y\": -7.681159420289855, \"x2\": -7.971014492753623, \"y2\": -7.391304347826088, \"center_x\": -8.115942028985508, \"center_y\": -7.536231884057972, \"value_uncond\": 2.129804989101398e-09}, {\"x\": -7.971014492753623, \"y\": -7.681159420289855, \"x2\": -7.681159420289855, \"y2\": -7.391304347826088, \"center_x\": -7.826086956521739, \"center_y\": -7.536231884057972, \"value_uncond\": 3.146333774436529e-09}, {\"x\": -7.681159420289855, \"y\": -7.681159420289855, \"x2\": -7.391304347826088, \"y2\": -7.391304347826088, \"center_x\": -7.536231884057972, \"center_y\": -7.536231884057972, \"value_uncond\": 4.604850753967282e-09}, {\"x\": -7.391304347826087, \"y\": -7.681159420289855, \"x2\": -7.101449275362319, \"y2\": -7.391304347826088, \"center_x\": -7.246376811594203, \"center_y\": -7.536231884057972, \"value_uncond\": 6.6768580050241456e-09}, {\"x\": -7.101449275362318, \"y\": -7.681159420289855, \"x2\": -6.811594202898551, \"y2\": -7.391304347826088, \"center_x\": -6.956521739130435, \"center_y\": -7.536231884057972, \"value_uncond\": 9.591235091357127e-09}, {\"x\": -6.811594202898551, \"y\": -7.681159420289855, \"x2\": -6.521739130434783, \"y2\": -7.391304347826088, \"center_x\": -6.666666666666667, \"center_y\": -7.536231884057972, \"value_uncond\": 1.3649688690943727e-08}, {\"x\": -6.521739130434782, \"y\": -7.681159420289855, \"x2\": -6.231884057971015, \"y2\": -7.391304347826088, \"center_x\": -6.3768115942028984, \"center_y\": -7.536231884057972, \"value_uncond\": 1.924494930576833e-08}, {\"x\": -6.231884057971014, \"y\": -7.681159420289855, \"x2\": -5.942028985507246, \"y2\": -7.391304347826088, \"center_x\": -6.08695652173913, \"center_y\": -7.536231884057972, \"value_uncond\": 2.688169262392831e-08}, {\"x\": -5.942028985507246, \"y\": -7.681159420289855, \"x2\": -5.6521739130434785, \"y2\": -7.391304347826088, \"center_x\": -5.797101449275362, \"center_y\": -7.536231884057972, \"value_uncond\": 3.719994218235569e-08}, {\"x\": -5.6521739130434785, \"y\": -7.681159420289855, \"x2\": -5.362318840579711, \"y2\": -7.391304347826088, \"center_x\": -5.507246376811595, \"center_y\": -7.536231884057972, \"value_uncond\": 5.100041774473357e-08}, {\"x\": -5.36231884057971, \"y\": -7.681159420289855, \"x2\": -5.072463768115942, \"y2\": -7.391304347826088, \"center_x\": -5.217391304347826, \"center_y\": -7.536231884057972, \"value_uncond\": 6.92709297100564e-08}, {\"x\": -5.0724637681159415, \"y\": -7.681159420289855, \"x2\": -4.782608695652174, \"y2\": -7.391304347826088, \"center_x\": -4.927536231884058, \"center_y\": -7.536231884057972, \"value_uncond\": 9.321249098921986e-08}, {\"x\": -4.782608695652174, \"y\": -7.681159420289855, \"x2\": -4.492753623188406, \"y2\": -7.391304347826088, \"center_x\": -4.63768115942029, \"center_y\": -7.536231884057972, \"value_uncond\": 1.2426334105807845e-07}, {\"x\": -4.492753623188405, \"y\": -7.681159420289855, \"x2\": -4.202898550724638, \"y2\": -7.391304347826088, \"center_x\": -4.3478260869565215, \"center_y\": -7.536231884057972, \"value_uncond\": 1.641185808684942e-07}, {\"x\": -4.202898550724638, \"y\": -7.681159420289855, \"x2\": -3.91304347826087, \"y2\": -7.391304347826088, \"center_x\": -4.057971014492754, \"center_y\": -7.536231884057972, \"value_uncond\": 2.1474264310538774e-07}, {\"x\": -3.913043478260869, \"y\": -7.681159420289855, \"x2\": -3.6231884057971016, \"y2\": -7.391304347826088, \"center_x\": -3.7681159420289854, \"center_y\": -7.536231884057972, \"value_uncond\": 2.783714233085887e-07}, {\"x\": -3.6231884057971016, \"y\": -7.681159420289855, \"x2\": -3.333333333333334, \"y2\": -7.391304347826088, \"center_x\": -3.4782608695652177, \"center_y\": -7.536231884057972, \"value_uncond\": 3.575006372780089e-07}, {\"x\": -3.333333333333333, \"y\": -7.681159420289855, \"x2\": -3.0434782608695654, \"y2\": -7.391304347826088, \"center_x\": -3.1884057971014492, \"center_y\": -7.536231884057972, \"value_uncond\": 4.548569188463666e-07}, {\"x\": -3.0434782608695645, \"y\": -7.681159420289855, \"x2\": -2.753623188405797, \"y2\": -7.391304347826088, \"center_x\": -2.8985507246376807, \"center_y\": -7.536231884057972, \"value_uncond\": 5.733483995698952e-07}, {\"x\": -2.753623188405797, \"y\": -7.681159420289855, \"x2\": -2.4637681159420293, \"y2\": -7.391304347826088, \"center_x\": -2.608695652173913, \"center_y\": -7.536231884057972, \"value_uncond\": 7.159920802534279e-07}, {\"x\": -2.4637681159420284, \"y\": -7.681159420289855, \"x2\": -2.1739130434782608, \"y2\": -7.391304347826088, \"center_x\": -2.3188405797101446, \"center_y\": -7.536231884057972, \"value_uncond\": 8.858162581182814e-07}, {\"x\": -2.1739130434782608, \"y\": -7.681159420289855, \"x2\": -1.8840579710144931, \"y2\": -7.391304347826088, \"center_x\": -2.028985507246377, \"center_y\": -7.536231884057972, \"value_uncond\": 1.0857376298486197e-06}, {\"x\": -1.8840579710144922, \"y\": -7.681159420289855, \"x2\": -1.5942028985507246, \"y2\": -7.391304347826088, \"center_x\": -1.7391304347826084, \"center_y\": -7.536231884057972, \"value_uncond\": 1.3184144295521006e-06}, {\"x\": -1.5942028985507246, \"y\": -7.681159420289855, \"x2\": -1.304347826086957, \"y2\": -7.391304347826088, \"center_x\": -1.4492753623188408, \"center_y\": -7.536231884057972, \"value_uncond\": 1.586079016993117e-06}, {\"x\": -1.304347826086957, \"y\": -7.681159420289855, \"x2\": -1.0144927536231894, \"y2\": -7.391304347826088, \"center_x\": -1.1594202898550732, \"center_y\": -7.536231884057972, \"value_uncond\": 1.8903555918294522e-06}, {\"x\": -1.0144927536231876, \"y\": -7.681159420289855, \"x2\": -0.72463768115942, \"y2\": -7.391304347826088, \"center_x\": -0.8695652173913038, \"center_y\": -7.536231884057972, \"value_uncond\": 2.2320710129818836e-06}, {\"x\": -0.72463768115942, \"y\": -7.681159420289855, \"x2\": -0.43478260869565233, \"y2\": -7.391304347826088, \"center_x\": -0.5797101449275361, \"center_y\": -7.536231884057972, \"value_uncond\": 2.611068847258569e-06}, {\"x\": -0.43478260869565233, \"y\": -7.681159420289855, \"x2\": -0.1449275362318847, \"y2\": -7.391304347826088, \"center_x\": -0.2898550724637685, \"center_y\": -7.536231884057972, \"value_uncond\": 3.0260385297535673e-06}, {\"x\": -0.14492753623188293, \"y\": -7.681159420289855, \"x2\": 0.1449275362318847, \"y2\": -7.391304347826088, \"center_x\": 8.881784197001252e-16, \"center_y\": -7.536231884057972, \"value_uncond\": 3.4743726551907147e-06}, {\"x\": 0.1449275362318847, \"y\": -7.681159420289855, \"x2\": 0.43478260869565233, \"y2\": -7.391304347826088, \"center_x\": 0.2898550724637685, \"center_y\": -7.536231884057972, \"value_uncond\": 3.952065716788075e-06}, {\"x\": 0.43478260869565233, \"y\": -7.681159420289855, \"x2\": 0.72463768115942, \"y2\": -7.391304347826088, \"center_x\": 0.5797101449275361, \"center_y\": -7.536231884057972, \"value_uncond\": 4.453666894683446e-06}, {\"x\": 0.72463768115942, \"y\": -7.681159420289855, \"x2\": 1.0144927536231876, \"y2\": -7.391304347826088, \"center_x\": 0.8695652173913038, \"center_y\": -7.536231884057972, \"value_uncond\": 4.97229766828531e-06}, {\"x\": 1.0144927536231894, \"y\": -7.681159420289855, \"x2\": 1.304347826086957, \"y2\": -7.391304347826088, \"center_x\": 1.1594202898550732, \"center_y\": -7.536231884057972, \"value_uncond\": 5.499742079040889e-06}, {\"x\": 1.304347826086957, \"y\": -7.681159420289855, \"x2\": 1.5942028985507246, \"y2\": -7.391304347826088, \"center_x\": 1.4492753623188408, \"center_y\": -7.536231884057972, \"value_uncond\": 6.026613504221936e-06}, {\"x\": 1.5942028985507246, \"y\": -7.681159420289855, \"x2\": 1.8840579710144922, \"y2\": -7.391304347826088, \"center_x\": 1.7391304347826084, \"center_y\": -7.536231884057972, \"value_uncond\": 6.5425970342707065e-06}, {\"x\": 1.884057971014494, \"y\": -7.681159420289855, \"x2\": 2.1739130434782616, \"y2\": -7.391304347826088, \"center_x\": 2.028985507246378, \"center_y\": -7.536231884057972, \"value_uncond\": 7.036761297266066e-06}, {\"x\": 2.1739130434782616, \"y\": -7.681159420289855, \"x2\": 2.4637681159420293, \"y2\": -7.391304347826088, \"center_x\": 2.3188405797101455, \"center_y\": -7.536231884057972, \"value_uncond\": 7.497928249183951e-06}, {\"x\": 2.4637681159420293, \"y\": -7.681159420289855, \"x2\": 2.753623188405797, \"y2\": -7.391304347826088, \"center_x\": 2.608695652173913, \"center_y\": -7.536231884057972, \"value_uncond\": 7.915084502802953e-06}, {\"x\": 2.753623188405797, \"y\": -7.681159420289855, \"x2\": 3.0434782608695645, \"y2\": -7.391304347826088, \"center_x\": 2.8985507246376807, \"center_y\": -7.536231884057972, \"value_uncond\": 8.277813663099864e-06}, {\"x\": 3.0434782608695663, \"y\": -7.681159420289855, \"x2\": 3.333333333333334, \"y2\": -7.391304347826088, \"center_x\": 3.18840579710145, \"center_y\": -7.536231884057972, \"value_uncond\": 8.57672629330027e-06}, {\"x\": 3.333333333333334, \"y\": -7.681159420289855, \"x2\": 3.6231884057971016, \"y2\": -7.391304347826088, \"center_x\": 3.4782608695652177, \"center_y\": -7.536231884057972, \"value_uncond\": 8.803862885277813e-06}, {\"x\": 3.6231884057971016, \"y\": -7.681159420289855, \"x2\": 3.913043478260869, \"y2\": -7.391304347826088, \"center_x\": 3.7681159420289854, \"center_y\": -7.536231884057972, \"value_uncond\": 8.953045753154204e-06}, {\"x\": 3.913043478260871, \"y\": -7.681159420289855, \"x2\": 4.202898550724639, \"y2\": -7.391304347826088, \"center_x\": 4.057971014492755, \"center_y\": -7.536231884057972, \"value_uncond\": 9.020158153905162e-06}, {\"x\": 4.202898550724639, \"y\": -7.681159420289855, \"x2\": 4.492753623188406, \"y2\": -7.391304347826088, \"center_x\": 4.347826086956522, \"center_y\": -7.536231884057972, \"value_uncond\": 9.003333036907952e-06}, {\"x\": 4.492753623188406, \"y\": -7.681159420289855, \"x2\": 4.782608695652174, \"y2\": -7.391304347826088, \"center_x\": 4.63768115942029, \"center_y\": -7.536231884057972, \"value_uncond\": 8.90303934437165e-06}, {\"x\": 4.782608695652174, \"y\": -7.681159420289855, \"x2\": 5.0724637681159415, \"y2\": -7.391304347826088, \"center_x\": 4.927536231884058, \"center_y\": -7.536231884057972, \"value_uncond\": 8.72206029521493e-06}, {\"x\": 5.072463768115943, \"y\": -7.681159420289855, \"x2\": 5.362318840579711, \"y2\": -7.391304347826088, \"center_x\": 5.217391304347827, \"center_y\": -7.536231884057972, \"value_uncond\": 8.465365055944217e-06}, {\"x\": 5.362318840579711, \"y\": -7.681159420289855, \"x2\": 5.6521739130434785, \"y2\": -7.391304347826088, \"center_x\": 5.507246376811595, \"center_y\": -7.536231884057972, \"value_uncond\": 8.139882056800119e-06}, {\"x\": 5.6521739130434785, \"y\": -7.681159420289855, \"x2\": 5.942028985507246, \"y2\": -7.391304347826088, \"center_x\": 5.797101449275362, \"center_y\": -7.536231884057972, \"value_uncond\": 7.754188384982478e-06}, {\"x\": 5.942028985507246, \"y\": -7.681159420289855, \"x2\": 6.231884057971014, \"y2\": -7.391304347826088, \"center_x\": 6.08695652173913, \"center_y\": -7.536231884057972, \"value_uncond\": 7.318134682692684e-06}, {\"x\": 6.2318840579710155, \"y\": -7.681159420289855, \"x2\": 6.521739130434783, \"y2\": -7.391304347826088, \"center_x\": 6.376811594202899, \"center_y\": -7.536231884057972, \"value_uncond\": 6.842428416685089e-06}, {\"x\": 6.521739130434785, \"y\": -7.681159420289855, \"x2\": 6.8115942028985526, \"y2\": -7.391304347826088, \"center_x\": 6.666666666666669, \"center_y\": -7.536231884057972, \"value_uncond\": 6.338200040615343e-06}, {\"x\": 6.811594202898551, \"y\": -7.681159420289855, \"x2\": 7.101449275362318, \"y2\": -7.391304347826088, \"center_x\": 6.956521739130435, \"center_y\": -7.536231884057972, \"value_uncond\": 5.816576383746788e-06}, {\"x\": 7.10144927536232, \"y\": -7.681159420289855, \"x2\": 7.391304347826088, \"y2\": -7.391304347826088, \"center_x\": 7.246376811594204, \"center_y\": -7.536231884057972, \"value_uncond\": 5.288283679482755e-06}, {\"x\": 7.391304347826086, \"y\": -7.681159420289855, \"x2\": 7.681159420289854, \"y2\": -7.391304347826088, \"center_x\": 7.53623188405797, \"center_y\": -7.536231884057972, \"value_uncond\": 4.763299253181387e-06}, {\"x\": 7.681159420289855, \"y\": -7.681159420289855, \"x2\": 7.971014492753623, \"y2\": -7.391304347826088, \"center_x\": 7.826086956521739, \"center_y\": -7.536231884057972, \"value_uncond\": 4.250566393509563e-06}, {\"x\": 7.971014492753625, \"y\": -7.681159420289855, \"x2\": 8.260869565217392, \"y2\": -7.391304347826088, \"center_x\": 8.115942028985508, \"center_y\": -7.536231884057972, \"value_uncond\": 3.7577817780669465e-06}, {\"x\": 8.26086956521739, \"y\": -7.681159420289855, \"x2\": 8.550724637681158, \"y2\": -7.391304347826088, \"center_x\": 8.405797101449274, \"center_y\": -7.536231884057972, \"value_uncond\": 3.291259476802988e-06}, {\"x\": 8.55072463768116, \"y\": -7.681159420289855, \"x2\": 8.840579710144928, \"y2\": -7.391304347826088, \"center_x\": 8.695652173913043, \"center_y\": -7.536231884057972, \"value_uncond\": 2.8558704555904338e-06}, {\"x\": 8.84057971014493, \"y\": -7.681159420289855, \"x2\": 9.130434782608697, \"y2\": -7.391304347826088, \"center_x\": 8.985507246376812, \"center_y\": -7.536231884057972, \"value_uncond\": 2.455052022138501e-06}, {\"x\": 9.130434782608695, \"y\": -7.681159420289855, \"x2\": 9.420289855072463, \"y2\": -7.391304347826088, \"center_x\": 9.275362318840578, \"center_y\": -7.536231884057972, \"value_uncond\": 2.0908780781662027e-06}, {\"x\": 9.420289855072465, \"y\": -7.681159420289855, \"x2\": 9.710144927536232, \"y2\": -7.391304347826088, \"center_x\": 9.565217391304348, \"center_y\": -7.536231884057972, \"value_uncond\": 1.7641785360445216e-06}, {\"x\": 9.710144927536234, \"y\": -7.681159420289855, \"x2\": 10.000000000000002, \"y2\": -7.391304347826088, \"center_x\": 9.855072463768117, \"center_y\": -7.536231884057972, \"value_uncond\": 1.4746948822507115e-06}, {\"x\": 10.0, \"y\": -7.681159420289855, \"x2\": 10.289855072463768, \"y2\": -7.391304347826088, \"center_x\": 10.144927536231883, \"center_y\": -7.536231884057972, \"value_uncond\": 1.221258576934201e-06}, {\"x\": -10.0, \"y\": -7.391304347826087, \"x2\": -9.710144927536232, \"y2\": -7.101449275362319, \"center_x\": -9.855072463768117, \"center_y\": -7.246376811594203, \"value_uncond\": 2.442130195215731e-10}, {\"x\": -9.710144927536232, \"y\": -7.391304347826087, \"x2\": -9.420289855072465, \"y2\": -7.101449275362319, \"center_x\": -9.565217391304348, \"center_y\": -7.246376811594203, \"value_uncond\": 3.815565193292877e-10}, {\"x\": -9.420289855072463, \"y\": -7.391304347826087, \"x2\": -9.130434782608695, \"y2\": -7.101449275362319, \"center_x\": -9.275362318840578, \"center_y\": -7.246376811594203, \"value_uncond\": 5.906017886267534e-10}, {\"x\": -9.130434782608695, \"y\": -7.391304347826087, \"x2\": -8.840579710144928, \"y2\": -7.101449275362319, \"center_x\": -8.985507246376812, \"center_y\": -7.246376811594203, \"value_uncond\": 9.056834921223715e-10}, {\"x\": -8.840579710144928, \"y\": -7.391304347826087, \"x2\": -8.55072463768116, \"y2\": -7.101449275362319, \"center_x\": -8.695652173913043, \"center_y\": -7.246376811594203, \"value_uncond\": 1.3759541439608688e-09}, {\"x\": -8.55072463768116, \"y\": -7.391304347826087, \"x2\": -8.260869565217392, \"y2\": -7.101449275362319, \"center_x\": -8.405797101449277, \"center_y\": -7.246376811594203, \"value_uncond\": 2.07098657518581e-09}, {\"x\": -8.26086956521739, \"y\": -7.391304347826087, \"x2\": -7.971014492753623, \"y2\": -7.101449275362319, \"center_x\": -8.115942028985508, \"center_y\": -7.246376811594203, \"value_uncond\": 3.0881360222957336e-09}, {\"x\": -7.971014492753623, \"y\": -7.391304347826087, \"x2\": -7.681159420289855, \"y2\": -7.101449275362319, \"center_x\": -7.826086956521739, \"center_y\": -7.246376811594203, \"value_uncond\": 4.5620639996259195e-09}, {\"x\": -7.681159420289855, \"y\": -7.391304347826087, \"x2\": -7.391304347826088, \"y2\": -7.101449275362319, \"center_x\": -7.536231884057972, \"center_y\": -7.246376811594203, \"value_uncond\": 6.6768580050241456e-09}, {\"x\": -7.391304347826087, \"y\": -7.391304347826087, \"x2\": -7.101449275362319, \"y2\": -7.101449275362319, \"center_x\": -7.246376811594203, \"center_y\": -7.246376811594203, \"value_uncond\": 9.681189511049189e-09}, {\"x\": -7.101449275362318, \"y\": -7.391304347826087, \"x2\": -6.811594202898551, \"y2\": -7.101449275362319, \"center_x\": -6.956521739130435, \"center_y\": -7.246376811594203, \"value_uncond\": 1.3906925157698896e-08}, {\"x\": -6.811594202898551, \"y\": -7.391304347826087, \"x2\": -6.521739130434783, \"y2\": -7.101449275362319, \"center_x\": -6.666666666666667, \"center_y\": -7.246376811594203, \"value_uncond\": 1.9791528123619735e-08}, {\"x\": -6.521739130434782, \"y\": -7.391304347826087, \"x2\": -6.231884057971015, \"y2\": -7.101449275362319, \"center_x\": -6.3768115942028984, \"center_y\": -7.246376811594203, \"value_uncond\": 2.7904442661425693e-08}, {\"x\": -6.231884057971014, \"y\": -7.391304347826087, \"x2\": -5.942028985507246, \"y2\": -7.101449275362319, \"center_x\": -6.08695652173913, \"center_y\": -7.246376811594203, \"value_uncond\": 3.897742927499661e-08}, {\"x\": -5.942028985507246, \"y\": -7.391304347826087, \"x2\": -5.6521739130434785, \"y2\": -7.101449275362319, \"center_x\": -5.797101449275362, \"center_y\": -7.246376811594203, \"value_uncond\": 5.3938497688053776e-08}, {\"x\": -5.6521739130434785, \"y\": -7.391304347826087, \"x2\": -5.362318840579711, \"y2\": -7.101449275362319, \"center_x\": -5.507246376811595, \"center_y\": -7.246376811594203, \"value_uncond\": 7.394866102557714e-08}, {\"x\": -5.36231884057971, \"y\": -7.391304347826087, \"x2\": -5.072463768115942, \"y2\": -7.101449275362319, \"center_x\": -5.217391304347826, \"center_y\": -7.246376811594203, \"value_uncond\": 1.0044020669976769e-07}, {\"x\": -5.0724637681159415, \"y\": -7.391304347826087, \"x2\": -4.782608695652174, \"y2\": -7.101449275362319, \"center_x\": -4.927536231884058, \"center_y\": -7.246376811594203, \"value_uncond\": 1.3515455763542766e-07}, {\"x\": -4.782608695652174, \"y\": -7.391304347826087, \"x2\": -4.492753623188406, \"y2\": -7.101449275362319, \"center_x\": -4.63768115942029, \"center_y\": -7.246376811594203, \"value_uncond\": 1.8017710623082913e-07}, {\"x\": -4.492753623188405, \"y\": -7.391304347826087, \"x2\": -4.202898550724638, \"y2\": -7.101449275362319, \"center_x\": -4.3478260869565215, \"center_y\": -7.246376811594203, \"value_uncond\": 2.379656842300335e-07}, {\"x\": -4.202898550724638, \"y\": -7.391304347826087, \"x2\": -3.91304347826087, \"y2\": -7.101449275362319, \"center_x\": -4.057971014492754, \"center_y\": -7.246376811594203, \"value_uncond\": 3.113686441201083e-07}, {\"x\": -3.913043478260869, \"y\": -7.391304347826087, \"x2\": -3.6231884057971016, \"y2\": -7.101449275362319, \"center_x\": -3.7681159420289854, \"center_y\": -7.246376811594203, \"value_uncond\": 4.036279491765524e-07}, {\"x\": -3.6231884057971016, \"y\": -7.391304347826087, \"x2\": -3.333333333333334, \"y2\": -7.101449275362319, \"center_x\": -3.4782608695652177, \"center_y\": -7.246376811594203, \"value_uncond\": 5.183622921447384e-07}, {\"x\": -3.333333333333333, \"y\": -7.391304347826087, \"x2\": -3.0434782608695654, \"y2\": -7.101449275362319, \"center_x\": -3.1884057971014492, \"center_y\": -7.246376811594203, \"value_uncond\": 6.595251881124395e-07}, {\"x\": -3.0434782608695645, \"y\": -7.391304347826087, \"x2\": -2.753623188405797, \"y2\": -7.101449275362319, \"center_x\": -2.8985507246376807, \"center_y\": -7.246376811594203, \"value_uncond\": 8.31333316945809e-07}, {\"x\": -2.753623188405797, \"y\": -7.391304347826087, \"x2\": -2.4637681159420293, \"y2\": -7.101449275362319, \"center_x\": -2.608695652173913, \"center_y\": -7.246376811594203, \"value_uncond\": 1.0381612147701664e-06}, {\"x\": -2.4637681159420284, \"y\": -7.391304347826087, \"x2\": -2.1739130434782608, \"y2\": -7.101449275362319, \"center_x\": -2.3188405797101446, \"center_y\": -7.246376811594203, \"value_uncond\": 1.2843997970839784e-06}, {\"x\": -2.1739130434782608, \"y\": -7.391304347826087, \"x2\": -1.8840579710144931, \"y2\": -7.101449275362319, \"center_x\": -2.028985507246377, \"center_y\": -7.246376811594203, \"value_uncond\": 1.574278162862302e-06}, {\"x\": -1.8840579710144922, \"y\": -7.391304347826087, \"x2\": -1.5942028985507246, \"y2\": -7.101449275362319, \"center_x\": -1.7391304347826084, \"center_y\": -7.246376811594203, \"value_uncond\": 1.9116506501997293e-06}, {\"x\": -1.5942028985507246, \"y\": -7.391304347826087, \"x2\": -1.304347826086957, \"y2\": -7.101449275362319, \"center_x\": -1.4492753623188408, \"center_y\": -7.246376811594203, \"value_uncond\": 2.299754095632208e-06}, {\"x\": -1.304347826086957, \"y\": -7.391304347826087, \"x2\": -1.0144927536231894, \"y2\": -7.101449275362319, \"center_x\": -1.1594202898550732, \"center_y\": -7.246376811594203, \"value_uncond\": 2.740943526730923e-06}, {\"x\": -1.0144927536231876, \"y\": -7.391304347826087, \"x2\": -0.72463768115942, \"y2\": -7.101449275362319, \"center_x\": -0.8695652173913038, \"center_y\": -7.246376811594203, \"value_uncond\": 3.2364178574019272e-06}, {\"x\": -0.72463768115942, \"y\": -7.391304347826087, \"x2\": -0.43478260869565233, \"y2\": -7.101449275362319, \"center_x\": -0.5797101449275361, \"center_y\": -7.246376811594203, \"value_uncond\": 3.785950265482027e-06}, {\"x\": -0.43478260869565233, \"y\": -7.391304347826087, \"x2\": -0.1449275362318847, \"y2\": -7.101449275362319, \"center_x\": -0.2898550724637685, \"center_y\": -7.246376811594203, \"value_uncond\": 4.387640481830946e-06}, {\"x\": -0.14492753623188293, \"y\": -7.391304347826087, \"x2\": 0.1449275362318847, \"y2\": -7.101449275362319, \"center_x\": 8.881784197001252e-16, \"center_y\": -7.246376811594203, \"value_uncond\": 5.037707868221594e-06}, {\"x\": 0.1449275362318847, \"y\": -7.391304347826087, \"x2\": 0.43478260869565233, \"y2\": -7.101449275362319, \"center_x\": 0.2898550724637685, \"center_y\": -7.246376811594203, \"value_uncond\": 5.73034459255472e-06}, {\"x\": 0.43478260869565233, \"y\": -7.391304347826087, \"x2\": 0.72463768115942, \"y2\": -7.101449275362319, \"center_x\": 0.5797101449275361, \"center_y\": -7.246376811594203, \"value_uncond\": 6.4576471738761325e-06}, {\"x\": 0.72463768115942, \"y\": -7.391304347826087, \"x2\": 1.0144927536231876, \"y2\": -7.101449275362319, \"center_x\": 0.8695652173913038, \"center_y\": -7.246376811594203, \"value_uncond\": 7.209642019613979e-06}, {\"x\": 1.0144927536231894, \"y\": -7.391304347826087, \"x2\": 1.304347826086957, \"y2\": -7.101449275362319, \"center_x\": 1.1594202898550732, \"center_y\": -7.246376811594203, \"value_uncond\": 7.97441630315065e-06}, {\"x\": 1.304347826086957, \"y\": -7.391304347826087, \"x2\": 1.5942028985507246, \"y2\": -7.101449275362319, \"center_x\": 1.4492753623188408, \"center_y\": -7.246376811594203, \"value_uncond\": 8.738359779452854e-06}, {\"x\": 1.5942028985507246, \"y\": -7.391304347826087, \"x2\": 1.8840579710144922, \"y2\": -7.101449275362319, \"center_x\": 1.7391304347826084, \"center_y\": -7.246376811594203, \"value_uncond\": 9.486516222981147e-06}, {\"x\": 1.884057971014494, \"y\": -7.391304347826087, \"x2\": 2.1739130434782616, \"y2\": -7.101449275362319, \"center_x\": 2.028985507246378, \"center_y\": -7.246376811594203, \"value_uncond\": 1.0203035561275618e-05}, {\"x\": 2.1739130434782616, \"y\": -7.391304347826087, \"x2\": 2.4637681159420293, \"y2\": -7.101449275362319, \"center_x\": 2.3188405797101455, \"center_y\": -7.246376811594203, \"value_uncond\": 1.0871710056732976e-05}, {\"x\": 2.4637681159420293, \"y\": -7.391304347826087, \"x2\": 2.753623188405797, \"y2\": -7.101449275362319, \"center_x\": 2.608695652173913, \"center_y\": -7.246376811594203, \"value_uncond\": 1.1476570717835243e-05}, {\"x\": 2.753623188405797, \"y\": -7.391304347826087, \"x2\": 3.0434782608695645, \"y2\": -7.101449275362319, \"center_x\": 2.8985507246376807, \"center_y\": -7.246376811594203, \"value_uncond\": 1.2002514168987824e-05}, {\"x\": 3.0434782608695663, \"y\": -7.391304347826087, \"x2\": 3.333333333333334, \"y2\": -7.101449275362319, \"center_x\": 3.18840579710145, \"center_y\": -7.246376811594203, \"value_uncond\": 1.2435926084897789e-05}, {\"x\": 3.333333333333334, \"y\": -7.391304347826087, \"x2\": 3.6231884057971016, \"y2\": -7.101449275362319, \"center_x\": 3.4782608695652177, \"center_y\": -7.246376811594203, \"value_uncond\": 1.2765265482287069e-05}, {\"x\": 3.6231884057971016, \"y\": -7.391304347826087, \"x2\": 3.913043478260869, \"y2\": -7.101449275362319, \"center_x\": 3.7681159420289854, \"center_y\": -7.246376811594203, \"value_uncond\": 1.2981574952194378e-05}, {\"x\": 3.913043478260871, \"y\": -7.391304347826087, \"x2\": 4.202898550724639, \"y2\": -7.101449275362319, \"center_x\": 4.057971014492755, \"center_y\": -7.246376811594203, \"value_uncond\": 1.3078885374210632e-05}, {\"x\": 4.202898550724639, \"y\": -7.391304347826087, \"x2\": 4.492753623188406, \"y2\": -7.101449275362319, \"center_x\": 4.347826086956522, \"center_y\": -7.246376811594203, \"value_uncond\": 1.3054489596125642e-05}, {\"x\": 4.492753623188406, \"y\": -7.391304347826087, \"x2\": 4.782608695652174, \"y2\": -7.101449275362319, \"center_x\": 4.63768115942029, \"center_y\": -7.246376811594203, \"value_uncond\": 1.2909067566261262e-05}, {\"x\": 4.782608695652174, \"y\": -7.391304347826087, \"x2\": 5.0724637681159415, \"y2\": -7.101449275362319, \"center_x\": 4.927536231884058, \"center_y\": -7.246376811594203, \"value_uncond\": 1.2646654845922255e-05}, {\"x\": 5.072463768115943, \"y\": -7.391304347826087, \"x2\": 5.362318840579711, \"y2\": -7.101449275362319, \"center_x\": 5.217391304347827, \"center_y\": -7.246376811594203, \"value_uncond\": 1.227445653706292e-05}, {\"x\": 5.362318840579711, \"y\": -7.391304347826087, \"x2\": 5.6521739130434785, \"y2\": -7.101449275362319, \"center_x\": 5.507246376811595, \"center_y\": -7.246376811594203, \"value_uncond\": 1.1802518599343171e-05}, {\"x\": 5.6521739130434785, \"y\": -7.391304347826087, \"x2\": 5.942028985507246, \"y2\": -7.101449275362319, \"center_x\": 5.797101449275362, \"center_y\": -7.246376811594203, \"value_uncond\": 1.1243277482148635e-05}, {\"x\": 5.942028985507246, \"y\": -7.391304347826087, \"x2\": 6.231884057971014, \"y2\": -7.101449275362319, \"center_x\": 6.08695652173913, \"center_y\": -7.246376811594203, \"value_uncond\": 1.0611016241055063e-05}, {\"x\": 6.2318840579710155, \"y\": -7.391304347826087, \"x2\": 6.521739130434783, \"y2\": -7.101449275362319, \"center_x\": 6.376811594202899, \"center_y\": -7.246376811594203, \"value_uncond\": 9.921260294568306e-06}, {\"x\": 6.521739130434785, \"y\": -7.391304347826087, \"x2\": 6.8115942028985526, \"y2\": -7.101449275362319, \"center_x\": 6.666666666666669, \"center_y\": -7.246376811594203, \"value_uncond\": 9.190148376072125e-06}, {\"x\": 6.811594202898551, \"y\": -7.391304347826087, \"x2\": 7.101449275362318, \"y2\": -7.101449275362319, \"center_x\": 6.956521739130435, \"center_y\": -7.246376811594203, \"value_uncond\": 8.433813963719633e-06}, {\"x\": 7.10144927536232, \"y\": -7.391304347826087, \"x2\": 7.391304347826088, \"y2\": -7.101449275362319, \"center_x\": 7.246376811594204, \"center_y\": -7.246376811594203, \"value_uncond\": 7.66780968694211e-06}, {\"x\": 7.391304347826086, \"y\": -7.391304347826087, \"x2\": 7.681159420289854, \"y2\": -7.101449275362319, \"center_x\": 7.53623188405797, \"center_y\": -7.246376811594203, \"value_uncond\": 6.906602287062016e-06}, {\"x\": 7.681159420289855, \"y\": -7.391304347826087, \"x2\": 7.971014492753623, \"y2\": -7.101449275362319, \"center_x\": 7.826086956521739, \"center_y\": -7.246376811594203, \"value_uncond\": 6.163159191628511e-06}, {\"x\": 7.971014492753625, \"y\": -7.391304347826087, \"x2\": 8.260869565217392, \"y2\": -7.101449275362319, \"center_x\": 8.115942028985508, \"center_y\": -7.246376811594203, \"value_uncond\": 5.448640289677979e-06}, {\"x\": 8.26086956521739, \"y\": -7.391304347826087, \"x2\": 8.550724637681158, \"y2\": -7.101449275362319, \"center_x\": 8.405797101449274, \"center_y\": -7.246376811594203, \"value_uncond\": 4.772200741874412e-06}, {\"x\": 8.55072463768116, \"y\": -7.391304347826087, \"x2\": 8.840579710144928, \"y2\": -7.101449275362319, \"center_x\": 8.695652173913043, \"center_y\": -7.246376811594203, \"value_uncond\": 4.140903262997788e-06}, {\"x\": 8.84057971014493, \"y\": -7.391304347826087, \"x2\": 9.130434782608697, \"y2\": -7.101449275362319, \"center_x\": 8.985507246376812, \"center_y\": -7.246376811594203, \"value_uncond\": 3.559731818157989e-06}, {\"x\": 9.130434782608695, \"y\": -7.391304347826087, \"x2\": 9.420289855072463, \"y2\": -7.101449275362319, \"center_x\": 9.275362318840578, \"center_y\": -7.246376811594203, \"value_uncond\": 3.0316934857673573e-06}, {\"x\": 9.420289855072465, \"y\": -7.391304347826087, \"x2\": 9.710144927536232, \"y2\": -7.101449275362319, \"center_x\": 9.565217391304348, \"center_y\": -7.246376811594203, \"value_uncond\": 2.5579916071182954e-06}, {\"x\": 9.710144927536234, \"y\": -7.391304347826087, \"x2\": 10.000000000000002, \"y2\": -7.101449275362319, \"center_x\": 9.855072463768117, \"center_y\": -7.246376811594203, \"value_uncond\": 2.138251347460231e-06}, {\"x\": 10.0, \"y\": -7.391304347826087, \"x2\": 10.289855072463768, \"y2\": -7.101449275362319, \"center_x\": 10.144927536231883, \"center_y\": -7.246376811594203, \"value_uncond\": 1.770778368567611e-06}, {\"x\": -10.0, \"y\": -7.101449275362318, \"x2\": -9.710144927536232, \"y2\": -6.811594202898551, \"center_x\": -9.855072463768117, \"center_y\": -6.956521739130435, \"value_uncond\": 3.508093898116566e-10}, {\"x\": -9.710144927536232, \"y\": -7.101449275362318, \"x2\": -9.420289855072465, \"y2\": -6.811594202898551, \"center_x\": -9.565217391304348, \"center_y\": -6.956521739130435, \"value_uncond\": 5.481018579058321e-10}, {\"x\": -9.420289855072463, \"y\": -7.101449275362318, \"x2\": -9.130434782608695, \"y2\": -6.811594202898551, \"center_x\": -9.275362318840578, \"center_y\": -6.956521739130435, \"value_uncond\": 8.48393150765341e-10}, {\"x\": -9.130434782608695, \"y\": -7.101449275362318, \"x2\": -8.840579710144928, \"y2\": -6.811594202898551, \"center_x\": -8.985507246376812, \"center_y\": -6.956521739130435, \"value_uncond\": 1.3010046469118486e-09}, {\"x\": -8.840579710144928, \"y\": -7.101449275362318, \"x2\": -8.55072463768116, \"y2\": -6.811594202898551, \"center_x\": -8.695652173913043, \"center_y\": -6.956521739130435, \"value_uncond\": 1.976543407052434e-09}, {\"x\": -8.55072463768116, \"y\": -7.101449275362318, \"x2\": -8.260869565217392, \"y2\": -6.811594202898551, \"center_x\": -8.405797101449277, \"center_y\": -6.956521739130435, \"value_uncond\": 2.974950058651102e-09}, {\"x\": -8.26086956521739, \"y\": -7.101449275362318, \"x2\": -7.971014492753623, \"y2\": -6.811594202898551, \"center_x\": -8.115942028985508, \"center_y\": -6.956521739130435, \"value_uncond\": 4.4360743573757856e-09}, {\"x\": -7.971014492753623, \"y\": -7.101449275362318, \"x2\": -7.681159420289855, \"y2\": -6.811594202898551, \"center_x\": -7.826086956521739, \"center_y\": -6.956521739130435, \"value_uncond\": 6.553356127882929e-09}, {\"x\": -7.681159420289855, \"y\": -7.101449275362318, \"x2\": -7.391304347826088, \"y2\": -6.811594202898551, \"center_x\": -7.536231884057972, \"center_y\": -6.956521739130435, \"value_uncond\": 9.591235091357127e-09}, {\"x\": -7.391304347826087, \"y\": -7.101449275362318, \"x2\": -7.101449275362319, \"y2\": -6.811594202898551, \"center_x\": -7.246376811594203, \"center_y\": -6.956521739130435, \"value_uncond\": 1.3906925157698896e-08}, {\"x\": -7.101449275362318, \"y\": -7.101449275362318, \"x2\": -6.811594202898551, \"y2\": -6.811594202898551, \"center_x\": -6.956521739130435, \"center_y\": -6.956521739130435, \"value_uncond\": 1.99771492047653e-08}, {\"x\": -6.811594202898551, \"y\": -7.101449275362318, \"x2\": -6.521739130434783, \"y2\": -6.811594202898551, \"center_x\": -6.666666666666667, \"center_y\": -6.956521739130435, \"value_uncond\": 2.8430318408449762e-08}, {\"x\": -6.521739130434782, \"y\": -7.101449275362318, \"x2\": -6.231884057971015, \"y2\": -6.811594202898551, \"center_x\": -6.3768115942028984, \"center_y\": -6.956521739130435, \"value_uncond\": 4.008443334539075e-08}, {\"x\": -6.231884057971014, \"y\": -7.101449275362318, \"x2\": -5.942028985507246, \"y2\": -6.811594202898551, \"center_x\": -6.08695652173913, \"center_y\": -6.956521739130435, \"value_uncond\": 5.599066015061769e-08}, {\"x\": -5.942028985507246, \"y\": -7.101449275362318, \"x2\": -5.6521739130434785, \"y2\": -6.811594202898551, \"center_x\": -5.797101449275362, \"center_y\": -6.956521739130435, \"value_uncond\": 7.748207486387541e-08}, {\"x\": -5.6521739130434785, \"y\": -7.101449275362318, \"x2\": -5.362318840579711, \"y2\": -6.811594202898551, \"center_x\": -5.507246376811595, \"center_y\": -6.956521739130435, \"value_uncond\": 1.062264604180127e-07}, {\"x\": -5.36231884057971, \"y\": -7.101449275362318, \"x2\": -5.072463768115942, \"y2\": -6.811594202898551, \"center_x\": -5.217391304347826, \"center_y\": -6.956521739130435, \"value_uncond\": 1.442812823572233e-07}, {\"x\": -5.0724637681159415, \"y\": -7.101449275362318, \"x2\": -4.782608695652174, \"y2\": -6.811594202898551, \"center_x\": -4.927536231884058, \"center_y\": -6.956521739130435, \"value_uncond\": 1.9414807608224334e-07}, {\"x\": -4.782608695652174, \"y\": -7.101449275362318, \"x2\": -4.492753623188406, \"y2\": -6.811594202898551, \"center_x\": -4.63768115942029, \"center_y\": -6.956521739130435, \"value_uncond\": 2.588224854624657e-07}, {\"x\": -4.492753623188405, \"y\": -7.101449275362318, \"x2\": -4.202898550724638, \"y2\": -6.811594202898551, \"center_x\": -4.3478260869565215, \"center_y\": -6.956521739130435, \"value_uncond\": 3.418351595029395e-07}, {\"x\": -4.202898550724638, \"y\": -7.101449275362318, \"x2\": -3.91304347826087, \"y2\": -6.811594202898551, \"center_x\": -4.057971014492754, \"center_y\": -6.956521739130435, \"value_uncond\": 4.4727772607802706e-07}, {\"x\": -3.913043478260869, \"y\": -7.101449275362318, \"x2\": -3.6231884057971016, \"y2\": -6.811594202898551, \"center_x\": -3.7681159420289854, \"center_y\": -6.956521739130435, \"value_uncond\": 5.798072307485984e-07}, {\"x\": -3.6231884057971016, \"y\": -7.101449275362318, \"x2\": -3.333333333333334, \"y2\": -6.811594202898551, \"center_x\": -3.4782608695652177, \"center_y\": -6.956521739130435, \"value_uncond\": 7.446218869285287e-07}, {\"x\": -3.333333333333333, \"y\": -7.101449275362318, \"x2\": -3.0434782608695654, \"y2\": -6.811594202898551, \"center_x\": -3.1884057971014492, \"center_y\": -6.956521739130435, \"value_uncond\": 9.474008767444301e-07}, {\"x\": -3.0434782608695645, \"y\": -7.101449275362318, \"x2\": -2.753623188405797, \"y2\": -6.811594202898551, \"center_x\": -2.8985507246376807, \"center_y\": -6.956521739130435, \"value_uncond\": 1.1942014157115696e-06}, {\"x\": -2.753623188405797, \"y\": -7.101449275362318, \"x2\": -2.4637681159420293, \"y2\": -6.811594202898551, \"center_x\": -2.608695652173913, \"center_y\": -6.956521739130435, \"value_uncond\": 1.4913074781726702e-06}, {\"x\": -2.4637681159420284, \"y\": -7.101449275362318, \"x2\": -2.1739130434782608, \"y2\": -6.811594202898551, \"center_x\": -2.3188405797101446, \"center_y\": -6.956521739130435, \"value_uncond\": 1.8450265672647442e-06}, {\"x\": -2.1739130434782608, \"y\": -7.101449275362318, \"x2\": -1.8840579710144931, \"y2\": -6.811594202898551, \"center_x\": -2.028985507246377, \"center_y\": -6.956521739130435, \"value_uncond\": 2.261433738420133e-06}, {\"x\": -1.8840579710144922, \"y\": -7.101449275362318, \"x2\": -1.5942028985507246, \"y2\": -6.811594202898551, \"center_x\": -1.7391304347826084, \"center_y\": -6.956521739130435, \"value_uncond\": 2.746065707075796e-06}, {\"x\": -1.5942028985507246, \"y\": -7.101449275362318, \"x2\": -1.304347826086957, \"y2\": -6.811594202898551, \"center_x\": -1.4492753623188408, \"center_y\": -6.956521739130435, \"value_uncond\": 3.3035721542860862e-06}, {\"x\": -1.304347826086957, \"y\": -7.101449275362318, \"x2\": -1.0144927536231894, \"y2\": -6.811594202898551, \"center_x\": -1.1594202898550732, \"center_y\": -6.956521739130435, \"value_uncond\": 3.937336051961573e-06}, {\"x\": -1.0144927536231876, \"y\": -7.101449275362318, \"x2\": -0.72463768115942, \"y2\": -6.811594202898551, \"center_x\": -0.8695652173913038, \"center_y\": -6.956521739130435, \"value_uncond\": 4.649079627101635e-06}, {\"x\": -0.72463768115942, \"y\": -7.101449275362318, \"x2\": -0.43478260869565233, \"y2\": -6.811594202898551, \"center_x\": -0.5797101449275361, \"center_y\": -6.956521739130435, \"value_uncond\": 5.4384770520955155e-06}, {\"x\": -0.43478260869565233, \"y\": -7.101449275362318, \"x2\": -0.1449275362318847, \"y2\": -6.811594202898551, \"center_x\": -0.2898550724637685, \"center_y\": -6.956521739130435, \"value_uncond\": 6.302798610653378e-06}, {\"x\": -0.14492753623188293, \"y\": -7.101449275362318, \"x2\": 0.1449275362318847, \"y2\": -6.811594202898551, \"center_x\": 8.881784197001252e-16, \"center_y\": -6.956521739130435, \"value_uncond\": 7.236613456409447e-06}, {\"x\": 0.1449275362318847, \"y\": -7.101449275362318, \"x2\": 0.43478260869565233, \"y2\": -6.811594202898551, \"center_x\": 0.2898550724637685, \"center_y\": -6.956521739130435, \"value_uncond\": 8.23157870068867e-06}, {\"x\": 0.43478260869565233, \"y\": -7.101449275362318, \"x2\": 0.72463768115942, \"y2\": -6.811594202898551, \"center_x\": 0.5797101449275361, \"center_y\": -6.956521739130435, \"value_uncond\": 9.276341077656326e-06}, {\"x\": 0.72463768115942, \"y\": -7.101449275362318, \"x2\": 1.0144927536231876, \"y2\": -6.811594202898551, \"center_x\": 0.8695652173913038, \"center_y\": -6.956521739130435, \"value_uncond\": 1.0356573628286171e-05}, {\"x\": 1.0144927536231894, \"y\": -7.101449275362318, \"x2\": 1.304347826086957, \"y2\": -6.811594202898551, \"center_x\": 1.1594202898550732, \"center_y\": -6.956521739130435, \"value_uncond\": 1.1455163704592264e-05}, {\"x\": 1.304347826086957, \"y\": -7.101449275362318, \"x2\": 1.5942028985507246, \"y2\": -6.811594202898551, \"center_x\": 1.4492753623188408, \"center_y\": -6.956521739130435, \"value_uncond\": 1.2552560335194498e-05}, {\"x\": 1.5942028985507246, \"y\": -7.101449275362318, \"x2\": 1.8840579710144922, \"y2\": -6.811594202898551, \"center_x\": 1.7391304347826084, \"center_y\": -6.956521739130435, \"value_uncond\": 1.362727906211575e-05}, {\"x\": 1.884057971014494, \"y\": -7.101449275362318, \"x2\": 2.1739130434782616, \"y2\": -6.811594202898551, \"center_x\": 2.028985507246378, \"center_y\": -6.956521739130435, \"value_uncond\": 1.465655142584053e-05}, {\"x\": 2.1739130434782616, \"y\": -7.101449275362318, \"x2\": 2.4637681159420293, \"y2\": -6.811594202898551, \"center_x\": 2.3188405797101455, \"center_y\": -6.956521739130435, \"value_uncond\": 1.5617095184701392e-05}, {\"x\": 2.4637681159420293, \"y\": -7.101449275362318, \"x2\": 2.753623188405797, \"y2\": -6.811594202898551, \"center_x\": 2.608695652173913, \"center_y\": -6.956521739130435, \"value_uncond\": 1.6485971053228203e-05}, {\"x\": 2.753623188405797, \"y\": -7.101449275362318, \"x2\": 3.0434782608695645, \"y2\": -6.811594202898551, \"center_x\": 2.8985507246376807, \"center_y\": -6.956521739130435, \"value_uncond\": 1.7241483193963902e-05}, {\"x\": 3.0434782608695663, \"y\": -7.101449275362318, \"x2\": 3.333333333333334, \"y2\": -6.811594202898551, \"center_x\": 3.18840579710145, \"center_y\": -6.956521739130435, \"value_uncond\": 1.7864074774279074e-05}, {\"x\": 3.333333333333334, \"y\": -7.101449275362318, \"x2\": 3.6231884057971016, \"y2\": -6.811594202898551, \"center_x\": 3.4782608695652177, \"center_y\": -6.956521739130435, \"value_uncond\": 1.833716729516683e-05}, {\"x\": 3.6231884057971016, \"y\": -7.101449275362318, \"x2\": 3.913043478260869, \"y2\": -6.811594202898551, \"center_x\": 3.7681159420289854, \"center_y\": -6.956521739130435, \"value_uncond\": 1.8647893534485788e-05}, {\"x\": 3.913043478260871, \"y\": -7.101449275362318, \"x2\": 4.202898550724639, \"y2\": -6.811594202898551, \"center_x\": 4.057971014492755, \"center_y\": -6.956521739130435, \"value_uncond\": 1.878767891462938e-05}, {\"x\": 4.202898550724639, \"y\": -7.101449275362318, \"x2\": 4.492753623188406, \"y2\": -6.811594202898551, \"center_x\": 4.347826086956522, \"center_y\": -6.956521739130435, \"value_uncond\": 1.8752634640410333e-05}, {\"x\": 4.492753623188406, \"y\": -7.101449275362318, \"x2\": 4.782608695652174, \"y2\": -6.811594202898551, \"center_x\": 4.63768115942029, \"center_y\": -6.956521739130435, \"value_uncond\": 1.8543737450318508e-05}, {\"x\": 4.782608695652174, \"y\": -7.101449275362318, \"x2\": 5.0724637681159415, \"y2\": -6.811594202898551, \"center_x\": 4.927536231884058, \"center_y\": -6.956521739130435, \"value_uncond\": 1.8166784384993456e-05}, {\"x\": 5.072463768115943, \"y\": -7.101449275362318, \"x2\": 5.362318840579711, \"y2\": -6.811594202898551, \"center_x\": 5.217391304347827, \"center_y\": -6.956521739130435, \"value_uncond\": 1.7632125496308203e-05}, {\"x\": 5.362318840579711, \"y\": -7.101449275362318, \"x2\": 5.6521739130434785, \"y2\": -6.811594202898551, \"center_x\": 5.507246376811595, \"center_y\": -6.956521739130435, \"value_uncond\": 1.6954191697836777e-05}, {\"x\": 5.6521739130434785, \"y\": -7.101449275362318, \"x2\": 5.942028985507246, \"y2\": -6.811594202898551, \"center_x\": 5.797101449275362, \"center_y\": -6.956521739130435, \"value_uncond\": 1.6150847816069353e-05}, {\"x\": 5.942028985507246, \"y\": -7.101449275362318, \"x2\": 6.231884057971014, \"y2\": -6.811594202898551, \"center_x\": 6.08695652173913, \"center_y\": -6.956521739130435, \"value_uncond\": 1.524261130753217e-05}, {\"x\": 6.2318840579710155, \"y\": -7.101449275362318, \"x2\": 6.521739130434783, \"y2\": -6.811594202898551, \"center_x\": 6.376811594202899, \"center_y\": -6.956521739130435, \"value_uncond\": 1.4251784269809043e-05}, {\"x\": 6.521739130434785, \"y\": -7.101449275362318, \"x2\": 6.8115942028985526, \"y2\": -6.811594202898551, \"center_x\": 6.666666666666669, \"center_y\": -6.956521739130435, \"value_uncond\": 1.3201549820744305e-05}, {\"x\": 6.811594202898551, \"y\": -7.101449275362318, \"x2\": 7.101449275362318, \"y2\": -6.811594202898551, \"center_x\": 6.956521739130435, \"center_y\": -6.956521739130435, \"value_uncond\": 1.2115083529099698e-05}, {\"x\": 7.10144927536232, \"y\": -7.101449275362318, \"x2\": 7.391304347826088, \"y2\": -6.811594202898551, \"center_x\": 7.246376811594204, \"center_y\": -6.956521739130435, \"value_uncond\": 1.1014726580662296e-05}, {\"x\": 7.391304347826086, \"y\": -7.101449275362318, \"x2\": 7.681159420289854, \"y2\": -6.811594202898551, \"center_x\": 7.53623188405797, \"center_y\": -6.956521739130435, \"value_uncond\": 9.921260294568306e-06}, {\"x\": 7.681159420289855, \"y\": -7.101449275362318, \"x2\": 7.971014492753623, \"y2\": -6.811594202898551, \"center_x\": 7.826086956521739, \"center_y\": -6.956521739130435, \"value_uncond\": 8.853312241759115e-06}, {\"x\": 7.971014492753625, \"y\": -7.101449275362318, \"x2\": 8.260869565217392, \"y2\": -6.811594202898551, \"center_x\": 8.115942028985508, \"center_y\": -6.956521739130435, \"value_uncond\": 7.826913483440587e-06}, {\"x\": 8.26086956521739, \"y\": -7.101449275362318, \"x2\": 8.550724637681158, \"y2\": -6.811594202898551, \"center_x\": 8.405797101449274, \"center_y\": -6.956521739130435, \"value_uncond\": 6.855215309959383e-06}, {\"x\": 8.55072463768116, \"y\": -7.101449275362318, \"x2\": 8.840579710144928, \"y2\": -6.811594202898551, \"center_x\": 8.695652173913043, \"center_y\": -6.956521739130435, \"value_uncond\": 5.948363235535961e-06}, {\"x\": 8.84057971014493, \"y\": -7.101449275362318, \"x2\": 9.130434782608697, \"y2\": -6.811594202898551, \"center_x\": 8.985507246376812, \"center_y\": -6.956521739130435, \"value_uncond\": 5.113516672729353e-06}, {\"x\": 9.130434782608695, \"y\": -7.101449275362318, \"x2\": 9.420289855072463, \"y2\": -6.811594202898551, \"center_x\": 9.275362318840578, \"center_y\": -6.956521739130435, \"value_uncond\": 4.354995257507432e-06}, {\"x\": 9.420289855072465, \"y\": -7.101449275362318, \"x2\": 9.710144927536232, \"y2\": -6.811594202898551, \"center_x\": 9.565217391304348, \"center_y\": -6.956521739130435, \"value_uncond\": 3.674527576762701e-06}, {\"x\": 9.710144927536234, \"y\": -7.101449275362318, \"x2\": 10.000000000000002, \"y2\": -6.811594202898551, \"center_x\": 9.855072463768117, \"center_y\": -6.956521739130435, \"value_uncond\": 3.071575184386158e-06}, {\"x\": 10.0, \"y\": -7.101449275362318, \"x2\": 10.289855072463768, \"y2\": -6.811594202898551, \"center_x\": 10.144927536231883, \"center_y\": -6.956521739130435, \"value_uncond\": 2.5437041816438e-06}, {\"x\": -10.0, \"y\": -6.811594202898551, \"x2\": -9.710144927536232, \"y2\": -6.521739130434783, \"center_x\": -9.855072463768117, \"center_y\": -6.666666666666667, \"value_uncond\": 4.99251547394975e-10}, {\"x\": -9.710144927536232, \"y\": -6.811594202898551, \"x2\": -9.420289855072465, \"y2\": -6.521739130434783, \"center_x\": -9.565217391304348, \"center_y\": -6.666666666666667, \"value_uncond\": 7.800267285789022e-10}, {\"x\": -9.420289855072463, \"y\": -6.811594202898551, \"x2\": -9.130434782608695, \"y2\": -6.521739130434783, \"center_x\": -9.275362318840578, \"center_y\": -6.666666666666667, \"value_uncond\": 1.207383854651945e-09}, {\"x\": -9.130434782608695, \"y\": -6.811594202898551, \"x2\": -8.840579710144928, \"y2\": -6.521739130434783, \"center_x\": -8.985507246376812, \"center_y\": -6.666666666666667, \"value_uncond\": 1.85151424677519e-09}, {\"x\": -8.840579710144928, \"y\": -6.811594202898551, \"x2\": -8.55072463768116, \"y2\": -6.521739130434783, \"center_x\": -8.695652173913043, \"center_y\": -6.666666666666667, \"value_uncond\": 2.8129017726522515e-09}, {\"x\": -8.55072463768116, \"y\": -6.811594202898551, \"x2\": -8.260869565217392, \"y2\": -6.521739130434783, \"center_x\": -8.405797101449277, \"center_y\": -6.666666666666667, \"value_uncond\": 4.233776128403348e-09}, {\"x\": -8.26086956521739, \"y\": -6.811594202898551, \"x2\": -7.971014492753623, \"y2\": -6.521739130434783, \"center_x\": -8.115942028985508, \"center_y\": -6.666666666666667, \"value_uncond\": 6.313163363352597e-09}, {\"x\": -7.971014492753623, \"y\": -6.811594202898551, \"x2\": -7.681159420289855, \"y2\": -6.521739130434783, \"center_x\": -7.826086956521739, \"center_y\": -6.666666666666667, \"value_uncond\": 9.326355800317806e-09}, {\"x\": -7.681159420289855, \"y\": -6.811594202898551, \"x2\": -7.391304347826088, \"y2\": -6.521739130434783, \"center_x\": -7.536231884057972, \"center_y\": -6.666666666666667, \"value_uncond\": 1.3649688690943727e-08}, {\"x\": -7.391304347826087, \"y\": -6.811594202898551, \"x2\": -7.101449275362319, \"y2\": -6.521739130434783, \"center_x\": -7.246376811594203, \"center_y\": -6.666666666666667, \"value_uncond\": 1.9791528123619735e-08}, {\"x\": -7.101449275362318, \"y\": -6.811594202898551, \"x2\": -6.811594202898551, \"y2\": -6.521739130434783, \"center_x\": -6.956521739130435, \"center_y\": -6.666666666666667, \"value_uncond\": 2.8430318408449762e-08}, {\"x\": -6.811594202898551, \"y\": -6.811594202898551, \"x2\": -6.521739130434783, \"y2\": -6.521739130434783, \"center_x\": -6.666666666666667, \"center_y\": -6.666666666666667, \"value_uncond\": 4.046037783073838e-08}, {\"x\": -6.521739130434782, \"y\": -6.811594202898551, \"x2\": -6.231884057971015, \"y2\": -6.521739130434783, \"center_x\": -6.3768115942028984, \"center_y\": -6.666666666666667, \"value_uncond\": 5.7045837298942615e-08}, {\"x\": -6.231884057971014, \"y\": -6.811594202898551, \"x2\": -5.942028985507246, \"y2\": -6.521739130434783, \"center_x\": -6.08695652173913, \"center_y\": -6.666666666666667, \"value_uncond\": 7.968265540118451e-08}, {\"x\": -5.942028985507246, \"y\": -6.811594202898551, \"x2\": -5.6521739130434785, \"y2\": -6.521739130434783, \"center_x\": -5.797101449275362, \"center_y\": -6.666666666666667, \"value_uncond\": 1.1026798852770564e-07}, {\"x\": -5.6521739130434785, \"y\": -6.811594202898551, \"x2\": -5.362318840579711, \"y2\": -6.521739130434783, \"center_x\": -5.507246376811595, \"center_y\": -6.666666666666667, \"value_uncond\": 1.5117532847811418e-07}, {\"x\": -5.36231884057971, \"y\": -6.811594202898551, \"x2\": -5.072463768115942, \"y2\": -6.521739130434783, \"center_x\": -5.217391304347826, \"center_y\": -6.666666666666667, \"value_uncond\": 2.053327407104132e-07}, {\"x\": -5.0724637681159415, \"y\": -6.811594202898551, \"x2\": -4.782608695652174, \"y2\": -6.521739130434783, \"center_x\": -4.927536231884058, \"center_y\": -6.666666666666667, \"value_uncond\": 2.763002651093713e-07}, {\"x\": -4.782608695652174, \"y\": -6.811594202898551, \"x2\": -4.492753623188406, \"y2\": -6.521739130434783, \"center_x\": -4.63768115942029, \"center_y\": -6.666666666666667, \"value_uncond\": 3.6834112803287286e-07}, {\"x\": -4.492753623188405, \"y\": -6.811594202898551, \"x2\": -4.202898550724638, \"y2\": -6.521739130434783, \"center_x\": -4.3478260869565215, \"center_y\": -6.666666666666667, \"value_uncond\": 4.86479944072979e-07}, {\"x\": -4.202898550724638, \"y\": -6.811594202898551, \"x2\": -3.91304347826087, \"y2\": -6.521739130434783, \"center_x\": -4.057971014492754, \"center_y\": -6.666666666666667, \"value_uncond\": 6.365396803650244e-07}, {\"x\": -3.913043478260869, \"y\": -6.811594202898551, \"x2\": -3.6231884057971016, \"y2\": -6.521739130434783, \"center_x\": -3.7681159420289854, \"center_y\": -6.666666666666667, \"value_uncond\": 8.25147973654423e-07}, {\"x\": -3.6231884057971016, \"y\": -6.811594202898551, \"x2\": -3.333333333333334, \"y2\": -6.521739130434783, \"center_x\": -3.4782608695652177, \"center_y\": -6.666666666666667, \"value_uncond\": 1.0597026193421523e-06}, {\"x\": -3.333333333333333, \"y\": -6.811594202898551, \"x2\": -3.0434782608695654, \"y2\": -6.521739130434783, \"center_x\": -3.1884057971014492, \"center_y\": -6.666666666666667, \"value_uncond\": 1.3482858995648702e-06}, {\"x\": -3.0434782608695645, \"y\": -6.811594202898551, \"x2\": -2.753623188405797, \"y2\": -6.521739130434783, \"center_x\": -2.8985507246376807, \"center_y\": -6.666666666666667, \"value_uncond\": 1.6995180916205377e-06}, {\"x\": -2.753623188405797, \"y\": -6.811594202898551, \"x2\": -2.4637681159420293, \"y2\": -6.521739130434783, \"center_x\": -2.608695652173913, \"center_y\": -6.666666666666667, \"value_uncond\": 2.1223421827994224e-06}, {\"x\": -2.4637681159420284, \"y\": -6.811594202898551, \"x2\": -2.1739130434782608, \"y2\": -6.521739130434783, \"center_x\": -2.3188405797101446, \"center_y\": -6.666666666666667, \"value_uncond\": 2.6257346452051987e-06}, {\"x\": -2.1739130434782608, \"y\": -6.811594202898551, \"x2\": -1.8840579710144931, \"y2\": -6.521739130434783, \"center_x\": -2.028985507246377, \"center_y\": -6.666666666666667, \"value_uncond\": 3.2183411448696105e-06}, {\"x\": -1.8840579710144922, \"y\": -6.811594202898551, \"x2\": -1.5942028985507246, \"y2\": -6.521739130434783, \"center_x\": -1.7391304347826084, \"center_y\": -6.666666666666667, \"value_uncond\": 3.9080412136115375e-06}, {\"x\": -1.5942028985507246, \"y\": -6.811594202898551, \"x2\": -1.304347826086957, \"y2\": -6.521739130434783, \"center_x\": -1.4492753623188408, \"center_y\": -6.666666666666667, \"value_uncond\": 4.701452007438475e-06}, {\"x\": -1.304347826086957, \"y\": -6.811594202898551, \"x2\": -1.0144927536231894, \"y2\": -6.521739130434783, \"center_x\": -1.1594202898550732, \"center_y\": -6.666666666666667, \"value_uncond\": 5.603387975479224e-06}, {\"x\": -1.0144927536231876, \"y\": -6.811594202898551, \"x2\": -0.72463768115942, \"y2\": -6.521739130434783, \"center_x\": -0.8695652173913038, \"center_y\": -6.666666666666667, \"value_uncond\": 6.616300091166552e-06}, {\"x\": -0.72463768115942, \"y\": -6.811594202898551, \"x2\": -0.43478260869565233, \"y2\": -6.521739130434783, \"center_x\": -0.5797101449275361, \"center_y\": -6.666666666666667, \"value_uncond\": 7.739724655570018e-06}, {\"x\": -0.43478260869565233, \"y\": -6.811594202898551, \"x2\": -0.1449275362318847, \"y2\": -6.521739130434783, \"center_x\": -0.2898550724637685, \"center_y\": -6.666666666666667, \"value_uncond\": 8.969776895016973e-06}, {\"x\": -0.14492753623188293, \"y\": -6.811594202898551, \"x2\": 0.1449275362318847, \"y2\": -6.521739130434783, \"center_x\": 8.881784197001252e-16, \"center_y\": -6.666666666666667, \"value_uncond\": 1.0298727944401408e-05}, {\"x\": 0.1449275362318847, \"y\": -6.811594202898551, \"x2\": 0.43478260869565233, \"y2\": -6.521739130434783, \"center_x\": 0.2898550724637685, \"center_y\": -6.666666666666667, \"value_uncond\": 1.1714704689143955e-05}, {\"x\": 0.43478260869565233, \"y\": -6.811594202898551, \"x2\": 0.72463768115942, \"y2\": -6.521739130434783, \"center_x\": 0.5797101449275361, \"center_y\": -6.666666666666667, \"value_uncond\": 1.3201549820744305e-05}, {\"x\": 0.72463768115942, \"y\": -6.811594202898551, \"x2\": 1.0144927536231876, \"y2\": -6.521739130434783, \"center_x\": 0.8695652173913038, \"center_y\": -6.666666666666667, \"value_uncond\": 1.4738874043274142e-05}, {\"x\": 1.0144927536231894, \"y\": -6.811594202898551, \"x2\": 1.304347826086957, \"y2\": -6.521739130434783, \"center_x\": 1.1594202898550732, \"center_y\": -6.666666666666667, \"value_uncond\": 1.6302323630079804e-05}, {\"x\": 1.304347826086957, \"y\": -6.811594202898551, \"x2\": 1.5942028985507246, \"y2\": -6.521739130434783, \"center_x\": 1.4492753623188408, \"center_y\": -6.666666666666667, \"value_uncond\": 1.7864074774279058e-05}, {\"x\": 1.5942028985507246, \"y\": -6.811594202898551, \"x2\": 1.8840579710144922, \"y2\": -6.521739130434783, \"center_x\": 1.7391304347826084, \"center_y\": -6.666666666666667, \"value_uncond\": 1.9393552043168186e-05}, {\"x\": 1.884057971014494, \"y\": -6.811594202898551, \"x2\": 2.1739130434782616, \"y2\": -6.521739130434783, \"center_x\": 2.028985507246378, \"center_y\": -6.666666666666667, \"value_uncond\": 2.0858352687633163e-05}, {\"x\": 2.1739130434782616, \"y\": -6.811594202898551, \"x2\": 2.4637681159420293, \"y2\": -6.521739130434783, \"center_x\": 2.3188405797101455, \"center_y\": -6.666666666666667, \"value_uncond\": 2.2225342773643506e-05}, {\"x\": 2.4637681159420293, \"y\": -6.811594202898551, \"x2\": 2.753623188405797, \"y2\": -6.521739130434783, \"center_x\": 2.608695652173913, \"center_y\": -6.666666666666667, \"value_uncond\": 2.346187644250868e-05}, {\"x\": 2.753623188405797, \"y\": -6.811594202898551, \"x2\": 3.0434782608695645, \"y2\": -6.521739130434783, \"center_x\": 2.8985507246376807, \"center_y\": -6.666666666666667, \"value_uncond\": 2.4537077438526764e-05}, {\"x\": 3.0434782608695663, \"y\": -6.811594202898551, \"x2\": 3.333333333333334, \"y2\": -6.521739130434783, \"center_x\": 3.18840579710145, \"center_y\": -6.666666666666667, \"value_uncond\": 2.542311361342594e-05}, {\"x\": 3.333333333333334, \"y\": -6.811594202898551, \"x2\": 3.6231884057971016, \"y2\": -6.521739130434783, \"center_x\": 3.4782608695652177, \"center_y\": -6.666666666666667, \"value_uncond\": 2.6096391410354376e-05}, {\"x\": 3.6231884057971016, \"y\": -6.811594202898551, \"x2\": 3.913043478260869, \"y2\": -6.521739130434783, \"center_x\": 3.7681159420289854, \"center_y\": -6.666666666666667, \"value_uncond\": 2.6538598946131853e-05}, {\"x\": 3.913043478260871, \"y\": -6.811594202898551, \"x2\": 4.202898550724639, \"y2\": -6.521739130434783, \"center_x\": 4.057971014492755, \"center_y\": -6.666666666666667, \"value_uncond\": 2.673753337994889e-05}, {\"x\": 4.202898550724639, \"y\": -6.811594202898551, \"x2\": 4.492753623188406, \"y2\": -6.521739130434783, \"center_x\": 4.347826086956522, \"center_y\": -6.666666666666667, \"value_uncond\": 2.6687660404369222e-05}, {\"x\": 4.492753623188406, \"y\": -6.811594202898551, \"x2\": 4.782608695652174, \"y2\": -6.521739130434783, \"center_x\": 4.63768115942029, \"center_y\": -6.666666666666667, \"value_uncond\": 2.639037005687939e-05}, {\"x\": 4.782608695652174, \"y\": -6.811594202898551, \"x2\": 5.0724637681159415, \"y2\": -6.521739130434783, \"center_x\": 4.927536231884058, \"center_y\": -6.666666666666667, \"value_uncond\": 2.585391234900603e-05}, {\"x\": 5.072463768115943, \"y\": -6.811594202898551, \"x2\": 5.362318840579711, \"y2\": -6.521739130434783, \"center_x\": 5.217391304347827, \"center_y\": -6.666666666666667, \"value_uncond\": 2.5093016873409156e-05}, {\"x\": 5.362318840579711, \"y\": -6.811594202898551, \"x2\": 5.6521739130434785, \"y2\": -6.521739130434783, \"center_x\": 5.507246376811595, \"center_y\": -6.666666666666667, \"value_uncond\": 2.4128220868091493e-05}, {\"x\": 5.6521739130434785, \"y\": -6.811594202898551, \"x2\": 5.942028985507246, \"y2\": -6.521739130434783, \"center_x\": 5.797101449275362, \"center_y\": -6.666666666666667, \"value_uncond\": 2.2984948516464874e-05}, {\"x\": 5.942028985507246, \"y\": -6.811594202898551, \"x2\": 6.231884057971014, \"y2\": -6.521739130434783, \"center_x\": 6.08695652173913, \"center_y\": -6.666666666666667, \"value_uncond\": 2.1692399070934804e-05}, {\"x\": 6.2318840579710155, \"y\": -6.811594202898551, \"x2\": 6.521739130434783, \"y2\": -6.521739130434783, \"center_x\": 6.376811594202899, \"center_y\": -6.666666666666667, \"value_uncond\": 2.0282311581402006e-05}, {\"x\": 6.521739130434785, \"y\": -6.811594202898551, \"x2\": 6.8115942028985526, \"y2\": -6.521739130434783, \"center_x\": 6.666666666666669, \"center_y\": -6.666666666666667, \"value_uncond\": 1.8787678914629364e-05}, {\"x\": 6.811594202898551, \"y\": -6.811594202898551, \"x2\": 7.101449275362318, \"y2\": -6.521739130434783, \"center_x\": 6.956521739130435, \"center_y\": -6.666666666666667, \"value_uncond\": 1.7241483193963888e-05}, {\"x\": 7.10144927536232, \"y\": -6.811594202898551, \"x2\": 7.391304347826088, \"y2\": -6.521739130434783, \"center_x\": 7.246376811594204, \"center_y\": -6.666666666666667, \"value_uncond\": 1.56755190973668e-05}, {\"x\": 7.391304347826086, \"y\": -6.811594202898551, \"x2\": 7.681159420289854, \"y2\": -6.521739130434783, \"center_x\": 7.53623188405797, \"center_y\": -6.666666666666667, \"value_uncond\": 1.4119361391184097e-05}, {\"x\": 7.681159420289855, \"y\": -6.811594202898551, \"x2\": 7.971014492753623, \"y2\": -6.521739130434783, \"center_x\": 7.826086956521739, \"center_y\": -6.666666666666667, \"value_uncond\": 1.2599519752427816e-05}, {\"x\": 7.971014492753625, \"y\": -6.811594202898551, \"x2\": 8.260869565217392, \"y2\": -6.521739130434783, \"center_x\": 8.115942028985508, \"center_y\": -6.666666666666667, \"value_uncond\": 1.1138808656268394e-05}, {\"x\": 8.26086956521739, \"y\": -6.811594202898551, \"x2\": 8.550724637681158, \"y2\": -6.521739130434783, \"center_x\": 8.405797101449274, \"center_y\": -6.666666666666667, \"value_uncond\": 9.755944255256153e-06}, {\"x\": 8.55072463768116, \"y\": -6.811594202898551, \"x2\": 8.840579710144928, \"y2\": -6.521739130434783, \"center_x\": 8.695652173913043, \"center_y\": -6.666666666666667, \"value_uncond\": 8.465365055944217e-06}, {\"x\": 8.84057971014493, \"y\": -6.811594202898551, \"x2\": 9.130434782608697, \"y2\": -6.521739130434783, \"center_x\": 8.985507246376812, \"center_y\": -6.666666666666667, \"value_uncond\": 7.277259918443921e-06}, {\"x\": 9.130434782608695, \"y\": -6.811594202898551, \"x2\": 9.420289855072463, \"y2\": -6.521739130434783, \"center_x\": 9.275362318840578, \"center_y\": -6.666666666666667, \"value_uncond\": 6.197776297765796e-06}, {\"x\": 9.420289855072465, \"y\": -6.811594202898551, \"x2\": 9.710144927536232, \"y2\": -6.521739130434783, \"center_x\": 9.565217391304348, \"center_y\": -6.666666666666667, \"value_uncond\": 5.229374218373128e-06}, {\"x\": 9.710144927536234, \"y\": -6.811594202898551, \"x2\": 10.000000000000002, \"y2\": -6.521739130434783, \"center_x\": 9.855072463768117, \"center_y\": -6.666666666666667, \"value_uncond\": 4.371287395038365e-06}, {\"x\": 10.0, \"y\": -6.811594202898551, \"x2\": 10.289855072463768, \"y2\": -6.521739130434783, \"center_x\": 10.144927536231883, \"center_y\": -6.666666666666667, \"value_uncond\": 3.6200520444522546e-06}, {\"x\": -10.0, \"y\": -6.521739130434782, \"x2\": -9.710144927536232, \"y2\": -6.231884057971015, \"center_x\": -9.855072463768117, \"center_y\": -6.3768115942028984, \"value_uncond\": 7.039040184716764e-10}, {\"x\": -9.710144927536232, \"y\": -6.521739130434782, \"x2\": -9.420289855072465, \"y2\": -6.231884057971015, \"center_x\": -9.565217391304348, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.0997741551867875e-09}, {\"x\": -9.420289855072463, \"y\": -6.521739130434782, \"x2\": -9.130434782608695, \"y2\": -6.231884057971015, \"center_x\": -9.275362318840578, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.7023128952967586e-09}, {\"x\": -9.130434782608695, \"y\": -6.521739130434782, \"x2\": -8.840579710144928, \"y2\": -6.231884057971015, \"center_x\": -8.985507246376812, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.6104842846516803e-09}, {\"x\": -8.840579710144928, \"y\": -6.521739130434782, \"x2\": -8.55072463768116, \"y2\": -6.231884057971015, \"center_x\": -8.695652173913043, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.965962392440151e-09}, {\"x\": -8.55072463768116, \"y\": -6.521739130434782, \"x2\": -8.260869565217392, \"y2\": -6.231884057971015, \"center_x\": -8.405797101449277, \"center_y\": -6.3768115942028984, \"value_uncond\": 5.969279505777591e-09}, {\"x\": -8.26086956521739, \"y\": -6.521739130434782, \"x2\": -7.971014492753623, \"y2\": -6.231884057971015, \"center_x\": -8.115942028985508, \"center_y\": -6.3768115942028984, \"value_uncond\": 8.901046143811682e-09}, {\"x\": -7.971014492753623, \"y\": -6.521739130434782, \"x2\": -7.681159420289855, \"y2\": -6.231884057971015, \"center_x\": -7.826086956521739, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.314940205953262e-08}, {\"x\": -7.681159420289855, \"y\": -6.521739130434782, \"x2\": -7.391304347826088, \"y2\": -6.231884057971015, \"center_x\": -7.536231884057972, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.924494930576833e-08}, {\"x\": -7.391304347826087, \"y\": -6.521739130434782, \"x2\": -7.101449275362319, \"y2\": -6.231884057971015, \"center_x\": -7.246376811594203, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.7904442661425693e-08}, {\"x\": -7.101449275362318, \"y\": -6.521739130434782, \"x2\": -6.811594202898551, \"y2\": -6.231884057971015, \"center_x\": -6.956521739130435, \"center_y\": -6.3768115942028984, \"value_uncond\": 4.008443334539075e-08}, {\"x\": -6.811594202898551, \"y\": -6.521739130434782, \"x2\": -6.521739130434783, \"y2\": -6.231884057971015, \"center_x\": -6.666666666666667, \"center_y\": -6.3768115942028984, \"value_uncond\": 5.7045837298942615e-08}, {\"x\": -6.521739130434782, \"y\": -6.521739130434782, \"x2\": -6.231884057971015, \"y2\": -6.231884057971015, \"center_x\": -6.3768115942028984, \"center_y\": -6.3768115942028984, \"value_uncond\": 8.042998428613649e-08}, {\"x\": -6.231884057971014, \"y\": -6.521739130434782, \"x2\": -5.942028985507246, \"y2\": -6.231884057971015, \"center_x\": -6.08695652173913, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.1234605407244484e-07}, {\"x\": -5.942028985507246, \"y\": -6.521739130434782, \"x2\": -5.6521739130434785, \"y2\": -6.231884057971015, \"center_x\": -5.797101449275362, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.5546888264731687e-07}, {\"x\": -5.6521739130434785, \"y\": -6.521739130434782, \"x2\": -5.362318840579711, \"y2\": -6.231884057971015, \"center_x\": -5.507246376811595, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.131449001305415e-07}, {\"x\": -5.36231884057971, \"y\": -6.521739130434782, \"x2\": -5.072463768115942, \"y2\": -6.231884057971015, \"center_x\": -5.217391304347826, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.895024403309789e-07}, {\"x\": -5.0724637681159415, \"y\": -6.521739130434782, \"x2\": -4.782608695652174, \"y2\": -6.231884057971015, \"center_x\": -4.927536231884058, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.8956086952577673e-07}, {\"x\": -4.782608695652174, \"y\": -6.521739130434782, \"x2\": -4.492753623188406, \"y2\": -6.231884057971015, \"center_x\": -4.63768115942029, \"center_y\": -6.3768115942028984, \"value_uncond\": 5.193309896456e-07}, {\"x\": -4.492753623188405, \"y\": -6.521739130434782, \"x2\": -4.202898550724638, \"y2\": -6.231884057971015, \"center_x\": -4.3478260869565215, \"center_y\": -6.3768115942028984, \"value_uncond\": 6.85897098017273e-07}, {\"x\": -4.202898550724638, \"y\": -6.521739130434782, \"x2\": -3.91304347826087, \"y2\": -6.231884057971015, \"center_x\": -4.057971014492754, \"center_y\": -6.3768115942028984, \"value_uncond\": 8.974691040289142e-07}, {\"x\": -3.913043478260869, \"y\": -6.521739130434782, \"x2\": -3.6231884057971016, \"y2\": -6.231884057971015, \"center_x\": -3.7681159420289854, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.1633914356796153e-06}, {\"x\": -3.6231884057971016, \"y\": -6.521739130434782, \"x2\": -3.333333333333334, \"y2\": -6.231884057971015, \"center_x\": -3.4782608695652177, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.4940943819444437e-06}, {\"x\": -3.333333333333333, \"y\": -6.521739130434782, \"x2\": -3.0434782608695654, \"y2\": -6.231884057971015, \"center_x\": -3.1884057971014492, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.9009733023452697e-06}, {\"x\": -3.0434782608695645, \"y\": -6.521739130434782, \"x2\": -2.753623188405797, \"y2\": -6.231884057971015, \"center_x\": -2.8985507246376807, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.3961820857624293e-06}, {\"x\": -2.753623188405797, \"y\": -6.521739130434782, \"x2\": -2.4637681159420293, \"y2\": -6.231884057971015, \"center_x\": -2.608695652173913, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.9923296158811253e-06}, {\"x\": -2.4637681159420284, \"y\": -6.521739130434782, \"x2\": -2.1739130434782608, \"y2\": -6.231884057971015, \"center_x\": -2.3188405797101446, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.7020719872461713e-06}, {\"x\": -2.1739130434782608, \"y\": -6.521739130434782, \"x2\": -1.8840579710144931, \"y2\": -6.231884057971015, \"center_x\": -2.028985507246377, \"center_y\": -6.3768115942028984, \"value_uncond\": 4.537598884784661e-06}, {\"x\": -1.8840579710144922, \"y\": -6.521739130434782, \"x2\": -1.5942028985507246, \"y2\": -6.231884057971015, \"center_x\": -1.7391304347826084, \"center_y\": -6.3768115942028984, \"value_uncond\": 5.510019806584133e-06}, {\"x\": -1.5942028985507246, \"y\": -6.521739130434782, \"x2\": -1.304347826086957, \"y2\": -6.231884057971015, \"center_x\": -1.4492753623188408, \"center_y\": -6.3768115942028984, \"value_uncond\": 6.628664403656853e-06}, {\"x\": -1.304347826086957, \"y\": -6.521739130434782, \"x2\": -1.0144927536231894, \"y2\": -6.231884057971015, \"center_x\": -1.1594202898550732, \"center_y\": -6.3768115942028984, \"value_uncond\": 7.900320657144142e-06}, {\"x\": -1.0144927536231876, \"y\": -6.521739130434782, \"x2\": -0.72463768115942, \"y2\": -6.231884057971015, \"center_x\": -0.8695652173913038, \"center_y\": -6.3768115942028984, \"value_uncond\": 9.328444239957765e-06}, {\"x\": -0.72463768115942, \"y\": -6.521739130434782, \"x2\": -0.43478260869565233, \"y2\": -6.231884057971015, \"center_x\": -0.5797101449275361, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.091238137437345e-05}, {\"x\": -0.43478260869565233, \"y\": -6.521739130434782, \"x2\": -0.1449275362318847, \"y2\": -6.231884057971015, \"center_x\": -0.2898550724637685, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.2646654845922255e-05}, {\"x\": -0.14492753623188293, \"y\": -6.521739130434782, \"x2\": 0.1449275362318847, \"y2\": -6.231884057971015, \"center_x\": 8.881784197001252e-16, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.4520367584310195e-05}, {\"x\": 0.1449275362318847, \"y\": -6.521739130434782, \"x2\": 0.43478260869565233, \"y2\": -6.231884057971015, \"center_x\": 0.2898550724637685, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.6516779465029294e-05}, {\"x\": 0.43478260869565233, \"y\": -6.521739130434782, \"x2\": 0.72463768115942, \"y2\": -6.231884057971015, \"center_x\": 0.5797101449275361, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.8613109999084778e-05}, {\"x\": 0.72463768115942, \"y\": -6.521739130434782, \"x2\": 1.0144927536231876, \"y2\": -6.231884057971015, \"center_x\": 0.8695652173913038, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.078061193989797e-05}, {\"x\": 1.0144927536231894, \"y\": -6.521739130434782, \"x2\": 1.304347826086957, \"y2\": -6.231884057971015, \"center_x\": 1.1594202898550732, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.2984948516464915e-05}, {\"x\": 1.304347826086957, \"y\": -6.521739130434782, \"x2\": 1.5942028985507246, \"y2\": -6.231884057971015, \"center_x\": 1.4492753623188408, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.5186890427292652e-05}, {\"x\": 1.5942028985507246, \"y\": -6.521739130434782, \"x2\": 1.8840579710144922, \"y2\": -6.231884057971015, \"center_x\": 1.7391304347826084, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.7343328802596077e-05}, {\"x\": 1.884057971014494, \"y\": -6.521739130434782, \"x2\": 2.1739130434782616, \"y2\": -6.231884057971015, \"center_x\": 2.028985507246378, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.9408578405283986e-05}, {\"x\": 2.1739130434782616, \"y\": -6.521739130434782, \"x2\": 2.4637681159420293, \"y2\": -6.231884057971015, \"center_x\": 2.3188405797101455, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.133592308708699e-05}, {\"x\": 2.4637681159420293, \"y\": -6.521739130434782, \"x2\": 2.753623188405797, \"y2\": -6.231884057971015, \"center_x\": 2.608695652173913, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.3079334846211935e-05}, {\"x\": 2.753623188405797, \"y\": -6.521739130434782, \"x2\": 3.0434782608695645, \"y2\": -6.231884057971015, \"center_x\": 2.8985507246376807, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.459528067694787e-05}, {\"x\": 3.0434782608695663, \"y\": -6.521739130434782, \"x2\": 3.333333333333334, \"y2\": -6.231884057971015, \"center_x\": 3.18840579710145, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.5844519517121926e-05}, {\"x\": 3.333333333333334, \"y\": -6.521739130434782, \"x2\": 3.6231884057971016, \"y2\": -6.231884057971015, \"center_x\": 3.4782608695652177, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.679378637323594e-05}, {\"x\": 3.6231884057971016, \"y\": -6.521739130434782, \"x2\": 3.913043478260869, \"y2\": -6.231884057971015, \"center_x\": 3.7681159420289854, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.741726298148362e-05}, {\"x\": 3.913043478260871, \"y\": -6.521739130434782, \"x2\": 4.202898550724639, \"y2\": -6.231884057971015, \"center_x\": 4.057971014492755, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.769774433022827e-05}, {\"x\": 4.202898550724639, \"y\": -6.521739130434782, \"x2\": 4.492753623188406, \"y2\": -6.231884057971015, \"center_x\": 4.347826086956522, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.762742749674654e-05}, {\"x\": 4.492753623188406, \"y\": -6.521739130434782, \"x2\": 4.782608695652174, \"y2\": -6.231884057971015, \"center_x\": 4.63768115942029, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.72082723206778e-05}, {\"x\": 4.782608695652174, \"y\": -6.521739130434782, \"x2\": 5.0724637681159415, \"y2\": -6.231884057971015, \"center_x\": 4.927536231884058, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.6451910646322456e-05}, {\"x\": 5.072463768115943, \"y\": -6.521739130434782, \"x2\": 5.362318840579711, \"y2\": -6.231884057971015, \"center_x\": 5.217391304347827, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.537910999962595e-05}, {\"x\": 5.362318840579711, \"y\": -6.521739130434782, \"x2\": 5.6521739130434785, \"y2\": -6.231884057971015, \"center_x\": 5.507246376811595, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.4018826213442224e-05}, {\"x\": 5.6521739130434785, \"y\": -6.521739130434782, \"x2\": 5.942028985507246, \"y2\": -6.231884057971015, \"center_x\": 5.797101449275362, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.2406905315616995e-05}, {\"x\": 5.942028985507246, \"y\": -6.521739130434782, \"x2\": 6.231884057971014, \"y2\": -6.231884057971015, \"center_x\": 6.08695652173913, \"center_y\": -6.3768115942028984, \"value_uncond\": 3.0584515873802894e-05}, {\"x\": 6.2318840579710155, \"y\": -6.521739130434782, \"x2\": 6.521739130434783, \"y2\": -6.231884057971015, \"center_x\": 6.376811594202899, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.8596407363257766e-05}, {\"x\": 6.521739130434785, \"y\": -6.521739130434782, \"x2\": 6.8115942028985526, \"y2\": -6.231884057971015, \"center_x\": 6.666666666666669, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.6489097038893434e-05}, {\"x\": 6.811594202898551, \"y\": -6.521739130434782, \"x2\": 7.101449275362318, \"y2\": -6.231884057971015, \"center_x\": 6.956521739130435, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.4309087008280366e-05}, {\"x\": 7.10144927536232, \"y\": -6.521739130434782, \"x2\": 7.391304347826088, \"y2\": -6.231884057971015, \"center_x\": 7.246376811594204, \"center_y\": -6.3768115942028984, \"value_uncond\": 2.21012051777109e-05}, {\"x\": 7.391304347826086, \"y\": -6.521739130434782, \"x2\": 7.681159420289854, \"y2\": -6.231884057971015, \"center_x\": 7.53623188405797, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.9907149558908627e-05}, {\"x\": 7.681159420289855, \"y\": -6.521739130434782, \"x2\": 7.971014492753623, \"y2\": -6.231884057971015, \"center_x\": 7.826086956521739, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.7764296637283633e-05}, {\"x\": 7.971014492753625, \"y\": -6.521739130434782, \"x2\": 8.260869565217392, \"y2\": -6.231884057971015, \"center_x\": 8.115942028985508, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.5704812964618436e-05}, {\"x\": 8.26086956521739, \"y\": -6.521739130434782, \"x2\": 8.550724637681158, \"y2\": -6.231884057971015, \"center_x\": 8.405797101449274, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.375508679160399e-05}, {\"x\": 8.55072463768116, \"y\": -6.521739130434782, \"x2\": 8.840579710144928, \"y2\": -6.231884057971015, \"center_x\": 8.695652173913043, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.1935475236483604e-05}, {\"x\": 8.84057971014493, \"y\": -6.521739130434782, \"x2\": 9.130434782608697, \"y2\": -6.231884057971015, \"center_x\": 8.985507246376812, \"center_y\": -6.3768115942028984, \"value_uncond\": 1.0260343762145541e-05}, {\"x\": 9.130434782608695, \"y\": -6.521739130434782, \"x2\": 9.420289855072463, \"y2\": -6.231884057971015, \"center_x\": 9.275362318840578, \"center_y\": -6.3768115942028984, \"value_uncond\": 8.738359779452863e-06}, {\"x\": 9.420289855072465, \"y\": -6.521739130434782, \"x2\": 9.710144927536232, \"y2\": -6.231884057971015, \"center_x\": 9.565217391304348, \"center_y\": -6.3768115942028984, \"value_uncond\": 7.372991722533171e-06}, {\"x\": 9.710144927536234, \"y\": -6.521739130434782, \"x2\": 10.000000000000002, \"y2\": -6.231884057971015, \"center_x\": 9.855072463768117, \"center_y\": -6.3768115942028984, \"value_uncond\": 6.1631591916285065e-06}, {\"x\": 10.0, \"y\": -6.521739130434782, \"x2\": 10.289855072463768, \"y2\": -6.231884057971015, \"center_x\": 10.144927536231883, \"center_y\": -6.3768115942028984, \"value_uncond\": 5.103978534393217e-06}, {\"x\": -10.0, \"y\": -6.231884057971014, \"x2\": -9.710144927536232, \"y2\": -5.942028985507246, \"center_x\": -9.855072463768117, \"center_y\": -6.08695652173913, \"value_uncond\": 9.832258407473207e-10}, {\"x\": -9.710144927536232, \"y\": -6.231884057971014, \"x2\": -9.420289855072465, \"y2\": -5.942028985507246, \"center_x\": -9.565217391304348, \"center_y\": -6.08695652173913, \"value_uncond\": 1.5361843944483886e-09}, {\"x\": -9.420289855072463, \"y\": -6.231884057971014, \"x2\": -9.130434782608695, \"y2\": -5.942028985507246, \"center_x\": -9.275362318840578, \"center_y\": -6.08695652173913, \"value_uncond\": 2.3778213844086803e-09}, {\"x\": -9.130434782608695, \"y\": -6.231884057971014, \"x2\": -8.840579710144928, \"y2\": -5.942028985507246, \"center_x\": -8.985507246376812, \"center_y\": -6.08695652173913, \"value_uncond\": 3.6463715764929747e-09}, {\"x\": -8.840579710144928, \"y\": -6.231884057971014, \"x2\": -8.55072463768116, \"y2\": -5.942028985507246, \"center_x\": -8.695652173913043, \"center_y\": -6.08695652173913, \"value_uncond\": 5.539727868219475e-09}, {\"x\": -8.55072463768116, \"y\": -6.231884057971014, \"x2\": -8.260869565217392, \"y2\": -5.942028985507246, \"center_x\": -8.405797101449277, \"center_y\": -6.08695652173913, \"value_uncond\": 8.33799737848785e-09}, {\"x\": -8.26086956521739, \"y\": -6.231884057971014, \"x2\": -7.971014492753623, \"y2\": -5.942028985507246, \"center_x\": -8.115942028985508, \"center_y\": -6.08695652173913, \"value_uncond\": 1.2433141946371896e-08}, {\"x\": -7.971014492753623, \"y\": -6.231884057971014, \"x2\": -7.681159420289855, \"y2\": -5.942028985507246, \"center_x\": -7.826086956521739, \"center_y\": -6.08695652173913, \"value_uncond\": 1.836732218602715e-08}, {\"x\": -7.681159420289855, \"y\": -6.231884057971014, \"x2\": -7.391304347826088, \"y2\": -5.942028985507246, \"center_x\": -7.536231884057972, \"center_y\": -6.08695652173913, \"value_uncond\": 2.688169262392831e-08}, {\"x\": -7.391304347826087, \"y\": -6.231884057971014, \"x2\": -7.101449275362319, \"y2\": -5.942028985507246, \"center_x\": -7.246376811594203, \"center_y\": -6.08695652173913, \"value_uncond\": 3.897742927499661e-08}, {\"x\": -7.101449275362318, \"y\": -6.231884057971014, \"x2\": -6.811594202898551, \"y2\": -5.942028985507246, \"center_x\": -6.956521739130435, \"center_y\": -6.08695652173913, \"value_uncond\": 5.599066015061769e-08}, {\"x\": -6.811594202898551, \"y\": -6.231884057971014, \"x2\": -6.521739130434783, \"y2\": -5.942028985507246, \"center_x\": -6.666666666666667, \"center_y\": -6.08695652173913, \"value_uncond\": 7.968265540118451e-08}, {\"x\": -6.521739130434782, \"y\": -6.231884057971014, \"x2\": -6.231884057971015, \"y2\": -5.942028985507246, \"center_x\": -6.3768115942028984, \"center_y\": -6.08695652173913, \"value_uncond\": 1.1234605407244484e-07}, {\"x\": -6.231884057971014, \"y\": -6.231884057971014, \"x2\": -5.942028985507246, \"y2\": -5.942028985507246, \"center_x\": -6.08695652173913, \"center_y\": -6.08695652173913, \"value_uncond\": 1.5692699653833282e-07}, {\"x\": -5.942028985507246, \"y\": -6.231884057971014, \"x2\": -5.6521739130434785, \"y2\": -5.942028985507246, \"center_x\": -5.797101449275362, \"center_y\": -6.08695652173913, \"value_uncond\": 2.1716174199835867e-07}, {\"x\": -5.6521739130434785, \"y\": -6.231884057971014, \"x2\": -5.362318840579711, \"y2\": -5.942028985507246, \"center_x\": -5.507246376811595, \"center_y\": -6.08695652173913, \"value_uncond\": 2.977246444577404e-07}, {\"x\": -5.36231884057971, \"y\": -6.231884057971014, \"x2\": -5.072463768115942, \"y2\": -5.942028985507246, \"center_x\": -5.217391304347826, \"center_y\": -6.08695652173913, \"value_uncond\": 4.0438223511048235e-07}, {\"x\": -5.0724637681159415, \"y\": -6.231884057971014, \"x2\": -4.782608695652174, \"y2\": -5.942028985507246, \"center_x\": -4.927536231884058, \"center_y\": -6.08695652173913, \"value_uncond\": 5.441456553883133e-07}, {\"x\": -4.782608695652174, \"y\": -6.231884057971014, \"x2\": -4.492753623188406, \"y2\": -5.942028985507246, \"center_x\": -4.63768115942029, \"center_y\": -6.08695652173913, \"value_uncond\": 7.254109019424205e-07}, {\"x\": -4.492753623188405, \"y\": -6.231884057971014, \"x2\": -4.202898550724638, \"y2\": -5.942028985507246, \"center_x\": -4.3478260869565215, \"center_y\": -6.08695652173913, \"value_uncond\": 9.580734491734053e-07}, {\"x\": -4.202898550724638, \"y\": -6.231884057971014, \"x2\": -3.91304347826087, \"y2\": -5.942028985507246, \"center_x\": -4.057971014492754, \"center_y\": -6.08695652173913, \"value_uncond\": 1.2536010467300358e-06}, {\"x\": -3.913043478260869, \"y\": -6.231884057971014, \"x2\": -3.6231884057971016, \"y2\": -5.942028985507246, \"center_x\": -3.7681159420289854, \"center_y\": -6.08695652173913, \"value_uncond\": 1.625046160338616e-06}, {\"x\": -3.6231884057971016, \"y\": -6.231884057971014, \"x2\": -3.333333333333334, \"y2\": -5.942028985507246, \"center_x\": -3.4782608695652177, \"center_y\": -6.08695652173913, \"value_uncond\": 2.0869780059399955e-06}, {\"x\": -3.333333333333333, \"y\": -6.231884057971014, \"x2\": -3.0434782608695654, \"y2\": -5.942028985507246, \"center_x\": -3.1884057971014492, \"center_y\": -6.08695652173913, \"value_uncond\": 2.6553138274374587e-06}, {\"x\": -3.0434782608695645, \"y\": -6.231884057971014, \"x2\": -2.753623188405797, \"y2\": -5.942028985507246, \"center_x\": -2.8985507246376807, \"center_y\": -6.08695652173913, \"value_uncond\": 3.3470303962360863e-06}, {\"x\": -2.753623188405797, \"y\": -6.231884057971014, \"x2\": -2.4637681159420293, \"y2\": -5.942028985507246, \"center_x\": -2.608695652173913, \"center_y\": -6.08695652173913, \"value_uncond\": 4.179740028698538e-06}, {\"x\": -2.4637681159420284, \"y\": -6.231884057971014, \"x2\": -2.1739130434782608, \"y2\": -5.942028985507246, \"center_x\": -2.3188405797101446, \"center_y\": -6.08695652173913, \"value_uncond\": 5.171120986168483e-06}, {\"x\": -2.1739130434782608, \"y\": -6.231884057971014, \"x2\": -1.8840579710144931, \"y2\": -5.942028985507246, \"center_x\": -2.028985507246377, \"center_y\": -6.08695652173913, \"value_uncond\": 6.338200040615355e-06}, {\"x\": -1.8840579710144922, \"y\": -6.231884057971014, \"x2\": -1.5942028985507246, \"y2\": -5.942028985507246, \"center_x\": -1.7391304347826084, \"center_y\": -6.08695652173913, \"value_uncond\": 7.696495139530241e-06}, {\"x\": -1.5942028985507246, \"y\": -6.231884057971014, \"x2\": -1.304347826086957, \"y2\": -5.942028985507246, \"center_x\": -1.4492753623188408, \"center_y\": -6.08695652173913, \"value_uncond\": 9.259038107877462e-06}, {\"x\": -1.304347826086957, \"y\": -6.231884057971014, \"x2\": -1.0144927536231894, \"y2\": -5.942028985507246, \"center_x\": -1.1594202898550732, \"center_y\": -6.08695652173913, \"value_uncond\": 1.1035310520260253e-05}, {\"x\": -1.0144927536231876, \"y\": -6.231884057971014, \"x2\": -0.72463768115942, \"y2\": -5.942028985507246, \"center_x\": -0.8695652173913038, \"center_y\": -6.08695652173913, \"value_uncond\": 1.3030139322987851e-05}, {\"x\": -0.72463768115942, \"y\": -6.231884057971014, \"x2\": -0.43478260869565233, \"y2\": -5.942028985507246, \"center_x\": -0.5797101449275361, \"center_y\": -6.08695652173913, \"value_uncond\": 1.5242611307532183e-05}, {\"x\": -0.43478260869565233, \"y\": -6.231884057971014, \"x2\": -0.1449275362318847, \"y2\": -5.942028985507246, \"center_x\": -0.2898550724637685, \"center_y\": -6.08695652173913, \"value_uncond\": 1.7665075801841584e-05}, {\"x\": -0.14492753623188293, \"y\": -6.231884057971014, \"x2\": 0.1449275362318847, \"y2\": -5.942028985507246, \"center_x\": 8.881784197001252e-16, \"center_y\": -6.08695652173913, \"value_uncond\": 2.0282311581402023e-05}, {\"x\": 0.1449275362318847, \"y\": -6.231884057971014, \"x2\": 0.43478260869565233, \"y2\": -5.942028985507246, \"center_x\": 0.2898550724637685, \"center_y\": -6.08695652173913, \"value_uncond\": 2.307093573808732e-05}, {\"x\": 0.43478260869565233, \"y\": -6.231884057971014, \"x2\": 0.72463768115942, \"y2\": -5.942028985507246, \"center_x\": 0.5797101449275361, \"center_y\": -6.08695652173913, \"value_uncond\": 2.5999128073608017e-05}, {\"x\": 0.72463768115942, \"y\": -6.231884057971014, \"x2\": 1.0144927536231876, \"y2\": -5.942028985507246, \"center_x\": 0.8695652173913038, \"center_y\": -6.08695652173913, \"value_uncond\": 2.9026733914962152e-05}, {\"x\": 1.0144927536231894, \"y\": -6.231884057971014, \"x2\": 1.304347826086957, \"y2\": -5.942028985507246, \"center_x\": 1.1594202898550732, \"center_y\": -6.08695652173913, \"value_uncond\": 3.210579104052153e-05}, {\"x\": 1.304347826086957, \"y\": -6.231884057971014, \"x2\": 1.5942028985507246, \"y2\": -5.942028985507246, \"center_x\": 1.4492753623188408, \"center_y\": -6.08695652173913, \"value_uncond\": 3.518150325374492e-05}, {\"x\": 1.5942028985507246, \"y\": -6.231884057971014, \"x2\": 1.8840579710144922, \"y2\": -5.942028985507246, \"center_x\": 1.7391304347826084, \"center_y\": -6.08695652173913, \"value_uncond\": 3.819365530706185e-05}, {\"x\": 1.884057971014494, \"y\": -6.231884057971014, \"x2\": 2.1739130434782616, \"y2\": -5.942028985507246, \"center_x\": 2.028985507246378, \"center_y\": -6.08695652173913, \"value_uncond\": 4.107843323653689e-05}, {\"x\": 2.1739130434782616, \"y\": -6.231884057971014, \"x2\": 2.4637681159420293, \"y2\": -5.942028985507246, \"center_x\": 2.3188405797101455, \"center_y\": -6.08695652173913, \"value_uncond\": 4.377058308288967e-05}, {\"x\": 2.4637681159420293, \"y\": -6.231884057971014, \"x2\": 2.753623188405797, \"y2\": -5.942028985507246, \"center_x\": 2.608695652173913, \"center_y\": -6.08695652173913, \"value_uncond\": 4.62058121022611e-05}, {\"x\": 2.753623188405797, \"y\": -6.231884057971014, \"x2\": 3.0434782608695645, \"y2\": -5.942028985507246, \"center_x\": 2.8985507246376807, \"center_y\": -6.08695652173913, \"value_uncond\": 4.832331260636244e-05}, {\"x\": 3.0434782608695663, \"y\": -6.231884057971014, \"x2\": 3.333333333333334, \"y2\": -5.942028985507246, \"center_x\": 3.18840579710145, \"center_y\": -6.08695652173913, \"value_uncond\": 5.006827197112243e-05}, {\"x\": 3.333333333333334, \"y\": -6.231884057971014, \"x2\": 3.6231884057971016, \"y2\": -5.942028985507246, \"center_x\": 3.4782608695652177, \"center_y\": -6.08695652173913, \"value_uncond\": 5.1394225053082035e-05}, {\"x\": 3.6231884057971016, \"y\": -6.231884057971014, \"x2\": 3.913043478260869, \"y2\": -5.942028985507246, \"center_x\": 3.7681159420289854, \"center_y\": -6.08695652173913, \"value_uncond\": 5.2265108435253366e-05}, {\"x\": 3.913043478260871, \"y\": -6.231884057971014, \"x2\": 4.202898550724639, \"y2\": -5.942028985507246, \"center_x\": 4.057971014492755, \"center_y\": -6.08695652173913, \"value_uncond\": 5.265688984677617e-05}, {\"x\": 4.202898550724639, \"y\": -6.231884057971014, \"x2\": 4.492753623188406, \"y2\": -5.942028985507246, \"center_x\": 4.347826086956522, \"center_y\": -6.08695652173913, \"value_uncond\": 5.2558670024322436e-05}, {\"x\": 4.492753623188406, \"y\": -6.231884057971014, \"x2\": 4.782608695652174, \"y2\": -5.942028985507246, \"center_x\": 4.63768115942029, \"center_y\": -6.08695652173913, \"value_uncond\": 5.197318650728187e-05}, {\"x\": 4.782608695652174, \"y\": -6.231884057971014, \"x2\": 5.0724637681159415, \"y2\": -5.942028985507246, \"center_x\": 4.927536231884058, \"center_y\": -6.08695652173913, \"value_uncond\": 5.0916686865765747e-05}, {\"x\": 5.072463768115943, \"y\": -6.231884057971014, \"x2\": 5.362318840579711, \"y2\": -5.942028985507246, \"center_x\": 5.217391304347827, \"center_y\": -6.08695652173913, \"value_uncond\": 4.941817955493573e-05}, {\"x\": 5.362318840579711, \"y\": -6.231884057971014, \"x2\": 5.6521739130434785, \"y2\": -5.942028985507246, \"center_x\": 5.507246376811595, \"center_y\": -6.08695652173913, \"value_uncond\": 4.7518110604868697e-05}, {\"x\": 5.6521739130434785, \"y\": -6.231884057971014, \"x2\": 5.942028985507246, \"y2\": -5.942028985507246, \"center_x\": 5.797101449275362, \"center_y\": -6.08695652173913, \"value_uncond\": 4.52665503943964e-05}, {\"x\": 5.942028985507246, \"y\": -6.231884057971014, \"x2\": 6.231884057971014, \"y2\": -5.942028985507246, \"center_x\": 6.08695652173913, \"center_y\": -6.08695652173913, \"value_uncond\": 4.272100392204194e-05}, {\"x\": 6.2318840579710155, \"y\": -6.231884057971014, \"x2\": 6.521739130434783, \"y2\": -5.942028985507246, \"center_x\": 6.376811594202899, \"center_y\": -6.08695652173913, \"value_uncond\": 3.9943978062718354e-05}, {\"x\": 6.521739130434785, \"y\": -6.231884057971014, \"x2\": 6.8115942028985526, \"y2\": -5.942028985507246, \"center_x\": 6.666666666666669, \"center_y\": -6.08695652173913, \"value_uncond\": 3.70004489578735e-05}, {\"x\": 6.811594202898551, \"y\": -6.231884057971014, \"x2\": 7.101449275362318, \"y2\": -5.942028985507246, \"center_x\": 6.956521739130435, \"center_y\": -6.08695652173913, \"value_uncond\": 3.3955371590875396e-05}, {\"x\": 7.10144927536232, \"y\": -6.231884057971014, \"x2\": 7.391304347826088, \"y2\": -5.942028985507246, \"center_x\": 7.246376811594204, \"center_y\": -6.08695652173913, \"value_uncond\": 3.0871362390521965e-05}, {\"x\": 7.391304347826086, \"y\": -6.231884057971014, \"x2\": 7.681159420289854, \"y2\": -5.942028985507246, \"center_x\": 7.53623188405797, \"center_y\": -6.08695652173913, \"value_uncond\": 2.780666589237285e-05}, {\"x\": 7.681159420289855, \"y\": -6.231884057971014, \"x2\": 7.971014492753623, \"y2\": -5.942028985507246, \"center_x\": 7.826086956521739, \"center_y\": -6.08695652173913, \"value_uncond\": 2.4813490246015368e-05}, {\"x\": 7.971014492753625, \"y\": -6.231884057971014, \"x2\": 8.260869565217392, \"y2\": -5.942028985507246, \"center_x\": 8.115942028985508, \"center_y\": -6.08695652173913, \"value_uncond\": 2.1936766271689755e-05}, {\"x\": 8.26086956521739, \"y\": -6.231884057971014, \"x2\": 8.550724637681158, \"y2\": -5.942028985507246, \"center_x\": 8.405797101449274, \"center_y\": -6.08695652173913, \"value_uncond\": 1.921335355435446e-05}, {\"x\": 8.55072463768116, \"y\": -6.231884057971014, \"x2\": 8.840579710144928, \"y2\": -5.942028985507246, \"center_x\": 8.695652173913043, \"center_y\": -6.08695652173913, \"value_uncond\": 1.6671687284283626e-05}, {\"x\": 8.84057971014493, \"y\": -6.231884057971014, \"x2\": 9.130434782608697, \"y2\": -5.942028985507246, \"center_x\": 8.985507246376812, \"center_y\": -6.08695652173913, \"value_uncond\": 1.4331833399382685e-05}, {\"x\": 9.130434782608695, \"y\": -6.231884057971014, \"x2\": 9.420289855072463, \"y2\": -5.942028985507246, \"center_x\": 9.275362318840578, \"center_y\": -6.08695652173913, \"value_uncond\": 1.2205898695619978e-05}, {\"x\": 9.420289855072465, \"y\": -6.231884057971014, \"x2\": 9.710144927536232, \"y2\": -5.942028985507246, \"center_x\": 9.565217391304348, \"center_y\": -6.08695652173913, \"value_uncond\": 1.0298727944401408e-05}, {\"x\": 9.710144927536234, \"y\": -6.231884057971014, \"x2\": 10.000000000000002, \"y2\": -5.942028985507246, \"center_x\": 9.855072463768117, \"center_y\": -6.08695652173913, \"value_uncond\": 8.608812023840343e-06}, {\"x\": 10.0, \"y\": -6.231884057971014, \"x2\": 10.289855072463768, \"y2\": -5.942028985507246, \"center_x\": 10.144927536231883, \"center_y\": -6.08695652173913, \"value_uncond\": 7.1293293601746525e-06}, {\"x\": -10.0, \"y\": -5.942028985507246, \"x2\": -9.710144927536232, \"y2\": -5.6521739130434785, \"center_x\": -9.855072463768117, \"center_y\": -5.797101449275362, \"value_uncond\": 1.360626540139841e-09}, {\"x\": -9.710144927536232, \"y\": -5.942028985507246, \"x2\": -9.420289855072465, \"y2\": -5.6521739130434785, \"center_x\": -9.565217391304348, \"center_y\": -5.797101449275362, \"value_uncond\": 2.125832307302315e-09}, {\"x\": -9.420289855072463, \"y\": -5.942028985507246, \"x2\": -9.130434782608695, \"y2\": -5.6521739130434785, \"center_x\": -9.275362318840578, \"center_y\": -5.797101449275362, \"value_uncond\": 3.290522634026223e-09}, {\"x\": -9.130434782608695, \"y\": -5.942028985507246, \"x2\": -8.840579710144928, \"y2\": -5.6521739130434785, \"center_x\": -8.985507246376812, \"center_y\": -5.797101449275362, \"value_uncond\": 5.045992219261586e-09}, {\"x\": -8.840579710144928, \"y\": -5.942028985507246, \"x2\": -8.55072463768116, \"y2\": -5.6521739130434785, \"center_x\": -8.695652173913043, \"center_y\": -5.797101449275362, \"value_uncond\": 7.666093027948395e-09}, {\"x\": -8.55072463768116, \"y\": -5.942028985507246, \"x2\": -8.260869565217392, \"y2\": -5.6521739130434785, \"center_x\": -8.405797101449277, \"center_y\": -5.797101449275362, \"value_uncond\": 1.153844829399938e-08}, {\"x\": -8.26086956521739, \"y\": -5.942028985507246, \"x2\": -7.971014492753623, \"y2\": -5.6521739130434785, \"center_x\": -8.115942028985508, \"center_y\": -5.797101449275362, \"value_uncond\": 1.720547020682608e-08}, {\"x\": -7.971014492753623, \"y\": -5.942028985507246, \"x2\": -7.681159420289855, \"y2\": -5.6521739130434785, \"center_x\": -7.826086956521739, \"center_y\": -5.797101449275362, \"value_uncond\": 2.5417421920698242e-08}, {\"x\": -7.681159420289855, \"y\": -5.942028985507246, \"x2\": -7.391304347826088, \"y2\": -5.6521739130434785, \"center_x\": -7.536231884057972, \"center_y\": -5.797101449275362, \"value_uncond\": 3.719994218235569e-08}, {\"x\": -7.391304347826087, \"y\": -5.942028985507246, \"x2\": -7.101449275362319, \"y2\": -5.6521739130434785, \"center_x\": -7.246376811594203, \"center_y\": -5.797101449275362, \"value_uncond\": 5.3938497688053776e-08}, {\"x\": -7.101449275362318, \"y\": -5.942028985507246, \"x2\": -6.811594202898551, \"y2\": -5.6521739130434785, \"center_x\": -6.956521739130435, \"center_y\": -5.797101449275362, \"value_uncond\": 7.748207486387541e-08}, {\"x\": -6.811594202898551, \"y\": -5.942028985507246, \"x2\": -6.521739130434783, \"y2\": -5.6521739130434785, \"center_x\": -6.666666666666667, \"center_y\": -5.797101449275362, \"value_uncond\": 1.1026798852770564e-07}, {\"x\": -6.521739130434782, \"y\": -5.942028985507246, \"x2\": -6.231884057971015, \"y2\": -5.6521739130434785, \"center_x\": -6.3768115942028984, \"center_y\": -5.797101449275362, \"value_uncond\": 1.5546888264731687e-07}, {\"x\": -6.231884057971014, \"y\": -5.942028985507246, \"x2\": -5.942028985507246, \"y2\": -5.6521739130434785, \"center_x\": -6.08695652173913, \"center_y\": -5.797101449275362, \"value_uncond\": 2.1716174199835867e-07}, {\"x\": -5.942028985507246, \"y\": -5.942028985507246, \"x2\": -5.6521739130434785, \"y2\": -5.6521739130434785, \"center_x\": -5.797101449275362, \"center_y\": -5.797101449275362, \"value_uncond\": 3.0051694882366615e-07}, {\"x\": -5.6521739130434785, \"y\": -5.942028985507246, \"x2\": -5.362318840579711, \"y2\": -5.6521739130434785, \"center_x\": -5.507246376811595, \"center_y\": -5.797101449275362, \"value_uncond\": 4.1200305780714903e-07}, {\"x\": -5.36231884057971, \"y\": -5.942028985507246, \"x2\": -5.072463768115942, \"y2\": -5.6521739130434785, \"center_x\": -5.217391304347826, \"center_y\": -5.797101449275362, \"value_uncond\": 5.596000213279511e-07}, {\"x\": -5.0724637681159415, \"y\": -5.942028985507246, \"x2\": -4.782608695652174, \"y2\": -5.6521739130434785, \"center_x\": -4.927536231884058, \"center_y\": -5.797101449275362, \"value_uncond\": 7.530101323012316e-07}, {\"x\": -4.782608695652174, \"y\": -5.942028985507246, \"x2\": -4.492753623188406, \"y2\": -5.6521739130434785, \"center_x\": -4.63768115942029, \"center_y\": -5.797101449275362, \"value_uncond\": 1.0038521006927966e-06}, {\"x\": -4.492753623188405, \"y\": -5.942028985507246, \"x2\": -4.202898550724638, \"y2\": -5.6521739130434785, \"center_x\": -4.3478260869565215, \"center_y\": -5.797101449275362, \"value_uncond\": 1.325819672678501e-06}, {\"x\": -4.202898550724638, \"y\": -5.942028985507246, \"x2\": -3.91304347826087, \"y2\": -5.6521739130434785, \"center_x\": -4.057971014492754, \"center_y\": -5.797101449275362, \"value_uncond\": 1.7347823706825448e-06}, {\"x\": -3.913043478260869, \"y\": -5.942028985507246, \"x2\": -3.6231884057971016, \"y2\": -5.6521739130434785, \"center_x\": -3.7681159420289854, \"center_y\": -5.797101449275362, \"value_uncond\": 2.248802709485845e-06}, {\"x\": -3.6231884057971016, \"y\": -5.942028985507246, \"x2\": -3.333333333333334, \"y2\": -5.6521739130434785, \"center_x\": -3.4782608695652177, \"center_y\": -5.797101449275362, \"value_uncond\": 2.8880421423950747e-06}, {\"x\": -3.333333333333333, \"y\": -5.942028985507246, \"x2\": -3.0434782608695654, \"y2\": -5.6521739130434785, \"center_x\": -3.1884057971014492, \"center_y\": -5.797101449275362, \"value_uncond\": 3.674527576762701e-06}, {\"x\": -3.0434782608695645, \"y\": -5.942028985507246, \"x2\": -2.753623188405797, \"y2\": -5.6521739130434785, \"center_x\": -2.8985507246376807, \"center_y\": -5.797101449275362, \"value_uncond\": 4.631752135717058e-06}, {\"x\": -2.753623188405797, \"y\": -5.942028985507246, \"x2\": -2.4637681159420293, \"y2\": -5.6521739130434785, \"center_x\": -2.608695652173913, \"center_y\": -5.797101449275362, \"value_uncond\": 5.7840884344633715e-06}, {\"x\": -2.4637681159420284, \"y\": -5.942028985507246, \"x2\": -2.1739130434782608, \"y2\": -5.6521739130434785, \"center_x\": -2.3188405797101446, \"center_y\": -5.797101449275362, \"value_uncond\": 7.15600034546198e-06}, {\"x\": -2.1739130434782608, \"y\": -5.942028985507246, \"x2\": -1.8840579710144931, \"y2\": -5.6521739130434785, \"center_x\": -2.028985507246377, \"center_y\": -5.797101449275362, \"value_uncond\": 8.771050184586184e-06}, {\"x\": -1.8840579710144922, \"y\": -5.942028985507246, \"x2\": -1.5942028985507246, \"y2\": -5.6521739130434785, \"center_x\": -1.7391304347826084, \"center_y\": -5.797101449275362, \"value_uncond\": 1.0650712297128669e-05}, {\"x\": -1.5942028985507246, \"y\": -5.942028985507246, \"x2\": -1.304347826086957, \"y2\": -5.6521739130434785, \"center_x\": -1.4492753623188408, \"center_y\": -5.797101449275362, \"value_uncond\": 1.2813020634373129e-05}, {\"x\": -1.304347826086957, \"y\": -5.942028985507246, \"x2\": -1.0144927536231894, \"y2\": -5.6521739130434785, \"center_x\": -1.1594202898550732, \"center_y\": -5.797101449275362, \"value_uncond\": 1.5271096171697562e-05}, {\"x\": -1.0144927536231876, \"y\": -5.942028985507246, \"x2\": -0.72463768115942, \"y2\": -5.6521739130434785, \"center_x\": -0.8695652173913038, \"center_y\": -5.797101449275362, \"value_uncond\": 1.8031618627010143e-05}, {\"x\": -0.72463768115942, \"y\": -5.942028985507246, \"x2\": -0.43478260869565233, \"y2\": -5.6521739130434785, \"center_x\": -0.5797101449275361, \"center_y\": -5.797101449275362, \"value_uncond\": 2.1093324266478302e-05}, {\"x\": -0.43478260869565233, \"y\": -5.942028985507246, \"x2\": -0.1449275362318847, \"y2\": -5.6521739130434785, \"center_x\": -0.2898550724637685, \"center_y\": -5.797101449275362, \"value_uncond\": 2.4445625789593858e-05}, {\"x\": -0.14492753623188293, \"y\": -5.942028985507246, \"x2\": 0.1449275362318847, \"y2\": -5.6521739130434785, \"center_x\": 8.881784197001252e-16, \"center_y\": -5.797101449275362, \"value_uncond\": 2.80674594679753e-05}, {\"x\": 0.1449275362318847, \"y\": -5.942028985507246, \"x2\": 0.43478260869565233, \"y2\": -5.6521739130434785, \"center_x\": 0.2898550724637685, \"center_y\": -5.797101449275362, \"value_uncond\": 3.192646711486255e-05}, {\"x\": 0.43478260869565233, \"y\": -5.942028985507246, \"x2\": 0.72463768115942, \"y2\": -5.6521739130434785, \"center_x\": 0.5797101449275361, \"center_y\": -5.797101449275362, \"value_uncond\": 3.5978614689945916e-05}, {\"x\": 0.72463768115942, \"y\": -5.942028985507246, \"x2\": 1.0144927536231876, \"y2\": -5.6521739130434785, \"center_x\": 0.8695652173913038, \"center_y\": -5.797101449275362, \"value_uncond\": 4.0168334579425016e-05}, {\"x\": 1.0144927536231894, \"y\": -5.942028985507246, \"x2\": 1.304347826086957, \"y2\": -5.6521739130434785, \"center_x\": 1.1594202898550732, \"center_y\": -5.797101449275362, \"value_uncond\": 4.442925477702533e-05}, {\"x\": 1.304347826086957, \"y\": -5.942028985507246, \"x2\": 1.5942028985507246, \"y2\": -5.6521739130434785, \"center_x\": 1.4492753623188408, \"center_y\": -5.797101449275362, \"value_uncond\": 4.8685546153544873e-05}, {\"x\": 1.5942028985507246, \"y\": -5.942028985507246, \"x2\": 1.8840579710144922, \"y2\": -5.6521739130434785, \"center_x\": 1.7391304347826084, \"center_y\": -5.797101449275362, \"value_uncond\": 5.285388048410381e-05}, {\"x\": 1.884057971014494, \"y\": -5.942028985507246, \"x2\": 2.1739130434782616, \"y2\": -5.6521739130434785, \"center_x\": 2.028985507246378, \"center_y\": -5.797101449275362, \"value_uncond\": 5.684594949875671e-05}, {\"x\": 2.1739130434782616, \"y\": -5.942028985507246, \"x2\": 2.4637681159420293, \"y2\": -5.6521739130434785, \"center_x\": 2.3188405797101455, \"center_y\": -5.797101449275362, \"value_uncond\": 6.057145220543583e-05}, {\"x\": 2.4637681159420293, \"y\": -5.942028985507246, \"x2\": 2.753623188405797, \"y2\": -5.6521739130434785, \"center_x\": 2.608695652173913, \"center_y\": -5.797101449275362, \"value_uncond\": 6.394141777973059e-05}, {\"x\": 2.753623188405797, \"y\": -5.942028985507246, \"x2\": 3.0434782608695645, \"y2\": -5.6521739130434785, \"center_x\": 2.8985507246376807, \"center_y\": -5.797101449275362, \"value_uncond\": 6.687169815402376e-05}, {\"x\": 3.0434782608695663, \"y\": -5.942028985507246, \"x2\": 3.333333333333334, \"y2\": -5.6521739130434785, \"center_x\": 3.18840579710145, \"center_y\": -5.797101449275362, \"value_uncond\": 6.928644146605207e-05}, {\"x\": 3.333333333333334, \"y\": -5.942028985507246, \"x2\": 3.6231884057971016, \"y2\": -5.6521739130434785, \"center_x\": 3.4782608695652177, \"center_y\": -5.797101449275362, \"value_uncond\": 7.112134742511759e-05}, {\"x\": 3.6231884057971016, \"y\": -5.942028985507246, \"x2\": 3.913043478260869, \"y2\": -5.6521739130434785, \"center_x\": 3.7681159420289854, \"center_y\": -5.797101449275362, \"value_uncond\": 7.232651005819936e-05}, {\"x\": 3.913043478260871, \"y\": -5.942028985507246, \"x2\": 4.202898550724639, \"y2\": -5.6521739130434785, \"center_x\": 4.057971014492755, \"center_y\": -5.797101449275362, \"value_uncond\": 7.28686725648786e-05}, {\"x\": 4.202898550724639, \"y\": -5.942028985507246, \"x2\": 4.492753623188406, \"y2\": -5.6521739130434785, \"center_x\": 4.347826086956522, \"center_y\": -5.797101449275362, \"value_uncond\": 7.273275211643228e-05}, {\"x\": 4.492753623188406, \"y\": -5.942028985507246, \"x2\": 4.782608695652174, \"y2\": -5.6521739130434785, \"center_x\": 4.63768115942029, \"center_y\": -5.797101449275362, \"value_uncond\": 7.192253702740012e-05}, {\"x\": 4.782608695652174, \"y\": -5.942028985507246, \"x2\": 5.0724637681159415, \"y2\": -5.6521739130434785, \"center_x\": 4.927536231884058, \"center_y\": -5.797101449275362, \"value_uncond\": 7.046051132351661e-05}, {\"x\": 5.072463768115943, \"y\": -5.942028985507246, \"x2\": 5.362318840579711, \"y2\": -5.6521739130434785, \"center_x\": 5.217391304347827, \"center_y\": -5.797101449275362, \"value_uncond\": 6.838681804450433e-05}, {\"x\": 5.362318840579711, \"y\": -5.942028985507246, \"x2\": 5.6521739130434785, \"y2\": -5.6521739130434785, \"center_x\": 5.507246376811595, \"center_y\": -5.797101449275362, \"value_uncond\": 6.575742799552855e-05}, {\"x\": 5.6521739130434785, \"y\": -5.942028985507246, \"x2\": 5.942028985507246, \"y2\": -5.6521739130434785, \"center_x\": 5.797101449275362, \"center_y\": -5.797101449275362, \"value_uncond\": 6.26416305336118e-05}, {\"x\": 5.942028985507246, \"y\": -5.942028985507246, \"x2\": 6.231884057971014, \"y2\": -5.6521739130434785, \"center_x\": 6.08695652173913, \"center_y\": -5.797101449275362, \"value_uncond\": 5.911900333454195e-05}, {\"x\": 6.2318840579710155, \"y\": -5.942028985507246, \"x2\": 6.521739130434783, \"y2\": -5.6521739130434785, \"center_x\": 6.376811594202899, \"center_y\": -5.797101449275362, \"value_uncond\": 5.5276045867132e-05}, {\"x\": 6.521739130434785, \"y\": -5.942028985507246, \"x2\": 6.8115942028985526, \"y2\": -5.6521739130434785, \"center_x\": 6.666666666666669, \"center_y\": -5.797101449275362, \"value_uncond\": 5.12026746682202e-05}, {\"x\": 6.811594202898551, \"y\": -5.942028985507246, \"x2\": 7.101449275362318, \"y2\": -5.6521739130434785, \"center_x\": 6.956521739130435, \"center_y\": -5.797101449275362, \"value_uncond\": 4.698877699526274e-05}, {\"x\": 7.10144927536232, \"y\": -5.942028985507246, \"x2\": 7.391304347826088, \"y2\": -5.6521739130434785, \"center_x\": 7.246376811594204, \"center_y\": -5.797101449275362, \"value_uncond\": 4.27210039220419e-05}, {\"x\": 7.391304347826086, \"y\": -5.942028985507246, \"x2\": 7.681159420289854, \"y2\": -5.6521739130434785, \"center_x\": 7.53623188405797, \"center_y\": -5.797101449275362, \"value_uncond\": 3.8479956524746164e-05}, {\"x\": 7.681159420289855, \"y\": -5.942028985507246, \"x2\": 7.971014492753623, \"y2\": -5.6521739130434785, \"center_x\": 7.826086956521739, \"center_y\": -5.797101449275362, \"value_uncond\": 3.43378824915426e-05}, {\"x\": 7.971014492753625, \"y\": -5.942028985507246, \"x2\": 8.260869565217392, \"y2\": -5.6521739130434785, \"center_x\": 8.115942028985508, \"center_y\": -5.797101449275362, \"value_uncond\": 3.035695885638976e-05}, {\"x\": 8.26086956521739, \"y\": -5.942028985507246, \"x2\": 8.550724637681158, \"y2\": -5.6521739130434785, \"center_x\": 8.405797101449274, \"center_y\": -5.797101449275362, \"value_uncond\": 2.658819336082033e-05}, {\"x\": 8.55072463768116, \"y\": -5.942028985507246, \"x2\": 8.840579710144928, \"y2\": -5.6521739130434785, \"center_x\": 8.695652173913043, \"center_y\": -5.797101449275362, \"value_uncond\": 2.3070935738087277e-05}, {\"x\": 8.84057971014493, \"y\": -5.942028985507246, \"x2\": 9.130434782608697, \"y2\": -5.6521739130434785, \"center_x\": 8.985507246376812, \"center_y\": -5.797101449275362, \"value_uncond\": 1.9832954021266523e-05}, {\"x\": 9.130434782608695, \"y\": -5.942028985507246, \"x2\": 9.420289855072463, \"y2\": -5.6521739130434785, \"center_x\": 9.275362318840578, \"center_y\": -5.797101449275362, \"value_uncond\": 1.6891002070181413e-05}, {\"x\": 9.420289855072465, \"y\": -5.942028985507246, \"x2\": 9.710144927536232, \"y2\": -5.6521739130434785, \"center_x\": 9.565217391304348, \"center_y\": -5.797101449275362, \"value_uncond\": 1.425178426980903e-05}, {\"x\": 9.710144927536234, \"y\": -5.942028985507246, \"x2\": 10.000000000000002, \"y2\": -5.6521739130434785, \"center_x\": 9.855072463768117, \"center_y\": -5.797101449275362, \"value_uncond\": 1.191321223800342e-05}, {\"x\": 10.0, \"y\": -5.942028985507246, \"x2\": 10.289855072463768, \"y2\": -5.6521739130434785, \"center_x\": 10.144927536231883, \"center_y\": -5.797101449275362, \"value_uncond\": 9.865846013036942e-06}, {\"x\": -10.0, \"y\": -5.6521739130434785, \"x2\": -9.710144927536232, \"y2\": -5.362318840579711, \"center_x\": -9.855072463768117, \"center_y\": -5.507246376811595, \"value_uncond\": 1.8653932740416187e-09}, {\"x\": -9.710144927536232, \"y\": -5.6521739130434785, \"x2\": -9.420289855072465, \"y2\": -5.362318840579711, \"center_x\": -9.565217391304348, \"center_y\": -5.507246376811595, \"value_uncond\": 2.9144759203172313e-09}, {\"x\": -9.420289855072463, \"y\": -5.6521739130434785, \"x2\": -9.130434782608695, \"y2\": -5.362318840579711, \"center_x\": -9.275362318840578, \"center_y\": -5.507246376811595, \"value_uncond\": 4.511244348477409e-09}, {\"x\": -9.130434782608695, \"y\": -5.6521739130434785, \"x2\": -8.840579710144928, \"y2\": -5.362318840579711, \"center_x\": -8.985507246376812, \"center_y\": -5.507246376811595, \"value_uncond\": 6.917959975784015e-09}, {\"x\": -8.840579710144928, \"y\": -5.6521739130434785, \"x2\": -8.55072463768116, \"y2\": -5.362318840579711, \"center_x\": -8.695652173913043, \"center_y\": -5.507246376811595, \"value_uncond\": 1.05100686710422e-08}, {\"x\": -8.55072463768116, \"y\": -5.6521739130434785, \"x2\": -8.260869565217392, \"y2\": -5.362318840579711, \"center_x\": -8.405797101449277, \"center_y\": -5.507246376811595, \"value_uncond\": 1.5818994562821986e-08}, {\"x\": -8.26086956521739, \"y\": -5.6521739130434785, \"x2\": -7.971014492753623, \"y2\": -5.362318840579711, \"center_x\": -8.115942028985508, \"center_y\": -5.507246376811595, \"value_uncond\": 2.358837451255229e-08}, {\"x\": -7.971014492753623, \"y\": -5.6521739130434785, \"x2\": -7.681159420289855, \"y2\": -5.362318840579711, \"center_x\": -7.826086956521739, \"center_y\": -5.507246376811595, \"value_uncond\": 3.484680512661137e-08}, {\"x\": -7.681159420289855, \"y\": -5.6521739130434785, \"x2\": -7.391304347826088, \"y2\": -5.362318840579711, \"center_x\": -7.536231884057972, \"center_y\": -5.507246376811595, \"value_uncond\": 5.100041774473357e-08}, {\"x\": -7.391304347826087, \"y\": -5.6521739130434785, \"x2\": -7.101449275362319, \"y2\": -5.362318840579711, \"center_x\": -7.246376811594203, \"center_y\": -5.507246376811595, \"value_uncond\": 7.394866102557714e-08}, {\"x\": -7.101449275362318, \"y\": -5.6521739130434785, \"x2\": -6.811594202898551, \"y2\": -5.362318840579711, \"center_x\": -6.956521739130435, \"center_y\": -5.507246376811595, \"value_uncond\": 1.062264604180127e-07}, {\"x\": -6.811594202898551, \"y\": -5.6521739130434785, \"x2\": -6.521739130434783, \"y2\": -5.362318840579711, \"center_x\": -6.666666666666667, \"center_y\": -5.507246376811595, \"value_uncond\": 1.5117532847811418e-07}, {\"x\": -6.521739130434782, \"y\": -5.6521739130434785, \"x2\": -6.231884057971015, \"y2\": -5.362318840579711, \"center_x\": -6.3768115942028984, \"center_y\": -5.507246376811595, \"value_uncond\": 2.131449001305415e-07}, {\"x\": -6.231884057971014, \"y\": -5.6521739130434785, \"x2\": -5.942028985507246, \"y2\": -5.362318840579711, \"center_x\": -6.08695652173913, \"center_y\": -5.507246376811595, \"value_uncond\": 2.977246444577404e-07}, {\"x\": -5.942028985507246, \"y\": -5.6521739130434785, \"x2\": -5.6521739130434785, \"y2\": -5.362318840579711, \"center_x\": -5.797101449275362, \"center_y\": -5.507246376811595, \"value_uncond\": 4.1200305780714903e-07}, {\"x\": -5.6521739130434785, \"y\": -5.6521739130434785, \"x2\": -5.362318840579711, \"y2\": -5.362318840579711, \"center_x\": -5.507246376811595, \"center_y\": -5.507246376811595, \"value_uncond\": 5.648484064106578e-07}, {\"x\": -5.36231884057971, \"y\": -5.6521739130434785, \"x2\": -5.072463768115942, \"y2\": -5.362318840579711, \"center_x\": -5.217391304347826, \"center_y\": -5.507246376811595, \"value_uncond\": 7.672010541786288e-07}, {\"x\": -5.0724637681159415, \"y\": -5.6521739130434785, \"x2\": -4.782608695652174, \"y2\": -5.362318840579711, \"center_x\": -4.927536231884058, \"center_y\": -5.507246376811595, \"value_uncond\": 1.032362661348308e-06}, {\"x\": -4.782608695652174, \"y\": -5.6521739130434785, \"x2\": -4.492753623188406, \"y2\": -5.362318840579711, \"center_x\": -4.63768115942029, \"center_y\": -5.507246376811595, \"value_uncond\": 1.3762622597178169e-06}, {\"x\": -4.492753623188405, \"y\": -5.6521739130434785, \"x2\": -4.202898550724638, \"y2\": -5.362318840579711, \"center_x\": -4.3478260869565215, \"center_y\": -5.507246376811595, \"value_uncond\": 1.81767371651618e-06}, {\"x\": -4.202898550724638, \"y\": -5.6521739130434785, \"x2\": -3.91304347826087, \"y2\": -5.362318840579711, \"center_x\": -4.057971014492754, \"center_y\": -5.507246376811595, \"value_uncond\": 2.3783538470920915e-06}, {\"x\": -3.913043478260869, \"y\": -5.6521739130434785, \"x2\": -3.6231884057971016, \"y2\": -5.362318840579711, \"center_x\": -3.7681159420289854, \"center_y\": -5.507246376811595, \"value_uncond\": 3.0830660178731517e-06}, {\"x\": -3.6231884057971016, \"y\": -5.6521739130434785, \"x2\": -3.333333333333334, \"y2\": -5.362318840579711, \"center_x\": -3.4782608695652177, \"center_y\": -5.507246376811595, \"value_uncond\": 3.959451200341003e-06}, {\"x\": -3.333333333333333, \"y\": -5.6521739130434785, \"x2\": -3.0434782608695654, \"y2\": -5.362318840579711, \"center_x\": -3.1884057971014492, \"center_y\": -5.507246376811595, \"value_uncond\": 5.037707868221586e-06}, {\"x\": -3.0434782608695645, \"y\": -5.6521739130434785, \"x2\": -2.753623188405797, \"y2\": -5.362318840579711, \"center_x\": -2.8985507246376807, \"center_y\": -5.507246376811595, \"value_uncond\": 6.350044649361683e-06}, {\"x\": -2.753623188405797, \"y\": -5.6521739130434785, \"x2\": -2.4637681159420293, \"y2\": -5.362318840579711, \"center_x\": -2.608695652173913, \"center_y\": -5.507246376811595, \"value_uncond\": 7.92987593862528e-06}, {\"x\": -2.4637681159420284, \"y\": -5.6521739130434785, \"x2\": -2.1739130434782608, \"y2\": -5.362318840579711, \"center_x\": -2.3188405797101446, \"center_y\": -5.507246376811595, \"value_uncond\": 9.810741242848559e-06}, {\"x\": -2.1739130434782608, \"y\": -5.6521739130434785, \"x2\": -1.8840579710144931, \"y2\": -5.362318840579711, \"center_x\": -2.028985507246377, \"center_y\": -5.507246376811595, \"value_uncond\": 1.2024944051824084e-05}, {\"x\": -1.8840579710144922, \"y\": -5.6521739130434785, \"x2\": -1.5942028985507246, \"y2\": -5.362318840579711, \"center_x\": -1.7391304347826084, \"center_y\": -5.507246376811595, \"value_uncond\": 1.4601925287135904e-05}, {\"x\": -1.5942028985507246, \"y\": -5.6521739130434785, \"x2\": -1.304347826086957, \"y2\": -5.362318840579711, \"center_x\": -1.4492753623188408, \"center_y\": -5.507246376811595, \"value_uncond\": 1.7566409155196697e-05}, {\"x\": -1.304347826086957, \"y\": -5.6521739130434785, \"x2\": -1.0144927536231894, \"y2\": -5.362318840579711, \"center_x\": -1.1594202898550732, \"center_y\": -5.507246376811595, \"value_uncond\": 2.0936384265295586e-05}, {\"x\": -1.0144927536231876, \"y\": -5.6521739130434785, \"x2\": -0.72463768115942, \"y2\": -5.362318840579711, \"center_x\": -0.8695652173913038, \"center_y\": -5.507246376811595, \"value_uncond\": 2.4721008384454473e-05}, {\"x\": -0.72463768115942, \"y\": -5.6521739130434785, \"x2\": -0.43478260869565233, \"y2\": -5.362318840579711, \"center_x\": -0.5797101449275361, \"center_y\": -5.507246376811595, \"value_uncond\": 2.8918548957470345e-05}, {\"x\": -0.43478260869565233, \"y\": -5.6521739130434785, \"x2\": -0.1449275362318847, \"y2\": -5.362318840579711, \"center_x\": -0.2898550724637685, \"center_y\": -5.507246376811595, \"value_uncond\": 3.3514490995420406e-05}, {\"x\": -0.14492753623188293, \"y\": -5.6521739130434785, \"x2\": 0.1449275362318847, \"y2\": -5.362318840579711, \"center_x\": 8.881784197001252e-16, \"center_y\": -5.507246376811595, \"value_uncond\": 3.8479956524746164e-05}, {\"x\": 0.1449275362318847, \"y\": -5.6521739130434785, \"x2\": 0.43478260869565233, \"y2\": -5.362318840579711, \"center_x\": 0.2898550724637685, \"center_y\": -5.507246376811595, \"value_uncond\": 4.37705830828896e-05}, {\"x\": 0.43478260869565233, \"y\": -5.6521739130434785, \"x2\": 0.72463768115942, \"y2\": -5.362318840579711, \"center_x\": 0.5797101449275361, \"center_y\": -5.507246376811595, \"value_uncond\": 4.932600083272101e-05}, {\"x\": 0.72463768115942, \"y\": -5.6521739130434785, \"x2\": 1.0144927536231876, \"y2\": -5.362318840579711, \"center_x\": 0.8695652173913038, \"center_y\": -5.507246376811595, \"value_uncond\": 5.507002762581109e-05}, {\"x\": 1.0144927536231894, \"y\": -5.6521739130434785, \"x2\": 1.304347826086957, \"y2\": -5.362318840579711, \"center_x\": 1.1594202898550732, \"center_y\": -5.507246376811595, \"value_uncond\": 6.09116686958249e-05}, {\"x\": 1.304347826086957, \"y\": -5.6521739130434785, \"x2\": 1.5942028985507246, \"y2\": -5.362318840579711, \"center_x\": 1.4492753623188408, \"center_y\": -5.507246376811595, \"value_uncond\": 6.674696373961032e-05}, {\"x\": 1.5942028985507246, \"y\": -5.6521739130434785, \"x2\": 1.8840579710144922, \"y2\": -5.362318840579711, \"center_x\": 1.7391304347826084, \"center_y\": -5.507246376811595, \"value_uncond\": 7.246167133555524e-05}, {\"x\": 1.884057971014494, \"y\": -5.6521739130434785, \"x2\": 2.1739130434782616, \"y2\": -5.362318840579711, \"center_x\": 2.028985507246378, \"center_y\": -5.507246376811595, \"value_uncond\": 7.793472251437328e-05}, {\"x\": 2.1739130434782616, \"y\": -5.6521739130434785, \"x2\": 2.4637681159420293, \"y2\": -5.362318840579711, \"center_x\": 2.3188405797101455, \"center_y\": -5.507246376811595, \"value_uncond\": 8.304231632240589e-05}, {\"x\": 2.4637681159420293, \"y\": -5.6521739130434785, \"x2\": 2.753623188405797, \"y2\": -5.362318840579711, \"center_x\": 2.608695652173913, \"center_y\": -5.507246376811595, \"value_uncond\": 8.766247544071558e-05}, {\"x\": 2.753623188405797, \"y\": -5.6521739130434785, \"x2\": 3.0434782608695645, \"y2\": -5.362318840579711, \"center_x\": 2.8985507246376807, \"center_y\": -5.507246376811595, \"value_uncond\": 9.167983445879034e-05}, {\"x\": 3.0434782608695663, \"y\": -5.6521739130434785, \"x2\": 3.333333333333334, \"y2\": -5.362318840579711, \"center_x\": 3.18840579710145, \"center_y\": -5.507246376811595, \"value_uncond\": 9.499040190688058e-05}, {\"x\": 3.333333333333334, \"y\": -5.6521739130434785, \"x2\": 3.6231884057971016, \"y2\": -5.362318840579711, \"center_x\": 3.4782608695652177, \"center_y\": -5.507246376811595, \"value_uncond\": 9.75060233015565e-05}, {\"x\": 3.6231884057971016, \"y\": -5.6521739130434785, \"x2\": 3.913043478260869, \"y2\": -5.362318840579711, \"center_x\": 3.7681159420289854, \"center_y\": -5.507246376811595, \"value_uncond\": 9.91582784969064e-05}, {\"x\": 3.913043478260871, \"y\": -5.6521739130434785, \"x2\": 4.202898550724639, \"y2\": -5.362318840579711, \"center_x\": 4.057971014492755, \"center_y\": -5.507246376811595, \"value_uncond\": 9.990157304802774e-05}, {\"x\": 4.202898550724639, \"y\": -5.6521739130434785, \"x2\": 4.492753623188406, \"y2\": -5.362318840579711, \"center_x\": 4.347826086956522, \"center_y\": -5.507246376811595, \"value_uncond\": 9.971522868176951e-05}, {\"x\": 4.492753623188406, \"y\": -5.6521739130434785, \"x2\": 4.782608695652174, \"y2\": -5.362318840579711, \"center_x\": 4.63768115942029, \"center_y\": -5.507246376811595, \"value_uncond\": 9.860443910577588e-05}, {\"x\": 4.782608695652174, \"y\": -5.6521739130434785, \"x2\": 5.0724637681159415, \"y2\": -5.362318840579711, \"center_x\": 4.927536231884058, \"center_y\": -5.507246376811595, \"value_uncond\": 9.66000294944361e-05}, {\"x\": 5.072463768115943, \"y\": -5.6521739130434785, \"x2\": 5.362318840579711, \"y2\": -5.362318840579711, \"center_x\": 5.217391304347827, \"center_y\": -5.507246376811595, \"value_uncond\": 9.37570351966053e-05}, {\"x\": 5.362318840579711, \"y\": -5.6521739130434785, \"x2\": 5.6521739130434785, \"y2\": -5.362318840579711, \"center_x\": 5.507246376811595, \"center_y\": -5.507246376811595, \"value_uncond\": 9.01521911284547e-05}, {\"x\": 5.6521739130434785, \"y\": -5.6521739130434785, \"x2\": 5.942028985507246, \"y2\": -5.362318840579711, \"center_x\": 5.797101449275362, \"center_y\": -5.507246376811595, \"value_uncond\": 8.588049168906403e-05}, {\"x\": 5.942028985507246, \"y\": -5.6521739130434785, \"x2\": 6.231884057971014, \"y2\": -5.362318840579711, \"center_x\": 6.08695652173913, \"center_y\": -5.507246376811595, \"value_uncond\": 8.105103636811636e-05}, {\"x\": 6.2318840579710155, \"y\": -5.6521739130434785, \"x2\": 6.521739130434783, \"y2\": -5.362318840579711, \"center_x\": 6.376811594202899, \"center_y\": -5.507246376811595, \"value_uncond\": 7.578241430272746e-05}, {\"x\": 6.521739130434785, \"y\": -5.6521739130434785, \"x2\": 6.8115942028985526, \"y2\": -5.362318840579711, \"center_x\": 6.666666666666669, \"center_y\": -5.507246376811595, \"value_uncond\": 7.019789936570147e-05}, {\"x\": 6.811594202898551, \"y\": -5.6521739130434785, \"x2\": 7.101449275362318, \"y2\": -5.362318840579711, \"center_x\": 6.956521739130435, \"center_y\": -5.507246376811595, \"value_uncond\": 6.44207252883631e-05}, {\"x\": 7.10144927536232, \"y\": -5.6521739130434785, \"x2\": 7.391304347826088, \"y2\": -5.362318840579711, \"center_x\": 7.246376811594204, \"center_y\": -5.507246376811595, \"value_uncond\": 5.856968905537602e-05}, {\"x\": 7.391304347826086, \"y\": -5.6521739130434785, \"x2\": 7.681159420289854, \"y2\": -5.362318840579711, \"center_x\": 7.53623188405797, \"center_y\": -5.507246376811595, \"value_uncond\": 5.275529321903279e-05}, {\"x\": 7.681159420289855, \"y\": -5.6521739130434785, \"x2\": 7.971014492753623, \"y2\": -5.362318840579711, \"center_x\": 7.826086956521739, \"center_y\": -5.507246376811595, \"value_uncond\": 4.707658799450714e-05}, {\"x\": 7.971014492753625, \"y\": -5.6521739130434785, \"x2\": 8.260869565217392, \"y2\": -5.362318840579711, \"center_x\": 8.115942028985508, \"center_y\": -5.507246376811595, \"value_uncond\": 4.161881692036346e-05}, {\"x\": 8.26086956521739, \"y\": -5.6521739130434785, \"x2\": 8.550724637681158, \"y2\": -5.362318840579711, \"center_x\": 8.405797101449274, \"center_y\": -5.507246376811595, \"value_uncond\": 3.645191064632239e-05}, {\"x\": 8.55072463768116, \"y\": -5.6521739130434785, \"x2\": 8.840579710144928, \"y2\": -5.362318840579711, \"center_x\": 8.695652173913043, \"center_y\": -5.507246376811595, \"value_uncond\": 3.1629816913060714e-05}, {\"x\": 8.84057971014493, \"y\": -5.6521739130434785, \"x2\": 9.130434782608697, \"y2\": -5.362318840579711, \"center_x\": 8.985507246376812, \"center_y\": -5.507246376811595, \"value_uncond\": 2.719060516917808e-05}, {\"x\": 9.130434782608695, \"y\": -5.6521739130434785, \"x2\": 9.420289855072463, \"y2\": -5.362318840579711, \"center_x\": 9.275362318840578, \"center_y\": -5.507246376811595, \"value_uncond\": 2.315724463988563e-05}, {\"x\": 9.420289855072465, \"y\": -5.6521739130434785, \"x2\": 9.710144927536232, \"y2\": -5.362318840579711, \"center_x\": 9.565217391304348, \"center_y\": -5.507246376811595, \"value_uncond\": 1.9538926910290582e-05}, {\"x\": 9.710144927536234, \"y\": -5.6521739130434785, \"x2\": 10.000000000000002, \"y2\": -5.362318840579711, \"center_x\": 9.855072463768117, \"center_y\": -5.507246376811595, \"value_uncond\": 1.6332788847936102e-05}, {\"x\": 10.0, \"y\": -5.6521739130434785, \"x2\": 10.289855072463768, \"y2\": -5.362318840579711, \"center_x\": 10.144927536231883, \"center_y\": -5.507246376811595, \"value_uncond\": 1.3525888443685628e-05}, {\"x\": -10.0, \"y\": -5.36231884057971, \"x2\": -9.710144927536232, \"y2\": -5.072463768115942, \"center_x\": -9.855072463768117, \"center_y\": -5.217391304347826, \"value_uncond\": 2.5336562342392283e-09}, {\"x\": -9.710144927536232, \"y\": -5.36231884057971, \"x2\": -9.420289855072465, \"y2\": -5.072463768115942, \"center_x\": -9.565217391304348, \"center_y\": -5.217391304347826, \"value_uncond\": 3.958564763693418e-09}, {\"x\": -9.420289855072463, \"y\": -5.36231884057971, \"x2\": -9.130434782608695, \"y2\": -5.072463768115942, \"center_x\": -9.275362318840578, \"center_y\": -5.217391304347826, \"value_uncond\": 6.127363343029421e-09}, {\"x\": -9.130434782608695, \"y\": -5.36231884057971, \"x2\": -8.840579710144928, \"y2\": -5.072463768115942, \"center_x\": -8.985507246376812, \"center_y\": -5.217391304347826, \"value_uncond\": 9.396266548601021e-09}, {\"x\": -8.840579710144928, \"y\": -5.36231884057971, \"x2\": -8.55072463768116, \"y2\": -5.072463768115942, \"center_x\": -8.695652173913043, \"center_y\": -5.217391304347826, \"value_uncond\": 1.4275220877672309e-08}, {\"x\": -8.55072463768116, \"y\": -5.36231884057971, \"x2\": -8.260869565217392, \"y2\": -5.072463768115942, \"center_x\": -8.405797101449277, \"center_y\": -5.217391304347826, \"value_uncond\": 2.1486029113127425e-08}, {\"x\": -8.26086956521739, \"y\": -5.36231884057971, \"x2\": -7.971014492753623, \"y2\": -5.072463768115942, \"center_x\": -8.115942028985508, \"center_y\": -5.217391304347826, \"value_uncond\": 3.203873036907085e-08}, {\"x\": -7.971014492753623, \"y\": -5.36231884057971, \"x2\": -7.681159420289855, \"y2\": -5.072463768115942, \"center_x\": -7.826086956521739, \"center_y\": -5.217391304347826, \"value_uncond\": 4.7330408166995674e-08}, {\"x\": -7.681159420289855, \"y\": -5.36231884057971, \"x2\": -7.391304347826088, \"y2\": -5.072463768115942, \"center_x\": -7.536231884057972, \"center_y\": -5.217391304347826, \"value_uncond\": 6.92709297100564e-08}, {\"x\": -7.391304347826087, \"y\": -5.36231884057971, \"x2\": -7.101449275362319, \"y2\": -5.072463768115942, \"center_x\": -7.246376811594203, \"center_y\": -5.217391304347826, \"value_uncond\": 1.0044020669976769e-07}, {\"x\": -7.101449275362318, \"y\": -5.36231884057971, \"x2\": -6.811594202898551, \"y2\": -5.072463768115942, \"center_x\": -6.956521739130435, \"center_y\": -5.217391304347826, \"value_uncond\": 1.442812823572233e-07}, {\"x\": -6.811594202898551, \"y\": -5.36231884057971, \"x2\": -6.521739130434783, \"y2\": -5.072463768115942, \"center_x\": -6.666666666666667, \"center_y\": -5.217391304347826, \"value_uncond\": 2.053327407104132e-07}, {\"x\": -6.521739130434782, \"y\": -5.36231884057971, \"x2\": -6.231884057971015, \"y2\": -5.072463768115942, \"center_x\": -6.3768115942028984, \"center_y\": -5.217391304347826, \"value_uncond\": 2.895024403309789e-07}, {\"x\": -6.231884057971014, \"y\": -5.36231884057971, \"x2\": -5.942028985507246, \"y2\": -5.072463768115942, \"center_x\": -6.08695652173913, \"center_y\": -5.217391304347826, \"value_uncond\": 4.0438223511048235e-07}, {\"x\": -5.942028985507246, \"y\": -5.36231884057971, \"x2\": -5.6521739130434785, \"y2\": -5.072463768115942, \"center_x\": -5.797101449275362, \"center_y\": -5.217391304347826, \"value_uncond\": 5.596000213279511e-07}, {\"x\": -5.6521739130434785, \"y\": -5.36231884057971, \"x2\": -5.362318840579711, \"y2\": -5.072463768115942, \"center_x\": -5.507246376811595, \"center_y\": -5.217391304347826, \"value_uncond\": 7.672010541786288e-07}, {\"x\": -5.36231884057971, \"y\": -5.36231884057971, \"x2\": -5.072463768115942, \"y2\": -5.072463768115942, \"center_x\": -5.217391304347826, \"center_y\": -5.217391304347826, \"value_uncond\": 1.0420449997780032e-06}, {\"x\": -5.0724637681159415, \"y\": -5.36231884057971, \"x2\": -4.782608695652174, \"y2\": -5.072463768115942, \"center_x\": -4.927536231884058, \"center_y\": -5.217391304347826, \"value_uncond\": 1.4021987370275998e-06}, {\"x\": -4.782608695652174, \"y\": -5.36231884057971, \"x2\": -4.492753623188406, \"y2\": -5.072463768115942, \"center_x\": -4.63768115942029, \"center_y\": -5.217391304347826, \"value_uncond\": 1.8692977522789173e-06}, {\"x\": -4.492753623188405, \"y\": -5.36231884057971, \"x2\": -4.202898550724638, \"y2\": -5.072463768115942, \"center_x\": -4.3478260869565215, \"center_y\": -5.217391304347826, \"value_uncond\": 2.4688415079817903e-06}, {\"x\": -4.202898550724638, \"y\": -5.36231884057971, \"x2\": -3.91304347826087, \"y2\": -5.072463768115942, \"center_x\": -4.057971014492754, \"center_y\": -5.217391304347826, \"value_uncond\": 3.230381033194009e-06}, {\"x\": -3.913043478260869, \"y\": -5.36231884057971, \"x2\": -3.6231884057971016, \"y2\": -5.072463768115942, \"center_x\": -3.7681159420289854, \"center_y\": -5.217391304347826, \"value_uncond\": 4.187550982121279e-06}, {\"x\": -3.6231884057971016, \"y\": -5.36231884057971, \"x2\": -3.333333333333334, \"y2\": -5.072463768115942, \"center_x\": -3.4782608695652177, \"center_y\": -5.217391304347826, \"value_uncond\": 5.377894494159164e-06}, {\"x\": -3.333333333333333, \"y\": -5.36231884057971, \"x2\": -3.0434782608695654, \"y2\": -5.072463768115942, \"center_x\": -3.1884057971014492, \"center_y\": -5.217391304347826, \"value_uncond\": 6.842428416685089e-06}, {\"x\": -3.0434782608695645, \"y\": -5.36231884057971, \"x2\": -2.753623188405797, \"y2\": -5.072463768115942, \"center_x\": -2.8985507246376807, \"center_y\": -5.217391304347826, \"value_uncond\": 8.624899873630453e-06}, {\"x\": -2.753623188405797, \"y\": -5.36231884057971, \"x2\": -2.4637681159420293, \"y2\": -5.072463768115942, \"center_x\": -2.608695652173913, \"center_y\": -5.217391304347826, \"value_uncond\": 1.077069371281184e-05}, {\"x\": -2.4637681159420284, \"y\": -5.36231884057971, \"x2\": -2.1739130434782608, \"y2\": -5.072463768115942, \"center_x\": -2.3188405797101446, \"center_y\": -5.217391304347826, \"value_uncond\": 1.3325364714431008e-05}, {\"x\": -2.1739130434782608, \"y\": -5.36231884057971, \"x2\": -1.8840579710144931, \"y2\": -5.072463768115942, \"center_x\": -2.028985507246377, \"center_y\": -5.217391304347826, \"value_uncond\": 1.6332788847936102e-05}, {\"x\": -1.8840579710144922, \"y\": -5.36231884057971, \"x2\": -1.5942028985507246, \"y2\": -5.072463768115942, \"center_x\": -1.7391304347826084, \"center_y\": -5.217391304347826, \"value_uncond\": 1.9832954021266523e-05}, {\"x\": -1.5942028985507246, \"y\": -5.36231884057971, \"x2\": -1.304347826086957, \"y2\": -5.072463768115942, \"center_x\": -1.4492753623188408, \"center_y\": -5.217391304347826, \"value_uncond\": 2.38594416998354e-05}, {\"x\": -1.304347826086957, \"y\": -5.36231884057971, \"x2\": -1.0144927536231894, \"y2\": -5.072463768115942, \"center_x\": -1.1594202898550732, \"center_y\": -5.217391304347826, \"value_uncond\": 2.8436684775465024e-05}, {\"x\": -1.0144927536231876, \"y\": -5.36231884057971, \"x2\": -0.72463768115942, \"y2\": -5.072463768115942, \"center_x\": -0.8695652173913038, \"center_y\": -5.217391304347826, \"value_uncond\": 3.3577121715597955e-05}, {\"x\": -0.72463768115942, \"y\": -5.36231884057971, \"x2\": -0.43478260869565233, \"y2\": -5.072463768115942, \"center_x\": -0.5797101449275361, \"center_y\": -5.217391304347826, \"value_uncond\": 3.927839929030012e-05}, {\"x\": -0.43478260869565233, \"y\": -5.36231884057971, \"x2\": -0.1449275362318847, \"y2\": -5.072463768115942, \"center_x\": -0.2898550724637685, \"center_y\": -5.217391304347826, \"value_uncond\": 4.5520802626206266e-05}, {\"x\": -0.14492753623188293, \"y\": -5.36231884057971, \"x2\": 0.1449275362318847, \"y2\": -5.072463768115942, \"center_x\": 8.881784197001252e-16, \"center_y\": -5.217391304347826, \"value_uncond\": 5.226510843525332e-05}, {\"x\": 0.1449275362318847, \"y\": -5.36231884057971, \"x2\": 0.43478260869565233, \"y2\": -5.072463768115942, \"center_x\": 0.2898550724637685, \"center_y\": -5.217391304347826, \"value_uncond\": 5.9451061739903565e-05}, {\"x\": 0.43478260869565233, \"y\": -5.36231884057971, \"x2\": 0.72463768115942, \"y2\": -5.072463768115942, \"center_x\": 0.5797101449275361, \"center_y\": -5.217391304347826, \"value_uncond\": 6.699666566779119e-05}, {\"x\": 0.72463768115942, \"y\": -5.36231884057971, \"x2\": 1.0144927536231876, \"y2\": -5.072463768115942, \"center_x\": 0.8695652173913038, \"center_y\": -5.217391304347826, \"value_uncond\": 7.47984463949287e-05}, {\"x\": 1.0144927536231894, \"y\": -5.36231884057971, \"x2\": 1.304347826086957, \"y2\": -5.072463768115942, \"center_x\": 1.1594202898550732, \"center_y\": -5.217391304347826, \"value_uncond\": 8.273281097165984e-05}, {\"x\": 1.304347826086957, \"y\": -5.36231884057971, \"x2\": 1.5942028985507246, \"y2\": -5.072463768115942, \"center_x\": 1.4492753623188408, \"center_y\": -5.217391304347826, \"value_uncond\": 9.065855610650711e-05}, {\"x\": 1.5942028985507246, \"y\": -5.36231884057971, \"x2\": 1.8840579710144922, \"y2\": -5.072463768115942, \"center_x\": 1.7391304347826084, \"center_y\": -5.217391304347826, \"value_uncond\": 9.8420514256999e-05}, {\"x\": 1.884057971014494, \"y\": -5.36231884057971, \"x2\": 2.1739130434782616, \"y2\": -5.072463768115942, \"center_x\": 2.028985507246378, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00010585424441593667}, {\"x\": 2.1739130434782616, \"y\": -5.36231884057971, \"x2\": 2.4637681159420293, \"y2\": -5.072463768115942, \"center_x\": 2.3188405797101455, \"center_y\": -5.217391304347826, \"value_uncond\": 0.0001127915948791156}, {\"x\": 2.4637681159420293, \"y\": -5.36231884057971, \"x2\": 2.753623188405797, \"y2\": -5.072463768115942, \"center_x\": 2.608695652173913, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00011906689088032833}, {\"x\": 2.753623188405797, \"y\": -5.36231884057971, \"x2\": 3.0434782608695645, \"y2\": -5.072463768115942, \"center_x\": 2.8985507246376807, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00012452343822772443}, {\"x\": 3.0434782608695663, \"y\": -5.36231884057971, \"x2\": 3.333333333333334, \"y2\": -5.072463768115942, \"center_x\": 3.18840579710145, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00012901999129803215}, {\"x\": 3.333333333333334, \"y\": -5.36231884057971, \"x2\": 3.6231884057971016, \"y2\": -5.072463768115942, \"center_x\": 3.4782608695652177, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00013243681493426023}, {\"x\": 3.6231884057971016, \"y\": -5.36231884057971, \"x2\": 3.913043478260869, \"y2\": -5.072463768115942, \"center_x\": 3.7681159420289854, \"center_y\": -5.217391304347826, \"value_uncond\": 0.0001346809779933359}, {\"x\": 3.913043478260871, \"y\": -5.36231884057971, \"x2\": 4.202898550724639, \"y2\": -5.072463768115942, \"center_x\": 4.057971014492755, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00013569055216706725}, {\"x\": 4.202898550724639, \"y\": -5.36231884057971, \"x2\": 4.492753623188406, \"y2\": -5.072463768115942, \"center_x\": 4.347826086956522, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00013543745134813776}, {\"x\": 4.492753623188406, \"y\": -5.36231884057971, \"x2\": 4.782608695652174, \"y2\": -5.072463768115942, \"center_x\": 4.63768115942029, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00013392872985047388}, {\"x\": 4.782608695652174, \"y\": -5.36231884057971, \"x2\": 5.0724637681159415, \"y2\": -5.072463768115942, \"center_x\": 4.927536231884058, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00013120625573286498}, {\"x\": 5.072463768115943, \"y\": -5.36231884057971, \"x2\": 5.362318840579711, \"y2\": -5.072463768115942, \"center_x\": 5.217391304347827, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00012734478033952931}, {\"x\": 5.362318840579711, \"y\": -5.36231884057971, \"x2\": 5.6521739130434785, \"y2\": -5.072463768115942, \"center_x\": 5.507246376811595, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00012244852828703783}, {\"x\": 5.6521739130434785, \"y\": -5.36231884057971, \"x2\": 5.942028985507246, \"y2\": -5.072463768115942, \"center_x\": 5.797101449275362, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00011664652499581822}, {\"x\": 5.942028985507246, \"y\": -5.36231884057971, \"x2\": 6.231884057971014, \"y2\": -5.072463768115942, \"center_x\": 6.08695652173913, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00011008695401838697}, {\"x\": 6.2318840579710155, \"y\": -5.36231884057971, \"x2\": 6.521739130434783, \"y2\": -5.072463768115942, \"center_x\": 6.376811594202899, \"center_y\": -5.217391304347826, \"value_uncond\": 0.00010293088814874822}, {\"x\": 6.521739130434785, \"y\": -5.36231884057971, \"x2\": 6.8115942028985526, \"y2\": -5.072463768115942, \"center_x\": 6.666666666666669, \"center_y\": -5.217391304347826, \"value_uncond\": 9.534576318754272e-05}, {\"x\": 6.811594202898551, \"y\": -5.36231884057971, \"x2\": 7.101449275362318, \"y2\": -5.072463768115942, \"center_x\": 6.956521739130435, \"center_y\": -5.217391304347826, \"value_uncond\": 8.74989604135519e-05}, {\"x\": 7.10144927536232, \"y\": -5.36231884057971, \"x2\": 7.391304347826088, \"y2\": -5.072463768115942, \"center_x\": 7.246376811594204, \"center_y\": -5.217391304347826, \"value_uncond\": 7.955183492813184e-05}, {\"x\": 7.391304347826086, \"y\": -5.36231884057971, \"x2\": 7.681159420289854, \"y2\": -5.072463768115942, \"center_x\": 7.53623188405797, \"center_y\": -5.217391304347826, \"value_uncond\": 7.165447598292267e-05}, {\"x\": 7.681159420289855, \"y\": -5.36231884057971, \"x2\": 7.971014492753623, \"y2\": -5.072463768115942, \"center_x\": 7.826086956521739, \"center_y\": -5.217391304347826, \"value_uncond\": 6.394141777973048e-05}, {\"x\": 7.971014492753625, \"y\": -5.36231884057971, \"x2\": 8.260869565217392, \"y2\": -5.072463768115942, \"center_x\": 8.115942028985508, \"center_y\": -5.217391304347826, \"value_uncond\": 5.652844170681143e-05}, {\"x\": 8.26086956521739, \"y\": -5.36231884057971, \"x2\": 8.550724637681158, \"y2\": -5.072463768115942, \"center_x\": 8.405797101449274, \"center_y\": -5.217391304347826, \"value_uncond\": 4.9510530537554236e-05}, {\"x\": 8.55072463768116, \"y\": -5.36231884057971, \"x2\": 8.840579710144928, \"y2\": -5.072463768115942, \"center_x\": 8.695652173913043, \"center_y\": -5.217391304347826, \"value_uncond\": 4.296095838063664e-05}, {\"x\": 8.84057971014493, \"y\": -5.36231884057971, \"x2\": 9.130434782608697, \"y2\": -5.072463768115942, \"center_x\": 8.985507246376812, \"center_y\": -5.217391304347826, \"value_uncond\": 3.6931432775225205e-05}, {\"x\": 9.130434782608695, \"y\": -5.36231884057971, \"x2\": 9.420289855072463, \"y2\": -5.072463768115942, \"center_x\": 9.275362318840578, \"center_y\": -5.217391304347826, \"value_uncond\": 3.1453151496856975e-05}, {\"x\": 9.420289855072465, \"y\": -5.36231884057971, \"x2\": 9.710144927536232, \"y2\": -5.072463768115942, \"center_x\": 9.565217391304348, \"center_y\": -5.217391304347826, \"value_uncond\": 2.6538598946131802e-05}, {\"x\": 9.710144927536234, \"y\": -5.36231884057971, \"x2\": 10.000000000000002, \"y2\": -5.072463768115942, \"center_x\": 9.855072463768117, \"center_y\": -5.217391304347826, \"value_uncond\": 2.2183886295154995e-05}, {\"x\": 10.0, \"y\": -5.36231884057971, \"x2\": 10.289855072463768, \"y2\": -5.072463768115942, \"center_x\": 10.144927536231883, \"center_y\": -5.217391304347826, \"value_uncond\": 1.837143515839854e-05}, {\"x\": -10.0, \"y\": -5.0724637681159415, \"x2\": -9.710144927536232, \"y2\": -4.782608695652174, \"center_x\": -9.855072463768117, \"center_y\": -4.927536231884058, \"value_uncond\": 3.4093437159328184e-09}, {\"x\": -9.710144927536232, \"y\": -5.0724637681159415, \"x2\": -9.420289855072465, \"y2\": -4.782608695652174, \"center_x\": -9.565217391304348, \"center_y\": -4.927536231884058, \"value_uncond\": 5.326732063658852e-09}, {\"x\": -9.420289855072463, \"y\": -5.0724637681159415, \"x2\": -9.130434782608695, \"y2\": -4.782608695652174, \"center_x\": -9.275362318840578, \"center_y\": -4.927536231884058, \"value_uncond\": 8.245115271159551e-09}, {\"x\": -9.130434782608695, \"y\": -5.0724637681159415, \"x2\": -8.840579710144928, \"y2\": -4.782608695652174, \"center_x\": -8.985507246376812, \"center_y\": -4.927536231884058, \"value_uncond\": 1.2643823529722732e-08}, {\"x\": -8.840579710144928, \"y\": -5.0724637681159415, \"x2\": -8.55072463768116, \"y2\": -4.782608695652174, \"center_x\": -8.695652173913043, \"center_y\": -4.927536231884058, \"value_uncond\": 1.9209052094416735e-08}, {\"x\": -8.55072463768116, \"y\": -5.0724637681159415, \"x2\": -8.260869565217392, \"y2\": -4.782608695652174, \"center_x\": -8.405797101449277, \"center_y\": -4.927536231884058, \"value_uncond\": 2.8912074711345388e-08}, {\"x\": -8.26086956521739, \"y\": -5.0724637681159415, \"x2\": -7.971014492753623, \"y2\": -4.782608695652174, \"center_x\": -8.115942028985508, \"center_y\": -4.927536231884058, \"value_uncond\": 4.311202229179132e-08}, {\"x\": -7.971014492753623, \"y\": -5.0724637681159415, \"x2\": -7.681159420289855, \"y2\": -4.782608695652174, \"center_x\": -7.826086956521739, \"center_y\": -4.927536231884058, \"value_uncond\": 6.368884123900681e-08}, {\"x\": -7.681159420289855, \"y\": -5.0724637681159415, \"x2\": -7.391304347826088, \"y2\": -4.782608695652174, \"center_x\": -7.536231884057972, \"center_y\": -4.927536231884058, \"value_uncond\": 9.321249098921986e-08}, {\"x\": -7.391304347826087, \"y\": -5.0724637681159415, \"x2\": -7.101449275362319, \"y2\": -4.782608695652174, \"center_x\": -7.246376811594203, \"center_y\": -4.927536231884058, \"value_uncond\": 1.3515455763542766e-07}, {\"x\": -7.101449275362318, \"y\": -5.0724637681159415, \"x2\": -6.811594202898551, \"y2\": -4.782608695652174, \"center_x\": -6.956521739130435, \"center_y\": -4.927536231884058, \"value_uncond\": 1.9414807608224334e-07}, {\"x\": -6.811594202898551, \"y\": -5.0724637681159415, \"x2\": -6.521739130434783, \"y2\": -4.782608695652174, \"center_x\": -6.666666666666667, \"center_y\": -4.927536231884058, \"value_uncond\": 2.763002651093713e-07}, {\"x\": -6.521739130434782, \"y\": -5.0724637681159415, \"x2\": -6.231884057971015, \"y2\": -4.782608695652174, \"center_x\": -6.3768115942028984, \"center_y\": -4.927536231884058, \"value_uncond\": 3.8956086952577673e-07}, {\"x\": -6.231884057971014, \"y\": -5.0724637681159415, \"x2\": -5.942028985507246, \"y2\": -4.782608695652174, \"center_x\": -6.08695652173913, \"center_y\": -4.927536231884058, \"value_uncond\": 5.441456553883133e-07}, {\"x\": -5.942028985507246, \"y\": -5.0724637681159415, \"x2\": -5.6521739130434785, \"y2\": -4.782608695652174, \"center_x\": -5.797101449275362, \"center_y\": -4.927536231884058, \"value_uncond\": 7.530101323012316e-07}, {\"x\": -5.6521739130434785, \"y\": -5.0724637681159415, \"x2\": -5.362318840579711, \"y2\": -4.782608695652174, \"center_x\": -5.507246376811595, \"center_y\": -4.927536231884058, \"value_uncond\": 1.032362661348308e-06}, {\"x\": -5.36231884057971, \"y\": -5.0724637681159415, \"x2\": -5.072463768115942, \"y2\": -4.782608695652174, \"center_x\": -5.217391304347826, \"center_y\": -4.927536231884058, \"value_uncond\": 1.4021987370275998e-06}, {\"x\": -5.0724637681159415, \"y\": -5.0724637681159415, \"x2\": -4.782608695652174, \"y2\": -4.782608695652174, \"center_x\": -4.927536231884058, \"center_y\": -4.927536231884058, \"value_uncond\": 1.886829550106441e-06}, {\"x\": -4.782608695652174, \"y\": -5.0724637681159415, \"x2\": -4.492753623188406, \"y2\": -4.782608695652174, \"center_x\": -4.63768115942029, \"center_y\": -4.927536231884058, \"value_uncond\": 2.5153682882528417e-06}, {\"x\": -4.492753623188405, \"y\": -5.0724637681159415, \"x2\": -4.202898550724638, \"y2\": -4.782608695652174, \"center_x\": -4.3478260869565215, \"center_y\": -4.927536231884058, \"value_uncond\": 3.3221275906039403e-06}, {\"x\": -4.202898550724638, \"y\": -5.0724637681159415, \"x2\": -3.91304347826087, \"y2\": -4.782608695652174, \"center_x\": -4.057971014492754, \"center_y\": -4.927536231884058, \"value_uncond\": 4.346871973693597e-06}, {\"x\": -3.913043478260869, \"y\": -5.0724637681159415, \"x2\": -3.6231884057971016, \"y2\": -4.782608695652174, \"center_x\": -3.7681159420289854, \"center_y\": -4.927536231884058, \"value_uncond\": 5.634860970130909e-06}, {\"x\": -3.6231884057971016, \"y\": -5.0724637681159415, \"x2\": -3.333333333333334, \"y2\": -4.782608695652174, \"center_x\": -3.4782608695652177, \"center_y\": -4.927536231884058, \"value_uncond\": 7.2366134564094345e-06}, {\"x\": -3.333333333333333, \"y\": -5.0724637681159415, \"x2\": -3.0434782608695654, \"y2\": -4.782608695652174, \"center_x\": -3.1884057971014492, \"center_y\": -4.927536231884058, \"value_uncond\": 9.207322607105823e-06}, {\"x\": -3.0434782608695645, \"y\": -5.0724637681159415, \"x2\": -2.753623188405797, \"y2\": -4.782608695652174, \"center_x\": -2.8985507246376807, \"center_y\": -4.927536231884058, \"value_uncond\": 1.1605855517151936e-05}, {\"x\": -2.753623188405797, \"y\": -5.0724637681159415, \"x2\": -2.4637681159420293, \"y2\": -4.782608695652174, \"center_x\": -2.608695652173913, \"center_y\": -4.927536231884058, \"value_uncond\": 1.4493283038864286e-05}, {\"x\": -2.4637681159420284, \"y\": -5.0724637681159415, \"x2\": -2.1739130434782608, \"y2\": -4.782608695652174, \"center_x\": -2.3188405797101446, \"center_y\": -4.927536231884058, \"value_uncond\": 1.7930904689325227e-05}, {\"x\": -2.1739130434782608, \"y\": -5.0724637681159415, \"x2\": -1.8840579710144931, \"y2\": -4.782608695652174, \"center_x\": -2.028985507246377, \"center_y\": -4.927536231884058, \"value_uncond\": 2.197776094083601e-05}, {\"x\": -1.8840579710144922, \"y\": -5.0724637681159415, \"x2\": -1.5942028985507246, \"y2\": -4.782608695652174, \"center_x\": -1.7391304347826084, \"center_y\": -4.927536231884058, \"value_uncond\": 2.6687660404369246e-05}, {\"x\": -1.5942028985507246, \"y\": -5.0724637681159415, \"x2\": -1.304347826086957, \"y2\": -4.782608695652174, \"center_x\": -1.4492753623188408, \"center_y\": -4.927536231884058, \"value_uncond\": 3.21057910405215e-05}, {\"x\": -1.304347826086957, \"y\": -5.0724637681159415, \"x2\": -1.0144927536231894, \"y2\": -4.782608695652174, \"center_x\": -1.1594202898550732, \"center_y\": -4.927536231884058, \"value_uncond\": 3.826503028746719e-05}, {\"x\": -1.0144927536231876, \"y\": -5.0724637681159415, \"x2\": -0.72463768115942, \"y2\": -4.782608695652174, \"center_x\": -0.8695652173913038, \"center_y\": -4.927536231884058, \"value_uncond\": 4.51821156213635e-05}, {\"x\": -0.72463768115942, \"y\": -5.0724637681159415, \"x2\": -0.43478260869565233, \"y2\": -4.782608695652174, \"center_x\": -0.5797101449275361, \"center_y\": -4.927536231884058, \"value_uncond\": 5.285388048410386e-05}, {\"x\": -0.43478260869565233, \"y\": -5.0724637681159415, \"x2\": -0.1449275362318847, \"y2\": -4.782608695652174, \"center_x\": -0.2898550724637685, \"center_y\": -4.927536231884058, \"value_uncond\": 6.125379610721919e-05}, {\"x\": -0.14492753623188293, \"y\": -5.0724637681159415, \"x2\": 0.1449275362318847, \"y2\": -4.782608695652174, \"center_x\": 8.881784197001252e-16, \"center_y\": -4.927536231884058, \"value_uncond\": 7.032908276910843e-05}, {\"x\": 0.1449275362318847, \"y\": -5.0724637681159415, \"x2\": 0.43478260869565233, \"y2\": -4.782608695652174, \"center_x\": 0.2898550724637685, \"center_y\": -4.927536231884058, \"value_uncond\": 7.999866004289843e-05}, {\"x\": 0.43478260869565233, \"y\": -5.0724637681159415, \"x2\": 0.72463768115942, \"y2\": -4.782608695652174, \"center_x\": 0.5797101449275361, \"center_y\": -4.927536231884058, \"value_uncond\": 9.015219112845478e-05}, {\"x\": 0.72463768115942, \"y\": -5.0724637681159415, \"x2\": 1.0144927536231876, \"y2\": -4.782608695652174, \"center_x\": 0.8695652173913038, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00010065043936580447}, {\"x\": 1.0144927536231894, \"y\": -5.0724637681159415, \"x2\": 1.304347826086957, \"y2\": -4.782608695652174, \"center_x\": 1.1594202898550732, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00011132709535568892}, {\"x\": 1.304347826086957, \"y\": -5.0724637681159415, \"x2\": 1.5942028985507246, \"y2\": -4.782608695652174, \"center_x\": 1.4492753623188408, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00012199215283444759}, {\"x\": 1.5942028985507246, \"y\": -5.0724637681159415, \"x2\": 1.8840579710144922, \"y2\": -4.782608695652174, \"center_x\": 1.7391304347826084, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00013243681493426047}, {\"x\": 1.884057971014494, \"y\": -5.0724637681159415, \"x2\": 2.1739130434782616, \"y2\": -4.782608695652174, \"center_x\": 2.028985507246378, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00014243980620861715}, {\"x\": 2.1739130434782616, \"y\": -5.0724637681159415, \"x2\": 2.4637681159420293, \"y2\": -4.782608695652174, \"center_x\": 2.3188405797101455, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00015177485801526626}, {\"x\": 2.4637681159420293, \"y\": -5.0724637681159415, \"x2\": 2.753623188405797, \"y2\": -4.782608695652174, \"center_x\": 2.608695652173913, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00016021903473436135}, {\"x\": 2.753623188405797, \"y\": -5.0724637681159415, \"x2\": 3.0434782608695645, \"y2\": -4.782608695652174, \"center_x\": 2.8985507246376807, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00016756148520500328}, {\"x\": 3.0434782608695663, \"y\": -5.0724637681159415, \"x2\": 3.333333333333334, \"y2\": -4.782608695652174, \"center_x\": 3.18840579710145, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00017361214620093563}, {\"x\": 3.333333333333334, \"y\": -5.0724637681159415, \"x2\": 3.6231884057971016, \"y2\": -4.782608695652174, \"center_x\": 3.4782608695652177, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00017820989945380452}, {\"x\": 3.6231884057971016, \"y\": -5.0724637681159415, \"x2\": 3.913043478260869, \"y2\": -4.782608695652174, \"center_x\": 3.7681159420289854, \"center_y\": -4.927536231884058, \"value_uncond\": 0.0001812296947676252}, {\"x\": 3.913043478260871, \"y\": -5.0724637681159415, \"x2\": 4.202898550724639, \"y2\": -4.782608695652174, \"center_x\": 4.057971014492755, \"center_y\": -4.927536231884058, \"value_uncond\": 0.0001825882000448861}, {\"x\": 4.202898550724639, \"y\": -5.0724637681159415, \"x2\": 4.492753623188406, \"y2\": -4.782608695652174, \"center_x\": 4.347826086956522, \"center_y\": -4.927536231884058, \"value_uncond\": 0.0001822476220000616}, {\"x\": 4.492753623188406, \"y\": -5.0724637681159415, \"x2\": 4.782608695652174, \"y2\": -4.782608695652174, \"center_x\": 4.63768115942029, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00018021745307357436}, {\"x\": 4.782608695652174, \"y\": -5.0724637681159415, \"x2\": 5.0724637681159415, \"y2\": -4.782608695652174, \"center_x\": 4.927536231884058, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00017655403184885295}, {\"x\": 5.072463768115943, \"y\": -5.0724637681159415, \"x2\": 5.362318840579711, \"y2\": -4.782608695652174, \"center_x\": 5.217391304347827, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00017135794538353534}, {\"x\": 5.362318840579711, \"y\": -5.0724637681159415, \"x2\": 5.6521739130434785, \"y2\": -4.782608695652174, \"center_x\": 5.507246376811595, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00016476944062065562}, {\"x\": 5.6521739130434785, \"y\": -5.0724637681159415, \"x2\": 5.942028985507246, \"y2\": -4.782608695652174, \"center_x\": 5.797101449275362, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00015696213701197142}, {\"x\": 5.942028985507246, \"y\": -5.0724637681159415, \"x2\": 6.231884057971014, \"y2\": -4.782608695652174, \"center_x\": 6.08695652173913, \"center_y\": -4.927536231884058, \"value_uncond\": 0.0001481354336143672}, {\"x\": 6.2318840579710155, \"y\": -5.0724637681159415, \"x2\": 6.521739130434783, \"y2\": -4.782608695652174, \"center_x\": 6.376811594202899, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00013850607353238278}, {\"x\": 6.521739130434785, \"y\": -5.0724637681159415, \"x2\": 6.8115942028985526, \"y2\": -4.782608695652174, \"center_x\": 6.666666666666669, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00012829936207264282}, {\"x\": 6.811594202898551, \"y\": -5.0724637681159415, \"x2\": 7.101449275362318, \"y2\": -4.782608695652174, \"center_x\": 6.956521739130435, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00011774053117595541}, {\"x\": 7.10144927536232, \"y\": -5.0724637681159415, \"x2\": 7.391304347826088, \"y2\": -4.782608695652174, \"center_x\": 7.246376811594204, \"center_y\": -4.927536231884058, \"value_uncond\": 0.00010704670382586031}, {\"x\": 7.391304347826086, \"y\": -5.0724637681159415, \"x2\": 7.681159420289854, \"y2\": -4.782608695652174, \"center_x\": 7.53623188405797, \"center_y\": -4.927536231884058, \"value_uncond\": 9.641984343001844e-05}, {\"x\": 7.681159420289855, \"y\": -5.0724637681159415, \"x2\": 7.971014492753623, \"y2\": -4.782608695652174, \"center_x\": 7.826086956521739, \"center_y\": -4.927536231884058, \"value_uncond\": 8.604098217792227e-05}, {\"x\": 7.971014492753625, \"y\": -5.0724637681159415, \"x2\": 8.260869565217392, \"y2\": -4.782608695652174, \"center_x\": 8.115942028985508, \"center_y\": -4.927536231884058, \"value_uncond\": 7.606591805950384e-05}, {\"x\": 8.26086956521739, \"y\": -5.0724637681159415, \"x2\": 8.550724637681158, \"y2\": -4.782608695652174, \"center_x\": 8.405797101449274, \"center_y\": -4.927536231884058, \"value_uncond\": 6.662246198975567e-05}, {\"x\": 8.55072463768116, \"y\": -5.0724637681159415, \"x2\": 8.840579710144928, \"y2\": -4.782608695652174, \"center_x\": 8.695652173913043, \"center_y\": -4.927536231884058, \"value_uncond\": 5.780921322558761e-05}, {\"x\": 8.84057971014493, \"y\": -5.0724637681159415, \"x2\": 9.130434782608697, \"y2\": -4.782608695652174, \"center_x\": 8.985507246376812, \"center_y\": -4.927536231884058, \"value_uncond\": 4.9695750572262035e-05}, {\"x\": 9.130434782608695, \"y\": -5.0724637681159415, \"x2\": 9.420289855072463, \"y2\": -4.782608695652174, \"center_x\": 9.275362318840578, \"center_y\": -4.927536231884058, \"value_uncond\": 4.2324054444699044e-05}, {\"x\": 9.420289855072465, \"y\": -5.0724637681159415, \"x2\": 9.710144927536232, \"y2\": -4.782608695652174, \"center_x\": 9.565217391304348, \"center_y\": -4.927536231884058, \"value_uncond\": 3.5710924127725504e-05}, {\"x\": 9.710144927536234, \"y\": -5.0724637681159415, \"x2\": 10.000000000000002, \"y2\": -4.782608695652174, \"center_x\": 9.855072463768117, \"center_y\": -4.927536231884058, \"value_uncond\": 2.9851126728746904e-05}, {\"x\": 10.0, \"y\": -5.0724637681159415, \"x2\": 10.289855072463768, \"y2\": -4.782608695652174, \"center_x\": 10.144927536231883, \"center_y\": -4.927536231884058, \"value_uncond\": 2.4721008384454473e-05}, {\"x\": -10.0, \"y\": -4.782608695652174, \"x2\": -9.710144927536232, \"y2\": -4.492753623188406, \"center_x\": -9.855072463768117, \"center_y\": -4.63768115942029, \"value_uncond\": 4.5450608224403395e-09}, {\"x\": -9.710144927536232, \"y\": -4.782608695652174, \"x2\": -9.420289855072465, \"y2\": -4.492753623188406, \"center_x\": -9.565217391304348, \"center_y\": -4.63768115942029, \"value_uncond\": 7.10116762385412e-09}, {\"x\": -9.420289855072463, \"y\": -4.782608695652174, \"x2\": -9.130434782608695, \"y2\": -4.492753623188406, \"center_x\": -9.275362318840578, \"center_y\": -4.63768115942029, \"value_uncond\": 1.0991719673297463e-08}, {\"x\": -9.130434782608695, \"y\": -4.782608695652174, \"x2\": -8.840579710144928, \"y2\": -4.492753623188406, \"center_x\": -8.985507246376812, \"center_y\": -4.63768115942029, \"value_uncond\": 1.68557211472205e-08}, {\"x\": -8.840579710144928, \"y\": -4.782608695652174, \"x2\": -8.55072463768116, \"y2\": -4.492753623188406, \"center_x\": -8.695652173913043, \"center_y\": -4.63768115942029, \"value_uncond\": 2.560795196522492e-08}, {\"x\": -8.55072463768116, \"y\": -4.782608695652174, \"x2\": -8.260869565217392, \"y2\": -4.492753623188406, \"center_x\": -8.405797101449277, \"center_y\": -4.63768115942029, \"value_uncond\": 3.854323559455201e-08}, {\"x\": -8.26086956521739, \"y\": -4.782608695652174, \"x2\": -7.971014492753623, \"y2\": -4.492753623188406, \"center_x\": -8.115942028985508, \"center_y\": -4.63768115942029, \"value_uncond\": 5.747345525148468e-08}, {\"x\": -7.971014492753623, \"y\": -4.782608695652174, \"x2\": -7.681159420289855, \"y2\": -4.492753623188406, \"center_x\": -7.826086956521739, \"center_y\": -4.63768115942029, \"value_uncond\": 8.490480317055164e-08}, {\"x\": -7.681159420289855, \"y\": -4.782608695652174, \"x2\": -7.391304347826088, \"y2\": -4.492753623188406, \"center_x\": -7.536231884057972, \"center_y\": -4.63768115942029, \"value_uncond\": 1.2426334105807845e-07}, {\"x\": -7.391304347826087, \"y\": -4.782608695652174, \"x2\": -7.101449275362319, \"y2\": -4.492753623188406, \"center_x\": -7.246376811594203, \"center_y\": -4.63768115942029, \"value_uncond\": 1.8017710623082913e-07}, {\"x\": -7.101449275362318, \"y\": -4.782608695652174, \"x2\": -6.811594202898551, \"y2\": -4.492753623188406, \"center_x\": -6.956521739130435, \"center_y\": -4.63768115942029, \"value_uncond\": 2.588224854624657e-07}, {\"x\": -6.811594202898551, \"y\": -4.782608695652174, \"x2\": -6.521739130434783, \"y2\": -4.492753623188406, \"center_x\": -6.666666666666667, \"center_y\": -4.63768115942029, \"value_uncond\": 3.6834112803287286e-07}, {\"x\": -6.521739130434782, \"y\": -4.782608695652174, \"x2\": -6.231884057971015, \"y2\": -4.492753623188406, \"center_x\": -6.3768115942028984, \"center_y\": -4.63768115942029, \"value_uncond\": 5.193309896456e-07}, {\"x\": -6.231884057971014, \"y\": -4.782608695652174, \"x2\": -5.942028985507246, \"y2\": -4.492753623188406, \"center_x\": -6.08695652173913, \"center_y\": -4.63768115942029, \"value_uncond\": 7.254109019424205e-07}, {\"x\": -5.942028985507246, \"y\": -4.782608695652174, \"x2\": -5.6521739130434785, \"y2\": -4.492753623188406, \"center_x\": -5.797101449275362, \"center_y\": -4.63768115942029, \"value_uncond\": 1.0038521006927966e-06}, {\"x\": -5.6521739130434785, \"y\": -4.782608695652174, \"x2\": -5.362318840579711, \"y2\": -4.492753623188406, \"center_x\": -5.507246376811595, \"center_y\": -4.63768115942029, \"value_uncond\": 1.3762622597178169e-06}, {\"x\": -5.36231884057971, \"y\": -4.782608695652174, \"x2\": -5.072463768115942, \"y2\": -4.492753623188406, \"center_x\": -5.217391304347826, \"center_y\": -4.63768115942029, \"value_uncond\": 1.8692977522789173e-06}, {\"x\": -5.0724637681159415, \"y\": -4.782608695652174, \"x2\": -4.782608695652174, \"y2\": -4.492753623188406, \"center_x\": -4.927536231884058, \"center_y\": -4.63768115942029, \"value_uncond\": 2.5153682882528417e-06}, {\"x\": -4.782608695652174, \"y\": -4.782608695652174, \"x2\": -4.492753623188406, \"y2\": -4.492753623188406, \"center_x\": -4.63768115942029, \"center_y\": -4.63768115942029, \"value_uncond\": 3.3532852107341146e-06}, {\"x\": -4.492753623188405, \"y\": -4.782608695652174, \"x2\": -4.202898550724638, \"y2\": -4.492753623188406, \"center_x\": -4.3478260869565215, \"center_y\": -4.63768115942029, \"value_uncond\": 4.428791350264565e-06}, {\"x\": -4.202898550724638, \"y\": -4.782608695652174, \"x2\": -3.91304347826087, \"y2\": -4.492753623188406, \"center_x\": -4.057971014492754, \"center_y\": -4.63768115942029, \"value_uncond\": 5.794897538628808e-06}, {\"x\": -3.913043478260869, \"y\": -4.782608695652174, \"x2\": -3.6231884057971016, \"y2\": -4.492753623188406, \"center_x\": -3.7681159420289854, \"center_y\": -4.63768115942029, \"value_uncond\": 7.511940117845491e-06}, {\"x\": -3.6231884057971016, \"y\": -4.782608695652174, \"x2\": -3.333333333333334, \"y2\": -4.492753623188406, \"center_x\": -3.4782608695652177, \"center_y\": -4.63768115942029, \"value_uncond\": 9.647266761096261e-06}, {\"x\": -3.333333333333333, \"y\": -4.782608695652174, \"x2\": -3.0434782608695654, \"y2\": -4.492753623188406, \"center_x\": -3.1884057971014492, \"center_y\": -4.63768115942029, \"value_uncond\": 1.227445653706291e-05}, {\"x\": -3.0434782608695645, \"y\": -4.782608695652174, \"x2\": -2.753623188405797, \"y2\": -4.492753623188406, \"center_x\": -2.8985507246376807, \"center_y\": -4.63768115942029, \"value_uncond\": 1.547198628738956e-05}, {\"x\": -2.753623188405797, \"y\": -4.782608695652174, \"x2\": -2.4637681159420293, \"y2\": -4.492753623188406, \"center_x\": -2.608695652173913, \"center_y\": -4.63768115942029, \"value_uncond\": 1.9321270724520628e-05}, {\"x\": -2.4637681159420284, \"y\": -4.782608695652174, \"x2\": -2.1739130434782608, \"y2\": -4.492753623188406, \"center_x\": -2.3188405797101446, \"center_y\": -4.63768115942029, \"value_uncond\": 2.3904029398240288e-05}, {\"x\": -2.1739130434782608, \"y\": -4.782608695652174, \"x2\": -1.8840579710144931, \"y2\": -4.492753623188406, \"center_x\": -2.028985507246377, \"center_y\": -4.63768115942029, \"value_uncond\": 2.929897028285477e-05}, {\"x\": -1.8840579710144922, \"y\": -4.782608695652174, \"x2\": -1.5942028985507246, \"y2\": -4.492753623188406, \"center_x\": -1.7391304347826084, \"center_y\": -4.63768115942029, \"value_uncond\": 3.557782665902412e-05}, {\"x\": -1.5942028985507246, \"y\": -4.782608695652174, \"x2\": -1.304347826086957, \"y2\": -4.492753623188406, \"center_x\": -1.4492753623188408, \"center_y\": -4.63768115942029, \"value_uncond\": 4.28008394547585e-05}, {\"x\": -1.304347826086957, \"y\": -4.782608695652174, \"x2\": -1.0144927536231894, \"y2\": -4.492753623188406, \"center_x\": -1.1594202898550732, \"center_y\": -4.63768115942029, \"value_uncond\": 5.1011838206953956e-05}, {\"x\": -1.0144927536231876, \"y\": -4.782608695652174, \"x2\": -0.72463768115942, \"y2\": -4.492753623188406, \"center_x\": -0.8695652173913038, \"center_y\": -4.63768115942029, \"value_uncond\": 6.0233135962779376e-05}, {\"x\": -0.72463768115942, \"y\": -4.782608695652174, \"x2\": -0.43478260869565233, \"y2\": -4.492753623188406, \"center_x\": -0.5797101449275361, \"center_y\": -4.63768115942029, \"value_uncond\": 7.046051132351661e-05}, {\"x\": -0.43478260869565233, \"y\": -4.782608695652174, \"x2\": -0.1449275362318847, \"y2\": -4.492753623188406, \"center_x\": -0.2898550724637685, \"center_y\": -4.63768115942029, \"value_uncond\": 8.165859828436157e-05}, {\"x\": -0.14492753623188293, \"y\": -4.782608695652174, \"x2\": 0.1449275362318847, \"y2\": -4.492753623188406, \"center_x\": 8.881784197001252e-16, \"center_y\": -4.63768115942029, \"value_uncond\": 9.37570351966054e-05}, {\"x\": 0.1449275362318847, \"y\": -4.782608695652174, \"x2\": 0.43478260869565233, \"y2\": -4.492753623188406, \"center_x\": 0.2898550724637685, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00010664773220414889}, {\"x\": 0.43478260869565233, \"y\": -4.782608695652174, \"x2\": 0.72463768115942, \"y2\": -4.492753623188406, \"center_x\": 0.5797101449275361, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00012018359722436608}, {\"x\": 0.72463768115942, \"y\": -4.782608695652174, \"x2\": 1.0144927536231876, \"y2\": -4.492753623188406, \"center_x\": 0.8695652173913038, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00013417901122291513}, {\"x\": 1.0144927536231894, \"y\": -4.782608695652174, \"x2\": 1.304347826086957, \"y2\": -4.492753623188406, \"center_x\": 1.1594202898550732, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00014841226398282928}, {\"x\": 1.304347826086957, \"y\": -4.782608695652174, \"x2\": 1.5942028985507246, \"y2\": -4.492753623188406, \"center_x\": 1.4492753623188408, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00016263005454740363}, {\"x\": 1.5942028985507246, \"y\": -4.782608695652174, \"x2\": 1.8840579710144922, \"y2\": -4.492753623188406, \"center_x\": 1.7391304347826084, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00017655403184885278}, {\"x\": 1.884057971014494, \"y\": -4.782608695652174, \"x2\": 2.1739130434782616, \"y2\": -4.492753623188406, \"center_x\": 2.028985507246378, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00018988920938927623}, {\"x\": 2.1739130434782616, \"y\": -4.782608695652174, \"x2\": 2.4637681159420293, \"y2\": -4.492753623188406, \"center_x\": 2.3188405797101455, \"center_y\": -4.63768115942029, \"value_uncond\": 0.0002023339441467523}, {\"x\": 2.4637681159420293, \"y\": -4.782608695652174, \"x2\": 2.753623188405797, \"y2\": -4.492753623188406, \"center_x\": 2.608695652173913, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00021359103641479342}, {\"x\": 2.753623188405797, \"y\": -4.782608695652174, \"x2\": 3.0434782608695645, \"y2\": -4.492753623188406, \"center_x\": 2.8985507246376807, \"center_y\": -4.63768115942029, \"value_uncond\": 0.0002233793965085168}, {\"x\": 3.0434782608695663, \"y\": -4.782608695652174, \"x2\": 3.333333333333334, \"y2\": -4.492753623188406, \"center_x\": 3.18840579710145, \"center_y\": -4.63768115942029, \"value_uncond\": 0.0002314456475332996}, {\"x\": 3.333333333333334, \"y\": -4.782608695652174, \"x2\": 3.6231884057971016, \"y2\": -4.492753623188406, \"center_x\": 3.4782608695652177, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00023757499966732003}, {\"x\": 3.6231884057971016, \"y\": -4.782608695652174, \"x2\": 3.913043478260869, \"y2\": -4.492753623188406, \"center_x\": 3.7681159420289854, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00024160074612066055}, {\"x\": 3.913043478260871, \"y\": -4.782608695652174, \"x2\": 4.202898550724639, \"y2\": -4.492753623188406, \"center_x\": 4.057971014492755, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00024341179529235364}, {\"x\": 4.202898550724639, \"y\": -4.782608695652174, \"x2\": 4.492753623188406, \"y2\": -4.492753623188406, \"center_x\": 4.347826086956522, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00024295776423608866}, {\"x\": 4.492753623188406, \"y\": -4.782608695652174, \"x2\": 4.782608695652174, \"y2\": -4.492753623188406, \"center_x\": 4.63768115942029, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00024025130750437475}, {\"x\": 4.782608695652174, \"y\": -4.782608695652174, \"x2\": 5.0724637681159415, \"y2\": -4.492753623188406, \"center_x\": 4.927536231884058, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00023536753113217578}, {\"x\": 5.072463768115943, \"y\": -4.782608695652174, \"x2\": 5.362318840579711, \"y2\": -4.492753623188406, \"center_x\": 5.217391304347827, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00022844052963533022}, {\"x\": 5.362318840579711, \"y\": -4.782608695652174, \"x2\": 5.6521739130434785, \"y2\": -4.492753623188406, \"center_x\": 5.507246376811595, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00021965726887570545}, {\"x\": 5.6521739130434785, \"y\": -4.782608695652174, \"x2\": 5.942028985507246, \"y2\": -4.492753623188406, \"center_x\": 5.797101449275362, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00020924920424001095}, {\"x\": 5.942028985507246, \"y\": -4.782608695652174, \"x2\": 6.231884057971014, \"y2\": -4.492753623188406, \"center_x\": 6.08695652173913, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00019748215839588857}, {\"x\": 6.2318840579710155, \"y\": -4.782608695652174, \"x2\": 6.521739130434783, \"y2\": -4.492753623188406, \"center_x\": 6.376811594202899, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00018464507569012695}, {\"x\": 6.521739130434785, \"y\": -4.782608695652174, \"x2\": 6.8115942028985526, \"y2\": -4.492753623188406, \"center_x\": 6.666666666666669, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00017103831490363806}, {\"x\": 6.811594202898551, \"y\": -4.782608695652174, \"x2\": 7.101449275362318, \"y2\": -4.492753623188406, \"center_x\": 6.956521739130435, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00015696213701197131}, {\"x\": 7.10144927536232, \"y\": -4.782608695652174, \"x2\": 7.391304347826088, \"y2\": -4.492753623188406, \"center_x\": 7.246376811594204, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00014270599278582075}, {\"x\": 7.391304347826086, \"y\": -4.782608695652174, \"x2\": 7.681159420289854, \"y2\": -4.492753623188406, \"center_x\": 7.53623188405797, \"center_y\": -4.63768115942029, \"value_uncond\": 0.0001285391234775238}, {\"x\": 7.681159420289855, \"y\": -4.782608695652174, \"x2\": 7.971014492753623, \"y2\": -4.492753623188406, \"center_x\": 7.826086956521739, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00011470286653516983}, {\"x\": 7.971014492753625, \"y\": -4.782608695652174, \"x2\": 8.260869565217392, \"y2\": -4.492753623188406, \"center_x\": 8.115942028985508, \"center_y\": -4.63768115942029, \"value_uncond\": 0.00010140491921642922}, {\"x\": 8.26086956521739, \"y\": -4.782608695652174, \"x2\": 8.550724637681158, \"y2\": -4.492753623188406, \"center_x\": 8.405797101449274, \"center_y\": -4.63768115942029, \"value_uncond\": 8.881566867813159e-05}, {\"x\": 8.55072463768116, \"y\": -4.782608695652174, \"x2\": 8.840579710144928, \"y2\": -4.492753623188406, \"center_x\": 8.695652173913043, \"center_y\": -4.63768115942029, \"value_uncond\": 7.706655946123317e-05}, {\"x\": 8.84057971014493, \"y\": -4.782608695652174, \"x2\": 9.130434782608697, \"y2\": -4.492753623188406, \"center_x\": 8.985507246376812, \"center_y\": -4.63768115942029, \"value_uncond\": 6.625034839174487e-05}, {\"x\": 9.130434782608695, \"y\": -4.782608695652174, \"x2\": 9.420289855072463, \"y2\": -4.492753623188406, \"center_x\": 9.275362318840578, \"center_y\": -4.63768115942029, \"value_uncond\": 5.642300035765128e-05}, {\"x\": 9.420289855072465, \"y\": -4.782608695652174, \"x2\": 9.710144927536232, \"y2\": -4.492753623188406, \"center_x\": 9.565217391304348, \"center_y\": -4.63768115942029, \"value_uncond\": 4.760691080443206e-05}, {\"x\": 9.710144927536234, \"y\": -4.782608695652174, \"x2\": 10.000000000000002, \"y2\": -4.492753623188406, \"center_x\": 9.855072463768117, \"center_y\": -4.63768115942029, \"value_uncond\": 3.979510366364091e-05}, {\"x\": 10.0, \"y\": -4.782608695652174, \"x2\": 10.289855072463768, \"y2\": -4.492753623188406, \"center_x\": 10.144927536231883, \"center_y\": -4.63768115942029, \"value_uncond\": 3.29560455211132e-05}, {\"x\": -10.0, \"y\": -4.492753623188405, \"x2\": -9.710144927536232, \"y2\": -4.202898550724638, \"center_x\": -9.855072463768117, \"center_y\": -4.3478260869565215, \"value_uncond\": 6.002807632471971e-09}, {\"x\": -9.710144927536232, \"y\": -4.492753623188405, \"x2\": -9.420289855072465, \"y2\": -4.202898550724638, \"center_x\": -9.565217391304348, \"center_y\": -4.3478260869565215, \"value_uncond\": 9.378739884287616e-09}, {\"x\": -9.420289855072463, \"y\": -4.492753623188405, \"x2\": -9.130434782608695, \"y2\": -4.202898550724638, \"center_x\": -9.275362318840578, \"center_y\": -4.3478260869565215, \"value_uncond\": 1.451711678380478e-08}, {\"x\": -9.130434782608695, \"y\": -4.492753623188405, \"x2\": -8.840579710144928, \"y2\": -4.202898550724638, \"center_x\": -8.985507246376812, \"center_y\": -4.3478260869565215, \"value_uncond\": 2.2261891645935698e-08}, {\"x\": -8.840579710144928, \"y\": -4.492753623188405, \"x2\": -8.55072463768116, \"y2\": -4.202898550724638, \"center_x\": -8.695652173913043, \"center_y\": -4.3478260869565215, \"value_uncond\": 3.382124365638135e-08}, {\"x\": -8.55072463768116, \"y\": -4.492753623188405, \"x2\": -8.260869565217392, \"y2\": -4.202898550724638, \"center_x\": -8.405797101449277, \"center_y\": -4.3478260869565215, \"value_uncond\": 5.0905287705900384e-08}, {\"x\": -8.26086956521739, \"y\": -4.492753623188405, \"x2\": -7.971014492753623, \"y2\": -4.202898550724638, \"center_x\": -8.115942028985508, \"center_y\": -4.3478260869565215, \"value_uncond\": 7.59070360829428e-08}, {\"x\": -7.971014492753623, \"y\": -4.492753623188405, \"x2\": -7.681159420289855, \"y2\": -4.202898550724638, \"center_x\": -7.826086956521739, \"center_y\": -4.3478260869565215, \"value_uncond\": 1.1213649726959334e-07}, {\"x\": -7.681159420289855, \"y\": -4.492753623188405, \"x2\": -7.391304347826088, \"y2\": -4.202898550724638, \"center_x\": -7.536231884057972, \"center_y\": -4.3478260869565215, \"value_uncond\": 1.641185808684942e-07}, {\"x\": -7.391304347826087, \"y\": -4.492753623188405, \"x2\": -7.101449275362319, \"y2\": -4.202898550724638, \"center_x\": -7.246376811594203, \"center_y\": -4.3478260869565215, \"value_uncond\": 2.379656842300335e-07}, {\"x\": -7.101449275362318, \"y\": -4.492753623188405, \"x2\": -6.811594202898551, \"y2\": -4.202898550724638, \"center_x\": -6.956521739130435, \"center_y\": -4.3478260869565215, \"value_uncond\": 3.418351595029395e-07}, {\"x\": -6.811594202898551, \"y\": -4.492753623188405, \"x2\": -6.521739130434783, \"y2\": -4.202898550724638, \"center_x\": -6.666666666666667, \"center_y\": -4.3478260869565215, \"value_uncond\": 4.86479944072979e-07}, {\"x\": -6.521739130434782, \"y\": -4.492753623188405, \"x2\": -6.231884057971015, \"y2\": -4.202898550724638, \"center_x\": -6.3768115942028984, \"center_y\": -4.3478260869565215, \"value_uncond\": 6.85897098017273e-07}, {\"x\": -6.231884057971014, \"y\": -4.492753623188405, \"x2\": -5.942028985507246, \"y2\": -4.202898550724638, \"center_x\": -6.08695652173913, \"center_y\": -4.3478260869565215, \"value_uncond\": 9.580734491734053e-07}, {\"x\": -5.942028985507246, \"y\": -4.492753623188405, \"x2\": -5.6521739130434785, \"y2\": -4.202898550724638, \"center_x\": -5.797101449275362, \"center_y\": -4.3478260869565215, \"value_uncond\": 1.325819672678501e-06}, {\"x\": -5.6521739130434785, \"y\": -4.492753623188405, \"x2\": -5.362318840579711, \"y2\": -4.202898550724638, \"center_x\": -5.507246376811595, \"center_y\": -4.3478260869565215, \"value_uncond\": 1.81767371651618e-06}, {\"x\": -5.36231884057971, \"y\": -4.492753623188405, \"x2\": -5.072463768115942, \"y2\": -4.202898550724638, \"center_x\": -5.217391304347826, \"center_y\": -4.3478260869565215, \"value_uncond\": 2.4688415079817903e-06}, {\"x\": -5.0724637681159415, \"y\": -4.492753623188405, \"x2\": -4.782608695652174, \"y2\": -4.202898550724638, \"center_x\": -4.927536231884058, \"center_y\": -4.3478260869565215, \"value_uncond\": 3.3221275906039403e-06}, {\"x\": -4.782608695652174, \"y\": -4.492753623188405, \"x2\": -4.492753623188406, \"y2\": -4.202898550724638, \"center_x\": -4.63768115942029, \"center_y\": -4.3478260869565215, \"value_uncond\": 4.428791350264565e-06}, {\"x\": -4.492753623188405, \"y\": -4.492753623188405, \"x2\": -4.202898550724638, \"y2\": -4.202898550724638, \"center_x\": -4.3478260869565215, \"center_y\": -4.3478260869565215, \"value_uncond\": 5.8492468106773934e-06}, {\"x\": -4.202898550724638, \"y\": -4.492753623188405, \"x2\": -3.91304347826087, \"y2\": -4.202898550724638, \"center_x\": -4.057971014492754, \"center_y\": -4.3478260869565215, \"value_uncond\": 7.653507077953004e-06}, {\"x\": -3.913043478260869, \"y\": -4.492753623188405, \"x2\": -3.6231884057971016, \"y2\": -4.202898550724638, \"center_x\": -3.7681159420289854, \"center_y\": -4.3478260869565215, \"value_uncond\": 9.921260294568287e-06}, {\"x\": -3.6231884057971016, \"y\": -4.492753623188405, \"x2\": -3.333333333333334, \"y2\": -4.202898550724638, \"center_x\": -3.4782608695652177, \"center_y\": -4.3478260869565215, \"value_uncond\": 1.2741454692988741e-05}, {\"x\": -3.333333333333333, \"y\": -4.492753623188405, \"x2\": -3.0434782608695654, \"y2\": -4.202898550724638, \"center_x\": -3.1884057971014492, \"center_y\": -4.3478260869565215, \"value_uncond\": 1.621126850961822e-05}, {\"x\": -3.0434782608695645, \"y\": -4.492753623188405, \"x2\": -2.753623188405797, \"y2\": -4.202898550724638, \"center_x\": -2.8985507246376807, \"center_y\": -4.3478260869565215, \"value_uncond\": 2.0434348626731224e-05}, {\"x\": -2.753623188405797, \"y\": -4.492753623188405, \"x2\": -2.4637681159420293, \"y2\": -4.202898550724638, \"center_x\": -2.608695652173913, \"center_y\": -4.3478260869565215, \"value_uncond\": 2.551822206681418e-05}, {\"x\": -2.4637681159420284, \"y\": -4.492753623188405, \"x2\": -2.1739130434782608, \"y2\": -4.202898550724638, \"center_x\": -2.3188405797101446, \"center_y\": -4.3478260869565215, \"value_uncond\": 3.157081846080717e-05}, {\"x\": -2.1739130434782608, \"y\": -4.492753623188405, \"x2\": -1.8840579710144931, \"y2\": -4.202898550724638, \"center_x\": -2.028985507246377, \"center_y\": -4.3478260869565215, \"value_uncond\": 3.869608995530632e-05}, {\"x\": -1.8840579710144922, \"y\": -4.492753623188405, \"x2\": -1.5942028985507246, \"y2\": -4.202898550724638, \"center_x\": -1.7391304347826084, \"center_y\": -4.3478260869565215, \"value_uncond\": 4.698877699526274e-05}, {\"x\": -1.5942028985507246, \"y\": -4.492753623188405, \"x2\": -1.304347826086957, \"y2\": -4.202898550724638, \"center_x\": -1.4492753623188408, \"center_y\": -4.3478260869565215, \"value_uncond\": 5.652844170681153e-05}, {\"x\": -1.304347826086957, \"y\": -4.492753623188405, \"x2\": -1.0144927536231894, \"y2\": -4.202898550724638, \"center_x\": -1.1594202898550732, \"center_y\": -4.3478260869565215, \"value_uncond\": 6.737297116537058e-05}, {\"x\": -1.0144927536231876, \"y\": -4.492753623188405, \"x2\": -0.72463768115942, \"y2\": -4.202898550724638, \"center_x\": -0.8695652173913038, \"center_y\": -4.3478260869565215, \"value_uncond\": 7.955183492813199e-05}, {\"x\": -0.72463768115942, \"y\": -4.492753623188405, \"x2\": -0.43478260869565233, \"y2\": -4.202898550724638, \"center_x\": -0.5797101449275361, \"center_y\": -4.3478260869565215, \"value_uncond\": 9.305945765838754e-05}, {\"x\": -0.43478260869565233, \"y\": -4.492753623188405, \"x2\": -0.1449275362318847, \"y2\": -4.202898550724638, \"center_x\": -0.2898550724637685, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00010784913033906096}, {\"x\": -0.14492753623188293, \"y\": -4.492753623188405, \"x2\": 0.1449275362318847, \"y2\": -4.202898550724638, \"center_x\": 8.881784197001252e-16, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0001238279240835204}, {\"x\": 0.1449275362318847, \"y\": -4.492753623188405, \"x2\": 0.43478260869565233, \"y2\": -4.202898550724638, \"center_x\": 0.2898550724637685, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0001408530811513238}, {\"x\": 0.43478260869565233, \"y\": -4.492753623188405, \"x2\": 0.72463768115942, \"y2\": -4.202898550724638, \"center_x\": 0.5797101449275361, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00015873033231027375}, {\"x\": 0.72463768115942, \"y\": -4.492753623188405, \"x2\": 1.0144927536231876, \"y2\": -4.202898550724638, \"center_x\": 0.8695652173913038, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00017721452454710887}, {\"x\": 1.0144927536231894, \"y\": -4.492753623188405, \"x2\": 1.304347826086957, \"y2\": -4.202898550724638, \"center_x\": 1.1594202898550732, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0001960128380658796}, {\"x\": 1.304347826086957, \"y\": -4.492753623188405, \"x2\": 1.5942028985507246, \"y2\": -4.202898550724638, \"center_x\": 1.4492753623188408, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0002147907301672421}, {\"x\": 1.5942028985507246, \"y\": -4.492753623188405, \"x2\": 1.8840579710144922, \"y2\": -4.202898550724638, \"center_x\": 1.7391304347826084, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00023318057366654825}, {\"x\": 1.884057971014494, \"y\": -4.492753623188405, \"x2\": 2.1739130434782616, \"y2\": -4.202898550724638, \"center_x\": 2.028985507246378, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0002507927704329367}, {\"x\": 2.1739130434782616, \"y\": -4.492753623188405, \"x2\": 2.4637681159420293, \"y2\": -4.202898550724638, \"center_x\": 2.3188405797101455, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0002672289308507321}, {\"x\": 2.4637681159420293, \"y\": -4.492753623188405, \"x2\": 2.753623188405797, \"y2\": -4.202898550724638, \"center_x\": 2.608695652173913, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0002820965337334932}, {\"x\": 2.753623188405797, \"y\": -4.492753623188405, \"x2\": 3.0434782608695645, \"y2\": -4.202898550724638, \"center_x\": 2.8985507246376807, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.000295024334917117}, {\"x\": 3.0434782608695663, \"y\": -4.492753623188405, \"x2\": 3.333333333333334, \"y2\": -4.202898550724638, \"center_x\": 3.18840579710145, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00030567769140861566}, {\"x\": 3.333333333333334, \"y\": -4.492753623188405, \"x2\": 3.6231884057971016, \"y2\": -4.202898550724638, \"center_x\": 3.4782608695652177, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0003137729233999119}, {\"x\": 3.6231884057971016, \"y\": -4.492753623188405, \"x2\": 3.913043478260869, \"y2\": -4.202898550724638, \"center_x\": 3.7681159420289854, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00031908985588565455}, {\"x\": 3.913043478260871, \"y\": -4.492753623188405, \"x2\": 4.202898550724639, \"y2\": -4.202898550724638, \"center_x\": 4.057971014492755, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0003214817666246586}, {\"x\": 4.202898550724639, \"y\": -4.492753623188405, \"x2\": 4.492753623188406, \"y2\": -4.202898550724638, \"center_x\": 4.347826086956522, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0003208821132434606}, {\"x\": 4.492753623188406, \"y\": -4.492753623188405, \"x2\": 4.782608695652174, \"y2\": -4.202898550724638, \"center_x\": 4.63768115942029, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00031730760901551403}, {\"x\": 4.782608695652174, \"y\": -4.492753623188405, \"x2\": 5.0724637681159415, \"y2\": -4.202898550724638, \"center_x\": 4.927536231884058, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0003108574488905761}, {\"x\": 5.072463768115943, \"y\": -4.492753623188405, \"x2\": 5.362318840579711, \"y2\": -4.202898550724638, \"center_x\": 5.217391304347827, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00030170873579742915}, {\"x\": 5.362318840579711, \"y\": -4.492753623188405, \"x2\": 5.6521739130434785, \"y2\": -4.202898550724638, \"center_x\": 5.507246376811595, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0002901084015476537}, {\"x\": 5.6521739130434785, \"y\": -4.492753623188405, \"x2\": 5.942028985507246, \"y2\": -4.202898550724638, \"center_x\": 5.797101449275362, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0002763621366955009}, {\"x\": 5.942028985507246, \"y\": -4.492753623188405, \"x2\": 6.231884057971014, \"y2\": -4.202898550724638, \"center_x\": 6.08695652173913, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00026082102176564175}, {\"x\": 6.2318840579710155, \"y\": -4.492753623188405, \"x2\": 6.521739130434783, \"y2\": -4.202898550724638, \"center_x\": 6.376811594202899, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00024386667482613364}, {\"x\": 6.521739130434785, \"y\": -4.492753623188405, \"x2\": 6.8115942028985526, \"y2\": -4.202898550724638, \"center_x\": 6.666666666666669, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00022589578935435225}, {\"x\": 6.811594202898551, \"y\": -4.492753623188405, \"x2\": 7.101449275362318, \"y2\": -4.202898550724638, \"center_x\": 6.956521739130435, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00020730492965299356}, {\"x\": 7.10144927536232, \"y\": -4.492753623188405, \"x2\": 7.391304347826088, \"y2\": -4.202898550724638, \"center_x\": 7.246376811594204, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00018847638264041263}, {\"x\": 7.391304347826086, \"y\": -4.492753623188405, \"x2\": 7.681159420289854, \"y2\": -4.202898550724638, \"center_x\": 7.53623188405797, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.0001697657438757553}, {\"x\": 7.681159420289855, \"y\": -4.492753623188405, \"x2\": 7.971014492753623, \"y2\": -4.202898550724638, \"center_x\": 7.826086956521739, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00015149175546875064}, {\"x\": 7.971014492753625, \"y\": -4.492753623188405, \"x2\": 8.260869565217392, \"y2\": -4.202898550724638, \"center_x\": 8.115942028985508, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00013392872985047388}, {\"x\": 8.26086956521739, \"y\": -4.492753623188405, \"x2\": 8.550724637681158, \"y2\": -4.202898550724638, \"center_x\": 8.405797101449274, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00011730170280492166}, {\"x\": 8.55072463768116, \"y\": -4.492753623188405, \"x2\": 8.840579710144928, \"y2\": -4.202898550724638, \"center_x\": 8.695652173913043, \"center_y\": -4.3478260869565215, \"value_uncond\": 0.00010178427735403919}, {\"x\": 8.84057971014493, \"y\": -4.492753623188405, \"x2\": 9.130434782608697, \"y2\": -4.202898550724638, \"center_x\": 8.985507246376812, \"center_y\": -4.3478260869565215, \"value_uncond\": 8.74989604135519e-05}, {\"x\": 9.130434782608695, \"y\": -4.492753623188405, \"x2\": 9.420289855072463, \"y2\": -4.202898550724638, \"center_x\": 9.275362318840578, \"center_y\": -4.3478260869565215, \"value_uncond\": 7.451966660635891e-05}, {\"x\": 9.420289855072465, \"y\": -4.492753623188405, \"x2\": 9.710144927536232, \"y2\": -4.202898550724638, \"center_x\": 9.565217391304348, \"center_y\": -4.3478260869565215, \"value_uncond\": 6.287597431574483e-05}, {\"x\": 9.710144927536234, \"y\": -4.492753623188405, \"x2\": 10.000000000000002, \"y2\": -4.202898550724638, \"center_x\": 9.855072463768117, \"center_y\": -4.3478260869565215, \"value_uncond\": 5.25586700243223e-05}, {\"x\": 10.0, \"y\": -4.492753623188405, \"x2\": 10.289855072463768, \"y2\": -4.202898550724638, \"center_x\": 10.144927536231883, \"center_y\": -4.3478260869565215, \"value_uncond\": 4.3526106540421027e-05}, {\"x\": -10.0, \"y\": -4.202898550724638, \"x2\": -9.710144927536232, \"y2\": -3.91304347826087, \"center_x\": -9.855072463768117, \"center_y\": -4.057971014492754, \"value_uncond\": 7.85443531273968e-09}, {\"x\": -9.710144927536232, \"y\": -4.202898550724638, \"x2\": -9.420289855072465, \"y2\": -3.91304347826087, \"center_x\": -9.565217391304348, \"center_y\": -4.057971014492754, \"value_uncond\": 1.2271708548123759e-08}, {\"x\": -9.420289855072463, \"y\": -4.202898550724638, \"x2\": -9.130434782608695, \"y2\": -3.91304347826087, \"center_x\": -9.275362318840578, \"center_y\": -4.057971014492754, \"value_uncond\": 1.8995070588148614e-08}, {\"x\": -9.130434782608695, \"y\": -4.202898550724638, \"x2\": -8.840579710144928, \"y2\": -3.91304347826087, \"center_x\": -8.985507246376812, \"center_y\": -4.057971014492754, \"value_uncond\": 2.912880081752954e-08}, {\"x\": -8.840579710144928, \"y\": -4.202898550724638, \"x2\": -8.55072463768116, \"y2\": -3.91304347826087, \"center_x\": -8.695652173913043, \"center_y\": -4.057971014492754, \"value_uncond\": 4.425375370325845e-08}, {\"x\": -8.55072463768116, \"y\": -4.202898550724638, \"x2\": -8.260869565217392, \"y2\": -3.91304347826087, \"center_x\": -8.405797101449277, \"center_y\": -4.057971014492754, \"value_uncond\": 6.660754664192793e-08}, {\"x\": -8.26086956521739, \"y\": -4.202898550724638, \"x2\": -7.971014492753623, \"y2\": -3.91304347826087, \"center_x\": -8.115942028985508, \"center_y\": -4.057971014492754, \"value_uncond\": 9.932134114545186e-08}, {\"x\": -7.971014492753623, \"y\": -4.202898550724638, \"x2\": -7.681159420289855, \"y2\": -3.91304347826087, \"center_x\": -7.826086956521739, \"center_y\": -4.057971014492754, \"value_uncond\": 1.467261518154846e-07}, {\"x\": -7.681159420289855, \"y\": -4.202898550724638, \"x2\": -7.391304347826088, \"y2\": -3.91304347826087, \"center_x\": -7.536231884057972, \"center_y\": -4.057971014492754, \"value_uncond\": 2.1474264310538774e-07}, {\"x\": -7.391304347826087, \"y\": -4.202898550724638, \"x2\": -7.101449275362319, \"y2\": -3.91304347826087, \"center_x\": -7.246376811594203, \"center_y\": -4.057971014492754, \"value_uncond\": 3.113686441201083e-07}, {\"x\": -7.101449275362318, \"y\": -4.202898550724638, \"x2\": -6.811594202898551, \"y2\": -3.91304347826087, \"center_x\": -6.956521739130435, \"center_y\": -4.057971014492754, \"value_uncond\": 4.4727772607802706e-07}, {\"x\": -6.811594202898551, \"y\": -4.202898550724638, \"x2\": -6.521739130434783, \"y2\": -3.91304347826087, \"center_x\": -6.666666666666667, \"center_y\": -4.057971014492754, \"value_uncond\": 6.365396803650244e-07}, {\"x\": -6.521739130434782, \"y\": -4.202898550724638, \"x2\": -6.231884057971015, \"y2\": -3.91304347826087, \"center_x\": -6.3768115942028984, \"center_y\": -4.057971014492754, \"value_uncond\": 8.974691040289142e-07}, {\"x\": -6.231884057971014, \"y\": -4.202898550724638, \"x2\": -5.942028985507246, \"y2\": -3.91304347826087, \"center_x\": -6.08695652173913, \"center_y\": -4.057971014492754, \"value_uncond\": 1.2536010467300358e-06}, {\"x\": -5.942028985507246, \"y\": -4.202898550724638, \"x2\": -5.6521739130434785, \"y2\": -3.91304347826087, \"center_x\": -5.797101449275362, \"center_y\": -4.057971014492754, \"value_uncond\": 1.7347823706825448e-06}, {\"x\": -5.6521739130434785, \"y\": -4.202898550724638, \"x2\": -5.362318840579711, \"y2\": -3.91304347826087, \"center_x\": -5.507246376811595, \"center_y\": -4.057971014492754, \"value_uncond\": 2.3783538470920915e-06}, {\"x\": -5.36231884057971, \"y\": -4.202898550724638, \"x2\": -5.072463768115942, \"y2\": -3.91304347826087, \"center_x\": -5.217391304347826, \"center_y\": -4.057971014492754, \"value_uncond\": 3.230381033194009e-06}, {\"x\": -5.0724637681159415, \"y\": -4.202898550724638, \"x2\": -4.782608695652174, \"y2\": -3.91304347826087, \"center_x\": -4.927536231884058, \"center_y\": -4.057971014492754, \"value_uncond\": 4.346871973693597e-06}, {\"x\": -4.782608695652174, \"y\": -4.202898550724638, \"x2\": -4.492753623188406, \"y2\": -3.91304347826087, \"center_x\": -4.63768115942029, \"center_y\": -4.057971014492754, \"value_uncond\": 5.794897538628808e-06}, {\"x\": -4.492753623188405, \"y\": -4.202898550724638, \"x2\": -4.202898550724638, \"y2\": -3.91304347826087, \"center_x\": -4.3478260869565215, \"center_y\": -4.057971014492754, \"value_uncond\": 7.653507077953004e-06}, {\"x\": -4.202898550724638, \"y\": -4.202898550724638, \"x2\": -3.91304347826087, \"y2\": -3.91304347826087, \"center_x\": -4.057971014492754, \"center_y\": -4.057971014492754, \"value_uncond\": 1.0014309959591713e-05}, {\"x\": -3.913043478260869, \"y\": -4.202898550724638, \"x2\": -3.6231884057971016, \"y2\": -3.91304347826087, \"center_x\": -3.7681159420289854, \"center_y\": -4.057971014492754, \"value_uncond\": 1.2981574952194378e-05}, {\"x\": -3.6231884057971016, \"y\": -4.202898550724638, \"x2\": -3.333333333333334, \"y2\": -3.91304347826087, \"center_x\": -3.4782608695652177, \"center_y\": -4.057971014492754, \"value_uncond\": 1.667168728428361e-05}, {\"x\": -3.333333333333333, \"y\": -4.202898550724638, \"x2\": -3.0434782608695654, \"y2\": -3.91304347826087, \"center_x\": -3.1884057971014492, \"center_y\": -4.057971014492754, \"value_uncond\": 2.1211800817580984e-05}, {\"x\": -3.0434782608695645, \"y\": -4.202898550724638, \"x2\": -2.753623188405797, \"y2\": -3.91304347826087, \"center_x\": -2.8985507246376807, \"center_y\": -4.057971014492754, \"value_uncond\": 2.6737533379948934e-05}, {\"x\": -2.753623188405797, \"y\": -4.202898550724638, \"x2\": -2.4637681159420293, \"y2\": -3.91304347826087, \"center_x\": -2.608695652173913, \"center_y\": -4.057971014492754, \"value_uncond\": 3.33895798085704e-05}, {\"x\": -2.4637681159420284, \"y\": -4.202898550724638, \"x2\": -2.1739130434782608, \"y2\": -3.91304347826087, \"center_x\": -2.3188405797101446, \"center_y\": -4.057971014492754, \"value_uncond\": 4.130916173779552e-05}, {\"x\": -2.1739130434782608, \"y\": -4.202898550724638, \"x2\": -1.8840579710144931, \"y2\": -3.91304347826087, \"center_x\": -2.028985507246377, \"center_y\": -4.057971014492754, \"value_uncond\": 5.063229642172422e-05}, {\"x\": -1.8840579710144922, \"y\": -4.202898550724638, \"x2\": -1.5942028985507246, \"y2\": -3.91304347826087, \"center_x\": -1.7391304347826084, \"center_y\": -4.057971014492754, \"value_uncond\": 6.148294796880874e-05}, {\"x\": -1.5942028985507246, \"y\": -4.202898550724638, \"x2\": -1.304347826086957, \"y2\": -3.91304347826087, \"center_x\": -1.4492753623188408, \"center_y\": -4.057971014492754, \"value_uncond\": 7.396522026032139e-05}, {\"x\": -1.304347826086957, \"y\": -4.202898550724638, \"x2\": -1.0144927536231894, \"y2\": -3.91304347826087, \"center_x\": -1.1594202898550732, \"center_y\": -4.057971014492754, \"value_uncond\": 8.815485623475879e-05}, {\"x\": -1.0144927536231876, \"y\": -4.202898550724638, \"x2\": -0.72463768115942, \"y2\": -3.91304347826087, \"center_x\": -0.8695652173913038, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0001040904156369658}, {\"x\": -0.72463768115942, \"y\": -4.202898550724638, \"x2\": -0.43478260869565233, \"y2\": -3.91304347826087, \"center_x\": -0.5797101449275361, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00012176460336035191}, {\"x\": -0.43478260869565233, \"y\": -4.202898550724638, \"x2\": -0.1449275362318847, \"y2\": -3.91304347826087, \"center_x\": -0.2898550724637685, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0001411163025116883}, {\"x\": -0.14492753623188293, \"y\": -4.202898550724638, \"x2\": 0.1449275362318847, \"y2\": -3.91304347826087, \"center_x\": 8.881784197001252e-16, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00016202391933461542}, {\"x\": 0.1449275362318847, \"y\": -4.202898550724638, \"x2\": 0.43478260869565233, \"y2\": -3.91304347826087, \"center_x\": 0.2898550724637685, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00018430066099712087}, {\"x\": 0.43478260869565233, \"y\": -4.202898550724638, \"x2\": 0.72463768115942, \"y2\": -3.91304347826087, \"center_x\": 0.5797101449275361, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00020769233392663476}, {\"x\": 0.72463768115942, \"y\": -4.202898550724638, \"x2\": 1.0144927536231876, \"y2\": -3.91304347826087, \"center_x\": 0.8695652173913038, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00023187816514453103}, {\"x\": 1.0144927536231894, \"y\": -4.202898550724638, \"x2\": 1.304347826086957, \"y2\": -3.91304347826087, \"center_x\": 1.1594202898550732, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0002564750115807015}, {\"x\": 1.304347826086957, \"y\": -4.202898550724638, \"x2\": 1.5942028985507246, \"y2\": -3.91304347826087, \"center_x\": 1.4492753623188408, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0002810451374034776}, {\"x\": 1.5942028985507246, \"y\": -4.202898550724638, \"x2\": 1.8840579710144922, \"y2\": -3.91304347826087, \"center_x\": 1.7391304347826084, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00030510751704652234}, {\"x\": 1.884057971014494, \"y\": -4.202898550724638, \"x2\": 2.1739130434782616, \"y2\": -3.91304347826087, \"center_x\": 2.028985507246378, \"center_y\": -4.057971014492754, \"value_uncond\": 0.000328152376833221}, {\"x\": 2.1739130434782616, \"y\": -4.202898550724638, \"x2\": 2.4637681159420293, \"y2\": -3.91304347826087, \"center_x\": 2.3188405797101455, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00034965843977834024}, {\"x\": 2.4637681159420293, \"y\": -4.202898550724638, \"x2\": 2.753623188405797, \"y2\": -3.91304347826087, \"center_x\": 2.608695652173913, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0003691121075031647}, {\"x\": 2.753623188405797, \"y\": -4.202898550724638, \"x2\": 3.0434782608695645, \"y2\": -3.91304347826087, \"center_x\": 2.8985507246376807, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0003860276217674322}, {\"x\": 3.0434782608695663, \"y\": -4.202898550724638, \"x2\": 3.333333333333334, \"y2\": -3.91304347826087, \"center_x\": 3.18840579710145, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0003999671155092253}, {\"x\": 3.333333333333334, \"y\": -4.202898550724638, \"x2\": 3.6231884057971016, \"y2\": -3.91304347826087, \"center_x\": 3.4782608695652177, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0004105594049694614}, {\"x\": 3.6231884057971016, \"y\": -4.202898550724638, \"x2\": 3.913043478260869, \"y2\": -3.91304347826087, \"center_x\": 3.7681159420289854, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00041751639990056063}, {\"x\": 3.913043478260871, \"y\": -4.202898550724638, \"x2\": 4.202898550724639, \"y2\": -3.91304347826087, \"center_x\": 4.057971014492755, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0004206461200787862}, {\"x\": 4.202898550724639, \"y\": -4.202898550724638, \"x2\": 4.492753623188406, \"y2\": -3.91304347826087, \"center_x\": 4.347826086956522, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0004198614974519994}, {\"x\": 4.492753623188406, \"y\": -4.202898550724638, \"x2\": 4.782608695652174, \"y2\": -3.91304347826087, \"center_x\": 4.63768115942029, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0004151844006745436}, {\"x\": 4.782608695652174, \"y\": -4.202898550724638, \"x2\": 5.0724637681159415, \"y2\": -3.91304347826087, \"center_x\": 4.927536231884058, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00040674462239744533}, {\"x\": 5.072463768115943, \"y\": -4.202898550724638, \"x2\": 5.362318840579711, \"y2\": -3.91304347826087, \"center_x\": 5.217391304347827, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0003947738947672235}, {\"x\": 5.362318840579711, \"y\": -4.202898550724638, \"x2\": 5.6521739130434785, \"y2\": -3.91304347826087, \"center_x\": 5.507246376811595, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0003795953182494388}, {\"x\": 5.6521739130434785, \"y\": -4.202898550724638, \"x2\": 5.942028985507246, \"y2\": -3.91304347826087, \"center_x\": 5.797101449275362, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00036160887679011775}, {\"x\": 5.942028985507246, \"y\": -4.202898550724638, \"x2\": 6.231884057971014, \"y2\": -3.91304347826087, \"center_x\": 6.08695652173913, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0003412739453083699}, {\"x\": 6.2318840579710155, \"y\": -4.202898550724638, \"x2\": 6.521739130434783, \"y2\": -3.91304347826087, \"center_x\": 6.376811594202899, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0003190898558856549}, {\"x\": 6.521739130434785, \"y\": -4.202898550724638, \"x2\": 6.8115942028985526, \"y2\": -3.91304347826087, \"center_x\": 6.666666666666669, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00029557566617762447}, {\"x\": 6.811594202898551, \"y\": -4.202898550724638, \"x2\": 7.101449275362318, \"y2\": -3.91304347826087, \"center_x\": 6.956521739130435, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0002712502648199919}, {\"x\": 7.10144927536232, \"y\": -4.202898550724638, \"x2\": 7.391304347826088, \"y2\": -3.91304347826087, \"center_x\": 7.246376811594204, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0002466138590582607}, {\"x\": 7.391304347826086, \"y\": -4.202898550724638, \"x2\": 7.681159420289854, \"y2\": -3.91304347826087, \"center_x\": 7.53623188405797, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00022213173155478084}, {\"x\": 7.681159420289855, \"y\": -4.202898550724638, \"x2\": 7.971014492753623, \"y2\": -3.91304347826087, \"center_x\": 7.826086956521739, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0001982209436974218}, {\"x\": 7.971014492753625, \"y\": -4.202898550724638, \"x2\": 8.260869565217392, \"y2\": -3.91304347826087, \"center_x\": 8.115942028985508, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00017524042240459845}, {\"x\": 8.26086956521739, \"y\": -4.202898550724638, \"x2\": 8.550724637681158, \"y2\": -3.91304347826087, \"center_x\": 8.405797101449274, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00015348461805964338}, {\"x\": 8.55072463768116, \"y\": -4.202898550724638, \"x2\": 8.840579710144928, \"y2\": -3.91304347826087, \"center_x\": 8.695652173913043, \"center_y\": -4.057971014492754, \"value_uncond\": 0.0001331806833200212}, {\"x\": 8.84057971014493, \"y\": -4.202898550724638, \"x2\": 9.130434782608697, \"y2\": -3.91304347826087, \"center_x\": 8.985507246376812, \"center_y\": -4.057971014492754, \"value_uncond\": 0.00011448891361810995}, {\"x\": 9.130434782608695, \"y\": -4.202898550724638, \"x2\": 9.420289855072463, \"y2\": -3.91304347826087, \"center_x\": 9.275362318840578, \"center_y\": -4.057971014492754, \"value_uncond\": 9.750602330155659e-05}, {\"x\": 9.420289855072465, \"y\": -4.202898550724638, \"x2\": 9.710144927536232, \"y2\": -3.91304347826087, \"center_x\": 9.565217391304348, \"center_y\": -4.057971014492754, \"value_uncond\": 8.227071450982501e-05}, {\"x\": 9.710144927536234, \"y\": -4.202898550724638, \"x2\": 10.000000000000002, \"y2\": -3.91304347826087, \"center_x\": 9.855072463768117, \"center_y\": -4.057971014492754, \"value_uncond\": 6.877093172144017e-05}, {\"x\": 10.0, \"y\": -4.202898550724638, \"x2\": 10.289855072463768, \"y2\": -3.91304347826087, \"center_x\": 10.144927536231883, \"center_y\": -4.057971014492754, \"value_uncond\": 5.695218124062533e-05}, {\"x\": -10.0, \"y\": -3.913043478260869, \"x2\": -9.710144927536232, \"y2\": -3.6231884057971016, \"center_x\": -9.855072463768117, \"center_y\": -3.7681159420289854, \"value_uncond\": 1.0181724065953475e-08}, {\"x\": -9.710144927536232, \"y\": -3.913043478260869, \"x2\": -9.420289855072465, \"y2\": -3.6231884057971016, \"center_x\": -9.565217391304348, \"center_y\": -3.7681159420289854, \"value_uncond\": 1.5907846367024987e-08}, {\"x\": -9.420289855072463, \"y\": -3.913043478260869, \"x2\": -9.130434782608695, \"y2\": -3.6231884057971016, \"center_x\": -9.275362318840578, \"center_y\": -3.7681159420289854, \"value_uncond\": 2.4623357331384997e-08}, {\"x\": -9.130434782608695, \"y\": -3.913043478260869, \"x2\": -8.840579710144928, \"y2\": -3.6231884057971016, \"center_x\": -8.985507246376812, \"center_y\": -3.7681159420289854, \"value_uncond\": 3.775973707685375e-08}, {\"x\": -8.840579710144928, \"y\": -3.913043478260869, \"x2\": -8.55072463768116, \"y2\": -3.6231884057971016, \"center_x\": -8.695652173913043, \"center_y\": -3.7681159420289854, \"value_uncond\": 5.736625118783737e-08}, {\"x\": -8.55072463768116, \"y\": -3.913043478260869, \"x2\": -8.260869565217392, \"y2\": -3.6231884057971016, \"center_x\": -8.405797101449277, \"center_y\": -3.7681159420289854, \"value_uncond\": 8.634352867076865e-08}, {\"x\": -8.26086956521739, \"y\": -3.913043478260869, \"x2\": -7.971014492753623, \"y2\": -3.6231884057971016, \"center_x\": -8.115942028985508, \"center_y\": -3.7681159420289854, \"value_uncond\": 1.287505019951189e-07}, {\"x\": -7.971014492753623, \"y\": -3.913043478260869, \"x2\": -7.681159420289855, \"y2\": -3.6231884057971016, \"center_x\": -7.826086956521739, \"center_y\": -3.7681159420289854, \"value_uncond\": 1.902014761801341e-07}, {\"x\": -7.681159420289855, \"y\": -3.913043478260869, \"x2\": -7.391304347826088, \"y2\": -3.6231884057971016, \"center_x\": -7.536231884057972, \"center_y\": -3.7681159420289854, \"value_uncond\": 2.783714233085887e-07}, {\"x\": -7.391304347826087, \"y\": -3.913043478260869, \"x2\": -7.101449275362319, \"y2\": -3.6231884057971016, \"center_x\": -7.246376811594203, \"center_y\": -3.7681159420289854, \"value_uncond\": 4.036279491765524e-07}, {\"x\": -7.101449275362318, \"y\": -3.913043478260869, \"x2\": -6.811594202898551, \"y2\": -3.6231884057971016, \"center_x\": -6.956521739130435, \"center_y\": -3.7681159420289854, \"value_uncond\": 5.798072307485984e-07}, {\"x\": -6.811594202898551, \"y\": -3.913043478260869, \"x2\": -6.521739130434783, \"y2\": -3.6231884057971016, \"center_x\": -6.666666666666667, \"center_y\": -3.7681159420289854, \"value_uncond\": 8.25147973654423e-07}, {\"x\": -6.521739130434782, \"y\": -3.913043478260869, \"x2\": -6.231884057971015, \"y2\": -3.6231884057971016, \"center_x\": -6.3768115942028984, \"center_y\": -3.7681159420289854, \"value_uncond\": 1.1633914356796153e-06}, {\"x\": -6.231884057971014, \"y\": -3.913043478260869, \"x2\": -5.942028985507246, \"y2\": -3.6231884057971016, \"center_x\": -6.08695652173913, \"center_y\": -3.7681159420289854, \"value_uncond\": 1.625046160338616e-06}, {\"x\": -5.942028985507246, \"y\": -3.913043478260869, \"x2\": -5.6521739130434785, \"y2\": -3.6231884057971016, \"center_x\": -5.797101449275362, \"center_y\": -3.7681159420289854, \"value_uncond\": 2.248802709485845e-06}, {\"x\": -5.6521739130434785, \"y\": -3.913043478260869, \"x2\": -5.362318840579711, \"y2\": -3.6231884057971016, \"center_x\": -5.507246376811595, \"center_y\": -3.7681159420289854, \"value_uncond\": 3.0830660178731517e-06}, {\"x\": -5.36231884057971, \"y\": -3.913043478260869, \"x2\": -5.072463768115942, \"y2\": -3.6231884057971016, \"center_x\": -5.217391304347826, \"center_y\": -3.7681159420289854, \"value_uncond\": 4.187550982121279e-06}, {\"x\": -5.0724637681159415, \"y\": -3.913043478260869, \"x2\": -4.782608695652174, \"y2\": -3.6231884057971016, \"center_x\": -4.927536231884058, \"center_y\": -3.7681159420289854, \"value_uncond\": 5.634860970130909e-06}, {\"x\": -4.782608695652174, \"y\": -3.913043478260869, \"x2\": -4.492753623188406, \"y2\": -3.6231884057971016, \"center_x\": -4.63768115942029, \"center_y\": -3.7681159420289854, \"value_uncond\": 7.511940117845491e-06}, {\"x\": -4.492753623188405, \"y\": -3.913043478260869, \"x2\": -4.202898550724638, \"y2\": -3.6231884057971016, \"center_x\": -4.3478260869565215, \"center_y\": -3.7681159420289854, \"value_uncond\": 9.921260294568287e-06}, {\"x\": -4.202898550724638, \"y\": -3.913043478260869, \"x2\": -3.91304347826087, \"y2\": -3.6231884057971016, \"center_x\": -4.057971014492754, \"center_y\": -3.7681159420289854, \"value_uncond\": 1.2981574952194378e-05}, {\"x\": -3.913043478260869, \"y\": -3.913043478260869, \"x2\": -3.6231884057971016, \"y2\": -3.6231884057971016, \"center_x\": -3.7681159420289854, \"center_y\": -3.7681159420289854, \"value_uncond\": 1.6828047955319243e-05}, {\"x\": -3.6231884057971016, \"y\": -3.913043478260869, \"x2\": -3.333333333333334, \"y2\": -3.6231884057971016, \"center_x\": -3.4782608695652177, \"center_y\": -3.7681159420289854, \"value_uncond\": 2.1611549765661293e-05}, {\"x\": -3.333333333333333, \"y\": -3.913043478260869, \"x2\": -3.0434782608695654, \"y2\": -3.6231884057971016, \"center_x\": -3.1884057971014492, \"center_y\": -3.7681159420289854, \"value_uncond\": 2.7496910250985696e-05}, {\"x\": -3.0434782608695645, \"y\": -3.913043478260869, \"x2\": -2.753623188405797, \"y2\": -3.6231884057971016, \"center_x\": -2.8985507246376807, \"center_y\": -3.7681159420289854, \"value_uncond\": 3.4659931139454876e-05}, {\"x\": -2.753623188405797, \"y\": -3.913043478260869, \"x2\": -2.4637681159420293, \"y2\": -3.6231884057971016, \"center_x\": -2.608695652173913, \"center_y\": -3.7681159420289854, \"value_uncond\": 4.328299549906327e-05}, {\"x\": -2.4637681159420284, \"y\": -3.913043478260869, \"x2\": -2.1739130434782608, \"y2\": -3.6231884057971016, \"center_x\": -2.3188405797101446, \"center_y\": -3.7681159420289854, \"value_uncond\": 5.354916928628562e-05}, {\"x\": -2.1739130434782608, \"y\": -3.913043478260869, \"x2\": -1.8840579710144931, \"y2\": -3.6231884057971016, \"center_x\": -2.028985507246377, \"center_y\": -3.7681159420289854, \"value_uncond\": 6.563477200651124e-05}, {\"x\": -1.8840579710144922, \"y\": -3.913043478260869, \"x2\": -1.5942028985507246, \"y2\": -3.6231884057971016, \"center_x\": -1.7391304347826084, \"center_y\": -3.7681159420289854, \"value_uncond\": 7.97004986423945e-05}, {\"x\": -1.5942028985507246, \"y\": -3.913043478260869, \"x2\": -1.304347826086957, \"y2\": -3.6231884057971016, \"center_x\": -1.4492753623188408, \"center_y\": -3.7681159420289854, \"value_uncond\": 9.588129931461353e-05}, {\"x\": -1.304347826086957, \"y\": -3.913043478260869, \"x2\": -1.0144927536231894, \"y2\": -3.6231884057971016, \"center_x\": -1.1594202898550732, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0001142753597830617}, {\"x\": -1.0144927536231876, \"y\": -3.913043478260869, \"x2\": -0.72463768115942, \"y2\": -3.6231884057971016, \"center_x\": -0.8695652173913038, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0001349326651410567}, {\"x\": -0.72463768115942, \"y\": -3.913043478260869, \"x2\": -0.43478260869565233, \"y2\": -3.6231884057971016, \"center_x\": -0.5797101449275361, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0001578437587237487}, {\"x\": -0.43478260869565233, \"y\": -3.913043478260869, \"x2\": -0.1449275362318847, \"y2\": -3.6231884057971016, \"center_x\": -0.2898550724637685, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00018292941455016692}, {\"x\": -0.14492753623188293, \"y\": -3.913043478260869, \"x2\": 0.1449275362318847, \"y2\": -3.6231884057971016, \"center_x\": 8.881784197001252e-16, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00021003201033098035}, {\"x\": 0.1449275362318847, \"y\": -3.913043478260869, \"x2\": 0.43478260869565233, \"y2\": -3.6231884057971016, \"center_x\": 0.2898550724637685, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00023890940605263985}, {\"x\": 0.43478260869565233, \"y\": -3.913043478260869, \"x2\": 0.72463768115942, \"y2\": -3.6231884057971016, \"center_x\": 0.5797101449275361, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0002692320899536763}, {\"x\": 0.72463768115942, \"y\": -3.913043478260869, \"x2\": 1.0144927536231876, \"y2\": -3.6231884057971016, \"center_x\": 0.8695652173913038, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00030058424322266115}, {\"x\": 1.0144927536231894, \"y\": -3.913043478260869, \"x2\": 1.304347826086957, \"y2\": -3.6231884057971016, \"center_x\": 1.1594202898550732, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0003324691965431773}, {\"x\": 1.304347826086957, \"y\": -3.913043478260869, \"x2\": 1.5942028985507246, \"y2\": -3.6231884057971016, \"center_x\": 1.4492753623188408, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00036431951186597375}, {\"x\": 1.5942028985507246, \"y\": -3.913043478260869, \"x2\": 1.8840579710144922, \"y2\": -3.6231884057971016, \"center_x\": 1.7391304347826084, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00039551163455088756}, {\"x\": 1.884057971014494, \"y\": -3.913043478260869, \"x2\": 2.1739130434782616, \"y2\": -3.6231884057971016, \"center_x\": 2.028985507246378, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00042538474371077597}, {\"x\": 2.1739130434782616, \"y\": -3.913043478260869, \"x2\": 2.4637681159420293, \"y2\": -3.6231884057971016, \"center_x\": 2.3188405797101455, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00045326310669087074}, {\"x\": 2.4637681159420293, \"y\": -3.913043478260869, \"x2\": 2.753623188405797, \"y2\": -3.6231884057971016, \"center_x\": 2.608695652173913, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0004784809446331656}, {\"x\": 2.753623188405797, \"y\": -3.913043478260869, \"x2\": 3.0434782608695645, \"y2\": -3.6231884057971016, \"center_x\": 2.8985507246376807, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0005004085679204973}, {\"x\": 3.0434782608695663, \"y\": -3.913043478260869, \"x2\": 3.333333333333334, \"y2\": -3.6231884057971016, \"center_x\": 3.18840579710145, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0005184783683895163}, {\"x\": 3.333333333333334, \"y\": -3.913043478260869, \"x2\": 3.6231884057971016, \"y2\": -3.6231884057971016, \"center_x\": 3.4782608695652177, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0005322091796084853}, {\"x\": 3.6231884057971016, \"y\": -3.913043478260869, \"x2\": 3.913043478260869, \"y2\": -3.6231884057971016, \"center_x\": 3.7681159420289854, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0005412275494716628}, {\"x\": 3.913043478260871, \"y\": -3.913043478260869, \"x2\": 4.202898550724639, \"y2\": -3.6231884057971016, \"center_x\": 4.057971014492755, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0005452846135366828}, {\"x\": 4.202898550724639, \"y\": -3.913043478260869, \"x2\": 4.492753623188406, \"y2\": -3.6231884057971016, \"center_x\": 4.347826086956522, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0005442675052706195}, {\"x\": 4.492753623188406, \"y\": -3.913043478260869, \"x2\": 4.782608695652174, \"y2\": -3.6231884057971016, \"center_x\": 4.63768115942029, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.000538204573064586}, {\"x\": 4.782608695652174, \"y\": -3.913043478260869, \"x2\": 5.0724637681159415, \"y2\": -3.6231884057971016, \"center_x\": 4.927536231884058, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0005272640674554986}, {\"x\": 5.072463768115943, \"y\": -3.913043478260869, \"x2\": 5.362318840579711, \"y2\": -3.6231884057971016, \"center_x\": 5.217391304347827, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0005117463834022716}, {\"x\": 5.362318840579711, \"y\": -3.913043478260869, \"x2\": 5.6521739130434785, \"y2\": -3.6231884057971016, \"center_x\": 5.507246376811595, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0004920703568434459}, {\"x\": 5.6521739130434785, \"y\": -3.913043478260869, \"x2\": 5.942028985507246, \"y2\": -3.6231884057971016, \"center_x\": 5.797101449275362, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0004687544879648525}, {\"x\": 5.942028985507246, \"y\": -3.913043478260869, \"x2\": 6.231884057971014, \"y2\": -3.6231884057971016, \"center_x\": 6.08695652173913, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00044239426561870794}, {\"x\": 6.2318840579710155, \"y\": -3.913043478260869, \"x2\": 6.521739130434783, \"y2\": -3.6231884057971016, \"center_x\": 6.376811594202899, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0004136369752263406}, {\"x\": 6.521739130434785, \"y\": -3.913043478260869, \"x2\": 6.8115942028985526, \"y2\": -3.6231884057971016, \"center_x\": 6.666666666666669, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00038315547252005096}, {\"x\": 6.811594202898551, \"y\": -3.913043478260869, \"x2\": 7.101449275362318, \"y2\": -3.6231884057971016, \"center_x\": 6.956521739130435, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.000351622394131174}, {\"x\": 7.10144927536232, \"y\": -3.913043478260869, \"x2\": 7.391304347826088, \"y2\": -3.6231884057971016, \"center_x\": 7.246376811594204, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00031968615995836775}, {\"x\": 7.391304347826086, \"y\": -3.913043478260869, \"x2\": 7.681159420289854, \"y2\": -3.6231884057971016, \"center_x\": 7.53623188405797, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.0002879499170761312}, {\"x\": 7.681159420289855, \"y\": -3.913043478260869, \"x2\": 7.971014492753623, \"y2\": -3.6231884057971016, \"center_x\": 7.826086956521739, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00025695430320070645}, {\"x\": 7.971014492753625, \"y\": -3.913043478260869, \"x2\": 8.260869565217392, \"y2\": -3.6231884057971016, \"center_x\": 8.115942028985508, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00022716459619073407}, {\"x\": 8.26086956521739, \"y\": -3.913043478260869, \"x2\": 8.550724637681158, \"y2\": -3.6231884057971016, \"center_x\": 8.405797101449274, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00019896249281177862}, {\"x\": 8.55072463768116, \"y\": -3.913043478260869, \"x2\": 8.840579710144928, \"y2\": -3.6231884057971016, \"center_x\": 8.695652173913043, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00017264245161968284}, {\"x\": 8.84057971014493, \"y\": -3.913043478260869, \"x2\": 9.130434782608697, \"y2\": -3.6231884057971016, \"center_x\": 8.985507246376812, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00014841226398282917}, {\"x\": 9.130434782608695, \"y\": -3.913043478260869, \"x2\": 9.420289855072463, \"y2\": -3.6231884057971016, \"center_x\": 9.275362318840578, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00012639730095104576}, {\"x\": 9.420289855072465, \"y\": -3.913043478260869, \"x2\": 9.710144927536232, \"y2\": -3.6231884057971016, \"center_x\": 9.565217391304348, \"center_y\": -3.7681159420289854, \"value_uncond\": 0.00010664773220414889}, {\"x\": 9.710144927536234, \"y\": -3.913043478260869, \"x2\": 10.000000000000002, \"y2\": -3.6231884057971016, \"center_x\": 9.855072463768117, \"center_y\": -3.7681159420289854, \"value_uncond\": 8.914793013961349e-05}, {\"x\": 10.0, \"y\": -3.913043478260869, \"x2\": 10.289855072463768, \"y2\": -3.6231884057971016, \"center_x\": 10.144927536231883, \"center_y\": -3.7681159420289854, \"value_uncond\": 7.382725444382787e-05}, {\"x\": -10.0, \"y\": -3.6231884057971016, \"x2\": -9.710144927536232, \"y2\": -3.333333333333334, \"center_x\": -9.855072463768117, \"center_y\": -3.4782608695652177, \"value_uncond\": 1.3075957290817584e-08}, {\"x\": -9.710144927536232, \"y\": -3.6231884057971016, \"x2\": -9.420289855072465, \"y2\": -3.333333333333334, \"center_x\": -9.565217391304348, \"center_y\": -3.4782608695652177, \"value_uncond\": 2.0429773812047134e-08}, {\"x\": -9.420289855072463, \"y\": -3.6231884057971016, \"x2\": -9.130434782608695, \"y2\": -3.333333333333334, \"center_x\": -9.275362318840578, \"center_y\": -3.4782608695652177, \"value_uncond\": 3.16227356718863e-08}, {\"x\": -9.130434782608695, \"y\": -3.6231884057971016, \"x2\": -8.840579710144928, \"y2\": -3.333333333333334, \"center_x\": -8.985507246376812, \"center_y\": -3.4782608695652177, \"value_uncond\": 4.8493232200278026e-08}, {\"x\": -8.840579710144928, \"y\": -3.6231884057971016, \"x2\": -8.55072463768116, \"y2\": -3.333333333333334, \"center_x\": -8.695652173913043, \"center_y\": -3.4782608695652177, \"value_uncond\": 7.36730484550044e-08}, {\"x\": -8.55072463768116, \"y\": -3.6231884057971016, \"x2\": -8.260869565217392, \"y2\": -3.333333333333334, \"center_x\": -8.405797101449277, \"center_y\": -3.4782608695652177, \"value_uncond\": 1.1088733950400234e-07}, {\"x\": -8.26086956521739, \"y\": -3.6231884057971016, \"x2\": -7.971014492753623, \"y2\": -3.333333333333334, \"center_x\": -8.115942028985508, \"center_y\": -3.4782608695652177, \"value_uncond\": 1.6534882052923152e-07}, {\"x\": -7.971014492753623, \"y\": -3.6231884057971016, \"x2\": -7.681159420289855, \"y2\": -3.333333333333334, \"center_x\": -7.826086956521739, \"center_y\": -3.4782608695652177, \"value_uncond\": 2.442677058493814e-07}, {\"x\": -7.681159420289855, \"y\": -3.6231884057971016, \"x2\": -7.391304347826088, \"y2\": -3.333333333333334, \"center_x\": -7.536231884057972, \"center_y\": -3.4782608695652177, \"value_uncond\": 3.575006372780089e-07}, {\"x\": -7.391304347826087, \"y\": -3.6231884057971016, \"x2\": -7.101449275362319, \"y2\": -3.333333333333334, \"center_x\": -7.246376811594203, \"center_y\": -3.4782608695652177, \"value_uncond\": 5.183622921447384e-07}, {\"x\": -7.101449275362318, \"y\": -3.6231884057971016, \"x2\": -6.811594202898551, \"y2\": -3.333333333333334, \"center_x\": -6.956521739130435, \"center_y\": -3.4782608695652177, \"value_uncond\": 7.446218869285287e-07}, {\"x\": -6.811594202898551, \"y\": -3.6231884057971016, \"x2\": -6.521739130434783, \"y2\": -3.333333333333334, \"center_x\": -6.666666666666667, \"center_y\": -3.4782608695652177, \"value_uncond\": 1.0597026193421523e-06}, {\"x\": -6.521739130434782, \"y\": -3.6231884057971016, \"x2\": -6.231884057971015, \"y2\": -3.333333333333334, \"center_x\": -6.3768115942028984, \"center_y\": -3.4782608695652177, \"value_uncond\": 1.4940943819444437e-06}, {\"x\": -6.231884057971014, \"y\": -3.6231884057971016, \"x2\": -5.942028985507246, \"y2\": -3.333333333333334, \"center_x\": -6.08695652173913, \"center_y\": -3.4782608695652177, \"value_uncond\": 2.0869780059399955e-06}, {\"x\": -5.942028985507246, \"y\": -3.6231884057971016, \"x2\": -5.6521739130434785, \"y2\": -3.333333333333334, \"center_x\": -5.797101449275362, \"center_y\": -3.4782608695652177, \"value_uncond\": 2.8880421423950747e-06}, {\"x\": -5.6521739130434785, \"y\": -3.6231884057971016, \"x2\": -5.362318840579711, \"y2\": -3.333333333333334, \"center_x\": -5.507246376811595, \"center_y\": -3.4782608695652177, \"value_uncond\": 3.959451200341003e-06}, {\"x\": -5.36231884057971, \"y\": -3.6231884057971016, \"x2\": -5.072463768115942, \"y2\": -3.333333333333334, \"center_x\": -5.217391304347826, \"center_y\": -3.4782608695652177, \"value_uncond\": 5.377894494159164e-06}, {\"x\": -5.0724637681159415, \"y\": -3.6231884057971016, \"x2\": -4.782608695652174, \"y2\": -3.333333333333334, \"center_x\": -4.927536231884058, \"center_y\": -3.4782608695652177, \"value_uncond\": 7.2366134564094345e-06}, {\"x\": -4.782608695652174, \"y\": -3.6231884057971016, \"x2\": -4.492753623188406, \"y2\": -3.333333333333334, \"center_x\": -4.63768115942029, \"center_y\": -3.4782608695652177, \"value_uncond\": 9.647266761096261e-06}, {\"x\": -4.492753623188405, \"y\": -3.6231884057971016, \"x2\": -4.202898550724638, \"y2\": -3.333333333333334, \"center_x\": -4.3478260869565215, \"center_y\": -3.4782608695652177, \"value_uncond\": 1.2741454692988741e-05}, {\"x\": -4.202898550724638, \"y\": -3.6231884057971016, \"x2\": -3.91304347826087, \"y2\": -3.333333333333334, \"center_x\": -4.057971014492754, \"center_y\": -3.4782608695652177, \"value_uncond\": 1.667168728428361e-05}, {\"x\": -3.913043478260869, \"y\": -3.6231884057971016, \"x2\": -3.6231884057971016, \"y2\": -3.333333333333334, \"center_x\": -3.7681159420289854, \"center_y\": -3.4782608695652177, \"value_uncond\": 2.1611549765661293e-05}, {\"x\": -3.6231884057971016, \"y\": -3.6231884057971016, \"x2\": -3.333333333333334, \"y2\": -3.333333333333334, \"center_x\": -3.4782608695652177, \"center_y\": -3.4782608695652177, \"value_uncond\": 2.775479868572752e-05}, {\"x\": -3.333333333333333, \"y\": -3.6231884057971016, \"x2\": -3.0434782608695654, \"y2\": -3.333333333333334, \"center_x\": -3.1884057971014492, \"center_y\": -3.4782608695652177, \"value_uncond\": 3.5313118067461914e-05}, {\"x\": -3.0434782608695645, \"y\": -3.6231884057971016, \"x2\": -2.753623188405797, \"y2\": -3.333333333333334, \"center_x\": -2.8985507246376807, \"center_y\": -3.4782608695652177, \"value_uncond\": 4.451228262978362e-05}, {\"x\": -2.753623188405797, \"y\": -3.6231884057971016, \"x2\": -2.4637681159420293, \"y2\": -3.333333333333334, \"center_x\": -2.608695652173913, \"center_y\": -3.4782608695652177, \"value_uncond\": 5.5586519227812194e-05}, {\"x\": -2.4637681159420284, \"y\": -3.6231884057971016, \"x2\": -2.1739130434782608, \"y2\": -3.333333333333334, \"center_x\": -2.3188405797101446, \"center_y\": -3.4782608695652177, \"value_uncond\": 6.87709317214403e-05}, {\"x\": -2.1739130434782608, \"y\": -3.6231884057971016, \"x2\": -1.8840579710144931, \"y2\": -3.333333333333334, \"center_x\": -2.028985507246377, \"center_y\": -3.4782608695652177, \"value_uncond\": 8.429195978896527e-05}, {\"x\": -1.8840579710144922, \"y\": -3.6231884057971016, \"x2\": -1.5942028985507246, \"y2\": -3.333333333333334, \"center_x\": -1.7391304347826084, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00010235597719542227}, {\"x\": -1.5942028985507246, \"y\": -3.6231884057971016, \"x2\": -1.304347826086957, \"y2\": -3.333333333333334, \"center_x\": -1.4492753623188408, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00012313629466922468}, {\"x\": -1.304347826086957, \"y\": -3.6231884057971016, \"x2\": -1.0144927536231894, \"y2\": -3.333333333333334, \"center_x\": -1.1594202898550732, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00014675900802623028}, {\"x\": -1.0144927536231876, \"y\": -3.6231884057971016, \"x2\": -0.72463768115942, \"y2\": -3.333333333333334, \"center_x\": -0.8695652173913038, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0001732883110062385}, {\"x\": -0.72463768115942, \"y\": -3.6231884057971016, \"x2\": -0.43478260869565233, \"y2\": -3.333333333333334, \"center_x\": -0.5797101449275361, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0002027120588148225}, {\"x\": -0.43478260869565233, \"y\": -3.6231884057971016, \"x2\": -0.1449275362318847, \"y2\": -3.333333333333334, \"center_x\": -0.2898550724637685, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00023492850487774914}, {\"x\": -0.14492753623188293, \"y\": -3.6231884057971016, \"x2\": 0.1449275362318847, \"y2\": -3.333333333333334, \"center_x\": 8.881784197001252e-16, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00026973522155997187}, {\"x\": 0.1449275362318847, \"y\": -3.6231884057971016, \"x2\": 0.43478260869565233, \"y2\": -3.333333333333334, \"center_x\": 0.2898550724637685, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0003068212386903227}, {\"x\": 0.43478260869565233, \"y\": -3.6231884057971016, \"x2\": 0.72463768115942, \"y2\": -3.333333333333334, \"center_x\": 0.5797101449275361, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00034576337825966737}, {\"x\": 0.72463768115942, \"y\": -3.6231884057971016, \"x2\": 1.0144927536231876, \"y2\": -3.333333333333334, \"center_x\": 0.8695652173913038, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0003860276217674317}, {\"x\": 1.0144927536231894, \"y\": -3.6231884057971016, \"x2\": 1.304347826086957, \"y2\": -3.333333333333334, \"center_x\": 1.1594202898550732, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0004269761178313679}, {\"x\": 1.304347826086957, \"y\": -3.6231884057971016, \"x2\": 1.5942028985507246, \"y2\": -3.333333333333334, \"center_x\": 1.4492753623188408, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0004678801297808369}, {\"x\": 1.5942028985507246, \"y\": -3.6231884057971016, \"x2\": 1.8840579710144922, \"y2\": -3.333333333333334, \"center_x\": 1.7391304347826084, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0005079388527825471}, {\"x\": 1.884057971014494, \"y\": -3.6231884057971016, \"x2\": 2.1739130434782616, \"y2\": -3.333333333333334, \"center_x\": 2.028985507246378, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.000546303622539451}, {\"x\": 2.1739130434782616, \"y\": -3.6231884057971016, \"x2\": 2.4637681159420293, \"y2\": -3.333333333333334, \"center_x\": 2.3188405797101455, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0005821066242024599}, {\"x\": 2.4637681159420293, \"y\": -3.6231884057971016, \"x2\": 2.753623188405797, \"y2\": -3.333333333333334, \"center_x\": 2.608695652173913, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0006144928261623858}, {\"x\": 2.753623188405797, \"y\": -3.6231884057971016, \"x2\": 3.0434782608695645, \"y2\": -3.333333333333334, \"center_x\": 2.8985507246376807, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0006426535446946294}, {\"x\": 3.0434782608695663, \"y\": -3.6231884057971016, \"x2\": 3.333333333333334, \"y2\": -3.333333333333334, \"center_x\": 3.18840579710145, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0006658598246582143}, {\"x\": 3.333333333333334, \"y\": -3.6231884057971016, \"x2\": 3.6231884057971016, \"y2\": -3.333333333333334, \"center_x\": 3.4782608695652177, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0006834937243695501}, {\"x\": 3.6231884057971016, \"y\": -3.6231884057971016, \"x2\": 3.913043478260869, \"y2\": -3.333333333333334, \"center_x\": 3.7681159420289854, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0006950756350950657}, {\"x\": 3.913043478260871, \"y\": -3.6231884057971016, \"x2\": 4.202898550724639, \"y2\": -3.333333333333334, \"center_x\": 4.057971014492755, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0007002859507642661}, {\"x\": 4.202898550724639, \"y\": -3.6231884057971016, \"x2\": 4.492753623188406, \"y2\": -3.333333333333334, \"center_x\": 4.347826086956522, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0006989797216658312}, {\"x\": 4.492753623188406, \"y\": -3.6231884057971016, \"x2\": 4.782608695652174, \"y2\": -3.333333333333334, \"center_x\": 4.63768115942029, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0006911933544386626}, {\"x\": 4.782608695652174, \"y\": -3.6231884057971016, \"x2\": 5.0724637681159415, \"y2\": -3.333333333333334, \"center_x\": 4.927536231884058, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0006771429261263549}, {\"x\": 5.072463768115943, \"y\": -3.6231884057971016, \"x2\": 5.362318840579711, \"y2\": -3.333333333333334, \"center_x\": 5.217391304347827, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0006572142212608497}, {\"x\": 5.362318840579711, \"y\": -3.6231884057971016, \"x2\": 5.6521739130434785, \"y2\": -3.333333333333334, \"center_x\": 5.507246376811595, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.000631945133111376}, {\"x\": 5.6521739130434785, \"y\": -3.6231884057971016, \"x2\": 5.942028985507246, \"y2\": -3.333333333333334, \"center_x\": 5.797101449275362, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0006020015495218082}, {\"x\": 5.942028985507246, \"y\": -3.6231884057971016, \"x2\": 6.231884057971014, \"y2\": -3.333333333333334, \"center_x\": 6.08695652173913, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0005681482316218242}, {\"x\": 6.2318840579710155, \"y\": -3.6231884057971016, \"x2\": 6.521739130434783, \"y2\": -3.333333333333334, \"center_x\": 6.376811594202899, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0005312164606825947}, {\"x\": 6.521739130434785, \"y\": -3.6231884057971016, \"x2\": 6.8115942028985526, \"y2\": -3.333333333333334, \"center_x\": 6.666666666666669, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.000492070356843445}, {\"x\": 6.811594202898551, \"y\": -3.6231884057971016, \"x2\": 7.101449275362318, \"y2\": -3.333333333333334, \"center_x\": 6.956521739130435, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0004515737588616033}, {\"x\": 7.10144927536232, \"y\": -3.6231884057971016, \"x2\": 7.391304347826088, \"y2\": -3.333333333333334, \"center_x\": 7.246376811594204, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00041055940496946086}, {\"x\": 7.391304347826086, \"y\": -3.6231884057971016, \"x2\": 7.681159420289854, \"y2\": -3.333333333333334, \"center_x\": 7.53623188405797, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0003698018914274478}, {\"x\": 7.681159420289855, \"y\": -3.6231884057971016, \"x2\": 7.971014492753623, \"y2\": -3.333333333333334, \"center_x\": 7.826086956521739, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00032999553637280677}, {\"x\": 7.971014492753625, \"y\": -3.6231884057971016, \"x2\": 8.260869565217392, \"y2\": -3.333333333333334, \"center_x\": 8.115942028985508, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00029173787646716157}, {\"x\": 8.26086956521739, \"y\": -3.6231884057971016, \"x2\": 8.550724637681158, \"y2\": -3.333333333333334, \"center_x\": 8.405797101449274, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.000255519108711751}, {\"x\": 8.55072463768116, \"y\": -3.6231884057971016, \"x2\": 8.840579710144928, \"y2\": -3.333333333333334, \"center_x\": 8.695652173913043, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.0002217173937673012}, {\"x\": 8.84057971014493, \"y\": -3.6231884057971016, \"x2\": 9.130434782608697, \"y2\": -3.333333333333334, \"center_x\": 8.985507246376812, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00019059958929374977}, {\"x\": 9.130434782608695, \"y\": -3.6231884057971016, \"x2\": 9.420289855072463, \"y2\": -3.333333333333334, \"center_x\": 9.275362318840578, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00016232670402423812}, {\"x\": 9.420289855072465, \"y\": -3.6231884057971016, \"x2\": 9.710144927536232, \"y2\": -3.333333333333334, \"center_x\": 9.565217391304348, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00013696316875519372}, {\"x\": 9.710144927536234, \"y\": -3.6231884057971016, \"x2\": 10.000000000000002, \"y2\": -3.333333333333334, \"center_x\": 9.855072463768117, \"center_y\": -3.4782608695652177, \"value_uncond\": 0.00011448891361810975}, {\"x\": 10.0, \"y\": -3.6231884057971016, \"x2\": 10.289855072463768, \"y2\": -3.333333333333334, \"center_x\": 10.144927536231883, \"center_y\": -3.4782608695652177, \"value_uncond\": 9.48132182479661e-05}, {\"x\": -10.0, \"y\": -3.333333333333333, \"x2\": -9.710144927536232, \"y2\": -3.0434782608695654, \"center_x\": -9.855072463768117, \"center_y\": -3.1884057971014492, \"value_uncond\": 1.663686445303529e-08}, {\"x\": -9.710144927536232, \"y\": -3.333333333333333, \"x2\": -9.420289855072465, \"y2\": -3.0434782608695654, \"center_x\": -9.565217391304348, \"center_y\": -3.1884057971014492, \"value_uncond\": 2.5993307423532162e-08}, {\"x\": -9.420289855072463, \"y\": -3.333333333333333, \"x2\": -9.130434782608695, \"y2\": -3.0434782608695654, \"center_x\": -9.275362318840578, \"center_y\": -3.1884057971014492, \"value_uncond\": 4.0234390133469245e-08}, {\"x\": -9.130434782608695, \"y\": -3.333333333333333, \"x2\": -8.840579710144928, \"y2\": -3.0434782608695654, \"center_x\": -8.985507246376812, \"center_y\": -3.1884057971014492, \"value_uncond\": 6.169914087836146e-08}, {\"x\": -8.840579710144928, \"y\": -3.333333333333333, \"x2\": -8.55072463768116, \"y2\": -3.0434782608695654, \"center_x\": -8.695652173913043, \"center_y\": -3.1884057971014492, \"value_uncond\": 9.373604499676155e-08}, {\"x\": -8.55072463768116, \"y\": -3.333333333333333, \"x2\": -8.260869565217392, \"y2\": -3.0434782608695654, \"center_x\": -8.405797101449277, \"center_y\": -3.1884057971014492, \"value_uncond\": 1.41084709582318e-07}, {\"x\": -8.26086956521739, \"y\": -3.333333333333333, \"x2\": -7.971014492753623, \"y2\": -3.0434782608695654, \"center_x\": -8.115942028985508, \"center_y\": -3.1884057971014492, \"value_uncond\": 2.1037740132004386e-07}, {\"x\": -7.971014492753623, \"y\": -3.333333333333333, \"x2\": -7.681159420289855, \"y2\": -3.0434782608695654, \"center_x\": -7.826086956521739, \"center_y\": -3.1884057971014492, \"value_uncond\": 3.1078785454001425e-07}, {\"x\": -7.681159420289855, \"y\": -3.333333333333333, \"x2\": -7.391304347826088, \"y2\": -3.0434782608695654, \"center_x\": -7.536231884057972, \"center_y\": -3.1884057971014492, \"value_uncond\": 4.548569188463666e-07}, {\"x\": -7.391304347826087, \"y\": -3.333333333333333, \"x2\": -7.101449275362319, \"y2\": -3.0434782608695654, \"center_x\": -7.246376811594203, \"center_y\": -3.1884057971014492, \"value_uncond\": 6.595251881124395e-07}, {\"x\": -7.101449275362318, \"y\": -3.333333333333333, \"x2\": -6.811594202898551, \"y2\": -3.0434782608695654, \"center_x\": -6.956521739130435, \"center_y\": -3.1884057971014492, \"value_uncond\": 9.474008767444301e-07}, {\"x\": -6.811594202898551, \"y\": -3.333333333333333, \"x2\": -6.521739130434783, \"y2\": -3.0434782608695654, \"center_x\": -6.666666666666667, \"center_y\": -3.1884057971014492, \"value_uncond\": 1.3482858995648702e-06}, {\"x\": -6.521739130434782, \"y\": -3.333333333333333, \"x2\": -6.231884057971015, \"y2\": -3.0434782608695654, \"center_x\": -6.3768115942028984, \"center_y\": -3.1884057971014492, \"value_uncond\": 1.9009733023452697e-06}, {\"x\": -6.231884057971014, \"y\": -3.333333333333333, \"x2\": -5.942028985507246, \"y2\": -3.0434782608695654, \"center_x\": -6.08695652173913, \"center_y\": -3.1884057971014492, \"value_uncond\": 2.6553138274374587e-06}, {\"x\": -5.942028985507246, \"y\": -3.333333333333333, \"x2\": -5.6521739130434785, \"y2\": -3.0434782608695654, \"center_x\": -5.797101449275362, \"center_y\": -3.1884057971014492, \"value_uncond\": 3.674527576762701e-06}, {\"x\": -5.6521739130434785, \"y\": -3.333333333333333, \"x2\": -5.362318840579711, \"y2\": -3.0434782608695654, \"center_x\": -5.507246376811595, \"center_y\": -3.1884057971014492, \"value_uncond\": 5.037707868221586e-06}, {\"x\": -5.36231884057971, \"y\": -3.333333333333333, \"x2\": -5.072463768115942, \"y2\": -3.0434782608695654, \"center_x\": -5.217391304347826, \"center_y\": -3.1884057971014492, \"value_uncond\": 6.842428416685089e-06}, {\"x\": -5.0724637681159415, \"y\": -3.333333333333333, \"x2\": -4.782608695652174, \"y2\": -3.0434782608695654, \"center_x\": -4.927536231884058, \"center_y\": -3.1884057971014492, \"value_uncond\": 9.207322607105823e-06}, {\"x\": -4.782608695652174, \"y\": -3.333333333333333, \"x2\": -4.492753623188406, \"y2\": -3.0434782608695654, \"center_x\": -4.63768115942029, \"center_y\": -3.1884057971014492, \"value_uncond\": 1.227445653706291e-05}, {\"x\": -4.492753623188405, \"y\": -3.333333333333333, \"x2\": -4.202898550724638, \"y2\": -3.0434782608695654, \"center_x\": -4.3478260869565215, \"center_y\": -3.1884057971014492, \"value_uncond\": 1.621126850961822e-05}, {\"x\": -4.202898550724638, \"y\": -3.333333333333333, \"x2\": -3.91304347826087, \"y2\": -3.0434782608695654, \"center_x\": -4.057971014492754, \"center_y\": -3.1884057971014492, \"value_uncond\": 2.1211800817580984e-05}, {\"x\": -3.913043478260869, \"y\": -3.333333333333333, \"x2\": -3.6231884057971016, \"y2\": -3.0434782608695654, \"center_x\": -3.7681159420289854, \"center_y\": -3.1884057971014492, \"value_uncond\": 2.7496910250985696e-05}, {\"x\": -3.6231884057971016, \"y\": -3.333333333333333, \"x2\": -3.333333333333334, \"y2\": -3.0434782608695654, \"center_x\": -3.4782608695652177, \"center_y\": -3.1884057971014492, \"value_uncond\": 3.5313118067461914e-05}, {\"x\": -3.333333333333333, \"y\": -3.333333333333333, \"x2\": -3.0434782608695654, \"y2\": -3.0434782608695654, \"center_x\": -3.1884057971014492, \"center_y\": -3.1884057971014492, \"value_uncond\": 4.492975509448617e-05}, {\"x\": -3.0434782608695645, \"y\": -3.333333333333333, \"x2\": -2.753623188405797, \"y2\": -3.0434782608695654, \"center_x\": -2.8985507246376807, \"center_y\": -3.1884057971014492, \"value_uncond\": 5.6634080101113846e-05}, {\"x\": -2.753623188405797, \"y\": -3.333333333333333, \"x2\": -2.4637681159420293, \"y2\": -3.0434782608695654, \"center_x\": -2.608695652173913, \"center_y\": -3.1884057971014492, \"value_uncond\": 7.072410571871243e-05}, {\"x\": -2.4637681159420284, \"y\": -3.333333333333333, \"x2\": -2.1739130434782608, \"y2\": -3.0434782608695654, \"center_x\": -2.3188405797101446, \"center_y\": -3.1884057971014492, \"value_uncond\": 8.749896041355213e-05}, {\"x\": -2.1739130434782608, \"y\": -3.333333333333333, \"x2\": -1.8840579710144931, \"y2\": -3.0434782608695654, \"center_x\": -2.028985507246377, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.00010724674899898157}, {\"x\": -1.8840579710144922, \"y\": -3.333333333333333, \"x2\": -1.5942028985507246, \"y2\": -3.0434782608695654, \"center_x\": -1.7391304347826084, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0001302300459297184}, {\"x\": -1.5942028985507246, \"y\": -3.333333333333333, \"x2\": -1.304347826086957, \"y2\": -3.0434782608695654, \"center_x\": -1.4492753623188408, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.00015666935873976176}, {\"x\": -1.304347826086957, \"y\": -3.333333333333333, \"x2\": -1.0144927536231894, \"y2\": -3.0434782608695654, \"center_x\": -1.1594202898550732, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.00018672512225998927}, {\"x\": -1.0144927536231876, \"y\": -3.333333333333333, \"x2\": -0.72463768115942, \"y2\": -3.0434782608695654, \"center_x\": -0.8695652173913038, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.00022047901177611992}, {\"x\": -0.72463768115942, \"y\": -3.333333333333333, \"x2\": -0.43478260869565233, \"y2\": -3.0434782608695654, \"center_x\": -0.5797101449275361, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0002579155751652848}, {\"x\": -0.43478260869565233, \"y\": -3.333333333333333, \"x2\": -0.1449275362318847, \"y2\": -3.0434782608695654, \"center_x\": -0.2898550724637685, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.00029890535774004296}, {\"x\": -0.14492753623188293, \"y\": -3.333333333333333, \"x2\": 0.1449275362318847, \"y2\": -3.0434782608695654, \"center_x\": 8.881784197001252e-16, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0003431908058046359}, {\"x\": 0.1449275362318847, \"y\": -3.333333333333333, \"x2\": 0.43478260869565233, \"y2\": -3.0434782608695654, \"center_x\": 0.2898550724637685, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0003903762643051674}, {\"x\": 0.43478260869565233, \"y\": -3.333333333333333, \"x2\": 0.72463768115942, \"y2\": -3.0434782608695654, \"center_x\": 0.5797101449275361, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0004399233133752442}, {\"x\": 0.72463768115942, \"y\": -3.333333333333333, \"x2\": 1.0144927536231876, \"y2\": -3.0434782608695654, \"center_x\": 0.8695652173913038, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.000491152508044845}, {\"x\": 1.0144927536231894, \"y\": -3.333333333333333, \"x2\": 1.304347826086957, \"y2\": -3.0434782608695654, \"center_x\": 1.1594202898550732, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0005432522941958565}, {\"x\": 1.304347826086957, \"y\": -3.333333333333333, \"x2\": 1.5942028985507246, \"y2\": -3.0434782608695654, \"center_x\": 1.4492753623188408, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0005952954821058184}, {\"x\": 1.5942028985507246, \"y\": -3.333333333333333, \"x2\": 1.8840579710144922, \"y2\": -3.0434782608695654, \"center_x\": 1.7391304347826084, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0006462631879432444}, {\"x\": 1.884057971014494, \"y\": -3.333333333333333, \"x2\": 2.1739130434782616, \"y2\": -3.0434782608695654, \"center_x\": 2.028985507246378, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0006950756350950666}, {\"x\": 2.1739130434782616, \"y\": -3.333333333333333, \"x2\": 2.4637681159420293, \"y2\": -3.0434782608695654, \"center_x\": 2.3188405797101455, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0007406286812263477}, {\"x\": 2.4637681159420293, \"y\": -3.333333333333333, \"x2\": 2.753623188405797, \"y2\": -3.0434782608695654, \"center_x\": 2.608695652173913, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0007818344484350156}, {\"x\": 2.753623188405797, \"y\": -3.333333333333333, \"x2\": 3.0434782608695645, \"y2\": -3.0434782608695654, \"center_x\": 2.8985507246376807, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0008176640283809533}, {\"x\": 3.0434782608695663, \"y\": -3.333333333333333, \"x2\": 3.333333333333334, \"y2\": -3.0434782608695654, \"center_x\": 3.18840579710145, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.000847189953376477}, {\"x\": 3.333333333333334, \"y\": -3.333333333333333, \"x2\": 3.6231884057971016, \"y2\": -3.0434782608695654, \"center_x\": 3.4782608695652177, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.000869626000906391}, {\"x\": 3.6231884057971016, \"y\": -3.333333333333333, \"x2\": 3.913043478260869, \"y2\": -3.0434782608695654, \"center_x\": 3.7681159420289854, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0008843619528953801}, {\"x\": 3.913043478260871, \"y\": -3.333333333333333, \"x2\": 4.202898550724639, \"y2\": -3.0434782608695654, \"center_x\": 4.057971014492755, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.000890991166620855}, {\"x\": 4.202898550724639, \"y\": -3.333333333333333, \"x2\": 4.492753623188406, \"y2\": -3.0434782608695654, \"center_x\": 4.347826086956522, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0008893292189735857}, {\"x\": 4.492753623188406, \"y\": -3.333333333333333, \"x2\": 4.782608695652174, \"y2\": -3.0434782608695654, \"center_x\": 4.63768115942029, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0008794224310223179}, {\"x\": 4.782608695652174, \"y\": -3.333333333333333, \"x2\": 5.0724637681159415, \"y2\": -3.0434782608695654, \"center_x\": 4.927536231884058, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0008615457229435064}, {\"x\": 5.072463768115943, \"y\": -3.333333333333333, \"x2\": 5.362318840579711, \"y2\": -3.0434782608695654, \"center_x\": 5.217391304347827, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0008361899379559874}, {\"x\": 5.362318840579711, \"y\": -3.333333333333333, \"x2\": 5.6521739130434785, \"y2\": -3.0434782608695654, \"center_x\": 5.507246376811595, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0008040394509939493}, {\"x\": 5.6521739130434785, \"y\": -3.333333333333333, \"x2\": 5.942028985507246, \"y2\": -3.0434782608695654, \"center_x\": 5.797101449275362, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0007659414876603125}, {\"x\": 5.942028985507246, \"y\": -3.333333333333333, \"x2\": 6.231884057971014, \"y2\": -3.0434782608695654, \"center_x\": 6.08695652173913, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0007228690724893748}, {\"x\": 6.2318840579710155, \"y\": -3.333333333333333, \"x2\": 6.521739130434783, \"y2\": -3.0434782608695654, \"center_x\": 6.376811594202899, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0006758798652396703}, {\"x\": 6.521739130434785, \"y\": -3.333333333333333, \"x2\": 6.8115942028985526, \"y2\": -3.0434782608695654, \"center_x\": 6.666666666666669, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0006260733073753584}, {\"x\": 6.811594202898551, \"y\": -3.333333333333333, \"x2\": 7.101449275362318, \"y2\": -3.0434782608695654, \"center_x\": 6.956521739130435, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0005745484823511837}, {\"x\": 7.10144927536232, \"y\": -3.333333333333333, \"x2\": 7.391304347826088, \"y2\": -3.0434782608695654, \"center_x\": 7.246376811594204, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0005223649036535408}, {\"x\": 7.391304347826086, \"y\": -3.333333333333333, \"x2\": 7.681159420289854, \"y2\": -3.0434782608695654, \"center_x\": 7.53623188405797, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.00047050810929727627}, {\"x\": 7.681159420289855, \"y\": -3.333333333333333, \"x2\": 7.971014492753623, \"y2\": -3.0434782608695654, \"center_x\": 7.826086956521739, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0004198614974519994}, {\"x\": 7.971014492753625, \"y\": -3.333333333333333, \"x2\": 8.260869565217392, \"y2\": -3.0434782608695654, \"center_x\": 8.115942028985508, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.00037118532881786785}, {\"x\": 8.26086956521739, \"y\": -3.333333333333333, \"x2\": 8.550724637681158, \"y2\": -3.0434782608695654, \"center_x\": 8.405797101449274, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0003251032931855033}, {\"x\": 8.55072463768116, \"y\": -3.333333333333333, \"x2\": 8.840579710144928, \"y2\": -3.0434782608695654, \"center_x\": 8.695652173913043, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0002820965337334934}, {\"x\": 8.84057971014493, \"y\": -3.333333333333333, \"x2\": 9.130434782608697, \"y2\": -3.0434782608695654, \"center_x\": 8.985507246376812, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.0002425045800746907}, {\"x\": 9.130434782608695, \"y\": -3.333333333333333, \"x2\": 9.420289855072463, \"y2\": -3.0434782608695654, \"center_x\": 9.275362318840578, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.000206532287609695}, {\"x\": 9.420289855072465, \"y\": -3.333333333333333, \"x2\": 9.710144927536232, \"y2\": -3.0434782608695654, \"center_x\": 9.565217391304348, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.00017426163323724657}, {\"x\": 9.710144927536234, \"y\": -3.333333333333333, \"x2\": 10.000000000000002, \"y2\": -3.0434782608695654, \"center_x\": 9.855072463768117, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.00014566708156635937}, {\"x\": 10.0, \"y\": -3.333333333333333, \"x2\": 10.289855072463768, \"y2\": -3.0434782608695654, \"center_x\": 10.144927536231883, \"center_y\": -3.1884057971014492, \"value_uncond\": 0.00012063320682877794}, {\"x\": -10.0, \"y\": -3.0434782608695645, \"x2\": -9.710144927536232, \"y2\": -2.753623188405797, \"center_x\": -9.855072463768117, \"center_y\": -2.8985507246376807, \"value_uncond\": 2.097081348614346e-08}, {\"x\": -9.710144927536232, \"y\": -3.0434782608695645, \"x2\": -9.420289855072465, \"y2\": -2.753623188405797, \"center_x\": -9.565217391304348, \"center_y\": -2.8985507246376807, \"value_uncond\": 3.276463563225292e-08}, {\"x\": -9.420289855072463, \"y\": -3.0434782608695645, \"x2\": -9.130434782608695, \"y2\": -2.753623188405797, \"center_x\": -9.275362318840578, \"center_y\": -2.8985507246376807, \"value_uncond\": 5.071555962961394e-08}, {\"x\": -9.130434782608695, \"y\": -3.0434782608695645, \"x2\": -8.840579710144928, \"y2\": -2.753623188405797, \"center_x\": -8.985507246376812, \"center_y\": -2.8985507246376807, \"value_uncond\": 7.777193708994542e-08}, {\"x\": -8.840579710144928, \"y\": -3.0434782608695645, \"x2\": -8.55072463768116, \"y2\": -2.753623188405797, \"center_x\": -8.695652173913043, \"center_y\": -2.8985507246376807, \"value_uncond\": 1.1815454300928705e-07}, {\"x\": -8.55072463768116, \"y\": -3.0434782608695645, \"x2\": -8.260869565217392, \"y2\": -2.753623188405797, \"center_x\": -8.405797101449277, \"center_y\": -2.8985507246376807, \"value_uncond\": 1.7783766518923127e-07}, {\"x\": -8.26086956521739, \"y\": -3.0434782608695645, \"x2\": -7.971014492753623, \"y2\": -2.753623188405797, \"center_x\": -8.115942028985508, \"center_y\": -2.8985507246376807, \"value_uncond\": 2.651812940615314e-07}, {\"x\": -7.971014492753623, \"y\": -3.0434782608695645, \"x2\": -7.681159420289855, \"y2\": -2.753623188405797, \"center_x\": -7.826086956521739, \"center_y\": -2.8985507246376807, \"value_uncond\": 3.917489470275911e-07}, {\"x\": -7.681159420289855, \"y\": -3.0434782608695645, \"x2\": -7.391304347826088, \"y2\": -2.753623188405797, \"center_x\": -7.536231884057972, \"center_y\": -2.8985507246376807, \"value_uncond\": 5.733483995698952e-07}, {\"x\": -7.391304347826087, \"y\": -3.0434782608695645, \"x2\": -7.101449275362319, \"y2\": -2.753623188405797, \"center_x\": -7.246376811594203, \"center_y\": -2.8985507246376807, \"value_uncond\": 8.31333316945809e-07}, {\"x\": -7.101449275362318, \"y\": -3.0434782608695645, \"x2\": -6.811594202898551, \"y2\": -2.753623188405797, \"center_x\": -6.956521739130435, \"center_y\": -2.8985507246376807, \"value_uncond\": 1.1942014157115696e-06}, {\"x\": -6.811594202898551, \"y\": -3.0434782608695645, \"x2\": -6.521739130434783, \"y2\": -2.753623188405797, \"center_x\": -6.666666666666667, \"center_y\": -2.8985507246376807, \"value_uncond\": 1.6995180916205377e-06}, {\"x\": -6.521739130434782, \"y\": -3.0434782608695645, \"x2\": -6.231884057971015, \"y2\": -2.753623188405797, \"center_x\": -6.3768115942028984, \"center_y\": -2.8985507246376807, \"value_uncond\": 2.3961820857624293e-06}, {\"x\": -6.231884057971014, \"y\": -3.0434782608695645, \"x2\": -5.942028985507246, \"y2\": -2.753623188405797, \"center_x\": -6.08695652173913, \"center_y\": -2.8985507246376807, \"value_uncond\": 3.3470303962360863e-06}, {\"x\": -5.942028985507246, \"y\": -3.0434782608695645, \"x2\": -5.6521739130434785, \"y2\": -2.753623188405797, \"center_x\": -5.797101449275362, \"center_y\": -2.8985507246376807, \"value_uncond\": 4.631752135717058e-06}, {\"x\": -5.6521739130434785, \"y\": -3.0434782608695645, \"x2\": -5.362318840579711, \"y2\": -2.753623188405797, \"center_x\": -5.507246376811595, \"center_y\": -2.8985507246376807, \"value_uncond\": 6.350044649361683e-06}, {\"x\": -5.36231884057971, \"y\": -3.0434782608695645, \"x2\": -5.072463768115942, \"y2\": -2.753623188405797, \"center_x\": -5.217391304347826, \"center_y\": -2.8985507246376807, \"value_uncond\": 8.624899873630453e-06}, {\"x\": -5.0724637681159415, \"y\": -3.0434782608695645, \"x2\": -4.782608695652174, \"y2\": -2.753623188405797, \"center_x\": -4.927536231884058, \"center_y\": -2.8985507246376807, \"value_uncond\": 1.1605855517151936e-05}, {\"x\": -4.782608695652174, \"y\": -3.0434782608695645, \"x2\": -4.492753623188406, \"y2\": -2.753623188405797, \"center_x\": -4.63768115942029, \"center_y\": -2.8985507246376807, \"value_uncond\": 1.547198628738956e-05}, {\"x\": -4.492753623188405, \"y\": -3.0434782608695645, \"x2\": -4.202898550724638, \"y2\": -2.753623188405797, \"center_x\": -4.3478260869565215, \"center_y\": -2.8985507246376807, \"value_uncond\": 2.0434348626731224e-05}, {\"x\": -4.202898550724638, \"y\": -3.0434782608695645, \"x2\": -3.91304347826087, \"y2\": -2.753623188405797, \"center_x\": -4.057971014492754, \"center_y\": -2.8985507246376807, \"value_uncond\": 2.6737533379948934e-05}, {\"x\": -3.913043478260869, \"y\": -3.0434782608695645, \"x2\": -3.6231884057971016, \"y2\": -2.753623188405797, \"center_x\": -3.7681159420289854, \"center_y\": -2.8985507246376807, \"value_uncond\": 3.4659931139454876e-05}, {\"x\": -3.6231884057971016, \"y\": -3.0434782608695645, \"x2\": -3.333333333333334, \"y2\": -2.753623188405797, \"center_x\": -3.4782608695652177, \"center_y\": -2.8985507246376807, \"value_uncond\": 4.451228262978362e-05}, {\"x\": -3.333333333333333, \"y\": -3.0434782608695645, \"x2\": -3.0434782608695654, \"y2\": -2.753623188405797, \"center_x\": -3.1884057971014492, \"center_y\": -2.8985507246376807, \"value_uncond\": 5.6634080101113846e-05}, {\"x\": -3.0434782608695645, \"y\": -3.0434782608695645, \"x2\": -2.753623188405797, \"y2\": -2.753623188405797, \"center_x\": -2.8985507246376807, \"center_y\": -2.8985507246376807, \"value_uncond\": 7.138741402338514e-05}, {\"x\": -2.753623188405797, \"y\": -3.0434782608695645, \"x2\": -2.4637681159420293, \"y2\": -2.753623188405797, \"center_x\": -2.608695652173913, \"center_y\": -2.8985507246376807, \"value_uncond\": 8.914793013961373e-05}, {\"x\": -2.4637681159420284, \"y\": -3.0434782608695645, \"x2\": -2.1739130434782608, \"y2\": -2.753623188405797, \"center_x\": -2.3188405797101446, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.00011029268070578547}, {\"x\": -2.1739130434782608, \"y\": -3.0434782608695645, \"x2\": -1.8840579710144931, \"y2\": -2.753623188405797, \"center_x\": -2.028985507246377, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.00013518482263300295}, {\"x\": -1.8840579710144922, \"y\": -3.0434782608695645, \"x2\": -1.5942028985507246, \"y2\": -2.753623188405797, \"center_x\": -1.7391304347826084, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0001641553317449651}, {\"x\": -1.5942028985507246, \"y\": -3.0434782608695645, \"x2\": -1.304347826086957, \"y2\": -2.753623188405797, \"center_x\": -1.4492753623188408, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.00019748215839588876}, {\"x\": -1.304347826086957, \"y\": -3.0434782608695645, \"x2\": -1.0144927536231894, \"y2\": -2.753623188405797, \"center_x\": -1.1594202898550732, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.000235367531132176}, {\"x\": -1.0144927536231876, \"y\": -3.0434782608695645, \"x2\": -0.72463768115942, \"y2\": -2.753623188405797, \"center_x\": -0.8695652173913038, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0002779144018765324}, {\"x\": -0.72463768115942, \"y\": -3.0434782608695645, \"x2\": -0.43478260869565233, \"y2\": -2.753623188405797, \"center_x\": -0.5797101449275361, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0003251032931855034}, {\"x\": -0.43478260869565233, \"y\": -3.0434782608695645, \"x2\": -0.1449275362318847, \"y2\": -2.753623188405797, \"center_x\": -0.2898550724637685, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.00037677102706885516}, {\"x\": -0.14492753623188293, \"y\": -3.0434782608695645, \"x2\": 0.1449275362318847, \"y2\": -2.753623188405797, \"center_x\": 8.881784197001252e-16, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0004325929563833926}, {\"x\": 0.1449275362318847, \"y\": -3.0434782608695645, \"x2\": 0.43478260869565233, \"y2\": -2.753623188405797, \"center_x\": 0.2898550724637685, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.000492070356843446}, {\"x\": 0.43478260869565233, \"y\": -3.0434782608695645, \"x2\": 0.72463768115942, \"y2\": -2.753623188405797, \"center_x\": 0.5797101449275361, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0005545245487238045}, {\"x\": 0.72463768115942, \"y\": -3.0434782608695645, \"x2\": 1.0144927536231876, \"y2\": -2.753623188405797, \"center_x\": 0.8695652173913038, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0006190990897675365}, {\"x\": 1.0144927536231894, \"y\": -3.0434782608695645, \"x2\": 1.304347826086957, \"y2\": -2.753623188405797, \"center_x\": 1.1594202898550732, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0006847710137725129}, {\"x\": 1.304347826086957, \"y\": -3.0434782608695645, \"x2\": 1.5942028985507246, \"y2\": -2.753623188405797, \"center_x\": 1.4492753623188408, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0007503715955386884}, {\"x\": 1.5942028985507246, \"y\": -3.0434782608695645, \"x2\": 1.8840579710144922, \"y2\": -2.753623188405797, \"center_x\": 1.7391304347826084, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0008146165291889287}, {\"x\": 1.884057971014494, \"y\": -3.0434782608695645, \"x2\": 2.1739130434782616, \"y2\": -2.753623188405797, \"center_x\": 2.028985507246378, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0008761447533271222}, {\"x\": 2.1739130434782616, \"y\": -3.0434782608695645, \"x2\": 2.4637681159420293, \"y2\": -2.753623188405797, \"center_x\": 2.3188405797101455, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0009335644934976026}, {\"x\": 2.4637681159420293, \"y\": -3.0434782608695645, \"x2\": 2.753623188405797, \"y2\": -2.753623188405797, \"center_x\": 2.608695652173913, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0009855044766071462}, {\"x\": 2.753623188405797, \"y\": -3.0434782608695645, \"x2\": 3.0434782608695645, \"y2\": -2.753623188405797, \"center_x\": 2.8985507246376807, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.001030667760857866}, {\"x\": 3.0434782608695663, \"y\": -3.0434782608695645, \"x2\": 3.333333333333334, \"y2\": -2.753623188405797, \"center_x\": 3.18840579710145, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.001067885270673787}, {\"x\": 3.333333333333334, \"y\": -3.0434782608695645, \"x2\": 3.6231884057971016, \"y2\": -2.753623188405797, \"center_x\": 3.4782608695652177, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.001096165970408059}, {\"x\": 3.6231884057971016, \"y\": -3.0434782608695645, \"x2\": 3.913043478260869, \"y2\": -2.753623188405797, \"center_x\": 3.7681159420289854, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0011147406784952837}, {\"x\": 3.913043478260871, \"y\": -3.0434782608695645, \"x2\": 4.202898550724639, \"y2\": -2.753623188405797, \"center_x\": 4.057971014492755, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.001123096820663128}, {\"x\": 4.202898550724639, \"y\": -3.0434782608695645, \"x2\": 4.492753623188406, \"y2\": -2.753623188405797, \"center_x\": 4.347826086956522, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0011210019310742272}, {\"x\": 4.492753623188406, \"y\": -3.0434782608695645, \"x2\": 4.782608695652174, \"y2\": -2.753623188405797, \"center_x\": 4.63768115942029, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0011085143975633734}, {\"x\": 4.782608695652174, \"y\": -3.0434782608695645, \"x2\": 5.0724637681159415, \"y2\": -2.753623188405797, \"center_x\": 4.927536231884058, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.001085980757770534}, {\"x\": 5.072463768115943, \"y\": -3.0434782608695645, \"x2\": 5.362318840579711, \"y2\": -2.753623188405797, \"center_x\": 5.217391304347827, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0010540197209255768}, {\"x\": 5.362318840579711, \"y\": -3.0434782608695645, \"x2\": 5.6521739130434785, \"y2\": -2.753623188405797, \"center_x\": 5.507246376811595, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0010134939435188506}, {\"x\": 5.6521739130434785, \"y\": -3.0434782608695645, \"x2\": 5.942028985507246, \"y2\": -2.753623188405797, \"center_x\": 5.797101449275362, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0009654713557573767}, {\"x\": 5.942028985507246, \"y\": -3.0434782608695645, \"x2\": 6.231884057971014, \"y2\": -2.753623188405797, \"center_x\": 6.08695652173913, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0009111784577478195}, {\"x\": 6.2318840579710155, \"y\": -3.0434782608695645, \"x2\": 6.521739130434783, \"y2\": -2.753623188405797, \"center_x\": 6.376811594202899, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0008519484325302061}, {\"x\": 6.521739130434785, \"y\": -3.0434782608695645, \"x2\": 6.8115942028985526, \"y2\": -2.753623188405797, \"center_x\": 6.666666666666669, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0007891671290996348}, {\"x\": 6.811594202898551, \"y\": -3.0434782608695645, \"x2\": 7.101449275362318, \"y2\": -2.753623188405797, \"center_x\": 6.956521739130435, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0007242199451793485}, {\"x\": 7.10144927536232, \"y\": -3.0434782608695645, \"x2\": 7.391304347826088, \"y2\": -2.753623188405797, \"center_x\": 7.246376811594204, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0006584424004384523}, {\"x\": 7.391304347826086, \"y\": -3.0434782608695645, \"x2\": 7.681159420289854, \"y2\": -2.753623188405797, \"center_x\": 7.53623188405797, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.000593076768260322}, {\"x\": 7.681159420289855, \"y\": -3.0434782608695645, \"x2\": 7.971014492753623, \"y2\": -2.753623188405797, \"center_x\": 7.826086956521739, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0005292365744719645}, {\"x\": 7.971014492753625, \"y\": -3.0434782608695645, \"x2\": 8.260869565217392, \"y2\": -2.753623188405797, \"center_x\": 8.115942028985508, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0004678801297808371}, {\"x\": 8.26086956521739, \"y\": -3.0434782608695645, \"x2\": 8.550724637681158, \"y2\": -2.753623188405797, \"center_x\": 8.405797101449274, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0004097935968866038}, {\"x\": 8.55072463768116, \"y\": -3.0434782608695645, \"x2\": 8.840579710144928, \"y2\": -2.753623188405797, \"center_x\": 8.695652173913043, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.0003555834580916702}, {\"x\": 8.84057971014493, \"y\": -3.0434782608695645, \"x2\": 9.130434782608697, \"y2\": -2.753623188405797, \"center_x\": 8.985507246376812, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.00030567769140861566}, {\"x\": 9.130434782608695, \"y\": -3.0434782608695645, \"x2\": 9.420289855072463, \"y2\": -2.753623188405797, \"center_x\": 9.275362318840578, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.00026033451763437723}, {\"x\": 9.420289855072465, \"y\": -3.0434782608695645, \"x2\": 9.710144927536232, \"y2\": -2.753623188405797, \"center_x\": 9.565217391304348, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.00021965726887570564}, {\"x\": 9.710144927536234, \"y\": -3.0434782608695645, \"x2\": 10.000000000000002, \"y2\": -2.753623188405797, \"center_x\": 9.855072463768117, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.00018361375770189993}, {\"x\": 10.0, \"y\": -3.0434782608695645, \"x2\": 10.289855072463768, \"y2\": -2.753623188405797, \"center_x\": 10.144927536231883, \"center_y\": -2.8985507246376807, \"value_uncond\": 0.00015205848961401678}, {\"x\": -10.0, \"y\": -2.753623188405797, \"x2\": -9.710144927536232, \"y2\": -2.4637681159420293, \"center_x\": -9.855072463768117, \"center_y\": -2.608695652173913, \"value_uncond\": 2.6188154329573736e-08}, {\"x\": -9.710144927536232, \"y\": -2.753623188405797, \"x2\": -9.420289855072465, \"y2\": -2.4637681159420293, \"center_x\": -9.565217391304348, \"center_y\": -2.608695652173913, \"value_uncond\": 4.0916168323973e-08}, {\"x\": -9.420289855072463, \"y\": -2.753623188405797, \"x2\": -9.130434782608695, \"y2\": -2.4637681159420293, \"center_x\": -9.275362318840578, \"center_y\": -2.608695652173913, \"value_uncond\": 6.333311310830191e-08}, {\"x\": -9.130434782608695, \"y\": -2.753623188405797, \"x2\": -8.840579710144928, \"y2\": -2.4637681159420293, \"center_x\": -8.985507246376812, \"center_y\": -2.608695652173913, \"value_uncond\": 9.71208624008385e-08}, {\"x\": -8.840579710144928, \"y\": -2.753623188405797, \"x2\": -8.55072463768116, \"y2\": -2.4637681159420293, \"center_x\": -8.695652173913043, \"center_y\": -2.608695652173913, \"value_uncond\": 1.475502802555563e-07}, {\"x\": -8.55072463768116, \"y\": -2.753623188405797, \"x2\": -8.260869565217392, \"y2\": -2.4637681159420293, \"center_x\": -8.405797101449277, \"center_y\": -2.608695652173913, \"value_uncond\": 2.2208200099933804e-07}, {\"x\": -8.26086956521739, \"y\": -2.753623188405797, \"x2\": -7.971014492753623, \"y2\": -2.4637681159420293, \"center_x\": -8.115942028985508, \"center_y\": -2.608695652173913, \"value_uncond\": 3.3115590192951433e-07}, {\"x\": -7.971014492753623, \"y\": -2.753623188405797, \"x2\": -7.681159420289855, \"y2\": -2.4637681159420293, \"center_x\": -7.826086956521739, \"center_y\": -2.608695652173913, \"value_uncond\": 4.892123946448407e-07}, {\"x\": -7.681159420289855, \"y\": -2.753623188405797, \"x2\": -7.391304347826088, \"y2\": -2.4637681159420293, \"center_x\": -7.536231884057972, \"center_y\": -2.608695652173913, \"value_uncond\": 7.159920802534279e-07}, {\"x\": -7.391304347826087, \"y\": -2.753623188405797, \"x2\": -7.101449275362319, \"y2\": -2.4637681159420293, \"center_x\": -7.246376811594203, \"center_y\": -2.608695652173913, \"value_uncond\": 1.0381612147701664e-06}, {\"x\": -7.101449275362318, \"y\": -2.753623188405797, \"x2\": -6.811594202898551, \"y2\": -2.4637681159420293, \"center_x\": -6.956521739130435, \"center_y\": -2.608695652173913, \"value_uncond\": 1.4913074781726702e-06}, {\"x\": -6.811594202898551, \"y\": -2.753623188405797, \"x2\": -6.521739130434783, \"y2\": -2.4637681159420293, \"center_x\": -6.666666666666667, \"center_y\": -2.608695652173913, \"value_uncond\": 2.1223421827994224e-06}, {\"x\": -6.521739130434782, \"y\": -2.753623188405797, \"x2\": -6.231884057971015, \"y2\": -2.4637681159420293, \"center_x\": -6.3768115942028984, \"center_y\": -2.608695652173913, \"value_uncond\": 2.9923296158811253e-06}, {\"x\": -6.231884057971014, \"y\": -2.753623188405797, \"x2\": -5.942028985507246, \"y2\": -2.4637681159420293, \"center_x\": -6.08695652173913, \"center_y\": -2.608695652173913, \"value_uncond\": 4.179740028698538e-06}, {\"x\": -5.942028985507246, \"y\": -2.753623188405797, \"x2\": -5.6521739130434785, \"y2\": -2.4637681159420293, \"center_x\": -5.797101449275362, \"center_y\": -2.608695652173913, \"value_uncond\": 5.7840884344633715e-06}, {\"x\": -5.6521739130434785, \"y\": -2.753623188405797, \"x2\": -5.362318840579711, \"y2\": -2.4637681159420293, \"center_x\": -5.507246376811595, \"center_y\": -2.608695652173913, \"value_uncond\": 7.92987593862528e-06}, {\"x\": -5.36231884057971, \"y\": -2.753623188405797, \"x2\": -5.072463768115942, \"y2\": -2.4637681159420293, \"center_x\": -5.217391304347826, \"center_y\": -2.608695652173913, \"value_uncond\": 1.077069371281184e-05}, {\"x\": -5.0724637681159415, \"y\": -2.753623188405797, \"x2\": -4.782608695652174, \"y2\": -2.4637681159420293, \"center_x\": -4.927536231884058, \"center_y\": -2.608695652173913, \"value_uncond\": 1.4493283038864286e-05}, {\"x\": -4.782608695652174, \"y\": -2.753623188405797, \"x2\": -4.492753623188406, \"y2\": -2.4637681159420293, \"center_x\": -4.63768115942029, \"center_y\": -2.608695652173913, \"value_uncond\": 1.9321270724520628e-05}, {\"x\": -4.492753623188405, \"y\": -2.753623188405797, \"x2\": -4.202898550724638, \"y2\": -2.4637681159420293, \"center_x\": -4.3478260869565215, \"center_y\": -2.608695652173913, \"value_uncond\": 2.551822206681418e-05}, {\"x\": -4.202898550724638, \"y\": -2.753623188405797, \"x2\": -3.91304347826087, \"y2\": -2.4637681159420293, \"center_x\": -4.057971014492754, \"center_y\": -2.608695652173913, \"value_uncond\": 3.33895798085704e-05}, {\"x\": -3.913043478260869, \"y\": -2.753623188405797, \"x2\": -3.6231884057971016, \"y2\": -2.4637681159420293, \"center_x\": -3.7681159420289854, \"center_y\": -2.608695652173913, \"value_uncond\": 4.328299549906327e-05}, {\"x\": -3.6231884057971016, \"y\": -2.753623188405797, \"x2\": -3.333333333333334, \"y2\": -2.4637681159420293, \"center_x\": -3.4782608695652177, \"center_y\": -2.608695652173913, \"value_uncond\": 5.5586519227812194e-05}, {\"x\": -3.333333333333333, \"y\": -2.753623188405797, \"x2\": -3.0434782608695654, \"y2\": -2.4637681159420293, \"center_x\": -3.1884057971014492, \"center_y\": -2.608695652173913, \"value_uncond\": 7.072410571871243e-05}, {\"x\": -3.0434782608695645, \"y\": -2.753623188405797, \"x2\": -2.753623188405797, \"y2\": -2.4637681159420293, \"center_x\": -2.8985507246376807, \"center_y\": -2.608695652173913, \"value_uncond\": 8.914793013961373e-05}, {\"x\": -2.753623188405797, \"y\": -2.753623188405797, \"x2\": -2.4637681159420293, \"y2\": -2.4637681159420293, \"center_x\": -2.608695652173913, \"center_y\": -2.608695652173913, \"value_uncond\": 0.00011132709535568892}, {\"x\": -2.4637681159420284, \"y\": -2.753623188405797, \"x2\": -2.1739130434782608, \"y2\": -2.4637681159420293, \"center_x\": -2.3188405797101446, \"center_y\": -2.608695652173913, \"value_uncond\": 0.00013773246067225788}, {\"x\": -2.1739130434782608, \"y\": -2.753623188405797, \"x2\": -1.8840579710144931, \"y2\": -2.4637681159420293, \"center_x\": -2.028985507246377, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0001688175330188482}, {\"x\": -1.8840579710144922, \"y\": -2.753623188405797, \"x2\": -1.5942028985507246, \"y2\": -2.4637681159420293, \"center_x\": -1.7391304347826084, \"center_y\": -2.608695652173913, \"value_uncond\": 0.00020499563188619514}, {\"x\": -1.5942028985507246, \"y\": -2.753623188405797, \"x2\": -1.304347826086957, \"y2\": -2.4637681159420293, \"center_x\": -1.4492753623188408, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0002466138590582609}, {\"x\": -1.304347826086957, \"y\": -2.753623188405797, \"x2\": -1.0144927536231894, \"y2\": -2.4637681159420293, \"center_x\": -1.1594202898550732, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0002939247556387334}, {\"x\": -1.0144927536231876, \"y\": -2.753623188405797, \"x2\": -0.72463768115942, \"y2\": -2.4637681159420293, \"center_x\": -0.8695652173913038, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0003470568870188469}, {\"x\": -0.72463768115942, \"y\": -2.753623188405797, \"x2\": -0.43478260869565233, \"y2\": -2.4637681159420293, \"center_x\": -0.5797101449275361, \"center_y\": -2.608695652173913, \"value_uncond\": 0.00040598592995069906}, {\"x\": -0.43478260869565233, \"y\": -2.753623188405797, \"x2\": -0.1449275362318847, \"y2\": -2.4637681159420293, \"center_x\": -0.2898550724637685, \"center_y\": -2.608695652173913, \"value_uncond\": 0.00047050810929727627}, {\"x\": -0.14492753623188293, \"y\": -2.753623188405797, \"x2\": 0.1449275362318847, \"y2\": -2.4637681159420293, \"center_x\": 8.881784197001252e-16, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0005402180087644379}, {\"x\": 0.1449275362318847, \"y\": -2.753623188405797, \"x2\": 0.43478260869565233, \"y2\": -2.4637681159420293, \"center_x\": 0.2898550724637685, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0006144928261623863}, {\"x\": 0.43478260869565233, \"y\": -2.753623188405797, \"x2\": 0.72463768115942, \"y2\": -2.4637681159420293, \"center_x\": 0.5797101449275361, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0006924850326436628}, {\"x\": 0.72463768115942, \"y\": -2.753623188405797, \"x2\": 1.0144927536231876, \"y2\": -2.4637681159420293, \"center_x\": 0.8695652173913038, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0007731251111857775}, {\"x\": 1.0144927536231894, \"y\": -2.753623188405797, \"x2\": 1.304347826086957, \"y2\": -2.4637681159420293, \"center_x\": 1.1594202898550732, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0008551355912321876}, {\"x\": 1.304347826086957, \"y\": -2.753623188405797, \"x2\": 1.5942028985507246, \"y2\": -2.4637681159420293, \"center_x\": 1.4492753623188408, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0009370569797628511}, {\"x\": 1.5942028985507246, \"y\": -2.753623188405797, \"x2\": 1.8840579710144922, \"y2\": -2.4637681159420293, \"center_x\": 1.7391304347826084, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0010172854476969823}, {\"x\": 1.884057971014494, \"y\": -2.753623188405797, \"x2\": 2.1739130434782616, \"y2\": -2.4637681159420293, \"center_x\": 2.028985507246378, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0010941213143847621}, {\"x\": 2.1739130434782616, \"y\": -2.753623188405797, \"x2\": 2.4637681159420293, \"y2\": -2.4637681159420293, \"center_x\": 2.3188405797101455, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0011658265449969248}, {\"x\": 2.4637681159420293, \"y\": -2.753623188405797, \"x2\": 2.753623188405797, \"y2\": -2.4637681159420293, \"center_x\": 2.608695652173913, \"center_y\": -2.608695652173913, \"value_uncond\": 0.001230688706612493}, {\"x\": 2.753623188405797, \"y\": -2.753623188405797, \"x2\": 3.0434782608695645, \"y2\": -2.4637681159420293, \"center_x\": 2.8985507246376807, \"center_y\": -2.608695652173913, \"value_uncond\": 0.001287088190531882}, {\"x\": 3.0434782608695663, \"y\": -2.753623188405797, \"x2\": 3.333333333333334, \"y2\": -2.4637681159420293, \"center_x\": 3.18840579710145, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0013335650661888887}, {\"x\": 3.333333333333334, \"y\": -2.753623188405797, \"x2\": 3.6231884057971016, \"y2\": -2.4637681159420293, \"center_x\": 3.4782608695652177, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0013688817376036064}, {\"x\": 3.6231884057971016, \"y\": -2.753623188405797, \"x2\": 3.913043478260869, \"y2\": -2.4637681159420293, \"center_x\": 3.7681159420289854, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0013920776580831067}, {\"x\": 3.913043478260871, \"y\": -2.753623188405797, \"x2\": 4.202898550724639, \"y2\": -2.4637681159420293, \"center_x\": 4.057971014492755, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0014025127297047182}, {\"x\": 4.202898550724639, \"y\": -2.753623188405797, \"x2\": 4.492753623188406, \"y2\": -2.4637681159420293, \"center_x\": 4.347826086956522, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0013998966513206438}, {\"x\": 4.492753623188406, \"y\": -2.753623188405797, \"x2\": 4.782608695652174, \"y2\": -2.4637681159420293, \"center_x\": 4.63768115942029, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0013843023371089397}, {\"x\": 4.782608695652174, \"y\": -2.753623188405797, \"x2\": 5.0724637681159415, \"y2\": -2.4637681159420293, \"center_x\": 4.927536231884058, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0013561625400098994}, {\"x\": 5.072463768115943, \"y\": -2.753623188405797, \"x2\": 5.362318840579711, \"y2\": -2.4637681159420293, \"center_x\": 5.217391304347827, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0013162498982813378}, {\"x\": 5.362318840579711, \"y\": -2.753623188405797, \"x2\": 5.6521739130434785, \"y2\": -2.4637681159420293, \"center_x\": 5.507246376811595, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0012656416892218962}, {\"x\": 5.6521739130434785, \"y\": -2.753623188405797, \"x2\": 5.942028985507246, \"y2\": -2.4637681159420293, \"center_x\": 5.797101449275362, \"center_y\": -2.608695652173913, \"value_uncond\": 0.001205671534013852}, {\"x\": 5.942028985507246, \"y\": -2.753623188405797, \"x2\": 6.231884057971014, \"y2\": -2.4637681159420293, \"center_x\": 6.08695652173913, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0011378710744363743}, {\"x\": 6.2318840579710155, \"y\": -2.753623188405797, \"x2\": 6.521739130434783, \"y2\": -2.4637681159420293, \"center_x\": 6.376811594202899, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0010639051769108295}, {\"x\": 6.521739130434785, \"y\": -2.753623188405797, \"x2\": 6.8115942028985526, \"y2\": -2.4637681159420293, \"center_x\": 6.666666666666669, \"center_y\": -2.608695652173913, \"value_uncond\": 0.000985504476607145}, {\"x\": 6.811594202898551, \"y\": -2.753623188405797, \"x2\": 7.101449275362318, \"y2\": -2.4637681159420293, \"center_x\": 6.956521739130435, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0009043990451512076}, {\"x\": 7.10144927536232, \"y\": -2.753623188405797, \"x2\": 7.391304347826088, \"y2\": -2.4637681159420293, \"center_x\": 7.246376811594204, \"center_y\": -2.608695652173913, \"value_uncond\": 0.000822256666924762}, {\"x\": 7.391304347826086, \"y\": -2.753623188405797, \"x2\": 7.681159420289854, \"y2\": -2.4637681159420293, \"center_x\": 7.53623188405797, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0007406286812263477}, {\"x\": 7.681159420289855, \"y\": -2.753623188405797, \"x2\": 7.971014492753623, \"y2\": -2.4637681159420293, \"center_x\": 7.826086956521739, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0006609056486189536}, {\"x\": 7.971014492753625, \"y\": -2.753623188405797, \"x2\": 8.260869565217392, \"y2\": -2.4637681159420293, \"center_x\": 8.115942028985508, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0005842842984864515}, {\"x\": 8.26086956521739, \"y\": -2.753623188405797, \"x2\": 8.550724637681158, \"y2\": -2.4637681159420293, \"center_x\": 8.405797101449274, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0005117463834022718}, {\"x\": 8.55072463768116, \"y\": -2.753623188405797, \"x2\": 8.840579710144928, \"y2\": -2.4637681159420293, \"center_x\": 8.695652173913043, \"center_y\": -2.608695652173913, \"value_uncond\": 0.0004440492727523974}, {\"x\": 8.84057971014493, \"y\": -2.753623188405797, \"x2\": 9.130434782608697, \"y2\": -2.4637681159420293, \"center_x\": 8.985507246376812, \"center_y\": -2.608695652173913, \"value_uncond\": 0.00038172742144724434}, {\"x\": 9.130434782608695, \"y\": -2.753623188405797, \"x2\": 9.420289855072463, \"y2\": -2.4637681159420293, \"center_x\": 9.275362318840578, \"center_y\": -2.608695652173913, \"value_uncond\": 0.00032510329318550315}, {\"x\": 9.420289855072465, \"y\": -2.753623188405797, \"x2\": 9.710144927536232, \"y2\": -2.4637681159420293, \"center_x\": 9.565217391304348, \"center_y\": -2.608695652173913, \"value_uncond\": 0.00027430592812866244}, {\"x\": 9.710144927536234, \"y\": -2.753623188405797, \"x2\": 10.000000000000002, \"y2\": -2.4637681159420293, \"center_x\": 9.855072463768117, \"center_y\": -2.608695652173913, \"value_uncond\": 0.00022929513091647812}, {\"x\": 10.0, \"y\": -2.753623188405797, \"x2\": 10.289855072463768, \"y2\": -2.4637681159420293, \"center_x\": 10.144927536231883, \"center_y\": -2.608695652173913, \"value_uncond\": 0.00018988920938927623}, {\"x\": -10.0, \"y\": -2.4637681159420284, \"x2\": -9.710144927536232, \"y2\": -2.1739130434782608, \"center_x\": -9.855072463768117, \"center_y\": -2.3188405797101446, \"value_uncond\": 3.239965010092863e-08}, {\"x\": -9.710144927536232, \"y\": -2.4637681159420284, \"x2\": -9.420289855072465, \"y2\": -2.1739130434782608, \"center_x\": -9.565217391304348, \"center_y\": -2.3188405797101446, \"value_uncond\": 5.0620960930811905e-08}, {\"x\": -9.420289855072463, \"y\": -2.4637681159420284, \"x2\": -9.130434782608695, \"y2\": -2.1739130434782608, \"center_x\": -9.275362318840578, \"center_y\": -2.3188405797101446, \"value_uncond\": 7.835491874256564e-08}, {\"x\": -9.130434782608695, \"y\": -2.4637681159420284, \"x2\": -8.840579710144928, \"y2\": -2.1739130434782608, \"center_x\": -8.985507246376812, \"center_y\": -2.3188405797101446, \"value_uncond\": 1.2015669068110387e-07}, {\"x\": -8.840579710144928, \"y\": -2.4637681159420284, \"x2\": -8.55072463768116, \"y2\": -2.1739130434782608, \"center_x\": -8.695652173913043, \"center_y\": -2.3188405797101446, \"value_uncond\": 1.8254732244247453e-07}, {\"x\": -8.55072463768116, \"y\": -2.4637681159420284, \"x2\": -8.260869565217392, \"y2\": -2.1739130434782608, \"center_x\": -8.405797101449277, \"center_y\": -2.3188405797101446, \"value_uncond\": 2.747570155399246e-07}, {\"x\": -8.26086956521739, \"y\": -2.4637681159420284, \"x2\": -7.971014492753623, \"y2\": -2.1739130434782608, \"center_x\": -8.115942028985508, \"center_y\": -2.3188405797101446, \"value_uncond\": 4.0970185284334017e-07}, {\"x\": -7.971014492753623, \"y\": -2.4637681159420284, \"x2\": -7.681159420289855, \"y2\": -2.1739130434782608, \"center_x\": -7.826086956521739, \"center_y\": -2.3188405797101446, \"value_uncond\": 6.052473271715371e-07}, {\"x\": -7.681159420289855, \"y\": -2.4637681159420284, \"x2\": -7.391304347826088, \"y2\": -2.1739130434782608, \"center_x\": -7.536231884057972, \"center_y\": -2.3188405797101446, \"value_uncond\": 8.858162581182814e-07}, {\"x\": -7.391304347826087, \"y\": -2.4637681159420284, \"x2\": -7.101449275362319, \"y2\": -2.1739130434782608, \"center_x\": -7.246376811594203, \"center_y\": -2.3188405797101446, \"value_uncond\": 1.2843997970839784e-06}, {\"x\": -7.101449275362318, \"y\": -2.4637681159420284, \"x2\": -6.811594202898551, \"y2\": -2.1739130434782608, \"center_x\": -6.956521739130435, \"center_y\": -2.3188405797101446, \"value_uncond\": 1.8450265672647442e-06}, {\"x\": -6.811594202898551, \"y\": -2.4637681159420284, \"x2\": -6.521739130434783, \"y2\": -2.1739130434782608, \"center_x\": -6.666666666666667, \"center_y\": -2.3188405797101446, \"value_uncond\": 2.6257346452051987e-06}, {\"x\": -6.521739130434782, \"y\": -2.4637681159420284, \"x2\": -6.231884057971015, \"y2\": -2.1739130434782608, \"center_x\": -6.3768115942028984, \"center_y\": -2.3188405797101446, \"value_uncond\": 3.7020719872461713e-06}, {\"x\": -6.231884057971014, \"y\": -2.4637681159420284, \"x2\": -5.942028985507246, \"y2\": -2.1739130434782608, \"center_x\": -6.08695652173913, \"center_y\": -2.3188405797101446, \"value_uncond\": 5.171120986168483e-06}, {\"x\": -5.942028985507246, \"y\": -2.4637681159420284, \"x2\": -5.6521739130434785, \"y2\": -2.1739130434782608, \"center_x\": -5.797101449275362, \"center_y\": -2.3188405797101446, \"value_uncond\": 7.15600034546198e-06}, {\"x\": -5.6521739130434785, \"y\": -2.4637681159420284, \"x2\": -5.362318840579711, \"y2\": -2.1739130434782608, \"center_x\": -5.507246376811595, \"center_y\": -2.3188405797101446, \"value_uncond\": 9.810741242848559e-06}, {\"x\": -5.36231884057971, \"y\": -2.4637681159420284, \"x2\": -5.072463768115942, \"y2\": -2.1739130434782608, \"center_x\": -5.217391304347826, \"center_y\": -2.3188405797101446, \"value_uncond\": 1.3325364714431008e-05}, {\"x\": -5.0724637681159415, \"y\": -2.4637681159420284, \"x2\": -4.782608695652174, \"y2\": -2.1739130434782608, \"center_x\": -4.927536231884058, \"center_y\": -2.3188405797101446, \"value_uncond\": 1.7930904689325227e-05}, {\"x\": -4.782608695652174, \"y\": -2.4637681159420284, \"x2\": -4.492753623188406, \"y2\": -2.1739130434782608, \"center_x\": -4.63768115942029, \"center_y\": -2.3188405797101446, \"value_uncond\": 2.3904029398240288e-05}, {\"x\": -4.492753623188405, \"y\": -2.4637681159420284, \"x2\": -4.202898550724638, \"y2\": -2.1739130434782608, \"center_x\": -4.3478260869565215, \"center_y\": -2.3188405797101446, \"value_uncond\": 3.157081846080717e-05}, {\"x\": -4.202898550724638, \"y\": -2.4637681159420284, \"x2\": -3.91304347826087, \"y2\": -2.1739130434782608, \"center_x\": -4.057971014492754, \"center_y\": -2.3188405797101446, \"value_uncond\": 4.130916173779552e-05}, {\"x\": -3.913043478260869, \"y\": -2.4637681159420284, \"x2\": -3.6231884057971016, \"y2\": -2.1739130434782608, \"center_x\": -3.7681159420289854, \"center_y\": -2.3188405797101446, \"value_uncond\": 5.354916928628562e-05}, {\"x\": -3.6231884057971016, \"y\": -2.4637681159420284, \"x2\": -3.333333333333334, \"y2\": -2.1739130434782608, \"center_x\": -3.4782608695652177, \"center_y\": -2.3188405797101446, \"value_uncond\": 6.87709317214403e-05}, {\"x\": -3.333333333333333, \"y\": -2.4637681159420284, \"x2\": -3.0434782608695654, \"y2\": -2.1739130434782608, \"center_x\": -3.1884057971014492, \"center_y\": -2.3188405797101446, \"value_uncond\": 8.749896041355213e-05}, {\"x\": -3.0434782608695645, \"y\": -2.4637681159420284, \"x2\": -2.753623188405797, \"y2\": -2.1739130434782608, \"center_x\": -2.8985507246376807, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.00011029268070578547}, {\"x\": -2.753623188405797, \"y\": -2.4637681159420284, \"x2\": -2.4637681159420293, \"y2\": -2.1739130434782608, \"center_x\": -2.608695652173913, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.00013773246067225788}, {\"x\": -2.4637681159420284, \"y\": -2.4637681159420284, \"x2\": -2.1739130434782608, \"y2\": -2.1739130434782608, \"center_x\": -2.3188405797101446, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.00017040084143240576}, {\"x\": -2.1739130434782608, \"y\": -2.4637681159420284, \"x2\": -1.8840579710144931, \"y2\": -2.1739130434782608, \"center_x\": -2.028985507246377, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.00020885889596793423}, {\"x\": -1.8840579710144922, \"y\": -2.4637681159420284, \"x2\": -1.5942028985507246, \"y2\": -2.1739130434782608, \"center_x\": -1.7391304347826084, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0002536179778744869}, {\"x\": -1.5942028985507246, \"y\": -2.4637681159420284, \"x2\": -1.304347826086957, \"y2\": -2.1739130434782608, \"center_x\": -1.4492753623188408, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.00030510751704652234}, {\"x\": -1.304347826086957, \"y\": -2.4637681159420284, \"x2\": -1.0144927536231894, \"y2\": -2.1739130434782608, \"center_x\": -1.1594202898550732, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0003636399541124481}, {\"x\": -1.0144927536231876, \"y\": -2.4637681159420284, \"x2\": -0.72463768115942, \"y2\": -2.1739130434782608, \"center_x\": -0.8695652173913038, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0004293743485324563}, {\"x\": -0.72463768115942, \"y\": -2.4637681159420284, \"x2\": -0.43478260869565233, \"y2\": -2.1739130434782608, \"center_x\": -0.5797101449275361, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0005022806078948621}, {\"x\": -0.43478260869565233, \"y\": -2.4637681159420284, \"x2\": -0.1449275362318847, \"y2\": -2.1739130434782608, \"center_x\": -0.2898550724637685, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0005821066242024608}, {\"x\": -0.14492753623188293, \"y\": -2.4637681159420284, \"x2\": 0.1449275362318847, \"y2\": -2.1739130434782608, \"center_x\": 8.881784197001252e-16, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0006683508215935073}, {\"x\": 0.1449275362318847, \"y\": -2.4637681159420284, \"x2\": 0.43478260869565233, \"y2\": -2.1739130434782608, \"center_x\": 0.2898550724637685, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0007602426771522744}, {\"x\": 0.43478260869565233, \"y\": -2.4637681159420284, \"x2\": 0.72463768115942, \"y2\": -2.1739130434782608, \"center_x\": 0.5797101449275361, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0008567336390120467}, {\"x\": 0.72463768115942, \"y\": -2.4637681159420284, \"x2\": 1.0144927536231876, \"y2\": -2.1739130434782608, \"center_x\": 0.8695652173913038, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0009565005143708588}, {\"x\": 1.0144927536231894, \"y\": -2.4637681159420284, \"x2\": 1.304347826086957, \"y2\": -2.1739130434782608, \"center_x\": 1.1594202898550732, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0010579628329700835}, {\"x\": 1.304347826086957, \"y\": -2.4637681159420284, \"x2\": 1.5942028985507246, \"y2\": -2.1739130434782608, \"center_x\": 1.4492753623188408, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0011593149286837688}, {\"x\": 1.5942028985507246, \"y\": -2.4637681159420284, \"x2\": 1.8840579710144922, \"y2\": -2.1739130434782608, \"center_x\": 1.7391304347826084, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0012585725646548536}, {\"x\": 1.884057971014494, \"y\": -2.4637681159420284, \"x2\": 2.1739130434782616, \"y2\": -2.1739130434782608, \"center_x\": 2.028985507246378, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0013536329176891404}, {\"x\": 2.1739130434782616, \"y\": -2.4637681159420284, \"x2\": 2.4637681159420293, \"y2\": -2.1739130434782608, \"center_x\": 2.3188405797101455, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0014423457132914212}, {\"x\": 2.4637681159420293, \"y\": -2.4637681159420284, \"x2\": 2.753623188405797, \"y2\": -2.1739130434782608, \"center_x\": 2.608695652173913, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0015225923513204752}, {\"x\": 2.753623188405797, \"y\": -2.4637681159420284, \"x2\": 3.0434782608695645, \"y2\": -2.1739130434782608, \"center_x\": 2.8985507246376807, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.001592369072576375}, {\"x\": 3.0434782608695663, \"y\": -2.4637681159420284, \"x2\": 3.333333333333334, \"y2\": -2.1739130434782608, \"center_x\": 3.18840579710145, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0016498696696066464}, {\"x\": 3.333333333333334, \"y\": -2.4637681159420284, \"x2\": 3.6231884057971016, \"y2\": -2.1739130434782608, \"center_x\": 3.4782608695652177, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.001693563004469659}, {\"x\": 3.6231884057971016, \"y\": -2.4637681159420284, \"x2\": 3.913043478260869, \"y2\": -2.1739130434782608, \"center_x\": 3.7681159420289854, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0017222607010635757}, {\"x\": 3.913043478260871, \"y\": -2.4637681159420284, \"x2\": 4.202898550724639, \"y2\": -2.1739130434782608, \"center_x\": 4.057971014492755, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.001735170838412833}, {\"x\": 4.202898550724639, \"y\": -2.4637681159420284, \"x2\": 4.492753623188406, \"y2\": -2.1739130434782608, \"center_x\": 4.347826086956522, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0017319342596446646}, {\"x\": 4.492753623188406, \"y\": -2.4637681159420284, \"x2\": 4.782608695652174, \"y2\": -2.1739130434782608, \"center_x\": 4.63768115942029, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0017126411732490121}, {\"x\": 4.782608695652174, \"y\": -2.4637681159420284, \"x2\": 5.0724637681159415, \"y2\": -2.1739130434782608, \"center_x\": 4.927536231884058, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.001677826975637138}, {\"x\": 5.072463768115943, \"y\": -2.4637681159420284, \"x2\": 5.362318840579711, \"y2\": -2.1739130434782608, \"center_x\": 5.217391304347827, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0016284475649946408}, {\"x\": 5.362318840579711, \"y\": -2.4637681159420284, \"x2\": 5.6521739130434785, \"y2\": -2.1739130434782608, \"center_x\": 5.507246376811595, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0015658357350380376}, {\"x\": 5.6521739130434785, \"y\": -2.4637681159420284, \"x2\": 5.942028985507246, \"y2\": -2.1739130434782608, \"center_x\": 5.797101449275362, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0014916414248630431}, {\"x\": 5.942028985507246, \"y\": -2.4637681159420284, \"x2\": 6.231884057971014, \"y2\": -2.1739130434782608, \"center_x\": 6.08695652173913, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0014077595621190266}, {\"x\": 6.2318840579710155, \"y\": -2.4637681159420284, \"x2\": 6.521739130434783, \"y2\": -2.1739130434782608, \"center_x\": 6.376811594202899, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0013162498982813384}, {\"x\": 6.521739130434785, \"y\": -2.4637681159420284, \"x2\": 6.8115942028985526, \"y2\": -2.1739130434782608, \"center_x\": 6.666666666666669, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0012192535530811497}, {\"x\": 6.811594202898551, \"y\": -2.4637681159420284, \"x2\": 7.101449275362318, \"y2\": -2.1739130434782608, \"center_x\": 6.956521739130435, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.001118910949040142}, {\"x\": 7.10144927536232, \"y\": -2.4637681159420284, \"x2\": 7.391304347826088, \"y2\": -2.1739130434782608, \"center_x\": 7.246376811594204, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0010172854476969823}, {\"x\": 7.391304347826086, \"y\": -2.4637681159420284, \"x2\": 7.681159420289854, \"y2\": -2.1739130434782608, \"center_x\": 7.53623188405797, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0009162963462204569}, {\"x\": 7.681159420289855, \"y\": -2.4637681159420284, \"x2\": 7.971014492753623, \"y2\": -2.1739130434782608, \"center_x\": 7.826086956521739, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0008176640283809533}, {\"x\": 7.971014492753625, \"y\": -2.4637681159420284, \"x2\": 8.260869565217392, \"y2\": -2.1739130434782608, \"center_x\": 8.115942028985508, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0007228690724893741}, {\"x\": 8.26086956521739, \"y\": -2.4637681159420284, \"x2\": 8.550724637681158, \"y2\": -2.1739130434782608, \"center_x\": 8.405797101449274, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0006331260902921042}, {\"x\": 8.55072463768116, \"y\": -2.4637681159420284, \"x2\": 8.840579710144928, \"y2\": -2.1739130434782608, \"center_x\": 8.695652173913043, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0005493720895215017}, {\"x\": 8.84057971014493, \"y\": -2.4637681159420284, \"x2\": 9.130434782608697, \"y2\": -2.1739130434782608, \"center_x\": 8.985507246376812, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.000472268290967481}, {\"x\": 9.130434782608695, \"y\": -2.4637681159420284, \"x2\": 9.420289855072463, \"y2\": -2.1739130434782608, \"center_x\": 9.275362318840578, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0004022136426000418}, {\"x\": 9.420289855072465, \"y\": -2.4637681159420284, \"x2\": 9.710144927536232, \"y2\": -2.1739130434782608, \"center_x\": 9.565217391304348, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0003393677912590714}, {\"x\": 9.710144927536234, \"y\": -2.4637681159420284, \"x2\": 10.000000000000002, \"y2\": -2.1739130434782608, \"center_x\": 9.855072463768117, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.0002836810077581909}, {\"x\": 10.0, \"y\": -2.4637681159420284, \"x2\": 10.289855072463768, \"y2\": -2.1739130434782608, \"center_x\": 10.144927536231883, \"center_y\": -2.3188405797101446, \"value_uncond\": 0.00023492850487774955}, {\"x\": -10.0, \"y\": -2.1739130434782608, \"x2\": -9.710144927536232, \"y2\": -1.8840579710144931, \"center_x\": -9.855072463768117, \"center_y\": -2.028985507246377, \"value_uncond\": 3.9711982012199266e-08}, {\"x\": -9.710144927536232, \"y\": -2.1739130434782608, \"x2\": -9.420289855072465, \"y2\": -1.8840579710144931, \"center_x\": -9.565217391304348, \"center_y\": -2.028985507246377, \"value_uncond\": 6.204569134735891e-08}, {\"x\": -9.420289855072463, \"y\": -2.1739130434782608, \"x2\": -9.130434782608695, \"y2\": -1.8840579710144931, \"center_x\": -9.275362318840578, \"center_y\": -2.028985507246377, \"value_uncond\": 9.603897307467887e-08}, {\"x\": -9.130434782608695, \"y\": -2.1739130434782608, \"x2\": -8.840579710144928, \"y2\": -1.8840579710144931, \"center_x\": -8.985507246376812, \"center_y\": -2.028985507246377, \"value_uncond\": 1.4727505772775686e-07}, {\"x\": -8.840579710144928, \"y\": -2.1739130434782608, \"x2\": -8.55072463768116, \"y2\": -1.8840579710144931, \"center_x\": -8.695652173913043, \"center_y\": -2.028985507246377, \"value_uncond\": 2.2374673685142385e-07}, {\"x\": -8.55072463768116, \"y\": -2.1739130434782608, \"x2\": -8.260869565217392, \"y2\": -1.8840579710144931, \"center_x\": -8.405797101449277, \"center_y\": -2.028985507246377, \"value_uncond\": 3.3676739177298414e-07}, {\"x\": -8.26086956521739, \"y\": -2.1739130434782608, \"x2\": -7.971014492753623, \"y2\": -1.8840579710144931, \"center_x\": -8.115942028985508, \"center_y\": -2.028985507246377, \"value_uncond\": 5.021681579830735e-07}, {\"x\": -7.971014492753623, \"y\": -2.1739130434782608, \"x2\": -7.681159420289855, \"y2\": -1.8840579710144931, \"center_x\": -7.826086956521739, \"center_y\": -2.028985507246377, \"value_uncond\": 7.418466216361657e-07}, {\"x\": -7.681159420289855, \"y\": -2.1739130434782608, \"x2\": -7.391304347826088, \"y2\": -1.8840579710144931, \"center_x\": -7.536231884057972, \"center_y\": -2.028985507246377, \"value_uncond\": 1.0857376298486197e-06}, {\"x\": -7.391304347826087, \"y\": -2.1739130434782608, \"x2\": -7.101449275362319, \"y2\": -1.8840579710144931, \"center_x\": -7.246376811594203, \"center_y\": -2.028985507246377, \"value_uncond\": 1.574278162862302e-06}, {\"x\": -7.101449275362318, \"y\": -2.1739130434782608, \"x2\": -6.811594202898551, \"y2\": -1.8840579710144931, \"center_x\": -6.956521739130435, \"center_y\": -2.028985507246377, \"value_uncond\": 2.261433738420133e-06}, {\"x\": -6.811594202898551, \"y\": -2.1739130434782608, \"x2\": -6.521739130434783, \"y2\": -1.8840579710144931, \"center_x\": -6.666666666666667, \"center_y\": -2.028985507246377, \"value_uncond\": 3.2183411448696105e-06}, {\"x\": -6.521739130434782, \"y\": -2.1739130434782608, \"x2\": -6.231884057971015, \"y2\": -1.8840579710144931, \"center_x\": -6.3768115942028984, \"center_y\": -2.028985507246377, \"value_uncond\": 4.537598884784661e-06}, {\"x\": -6.231884057971014, \"y\": -2.1739130434782608, \"x2\": -5.942028985507246, \"y2\": -1.8840579710144931, \"center_x\": -6.08695652173913, \"center_y\": -2.028985507246377, \"value_uncond\": 6.338200040615355e-06}, {\"x\": -5.942028985507246, \"y\": -2.1739130434782608, \"x2\": -5.6521739130434785, \"y2\": -1.8840579710144931, \"center_x\": -5.797101449275362, \"center_y\": -2.028985507246377, \"value_uncond\": 8.771050184586184e-06}, {\"x\": -5.6521739130434785, \"y\": -2.1739130434782608, \"x2\": -5.362318840579711, \"y2\": -1.8840579710144931, \"center_x\": -5.507246376811595, \"center_y\": -2.028985507246377, \"value_uncond\": 1.2024944051824084e-05}, {\"x\": -5.36231884057971, \"y\": -2.1739130434782608, \"x2\": -5.072463768115942, \"y2\": -1.8840579710144931, \"center_x\": -5.217391304347826, \"center_y\": -2.028985507246377, \"value_uncond\": 1.6332788847936102e-05}, {\"x\": -5.0724637681159415, \"y\": -2.1739130434782608, \"x2\": -4.782608695652174, \"y2\": -1.8840579710144931, \"center_x\": -4.927536231884058, \"center_y\": -2.028985507246377, \"value_uncond\": 2.197776094083601e-05}, {\"x\": -4.782608695652174, \"y\": -2.1739130434782608, \"x2\": -4.492753623188406, \"y2\": -1.8840579710144931, \"center_x\": -4.63768115942029, \"center_y\": -2.028985507246377, \"value_uncond\": 2.929897028285477e-05}, {\"x\": -4.492753623188405, \"y\": -2.1739130434782608, \"x2\": -4.202898550724638, \"y2\": -1.8840579710144931, \"center_x\": -4.3478260869565215, \"center_y\": -2.028985507246377, \"value_uncond\": 3.869608995530632e-05}, {\"x\": -4.202898550724638, \"y\": -2.1739130434782608, \"x2\": -3.91304347826087, \"y2\": -1.8840579710144931, \"center_x\": -4.057971014492754, \"center_y\": -2.028985507246377, \"value_uncond\": 5.063229642172422e-05}, {\"x\": -3.913043478260869, \"y\": -2.1739130434782608, \"x2\": -3.6231884057971016, \"y2\": -1.8840579710144931, \"center_x\": -3.7681159420289854, \"center_y\": -2.028985507246377, \"value_uncond\": 6.563477200651124e-05}, {\"x\": -3.6231884057971016, \"y\": -2.1739130434782608, \"x2\": -3.333333333333334, \"y2\": -1.8840579710144931, \"center_x\": -3.4782608695652177, \"center_y\": -2.028985507246377, \"value_uncond\": 8.429195978896527e-05}, {\"x\": -3.333333333333333, \"y\": -2.1739130434782608, \"x2\": -3.0434782608695654, \"y2\": -1.8840579710144931, \"center_x\": -3.1884057971014492, \"center_y\": -2.028985507246377, \"value_uncond\": 0.00010724674899898157}, {\"x\": -3.0434782608695645, \"y\": -2.1739130434782608, \"x2\": -2.753623188405797, \"y2\": -1.8840579710144931, \"center_x\": -2.8985507246376807, \"center_y\": -2.028985507246377, \"value_uncond\": 0.00013518482263300295}, {\"x\": -2.753623188405797, \"y\": -2.1739130434782608, \"x2\": -2.4637681159420293, \"y2\": -1.8840579710144931, \"center_x\": -2.608695652173913, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0001688175330188482}, {\"x\": -2.4637681159420284, \"y\": -2.1739130434782608, \"x2\": -2.1739130434782608, \"y2\": -1.8840579710144931, \"center_x\": -2.3188405797101446, \"center_y\": -2.028985507246377, \"value_uncond\": 0.00020885889596793423}, {\"x\": -2.1739130434782608, \"y\": -2.1739130434782608, \"x2\": -1.8840579710144931, \"y2\": -1.8840579710144931, \"center_x\": -2.028985507246377, \"center_y\": -2.028985507246377, \"value_uncond\": 0.00025599661397357725}, {\"x\": -1.8840579710144922, \"y\": -2.1739130434782608, \"x2\": -1.5942028985507246, \"y2\": -1.8840579710144931, \"center_x\": -1.7391304347826084, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0003108574488905764}, {\"x\": -1.5942028985507246, \"y\": -2.1739130434782608, \"x2\": -1.304347826086957, \"y2\": -1.8840579710144931, \"center_x\": -1.4492753623188408, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0003739677493736574}, {\"x\": -1.304347826086957, \"y\": -2.1739130434782608, \"x2\": -1.0144927536231894, \"y2\": -1.8840579710144931, \"center_x\": -1.1594202898550732, \"center_y\": -2.028985507246377, \"value_uncond\": 0.00044571047130588027}, {\"x\": -1.0144927536231876, \"y\": -2.1739130434782608, \"x2\": -0.72463768115942, \"y2\": -1.8840579710144931, \"center_x\": -0.8695652173913038, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0005262805725464293}, {\"x\": -0.72463768115942, \"y\": -2.1739130434782608, \"x2\": -0.43478260869565233, \"y2\": -1.8840579710144931, \"center_x\": -0.5797101449275361, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0006156411690762544}, {\"x\": -0.43478260869565233, \"y\": -2.1739130434782608, \"x2\": -0.1449275362318847, \"y2\": -1.8840579710144931, \"center_x\": -0.2898550724637685, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0007134832542172296}, {\"x\": -0.14492753623188293, \"y\": -2.1739130434782608, \"x2\": 0.1449275362318847, \"y2\": -1.8840579710144931, \"center_x\": 8.881784197001252e-16, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0008191920506017823}, {\"x\": 0.1449275362318847, \"y\": -2.1739130434782608, \"x2\": 0.43478260869565233, \"y2\": -1.8840579710144931, \"center_x\": 0.2898550724637685, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0009318231346921867}, {\"x\": 0.43478260869565233, \"y\": -2.1739130434782608, \"x2\": 0.72463768115942, \"y2\": -1.8840579710144931, \"center_x\": 0.5797101449275361, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0010500913051748446}, {\"x\": 0.72463768115942, \"y\": -2.1739130434782608, \"x2\": 1.0144927536231876, \"y2\": -1.8840579710144931, \"center_x\": 0.8695652173913038, \"center_y\": -2.028985507246377, \"value_uncond\": 0.001172374735623031}, {\"x\": 1.0144927536231894, \"y\": -2.1739130434782608, \"x2\": 1.304347826086957, \"y2\": -1.8840579710144931, \"center_x\": 1.1594202898550732, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0012967362567683765}, {\"x\": 1.304347826086957, \"y\": -2.1739130434782608, \"x2\": 1.5942028985507246, \"y2\": -1.8840579710144931, \"center_x\": 1.4492753623188408, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0014209626786384445}, {\"x\": 1.5942028985507246, \"y\": -2.1739130434782608, \"x2\": 1.8840579710144922, \"y2\": -1.8840579710144931, \"center_x\": 1.7391304347826084, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0015426219385989153}, {\"x\": 1.884057971014494, \"y\": -2.1739130434782608, \"x2\": 2.1739130434782616, \"y2\": -1.8840579710144931, \"center_x\": 2.028985507246378, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0016591366237270336}, {\"x\": 2.1739130434782616, \"y\": -2.1739130434782608, \"x2\": 2.4637681159420293, \"y2\": -1.8840579710144931, \"center_x\": 2.3188405797101455, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0017678711604345368}, {\"x\": 2.4637681159420293, \"y\": -2.1739130434782608, \"x2\": 2.753623188405797, \"y2\": -1.8840579710144931, \"center_x\": 2.608695652173913, \"center_y\": -2.028985507246377, \"value_uncond\": 0.001866228798125751}, {\"x\": 2.753623188405797, \"y\": -2.1739130434782608, \"x2\": 3.0434782608695645, \"y2\": -1.8840579710144931, \"center_x\": 2.8985507246376807, \"center_y\": -2.028985507246377, \"value_uncond\": 0.00195175354579286}, {\"x\": 3.0434782608695663, \"y\": -2.1739130434782608, \"x2\": 3.333333333333334, \"y2\": -1.8840579710144931, \"center_x\": 3.18840579710145, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0020222315499640042}, {\"x\": 3.333333333333334, \"y\": -2.1739130434782608, \"x2\": 3.6231884057971016, \"y2\": -1.8840579710144931, \"center_x\": 3.4782608695652177, \"center_y\": -2.028985507246377, \"value_uncond\": 0.002075786107581996}, {\"x\": 3.6231884057971016, \"y\": -2.1739130434782608, \"x2\": 3.913043478260869, \"y2\": -1.8840579710144931, \"center_x\": 3.7681159420289854, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0021109606359296495}, {\"x\": 3.913043478260871, \"y\": -2.1739130434782608, \"x2\": 4.202898550724639, \"y2\": -1.8840579710144931, \"center_x\": 4.057971014492755, \"center_y\": -2.028985507246377, \"value_uncond\": 0.002126784484045035}, {\"x\": 4.202898550724639, \"y\": -2.1739130434782608, \"x2\": 4.492753623188406, \"y2\": -1.8840579710144931, \"center_x\": 4.347826086956522, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0021228174363324154}, {\"x\": 4.492753623188406, \"y\": -2.1739130434782608, \"x2\": 4.782608695652174, \"y2\": -1.8840579710144931, \"center_x\": 4.63768115942029, \"center_y\": -2.028985507246377, \"value_uncond\": 0.002099170060588626}, {\"x\": 4.782608695652174, \"y\": -2.1739130434782608, \"x2\": 5.0724637681159415, \"y2\": -1.8840579710144931, \"center_x\": 4.927536231884058, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0020564985877478664}, {\"x\": 5.072463768115943, \"y\": -2.1739130434782608, \"x2\": 5.362318840579711, \"y2\": -1.8840579710144931, \"center_x\": 5.217391304347827, \"center_y\": -2.028985507246377, \"value_uncond\": 0.001995974654276386}, {\"x\": 5.362318840579711, \"y\": -2.1739130434782608, \"x2\": 5.6521739130434785, \"y2\": -1.8840579710144931, \"center_x\": 5.507246376811595, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0019192318543621285}, {\"x\": 5.6521739130434785, \"y\": -2.1739130434782608, \"x2\": 5.942028985507246, \"y2\": -1.8840579710144931, \"center_x\": 5.797101449275362, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0018282925046500629}, {\"x\": 5.942028985507246, \"y\": -2.1739130434782608, \"x2\": 6.231884057971014, \"y2\": -1.8840579710144931, \"center_x\": 6.08695652173913, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0017254792022204579}, {\"x\": 6.2318840579710155, \"y\": -2.1739130434782608, \"x2\": 6.521739130434783, \"y2\": -1.8840579710144931, \"center_x\": 6.376811594202899, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0016133165673480364}, {\"x\": 6.521739130434785, \"y\": -2.1739130434782608, \"x2\": 6.8115942028985526, \"y2\": -1.8840579710144931, \"center_x\": 6.666666666666669, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0014944289527028226}, {\"x\": 6.811594202898551, \"y\": -2.1739130434782608, \"x2\": 7.101449275362318, \"y2\": -1.8840579710144931, \"center_x\": 6.956521739130435, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0013714398563909602}, {\"x\": 7.10144927536232, \"y\": -2.1739130434782608, \"x2\": 7.391304347826088, \"y2\": -1.8840579710144931, \"center_x\": 7.246376811594204, \"center_y\": -2.028985507246377, \"value_uncond\": 0.001246878323511795}, {\"x\": 7.391304347826086, \"y\": -2.1739130434782608, \"x2\": 7.681159420289854, \"y2\": -1.8840579710144931, \"center_x\": 7.53623188405797, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0011230968206631274}, {\"x\": 7.681159420289855, \"y\": -2.1739130434782608, \"x2\": 7.971014492753623, \"y2\": -1.8840579710144931, \"center_x\": 7.826086956521739, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0010022040079425468}, {\"x\": 7.971014492753625, \"y\": -2.1739130434782608, \"x2\": 8.260869565217392, \"y2\": -1.8840579710144931, \"center_x\": 8.115942028985508, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0008860146178878153}, {\"x\": 8.26086956521739, \"y\": -2.1739130434782608, \"x2\": 8.550724637681158, \"y2\": -1.8840579710144931, \"center_x\": 8.405797101449274, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0007760173900277234}, {\"x\": 8.55072463768116, \"y\": -2.1739130434782608, \"x2\": 8.840579710144928, \"y2\": -1.8840579710144931, \"center_x\": 8.695652173913043, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0006733608069568906}, {\"x\": 8.84057971014493, \"y\": -2.1739130434782608, \"x2\": 9.130434782608697, \"y2\": -1.8840579710144931, \"center_x\": 8.985507246376812, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0005788553215053133}, {\"x\": 9.130434782608695, \"y\": -2.1739130434782608, \"x2\": 9.420289855072463, \"y2\": -1.8840579710144931, \"center_x\": 9.275362318840578, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0004929899208860965}, {\"x\": 9.420289855072465, \"y\": -2.1739130434782608, \"x2\": 9.710144927536232, \"y2\": -1.8840579710144931, \"center_x\": 9.565217391304348, \"center_y\": -2.028985507246377, \"value_uncond\": 0.0004159602829048383}, {\"x\": 9.710144927536234, \"y\": -2.1739130434782608, \"x2\": 10.000000000000002, \"y2\": -1.8840579710144931, \"center_x\": 9.855072463768117, \"center_y\": -2.028985507246377, \"value_uncond\": 0.00034770545491085266}, {\"x\": 10.0, \"y\": -2.1739130434782608, \"x2\": 10.289855072463768, \"y2\": -1.8840579710144931, \"center_x\": 10.144927536231883, \"center_y\": -2.028985507246377, \"value_uncond\": 0.00028794991707613093}, {\"x\": -10.0, \"y\": -1.8840579710144922, \"x2\": -9.710144927536232, \"y2\": -1.5942028985507246, \"center_x\": -9.855072463768117, \"center_y\": -1.7391304347826084, \"value_uncond\": 4.822237773806992e-08}, {\"x\": -9.710144927536232, \"y\": -1.8840579710144922, \"x2\": -9.420289855072465, \"y2\": -1.5942028985507246, \"center_x\": -9.565217391304348, \"center_y\": -1.7391304347826084, \"value_uncond\": 7.53422673351565e-08}, {\"x\": -9.420289855072463, \"y\": -1.8840579710144922, \"x2\": -9.130434782608695, \"y2\": -1.5942028985507246, \"center_x\": -9.275362318840578, \"center_y\": -1.7391304347826084, \"value_uncond\": 1.1662041032756351e-07}, {\"x\": -9.130434782608695, \"y\": -1.8840579710144922, \"x2\": -8.840579710144928, \"y2\": -1.5942028985507246, \"center_x\": -8.985507246376812, \"center_y\": -1.7391304347826084, \"value_uncond\": 1.7883654013950458e-07}, {\"x\": -8.840579710144928, \"y\": -1.8840579710144922, \"x2\": -8.55072463768116, \"y2\": -1.5942028985507246, \"center_x\": -8.695652173913043, \"center_y\": -1.7391304347826084, \"value_uncond\": 2.7169632728971814e-07}, {\"x\": -8.55072463768116, \"y\": -1.8840579710144922, \"x2\": -8.260869565217392, \"y2\": -1.5942028985507246, \"center_x\": -8.405797101449277, \"center_y\": -1.7391304347826084, \"value_uncond\": 4.089376443349696e-07}, {\"x\": -8.26086956521739, \"y\": -1.8840579710144922, \"x2\": -7.971014492753623, \"y2\": -1.5942028985507246, \"center_x\": -8.115942028985508, \"center_y\": -1.7391304347826084, \"value_uncond\": 6.09784286134387e-07}, {\"x\": -7.971014492753623, \"y\": -1.8840579710144922, \"x2\": -7.681159420289855, \"y2\": -1.5942028985507246, \"center_x\": -7.826086956521739, \"center_y\": -1.7391304347826084, \"value_uncond\": 9.008265566110717e-07}, {\"x\": -7.681159420289855, \"y\": -1.8840579710144922, \"x2\": -7.391304347826088, \"y2\": -1.5942028985507246, \"center_x\": -7.536231884057972, \"center_y\": -1.7391304347826084, \"value_uncond\": 1.3184144295521006e-06}, {\"x\": -7.391304347826087, \"y\": -1.8840579710144922, \"x2\": -7.101449275362319, \"y2\": -1.5942028985507246, \"center_x\": -7.246376811594203, \"center_y\": -1.7391304347826084, \"value_uncond\": 1.9116506501997293e-06}, {\"x\": -7.101449275362318, \"y\": -1.8840579710144922, \"x2\": -6.811594202898551, \"y2\": -1.5942028985507246, \"center_x\": -6.956521739130435, \"center_y\": -1.7391304347826084, \"value_uncond\": 2.746065707075796e-06}, {\"x\": -6.811594202898551, \"y\": -1.8840579710144922, \"x2\": -6.521739130434783, \"y2\": -1.5942028985507246, \"center_x\": -6.666666666666667, \"center_y\": -1.7391304347826084, \"value_uncond\": 3.9080412136115375e-06}, {\"x\": -6.521739130434782, \"y\": -1.8840579710144922, \"x2\": -6.231884057971015, \"y2\": -1.5942028985507246, \"center_x\": -6.3768115942028984, \"center_y\": -1.7391304347826084, \"value_uncond\": 5.510019806584133e-06}, {\"x\": -6.231884057971014, \"y\": -1.8840579710144922, \"x2\": -5.942028985507246, \"y2\": -1.5942028985507246, \"center_x\": -6.08695652173913, \"center_y\": -1.7391304347826084, \"value_uncond\": 7.696495139530241e-06}, {\"x\": -5.942028985507246, \"y\": -1.8840579710144922, \"x2\": -5.6521739130434785, \"y2\": -1.5942028985507246, \"center_x\": -5.797101449275362, \"center_y\": -1.7391304347826084, \"value_uncond\": 1.0650712297128669e-05}, {\"x\": -5.6521739130434785, \"y\": -1.8840579710144922, \"x2\": -5.362318840579711, \"y2\": -1.5942028985507246, \"center_x\": -5.507246376811595, \"center_y\": -1.7391304347826084, \"value_uncond\": 1.4601925287135904e-05}, {\"x\": -5.36231884057971, \"y\": -1.8840579710144922, \"x2\": -5.072463768115942, \"y2\": -1.5942028985507246, \"center_x\": -5.217391304347826, \"center_y\": -1.7391304347826084, \"value_uncond\": 1.9832954021266523e-05}, {\"x\": -5.0724637681159415, \"y\": -1.8840579710144922, \"x2\": -4.782608695652174, \"y2\": -1.5942028985507246, \"center_x\": -4.927536231884058, \"center_y\": -1.7391304347826084, \"value_uncond\": 2.6687660404369246e-05}, {\"x\": -4.782608695652174, \"y\": -1.8840579710144922, \"x2\": -4.492753623188406, \"y2\": -1.5942028985507246, \"center_x\": -4.63768115942029, \"center_y\": -1.7391304347826084, \"value_uncond\": 3.557782665902412e-05}, {\"x\": -4.492753623188405, \"y\": -1.8840579710144922, \"x2\": -4.202898550724638, \"y2\": -1.5942028985507246, \"center_x\": -4.3478260869565215, \"center_y\": -1.7391304347826084, \"value_uncond\": 4.698877699526274e-05}, {\"x\": -4.202898550724638, \"y\": -1.8840579710144922, \"x2\": -3.91304347826087, \"y2\": -1.5942028985507246, \"center_x\": -4.057971014492754, \"center_y\": -1.7391304347826084, \"value_uncond\": 6.148294796880874e-05}, {\"x\": -3.913043478260869, \"y\": -1.8840579710144922, \"x2\": -3.6231884057971016, \"y2\": -1.5942028985507246, \"center_x\": -3.7681159420289854, \"center_y\": -1.7391304347826084, \"value_uncond\": 7.97004986423945e-05}, {\"x\": -3.6231884057971016, \"y\": -1.8840579710144922, \"x2\": -3.333333333333334, \"y2\": -1.5942028985507246, \"center_x\": -3.4782608695652177, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.00010235597719542227}, {\"x\": -3.333333333333333, \"y\": -1.8840579710144922, \"x2\": -3.0434782608695654, \"y2\": -1.5942028985507246, \"center_x\": -3.1884057971014492, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0001302300459297184}, {\"x\": -3.0434782608695645, \"y\": -1.8840579710144922, \"x2\": -2.753623188405797, \"y2\": -1.5942028985507246, \"center_x\": -2.8985507246376807, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0001641553317449651}, {\"x\": -2.753623188405797, \"y\": -1.8840579710144922, \"x2\": -2.4637681159420293, \"y2\": -1.5942028985507246, \"center_x\": -2.608695652173913, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.00020499563188619514}, {\"x\": -2.4637681159420284, \"y\": -1.8840579710144922, \"x2\": -2.1739130434782608, \"y2\": -1.5942028985507246, \"center_x\": -2.3188405797101446, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0002536179778744869}, {\"x\": -2.1739130434782608, \"y\": -1.8840579710144922, \"x2\": -1.8840579710144931, \"y2\": -1.5942028985507246, \"center_x\": -2.028985507246377, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0003108574488905764}, {\"x\": -1.8840579710144922, \"y\": -1.8840579710144922, \"x2\": -1.5942028985507246, \"y2\": -1.5942028985507246, \"center_x\": -1.7391304347826084, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0003774751237167975}, {\"x\": -1.5942028985507246, \"y\": -1.8840579710144922, \"x2\": -1.304347826086957, \"y2\": -1.5942028985507246, \"center_x\": -1.4492753623188408, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.00045411014908831735}, {\"x\": -1.304347826086957, \"y\": -1.8840579710144922, \"x2\": -1.0144927536231894, \"y2\": -1.5942028985507246, \"center_x\": -1.1594202898550732, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0005412275494716625}, {\"x\": -1.0144927536231876, \"y\": -1.8840579710144922, \"x2\": -0.72463768115942, \"y2\": -1.5942028985507246, \"center_x\": -0.8695652173913038, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0006390640627744426}, {\"x\": -0.72463768115942, \"y\": -1.8840579710144922, \"x2\": -0.43478260869565233, \"y2\": -1.5942028985507246, \"center_x\": -0.5797101449275361, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.000747574900622746}, {\"x\": -0.43478260869565233, \"y\": -1.8840579710144922, \"x2\": -0.1449275362318847, \"y2\": -1.5942028985507246, \"center_x\": -0.2898550724637685, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0008663848352892936}, {\"x\": -0.14492753623188293, \"y\": -1.8840579710144922, \"x2\": 0.1449275362318847, \"y2\": -1.5942028985507246, \"center_x\": 8.881784197001252e-16, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0009947473407901947}, {\"x\": 0.1449275362318847, \"y\": -1.8840579710144922, \"x2\": 0.43478260869565233, \"y2\": -1.5942028985507246, \"center_x\": 0.2898550724637685, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.001131515600817794}, {\"x\": 0.43478260869565233, \"y\": -1.8840579710144922, \"x2\": 0.72463768115942, \"y2\": -1.5942028985507246, \"center_x\": 0.5797101449275361, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0012751289915987729}, {\"x\": 0.72463768115942, \"y\": -1.8840579710144922, \"x2\": 1.0144927536231876, \"y2\": -1.5942028985507246, \"center_x\": 0.8695652173913038, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0014236181244848623}, {\"x\": 1.0144927536231894, \"y\": -1.8840579710144922, \"x2\": 1.304347826086957, \"y2\": -1.5942028985507246, \"center_x\": 1.1594202898550732, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.001574630689078329}, {\"x\": 1.304347826086957, \"y\": -1.8840579710144922, \"x2\": 1.5942028985507246, \"y2\": -1.5942028985507246, \"center_x\": 1.4492753623188408, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0017254792022204585}, {\"x\": 1.5942028985507246, \"y\": -1.8840579710144922, \"x2\": 1.8840579710144922, \"y2\": -1.5942028985507246, \"center_x\": 1.7391304347826084, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0018732104030289617}, {\"x\": 1.884057971014494, \"y\": -1.8840579710144922, \"x2\": 2.1739130434782616, \"y2\": -1.5942028985507246, \"center_x\": 2.028985507246378, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.002014694531334479}, {\"x\": 2.1739130434782616, \"y\": -1.8840579710144922, \"x2\": 2.4637681159420293, \"y2\": -1.5942028985507246, \"center_x\": 2.3188405797101455, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.002146731202298736}, {\"x\": 2.4637681159420293, \"y\": -1.8840579710144922, \"x2\": 2.753623188405797, \"y2\": -1.5942028985507246, \"center_x\": 2.608695652173913, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0022661671739586985}, {\"x\": 2.753623188405797, \"y\": -1.8840579710144922, \"x2\": 3.0434782608695645, \"y2\": -1.5942028985507246, \"center_x\": 2.8985507246376807, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0023700201291370505}, {\"x\": 3.0434782608695663, \"y\": -1.8840579710144922, \"x2\": 3.333333333333334, \"y2\": -1.5942028985507246, \"center_x\": 3.18840579710145, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.002455601778985758}, {\"x\": 3.333333333333334, \"y\": -1.8840579710144922, \"x2\": 3.6231884057971016, \"y2\": -1.5942028985507246, \"center_x\": 3.4782608695652177, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0025206332374069643}, {\"x\": 3.6231884057971016, \"y\": -1.8840579710144922, \"x2\": 3.913043478260869, \"y2\": -1.5942028985507246, \"center_x\": 3.7681159420289854, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.002563345771679817}, {\"x\": 3.913043478260871, \"y\": -1.8840579710144922, \"x2\": 4.202898550724639, \"y2\": -1.5942028985507246, \"center_x\": 4.057971014492755, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.002582560717457531}, {\"x\": 4.202898550724639, \"y\": -1.8840579710144922, \"x2\": 4.492753623188406, \"y2\": -1.5942028985507246, \"center_x\": 4.347826086956522, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0025777435196343624}, {\"x\": 4.492753623188406, \"y\": -1.8840579710144922, \"x2\": 4.782608695652174, \"y2\": -1.5942028985507246, \"center_x\": 4.63768115942029, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0025490284410144945}, {\"x\": 4.782608695652174, \"y\": -1.8840579710144922, \"x2\": 5.0724637681159415, \"y2\": -1.5942028985507246, \"center_x\": 4.927536231884058, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0024972123447709275}, {\"x\": 5.072463768115943, \"y\": -1.8840579710144922, \"x2\": 5.362318840579711, \"y2\": -1.5942028985507246, \"center_x\": 5.217391304347827, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0024237179525454537}, {\"x\": 5.362318840579711, \"y\": -1.8840579710144922, \"x2\": 5.6521739130434785, \"y2\": -1.5942028985507246, \"center_x\": 5.507246376811595, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0023305289426137506}, {\"x\": 5.6521739130434785, \"y\": -1.8840579710144922, \"x2\": 5.942028985507246, \"y2\": -1.5942028985507246, \"center_x\": 5.797101449275362, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.002220101020085922}, {\"x\": 5.942028985507246, \"y\": -1.8840579710144922, \"x2\": 6.231884057971014, \"y2\": -1.5942028985507246, \"center_x\": 6.08695652173913, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0020952545214967607}, {\"x\": 6.2318840579710155, \"y\": -1.8840579710144922, \"x2\": 6.521739130434783, \"y2\": -1.5942028985507246, \"center_x\": 6.376811594202899, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.001959055100746278}, {\"x\": 6.521739130434785, \"y\": -1.8840579710144922, \"x2\": 6.8115942028985526, \"y2\": -1.5942028985507246, \"center_x\": 6.666666666666669, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0018146895170783953}, {\"x\": 6.811594202898551, \"y\": -1.8840579710144922, \"x2\": 7.101449275362318, \"y2\": -1.5942028985507246, \"center_x\": 6.956521739130435, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0016653434920375757}, {\"x\": 7.10144927536232, \"y\": -1.8840579710144922, \"x2\": 7.391304347826088, \"y2\": -1.5942028985507246, \"center_x\": 7.246376811594204, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.001514088052601515}, {\"x\": 7.391304347826086, \"y\": -1.8840579710144922, \"x2\": 7.681159420289854, \"y2\": -1.5942028985507246, \"center_x\": 7.53623188405797, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0013637798059488858}, {\"x\": 7.681159420289855, \"y\": -1.8840579710144922, \"x2\": 7.971014492753623, \"y2\": -1.5942028985507246, \"center_x\": 7.826086956521739, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0012169793043008256}, {\"x\": 7.971014492753625, \"y\": -1.8840579710144922, \"x2\": 8.260869565217392, \"y2\": -1.5942028985507246, \"center_x\": 8.115942028985508, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0010758901827693436}, {\"x\": 8.26086956521739, \"y\": -1.8840579710144922, \"x2\": 8.550724637681158, \"y2\": -1.5942028985507246, \"center_x\": 8.405797101449274, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0009423202221871583}, {\"x\": 8.55072463768116, \"y\": -1.8840579710144922, \"x2\": 8.840579710144928, \"y2\": -1.5942028985507246, \"center_x\": 8.695652173913043, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0008176640283809529}, {\"x\": 8.84057971014493, \"y\": -1.8840579710144922, \"x2\": 9.130434782608697, \"y2\": -1.5942028985507246, \"center_x\": 8.985507246376812, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0007029057366299728}, {\"x\": 9.130434782608695, \"y\": -1.8840579710144922, \"x2\": 9.420289855072463, \"y2\": -1.5942028985507246, \"center_x\": 9.275362318840578, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0005986391255598276}, {\"x\": 9.420289855072465, \"y\": -1.8840579710144922, \"x2\": 9.710144927536232, \"y2\": -1.5942028985507246, \"center_x\": 9.565217391304348, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.0005051018073111961}, {\"x\": 9.710144927536234, \"y\": -1.8840579710144922, \"x2\": 10.000000000000002, \"y2\": -1.5942028985507246, \"center_x\": 9.855072463768117, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.00042221976689926533}, {\"x\": 10.0, \"y\": -1.8840579710144922, \"x2\": 10.289855072463768, \"y2\": -1.5942028985507246, \"center_x\": 10.144927536231883, \"center_y\": -1.7391304347826084, \"value_uncond\": 0.00034965843977834024}, {\"x\": -10.0, \"y\": -1.5942028985507246, \"x2\": -9.710144927536232, \"y2\": -1.304347826086957, \"center_x\": -9.855072463768117, \"center_y\": -1.4492753623188408, \"value_uncond\": 5.801248815659017e-08}, {\"x\": -9.710144927536232, \"y\": -1.5942028985507246, \"x2\": -9.420289855072465, \"y2\": -1.304347826086957, \"center_x\": -9.565217391304348, \"center_y\": -1.4492753623188408, \"value_uncond\": 9.063825959002471e-08}, {\"x\": -9.420289855072463, \"y\": -1.5942028985507246, \"x2\": -9.130434782608695, \"y2\": -1.304347826086957, \"center_x\": -9.275362318840578, \"center_y\": -1.4492753623188408, \"value_uncond\": 1.4029669398909313e-07}, {\"x\": -9.130434782608695, \"y\": -1.5942028985507246, \"x2\": -8.840579710144928, \"y2\": -1.304347826086957, \"center_x\": -8.985507246376812, \"center_y\": -1.4492753623188408, \"value_uncond\": 2.1514394672036343e-07}, {\"x\": -8.840579710144928, \"y\": -1.5942028985507246, \"x2\": -8.55072463768116, \"y2\": -1.304347826086957, \"center_x\": -8.695652173913043, \"center_y\": -1.4492753623188408, \"value_uncond\": 3.268561341934916e-07}, {\"x\": -8.55072463768116, \"y\": -1.5942028985507246, \"x2\": -8.260869565217392, \"y2\": -1.304347826086957, \"center_x\": -8.405797101449277, \"center_y\": -1.4492753623188408, \"value_uncond\": 4.919601927890292e-07}, {\"x\": -8.26086956521739, \"y\": -1.5942028985507246, \"x2\": -7.971014492753623, \"y2\": -1.304347826086957, \"center_x\": -8.115942028985508, \"center_y\": -1.4492753623188408, \"value_uncond\": 7.33582733510017e-07}, {\"x\": -7.971014492753623, \"y\": -1.5942028985507246, \"x2\": -7.681159420289855, \"y2\": -1.304347826086957, \"center_x\": -7.826086956521739, \"center_y\": -1.4492753623188408, \"value_uncond\": 1.0837124255962345e-06}, {\"x\": -7.681159420289855, \"y\": -1.5942028985507246, \"x2\": -7.391304347826088, \"y2\": -1.304347826086957, \"center_x\": -7.536231884057972, \"center_y\": -1.4492753623188408, \"value_uncond\": 1.586079016993117e-06}, {\"x\": -7.391304347826087, \"y\": -1.5942028985507246, \"x2\": -7.101449275362319, \"y2\": -1.304347826086957, \"center_x\": -7.246376811594203, \"center_y\": -1.4492753623188408, \"value_uncond\": 2.299754095632208e-06}, {\"x\": -7.101449275362318, \"y\": -1.5942028985507246, \"x2\": -6.811594202898551, \"y2\": -1.304347826086957, \"center_x\": -6.956521739130435, \"center_y\": -1.4492753623188408, \"value_uncond\": 3.3035721542860862e-06}, {\"x\": -6.811594202898551, \"y\": -1.5942028985507246, \"x2\": -6.521739130434783, \"y2\": -1.304347826086957, \"center_x\": -6.666666666666667, \"center_y\": -1.4492753623188408, \"value_uncond\": 4.701452007438475e-06}, {\"x\": -6.521739130434782, \"y\": -1.5942028985507246, \"x2\": -6.231884057971015, \"y2\": -1.304347826086957, \"center_x\": -6.3768115942028984, \"center_y\": -1.4492753623188408, \"value_uncond\": 6.628664403656853e-06}, {\"x\": -6.231884057971014, \"y\": -1.5942028985507246, \"x2\": -5.942028985507246, \"y2\": -1.304347826086957, \"center_x\": -6.08695652173913, \"center_y\": -1.4492753623188408, \"value_uncond\": 9.259038107877462e-06}, {\"x\": -5.942028985507246, \"y\": -1.5942028985507246, \"x2\": -5.6521739130434785, \"y2\": -1.304347826086957, \"center_x\": -5.797101449275362, \"center_y\": -1.4492753623188408, \"value_uncond\": 1.2813020634373129e-05}, {\"x\": -5.6521739130434785, \"y\": -1.5942028985507246, \"x2\": -5.362318840579711, \"y2\": -1.304347826086957, \"center_x\": -5.507246376811595, \"center_y\": -1.4492753623188408, \"value_uncond\": 1.7566409155196697e-05}, {\"x\": -5.36231884057971, \"y\": -1.5942028985507246, \"x2\": -5.072463768115942, \"y2\": -1.304347826086957, \"center_x\": -5.217391304347826, \"center_y\": -1.4492753623188408, \"value_uncond\": 2.38594416998354e-05}, {\"x\": -5.0724637681159415, \"y\": -1.5942028985507246, \"x2\": -4.782608695652174, \"y2\": -1.304347826086957, \"center_x\": -4.927536231884058, \"center_y\": -1.4492753623188408, \"value_uncond\": 3.21057910405215e-05}, {\"x\": -4.782608695652174, \"y\": -1.5942028985507246, \"x2\": -4.492753623188406, \"y2\": -1.304347826086957, \"center_x\": -4.63768115942029, \"center_y\": -1.4492753623188408, \"value_uncond\": 4.28008394547585e-05}, {\"x\": -4.492753623188405, \"y\": -1.5942028985507246, \"x2\": -4.202898550724638, \"y2\": -1.304347826086957, \"center_x\": -4.3478260869565215, \"center_y\": -1.4492753623188408, \"value_uncond\": 5.652844170681153e-05}, {\"x\": -4.202898550724638, \"y\": -1.5942028985507246, \"x2\": -3.91304347826087, \"y2\": -1.304347826086957, \"center_x\": -4.057971014492754, \"center_y\": -1.4492753623188408, \"value_uncond\": 7.396522026032139e-05}, {\"x\": -3.913043478260869, \"y\": -1.5942028985507246, \"x2\": -3.6231884057971016, \"y2\": -1.304347826086957, \"center_x\": -3.7681159420289854, \"center_y\": -1.4492753623188408, \"value_uncond\": 9.588129931461353e-05}, {\"x\": -3.6231884057971016, \"y\": -1.5942028985507246, \"x2\": -3.333333333333334, \"y2\": -1.304347826086957, \"center_x\": -3.4782608695652177, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.00012313629466922468}, {\"x\": -3.333333333333333, \"y\": -1.5942028985507246, \"x2\": -3.0434782608695654, \"y2\": -1.304347826086957, \"center_x\": -3.1884057971014492, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.00015666935873976176}, {\"x\": -3.0434782608695645, \"y\": -1.5942028985507246, \"x2\": -2.753623188405797, \"y2\": -1.304347826086957, \"center_x\": -2.8985507246376807, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.00019748215839588876}, {\"x\": -2.753623188405797, \"y\": -1.5942028985507246, \"x2\": -2.4637681159420293, \"y2\": -1.304347826086957, \"center_x\": -2.608695652173913, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0002466138590582609}, {\"x\": -2.4637681159420284, \"y\": -1.5942028985507246, \"x2\": -2.1739130434782608, \"y2\": -1.304347826086957, \"center_x\": -2.3188405797101446, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.00030510751704652234}, {\"x\": -2.1739130434782608, \"y\": -1.5942028985507246, \"x2\": -1.8840579710144931, \"y2\": -1.304347826086957, \"center_x\": -2.028985507246377, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0003739677493736574}, {\"x\": -1.8840579710144922, \"y\": -1.5942028985507246, \"x2\": -1.5942028985507246, \"y2\": -1.304347826086957, \"center_x\": -1.7391304347826084, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.00045411014908831735}, {\"x\": -1.5942028985507246, \"y\": -1.5942028985507246, \"x2\": -1.304347826086957, \"y2\": -1.304347826086957, \"center_x\": -1.4492753623188408, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.000546303622539451}, {\"x\": -1.304347826086957, \"y\": -1.5942028985507246, \"x2\": -1.0144927536231894, \"y2\": -1.304347826086957, \"center_x\": -1.1594202898550732, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0006511076034925066}, {\"x\": -1.0144927536231876, \"y\": -1.5942028985507246, \"x2\": -0.72463768115942, \"y2\": -1.304347826086957, \"center_x\": -0.8695652173913038, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0007688068924012487}, {\"x\": -0.72463768115942, \"y\": -1.5942028985507246, \"x2\": -0.43478260869565233, \"y2\": -1.304347826086957, \"center_x\": -0.5797101449275361, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0008993476079530388}, {\"x\": -0.43478260869565233, \"y\": -1.5942028985507246, \"x2\": -0.1449275362318847, \"y2\": -1.304347826086957, \"center_x\": -0.2898550724637685, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.001042278343661805}, {\"x\": -0.14492753623188293, \"y\": -1.5942028985507246, \"x2\": 0.1449275362318847, \"y2\": -1.304347826086957, \"center_x\": 8.881784197001252e-16, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0011967010137874715}, {\"x\": 0.1449275362318847, \"y\": -1.5942028985507246, \"x2\": 0.43478260869565233, \"y2\": -1.304347826086957, \"center_x\": 0.2898550724637685, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0013612359752973578}, {\"x\": 0.43478260869565233, \"y\": -1.5942028985507246, \"x2\": 0.72463768115942, \"y2\": -1.304347826086957, \"center_x\": 0.5797101449275361, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0015340057664732067}, {\"x\": 0.72463768115942, \"y\": -1.5942028985507246, \"x2\": 1.0144927536231876, \"y2\": -1.304347826086957, \"center_x\": 0.8695652173913038, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0017126411732490106}, {\"x\": 1.0144927536231894, \"y\": -1.5942028985507246, \"x2\": 1.304347826086957, \"y2\": -1.304347826086957, \"center_x\": 1.1594202898550732, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0018943123190095946}, {\"x\": 1.304347826086957, \"y\": -1.5942028985507246, \"x2\": 1.5942028985507246, \"y2\": -1.304347826086957, \"center_x\": 1.4492753623188408, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0020757861075819967}, {\"x\": 1.5942028985507246, \"y\": -1.5942028985507246, \"x2\": 1.8840579710144922, \"y2\": -1.304347826086957, \"center_x\": 1.7391304347826084, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0022535097068581106}, {\"x\": 1.884057971014494, \"y\": -1.5942028985507246, \"x2\": 2.1739130434782616, \"y2\": -1.304347826086957, \"center_x\": 2.028985507246378, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0024237179525454533}, {\"x\": 2.1739130434782616, \"y\": -1.5942028985507246, \"x2\": 2.4637681159420293, \"y2\": -1.304347826086957, \"center_x\": 2.3188405797101455, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0025825607174575303}, {\"x\": 2.4637681159420293, \"y\": -1.5942028985507246, \"x2\": 2.753623188405797, \"y2\": -1.304347826086957, \"center_x\": 2.608695652173913, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.002726244588232826}, {\"x\": 2.753623188405797, \"y\": -1.5942028985507246, \"x2\": 3.0434782608695645, \"y2\": -1.304347826086957, \"center_x\": 2.8985507246376807, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0028511817774572105}, {\"x\": 3.0434782608695663, \"y\": -1.5942028985507246, \"x2\": 3.333333333333334, \"y2\": -1.304347826086957, \"center_x\": 3.18840579710145, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0029541382196973053}, {\"x\": 3.333333333333334, \"y\": -1.5942028985507246, \"x2\": 3.6231884057971016, \"y2\": -1.304347826086957, \"center_x\": 3.4782608695652177, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0030323723692441797}, {\"x\": 3.6231884057971016, \"y\": -1.5942028985507246, \"x2\": 3.913043478260869, \"y2\": -1.304347826086957, \"center_x\": 3.7681159420289854, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0030837564051393158}, {\"x\": 3.913043478260871, \"y\": -1.5942028985507246, \"x2\": 4.202898550724639, \"y2\": -1.304347826086957, \"center_x\": 4.057971014492755, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.003106872370519827}, {\"x\": 4.202898550724639, \"y\": -1.5942028985507246, \"x2\": 4.492753623188406, \"y2\": -1.304347826086957, \"center_x\": 4.347826086956522, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.003101077184865929}, {\"x\": 4.492753623188406, \"y\": -1.5942028985507246, \"x2\": 4.782608695652174, \"y2\": -1.304347826086957, \"center_x\": 4.63768115942029, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.00306653236902547}, {\"x\": 4.782608695652174, \"y\": -1.5942028985507246, \"x2\": 5.0724637681159415, \"y2\": -1.304347826086957, \"center_x\": 4.927536231884058, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.003004196565387203}, {\"x\": 5.072463768115943, \"y\": -1.5942028985507246, \"x2\": 5.362318840579711, \"y2\": -1.304347826086957, \"center_x\": 5.217391304347827, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.002915781336637707}, {\"x\": 5.362318840579711, \"y\": -1.5942028985507246, \"x2\": 5.6521739130434785, \"y2\": -1.304347826086957, \"center_x\": 5.507246376811595, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0028036730875515294}, {\"x\": 5.6521739130434785, \"y\": -1.5942028985507246, \"x2\": 5.942028985507246, \"y2\": -1.304347826086957, \"center_x\": 5.797101449275362, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0026708260806577767}, {\"x\": 5.942028985507246, \"y\": -1.5942028985507246, \"x2\": 6.231884057971014, \"y2\": -1.304347826086957, \"center_x\": 6.08695652173913, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.002520633237406963}, {\"x\": 6.2318840579710155, \"y\": -1.5942028985507246, \"x2\": 6.521739130434783, \"y2\": -1.304347826086957, \"center_x\": 6.376811594202899, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0023567826009630436}, {\"x\": 6.521739130434785, \"y\": -1.5942028985507246, \"x2\": 6.8115942028985526, \"y2\": -1.304347826086957, \"center_x\": 6.666666666666669, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0021831079066490715}, {\"x\": 6.811594202898551, \"y\": -1.5942028985507246, \"x2\": 7.101449275362318, \"y2\": -1.304347826086957, \"center_x\": 6.956521739130435, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0020034416414148196}, {\"x\": 7.10144927536232, \"y\": -1.5942028985507246, \"x2\": 7.391304347826088, \"y2\": -1.304347826086957, \"center_x\": 7.246376811594204, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.001821478312344528}, {\"x\": 7.391304347826086, \"y\": -1.5942028985507246, \"x2\": 7.681159420289854, \"y2\": -1.304347826086957, \"center_x\": 7.53623188405797, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0016406544752011858}, {\"x\": 7.681159420289855, \"y\": -1.5942028985507246, \"x2\": 7.971014492753623, \"y2\": -1.304347826086957, \"center_x\": 7.826086956521739, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0014640505256925686}, {\"x\": 7.971014492753625, \"y\": -1.5942028985507246, \"x2\": 8.260869565217392, \"y2\": -1.304347826086957, \"center_x\": 8.115942028985508, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0012943174810814762}, {\"x\": 8.26086956521739, \"y\": -1.5942028985507246, \"x2\": 8.550724637681158, \"y2\": -1.304347826086957, \"center_x\": 8.405797101449274, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.001133630137988626}, {\"x\": 8.55072463768116, \"y\": -1.5942028985507246, \"x2\": 8.840579710144928, \"y2\": -1.304347826086957, \"center_x\": 8.695652173913043, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0009836662352107881}, {\"x\": 8.84057971014493, \"y\": -1.5942028985507246, \"x2\": 9.130434782608697, \"y2\": -1.304347826086957, \"center_x\": 8.985507246376812, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0008456097072387457}, {\"x\": 9.130434782608695, \"y\": -1.5942028985507246, \"x2\": 9.420289855072463, \"y2\": -1.304347826086957, \"center_x\": 9.275362318840578, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0007201748816751926}, {\"x\": 9.420289855072465, \"y\": -1.5942028985507246, \"x2\": 9.710144927536232, \"y2\": -1.304347826086957, \"center_x\": 9.565217391304348, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0006076476106938192}, {\"x\": 9.710144927536234, \"y\": -1.5942028985507246, \"x2\": 10.000000000000002, \"y2\": -1.304347826086957, \"center_x\": 9.855072463768117, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.0005079388527825467}, {\"x\": 10.0, \"y\": -1.5942028985507246, \"x2\": 10.289855072463768, \"y2\": -1.304347826086957, \"center_x\": 10.144927536231883, \"center_y\": -1.4492753623188408, \"value_uncond\": 0.00042064612007878583}, {\"x\": -10.0, \"y\": -1.304347826086957, \"x2\": -9.710144927536232, \"y2\": -1.0144927536231894, \"center_x\": -9.855072463768117, \"center_y\": -1.1594202898550732, \"value_uncond\": 6.914172005796482e-08}, {\"x\": -9.710144927536232, \"y\": -1.304347826086957, \"x2\": -9.420289855072465, \"y2\": -1.0144927536231894, \"center_x\": -9.565217391304348, \"center_y\": -1.1594202898550732, \"value_uncond\": 1.080264848182127e-07}, {\"x\": -9.420289855072463, \"y\": -1.304347826086957, \"x2\": -9.130434782608695, \"y2\": -1.0144927536231894, \"center_x\": -9.275362318840578, \"center_y\": -1.1594202898550732, \"value_uncond\": 1.6721149271632956e-07}, {\"x\": -9.130434782608695, \"y\": -1.304347826086957, \"x2\": -8.840579710144928, \"y2\": -1.0144927536231894, \"center_x\": -8.985507246376812, \"center_y\": -1.1594202898550732, \"value_uncond\": 2.564175922975858e-07}, {\"x\": -8.840579710144928, \"y\": -1.304347826086957, \"x2\": -8.55072463768116, \"y2\": -1.0144927536231894, \"center_x\": -8.695652173913043, \"center_y\": -1.1594202898550732, \"value_uncond\": 3.895608695257747e-07}, {\"x\": -8.55072463768116, \"y\": -1.304347826086957, \"x2\": -8.260869565217392, \"y2\": -1.0144927536231894, \"center_x\": -8.405797101449277, \"center_y\": -1.1594202898550732, \"value_uncond\": 5.863388213528535e-07}, {\"x\": -8.26086956521739, \"y\": -1.304347826086957, \"x2\": -7.971014492753623, \"y2\": -1.0144927536231894, \"center_x\": -8.115942028985508, \"center_y\": -1.1594202898550732, \"value_uncond\": 8.743147141490828e-07}, {\"x\": -7.971014492753623, \"y\": -1.304347826086957, \"x2\": -7.681159420289855, \"y2\": -1.0144927536231894, \"center_x\": -7.826086956521739, \"center_y\": -1.1594202898550732, \"value_uncond\": 1.291613987520393e-06}, {\"x\": -7.681159420289855, \"y\": -1.304347826086957, \"x2\": -7.391304347826088, \"y2\": -1.0144927536231894, \"center_x\": -7.536231884057972, \"center_y\": -1.1594202898550732, \"value_uncond\": 1.8903555918294522e-06}, {\"x\": -7.391304347826087, \"y\": -1.304347826086957, \"x2\": -7.101449275362319, \"y2\": -1.0144927536231894, \"center_x\": -7.246376811594203, \"center_y\": -1.1594202898550732, \"value_uncond\": 2.740943526730923e-06}, {\"x\": -7.101449275362318, \"y\": -1.304347826086957, \"x2\": -6.811594202898551, \"y2\": -1.0144927536231894, \"center_x\": -6.956521739130435, \"center_y\": -1.1594202898550732, \"value_uncond\": 3.937336051961573e-06}, {\"x\": -6.811594202898551, \"y\": -1.304347826086957, \"x2\": -6.521739130434783, \"y2\": -1.0144927536231894, \"center_x\": -6.666666666666667, \"center_y\": -1.1594202898550732, \"value_uncond\": 5.603387975479224e-06}, {\"x\": -6.521739130434782, \"y\": -1.304347826086957, \"x2\": -6.231884057971015, \"y2\": -1.0144927536231894, \"center_x\": -6.3768115942028984, \"center_y\": -1.1594202898550732, \"value_uncond\": 7.900320657144142e-06}, {\"x\": -6.231884057971014, \"y\": -1.304347826086957, \"x2\": -5.942028985507246, \"y2\": -1.0144927536231894, \"center_x\": -6.08695652173913, \"center_y\": -1.1594202898550732, \"value_uncond\": 1.1035310520260253e-05}, {\"x\": -5.942028985507246, \"y\": -1.304347826086957, \"x2\": -5.6521739130434785, \"y2\": -1.0144927536231894, \"center_x\": -5.797101449275362, \"center_y\": -1.1594202898550732, \"value_uncond\": 1.5271096171697562e-05}, {\"x\": -5.6521739130434785, \"y\": -1.304347826086957, \"x2\": -5.362318840579711, \"y2\": -1.0144927536231894, \"center_x\": -5.507246376811595, \"center_y\": -1.1594202898550732, \"value_uncond\": 2.0936384265295586e-05}, {\"x\": -5.36231884057971, \"y\": -1.304347826086957, \"x2\": -5.072463768115942, \"y2\": -1.0144927536231894, \"center_x\": -5.217391304347826, \"center_y\": -1.1594202898550732, \"value_uncond\": 2.8436684775465024e-05}, {\"x\": -5.0724637681159415, \"y\": -1.304347826086957, \"x2\": -4.782608695652174, \"y2\": -1.0144927536231894, \"center_x\": -4.927536231884058, \"center_y\": -1.1594202898550732, \"value_uncond\": 3.826503028746719e-05}, {\"x\": -4.782608695652174, \"y\": -1.304347826086957, \"x2\": -4.492753623188406, \"y2\": -1.0144927536231894, \"center_x\": -4.63768115942029, \"center_y\": -1.1594202898550732, \"value_uncond\": 5.1011838206953956e-05}, {\"x\": -4.492753623188405, \"y\": -1.304347826086957, \"x2\": -4.202898550724638, \"y2\": -1.0144927536231894, \"center_x\": -4.3478260869565215, \"center_y\": -1.1594202898550732, \"value_uncond\": 6.737297116537058e-05}, {\"x\": -4.202898550724638, \"y\": -1.304347826086957, \"x2\": -3.91304347826087, \"y2\": -1.0144927536231894, \"center_x\": -4.057971014492754, \"center_y\": -1.1594202898550732, \"value_uncond\": 8.815485623475879e-05}, {\"x\": -3.913043478260869, \"y\": -1.304347826086957, \"x2\": -3.6231884057971016, \"y2\": -1.0144927536231894, \"center_x\": -3.7681159420289854, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0001142753597830617}, {\"x\": -3.6231884057971016, \"y\": -1.304347826086957, \"x2\": -3.333333333333334, \"y2\": -1.0144927536231894, \"center_x\": -3.4782608695652177, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.00014675900802623028}, {\"x\": -3.333333333333333, \"y\": -1.304347826086957, \"x2\": -3.0434782608695654, \"y2\": -1.0144927536231894, \"center_x\": -3.1884057971014492, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.00018672512225998927}, {\"x\": -3.0434782608695645, \"y\": -1.304347826086957, \"x2\": -2.753623188405797, \"y2\": -1.0144927536231894, \"center_x\": -2.8985507246376807, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.000235367531132176}, {\"x\": -2.753623188405797, \"y\": -1.304347826086957, \"x2\": -2.4637681159420293, \"y2\": -1.0144927536231894, \"center_x\": -2.608695652173913, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0002939247556387334}, {\"x\": -2.4637681159420284, \"y\": -1.304347826086957, \"x2\": -2.1739130434782608, \"y2\": -1.0144927536231894, \"center_x\": -2.3188405797101446, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0003636399541124481}, {\"x\": -2.1739130434782608, \"y\": -1.304347826086957, \"x2\": -1.8840579710144931, \"y2\": -1.0144927536231894, \"center_x\": -2.028985507246377, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.00044571047130588027}, {\"x\": -1.8840579710144922, \"y\": -1.304347826086957, \"x2\": -1.5942028985507246, \"y2\": -1.0144927536231894, \"center_x\": -1.7391304347826084, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0005412275494716625}, {\"x\": -1.5942028985507246, \"y\": -1.304347826086957, \"x2\": -1.304347826086957, \"y2\": -1.0144927536231894, \"center_x\": -1.4492753623188408, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0006511076034925066}, {\"x\": -1.304347826086957, \"y\": -1.304347826086957, \"x2\": -1.0144927536231894, \"y2\": -1.0144927536231894, \"center_x\": -1.1594202898550732, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0007760173900277227}, {\"x\": -1.0144927536231876, \"y\": -1.304347826086957, \"x2\": -0.72463768115942, \"y2\": -1.0144927536231894, \"center_x\": -0.8695652173913038, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0009162963462204561}, {\"x\": -0.72463768115942, \"y\": -1.304347826086957, \"x2\": -0.43478260869565233, \"y2\": -1.0144927536231894, \"center_x\": -0.5797101449275361, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0010718802540591508}, {\"x\": -0.43478260869565233, \"y\": -1.304347826086957, \"x2\": -0.1449275362318847, \"y2\": -1.0144927536231894, \"center_x\": -0.2898550724637685, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0012422311083334794}, {\"x\": -0.14492753623188293, \"y\": -1.304347826086957, \"x2\": 0.1449275362318847, \"y2\": -1.0144927536231894, \"center_x\": 8.881784197001252e-16, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.001426278532736519}, {\"x\": 0.1449275362318847, \"y\": -1.304347826086957, \"x2\": 0.43478260869565233, \"y2\": -1.0144927536231894, \"center_x\": 0.2898550724637685, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.001622378210753385}, {\"x\": 0.43478260869565233, \"y\": -1.304347826086957, \"x2\": 0.72463768115942, \"y2\": -1.0144927536231894, \"center_x\": 0.5797101449275361, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0018282925046500629}, {\"x\": 0.72463768115942, \"y\": -1.304347826086957, \"x2\": 1.0144927536231876, \"y2\": -1.0144927536231894, \"center_x\": 0.8695652173913038, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0020411976855896296}, {\"x\": 1.0144927536231894, \"y\": -1.304347826086957, \"x2\": 1.304347826086957, \"y2\": -1.0144927536231894, \"center_x\": 1.1594202898550732, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.002257720987760061}, {\"x\": 1.304347826086957, \"y\": -1.304347826086957, \"x2\": 1.5942028985507246, \"y2\": -1.0144927536231894, \"center_x\": 1.4492753623188408, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.002474009071344113}, {\"x\": 1.5942028985507246, \"y\": -1.304347826086957, \"x2\": 1.8840579710144922, \"y2\": -1.0144927536231894, \"center_x\": 1.7391304347826084, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0026858275218073005}, {\"x\": 1.884057971014494, \"y\": -1.304347826086957, \"x2\": 2.1739130434782616, \"y2\": -1.0144927536231894, \"center_x\": 2.028985507246378, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0028886888581993115}, {\"x\": 2.1739130434782616, \"y\": -1.304347826086957, \"x2\": 2.4637681159420293, \"y2\": -1.0144927536231894, \"center_x\": 2.3188405797101455, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0030780043372240864}, {\"x\": 2.4637681159420293, \"y\": -1.304347826086957, \"x2\": 2.753623188405797, \"y2\": -1.0144927536231894, \"center_x\": 2.608695652173913, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.003249252809504304}, {\"x\": 2.753623188405797, \"y\": -1.304347826086957, \"x2\": 3.0434782608695645, \"y2\": -1.0144927536231894, \"center_x\": 2.8985507246376807, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0033981581993035538}, {\"x\": 3.0434782608695663, \"y\": -1.304347826086957, \"x2\": 3.333333333333334, \"y2\": -1.0144927536231894, \"center_x\": 3.18840579710145, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0035208660115993097}, {\"x\": 3.333333333333334, \"y\": -1.304347826086957, \"x2\": 3.6231884057971016, \"y2\": -1.0144927536231894, \"center_x\": 3.4782608695652177, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0036141087570637355}, {\"x\": 3.6231884057971016, \"y\": -1.304347826086957, \"x2\": 3.913043478260869, \"y2\": -1.0144927536231894, \"center_x\": 3.7681159420289854, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0036753504093045447}, {\"x\": 3.913043478260871, \"y\": -1.304347826086957, \"x2\": 4.202898550724639, \"y2\": -1.0144927536231894, \"center_x\": 4.057971014492755, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0037029009877747312}, {\"x\": 4.202898550724639, \"y\": -1.304347826086957, \"x2\": 4.492753623188406, \"y2\": -1.0144927536231894, \"center_x\": 4.347826086956522, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0036959940420997896}, {\"x\": 4.492753623188406, \"y\": -1.304347826086957, \"x2\": 4.782608695652174, \"y2\": -1.0144927536231894, \"center_x\": 4.63768115942029, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.003654822079610475}, {\"x\": 4.782608695652174, \"y\": -1.304347826086957, \"x2\": 5.0724637681159415, \"y2\": -1.0144927536231894, \"center_x\": 4.927536231884058, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0035805276505711356}, {\"x\": 5.072463768115943, \"y\": -1.304347826086957, \"x2\": 5.362318840579711, \"y2\": -1.0144927536231894, \"center_x\": 5.217391304347827, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0034751506672816477}, {\"x\": 5.362318840579711, \"y\": -1.304347826086957, \"x2\": 5.6521739130434785, \"y2\": -1.0144927536231894, \"center_x\": 5.507246376811595, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0033415353471874256}, {\"x\": 5.6521739130434785, \"y\": -1.304347826086957, \"x2\": 5.942028985507246, \"y2\": -1.0144927536231894, \"center_x\": 5.797101449275362, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.003183202704457242}, {\"x\": 5.942028985507246, \"y\": -1.304347826086957, \"x2\": 6.231884057971014, \"y2\": -1.0144927536231894, \"center_x\": 6.08695652173913, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.003004196565387202}, {\"x\": 6.2318840579710155, \"y\": -1.304347826086957, \"x2\": 6.521739130434783, \"y2\": -1.0144927536231894, \"center_x\": 6.376811594202899, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0028089124947273613}, {\"x\": 6.521739130434785, \"y\": -1.304347826086957, \"x2\": 6.8115942028985526, \"y2\": -1.0144927536231894, \"center_x\": 6.666666666666669, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0026019196992624204}, {\"x\": 6.811594202898551, \"y\": -1.304347826086957, \"x2\": 7.101449275362318, \"y2\": -1.0144927536231894, \"center_x\": 6.956521739130435, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.002387785897913383}, {\"x\": 7.10144927536232, \"y\": -1.304347826086957, \"x2\": 7.391304347826088, \"y2\": -1.0144927536231894, \"center_x\": 7.246376811594204, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0021709143594019938}, {\"x\": 7.391304347826086, \"y\": -1.304347826086957, \"x2\": 7.681159420289854, \"y2\": -1.0144927536231894, \"center_x\": 7.53623188405797, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.001955400915230719}, {\"x\": 7.681159420289855, \"y\": -1.304347826086957, \"x2\": 7.971014492753623, \"y2\": -1.0144927536231894, \"center_x\": 7.826086956521739, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0017449169103885887}, {\"x\": 7.971014492753625, \"y\": -1.304347826086957, \"x2\": 8.260869565217392, \"y2\": -1.0144927536231894, \"center_x\": 8.115942028985508, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.001542621938598914}, {\"x\": 8.26086956521739, \"y\": -1.304347826086957, \"x2\": 8.550724637681158, \"y2\": -1.0144927536231894, \"center_x\": 8.405797101449274, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0013511080138212909}, {\"x\": 8.55072463768116, \"y\": -1.304347826086957, \"x2\": 8.840579710144928, \"y2\": -1.0144927536231894, \"center_x\": 8.695652173913043, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.00117237473562303}, {\"x\": 8.84057971014493, \"y\": -1.304347826086957, \"x2\": 9.130434782608697, \"y2\": -1.0144927536231894, \"center_x\": 8.985507246376812, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0010078331668585262}, {\"x\": 9.130434782608695, \"y\": -1.304347826086957, \"x2\": 9.420289855072463, \"y2\": -1.0144927536231894, \"center_x\": 9.275362318840578, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0008583346731682558}, {\"x\": 9.420289855072465, \"y\": -1.304347826086957, \"x2\": 9.710144927536232, \"y2\": -1.0144927536231894, \"center_x\": 9.565217391304348, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0007242199451793476}, {\"x\": 9.710144927536234, \"y\": -1.304347826086957, \"x2\": 10.000000000000002, \"y2\": -1.0144927536231894, \"center_x\": 9.855072463768117, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.000605382859477733}, {\"x\": 10.0, \"y\": -1.304347826086957, \"x2\": 10.289855072463768, \"y2\": -1.0144927536231894, \"center_x\": 10.144927536231883, \"center_y\": -1.1594202898550732, \"value_uncond\": 0.0005013437141232592}, {\"x\": -10.0, \"y\": -1.0144927536231876, \"x2\": -9.710144927536232, \"y2\": -0.72463768115942, \"center_x\": -9.855072463768117, \"center_y\": -0.8695652173913038, \"value_uncond\": 8.164031666641845e-08}, {\"x\": -9.710144927536232, \"y\": -1.0144927536231876, \"x2\": -9.420289855072465, \"y2\": -0.72463768115942, \"center_x\": -9.565217391304348, \"center_y\": -0.8695652173913038, \"value_uncond\": 1.2755419479766016e-07}, {\"x\": -9.420289855072463, \"y\": -1.0144927536231876, \"x2\": -9.130434782608695, \"y2\": -0.72463768115942, \"center_x\": -9.275362318840578, \"center_y\": -0.8695652173913038, \"value_uncond\": 1.9743794635396995e-07}, {\"x\": -9.130434782608695, \"y\": -1.0144927536231876, \"x2\": -8.840579710144928, \"y2\": -0.72463768115942, \"center_x\": -8.985507246376812, \"center_y\": -0.8695652173913038, \"value_uncond\": 3.0276963628422175e-07}, {\"x\": -8.840579710144928, \"y\": -1.0144927536231876, \"x2\": -8.55072463768116, \"y2\": -0.72463768115942, \"center_x\": -8.695652173913043, \"center_y\": -0.8695652173913038, \"value_uncond\": 4.5998093079354775e-07}, {\"x\": -8.55072463768116, \"y\": -1.0144927536231876, \"x2\": -8.260869565217392, \"y2\": -0.72463768115942, \"center_x\": -8.405797101449277, \"center_y\": -0.8695652173913038, \"value_uncond\": 6.923300000192465e-07}, {\"x\": -8.26086956521739, \"y\": -1.0144927536231876, \"x2\": -7.971014492753623, \"y2\": -0.72463768115942, \"center_x\": -8.115942028985508, \"center_y\": -0.8695652173913038, \"value_uncond\": 1.032362661348308e-06}, {\"x\": -7.971014492753623, \"y\": -1.0144927536231876, \"x2\": -7.681159420289855, \"y2\": -0.72463768115942, \"center_x\": -7.826086956521739, \"center_y\": -0.8695652173913038, \"value_uncond\": 1.5250962062201841e-06}, {\"x\": -7.681159420289855, \"y\": -1.0144927536231876, \"x2\": -7.391304347826088, \"y2\": -0.72463768115942, \"center_x\": -7.536231884057972, \"center_y\": -0.8695652173913038, \"value_uncond\": 2.2320710129818836e-06}, {\"x\": -7.391304347826087, \"y\": -1.0144927536231876, \"x2\": -7.101449275362319, \"y2\": -0.72463768115942, \"center_x\": -7.246376811594203, \"center_y\": -0.8695652173913038, \"value_uncond\": 3.2364178574019272e-06}, {\"x\": -7.101449275362318, \"y\": -1.0144927536231876, \"x2\": -6.811594202898551, \"y2\": -0.72463768115942, \"center_x\": -6.956521739130435, \"center_y\": -0.8695652173913038, \"value_uncond\": 4.649079627101635e-06}, {\"x\": -6.811594202898551, \"y\": -1.0144927536231876, \"x2\": -6.521739130434783, \"y2\": -0.72463768115942, \"center_x\": -6.666666666666667, \"center_y\": -0.8695652173913038, \"value_uncond\": 6.616300091166552e-06}, {\"x\": -6.521739130434782, \"y\": -1.0144927536231876, \"x2\": -6.231884057971015, \"y2\": -0.72463768115942, \"center_x\": -6.3768115942028984, \"center_y\": -0.8695652173913038, \"value_uncond\": 9.328444239957765e-06}, {\"x\": -6.231884057971014, \"y\": -1.0144927536231876, \"x2\": -5.942028985507246, \"y2\": -0.72463768115942, \"center_x\": -6.08695652173913, \"center_y\": -0.8695652173913038, \"value_uncond\": 1.3030139322987851e-05}, {\"x\": -5.942028985507246, \"y\": -1.0144927536231876, \"x2\": -5.6521739130434785, \"y2\": -0.72463768115942, \"center_x\": -5.797101449275362, \"center_y\": -0.8695652173913038, \"value_uncond\": 1.8031618627010143e-05}, {\"x\": -5.6521739130434785, \"y\": -1.0144927536231876, \"x2\": -5.362318840579711, \"y2\": -0.72463768115942, \"center_x\": -5.507246376811595, \"center_y\": -0.8695652173913038, \"value_uncond\": 2.4721008384454473e-05}, {\"x\": -5.36231884057971, \"y\": -1.0144927536231876, \"x2\": -5.072463768115942, \"y2\": -0.72463768115942, \"center_x\": -5.217391304347826, \"center_y\": -0.8695652173913038, \"value_uncond\": 3.3577121715597955e-05}, {\"x\": -5.0724637681159415, \"y\": -1.0144927536231876, \"x2\": -4.782608695652174, \"y2\": -0.72463768115942, \"center_x\": -4.927536231884058, \"center_y\": -0.8695652173913038, \"value_uncond\": 4.51821156213635e-05}, {\"x\": -4.782608695652174, \"y\": -1.0144927536231876, \"x2\": -4.492753623188406, \"y2\": -0.72463768115942, \"center_x\": -4.63768115942029, \"center_y\": -0.8695652173913038, \"value_uncond\": 6.0233135962779376e-05}, {\"x\": -4.492753623188405, \"y\": -1.0144927536231876, \"x2\": -4.202898550724638, \"y2\": -0.72463768115942, \"center_x\": -4.3478260869565215, \"center_y\": -0.8695652173913038, \"value_uncond\": 7.955183492813199e-05}, {\"x\": -4.202898550724638, \"y\": -1.0144927536231876, \"x2\": -3.91304347826087, \"y2\": -0.72463768115942, \"center_x\": -4.057971014492754, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0001040904156369658}, {\"x\": -3.913043478260869, \"y\": -1.0144927536231876, \"x2\": -3.6231884057971016, \"y2\": -0.72463768115942, \"center_x\": -3.7681159420289854, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0001349326651410567}, {\"x\": -3.6231884057971016, \"y\": -1.0144927536231876, \"x2\": -3.333333333333334, \"y2\": -0.72463768115942, \"center_x\": -3.4782608695652177, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0001732883110062385}, {\"x\": -3.333333333333333, \"y\": -1.0144927536231876, \"x2\": -3.0434782608695654, \"y2\": -0.72463768115942, \"center_x\": -3.1884057971014492, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.00022047901177611992}, {\"x\": -3.0434782608695645, \"y\": -1.0144927536231876, \"x2\": -2.753623188405797, \"y2\": -0.72463768115942, \"center_x\": -2.8985507246376807, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0002779144018765324}, {\"x\": -2.753623188405797, \"y\": -1.0144927536231876, \"x2\": -2.4637681159420293, \"y2\": -0.72463768115942, \"center_x\": -2.608695652173913, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0003470568870188469}, {\"x\": -2.4637681159420284, \"y\": -1.0144927536231876, \"x2\": -2.1739130434782608, \"y2\": -0.72463768115942, \"center_x\": -2.3188405797101446, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0004293743485324563}, {\"x\": -2.1739130434782608, \"y\": -1.0144927536231876, \"x2\": -1.8840579710144931, \"y2\": -0.72463768115942, \"center_x\": -2.028985507246377, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0005262805725464293}, {\"x\": -1.8840579710144922, \"y\": -1.0144927536231876, \"x2\": -1.5942028985507246, \"y2\": -0.72463768115942, \"center_x\": -1.7391304347826084, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0006390640627744426}, {\"x\": -1.5942028985507246, \"y\": -1.0144927536231876, \"x2\": -1.304347826086957, \"y2\": -0.72463768115942, \"center_x\": -1.4492753623188408, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0007688068924012487}, {\"x\": -1.304347826086957, \"y\": -1.0144927536231876, \"x2\": -1.0144927536231894, \"y2\": -0.72463768115942, \"center_x\": -1.1594202898550732, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0009162963462204561}, {\"x\": -1.0144927536231876, \"y\": -1.0144927536231876, \"x2\": -0.72463768115942, \"y2\": -0.72463768115942, \"center_x\": -0.8695652173913038, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.001081933220680743}, {\"x\": -0.72463768115942, \"y\": -1.0144927536231876, \"x2\": -0.43478260869565233, \"y2\": -0.72463768115942, \"center_x\": -0.5797101449275361, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0012656416892218969}, {\"x\": -0.43478260869565233, \"y\": -1.0144927536231876, \"x2\": -0.1449275362318847, \"y2\": -0.72463768115942, \"center_x\": -0.2898550724637685, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0014667864926154442}, {\"x\": -0.14492753623188293, \"y\": -1.0144927536231876, \"x2\": 0.1449275362318847, \"y2\": -0.72463768115942, \"center_x\": 8.881784197001252e-16, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0016841037649845162}, {\"x\": 0.1449275362318847, \"y\": -1.0144927536231876, \"x2\": 0.43478260869565233, \"y2\": -0.72463768115942, \"center_x\": 0.2898550724637685, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0019156519503356758}, {\"x\": 0.43478260869565233, \"y\": -1.0144927536231876, \"x2\": 0.72463768115942, \"y2\": -0.72463768115942, \"center_x\": 0.5797101449275361, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0021587889180850073}, {\"x\": 0.72463768115942, \"y\": -1.0144927536231876, \"x2\": 1.0144927536231876, \"y2\": -0.72463768115942, \"center_x\": 0.8695652173913038, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0024101805001465397}, {\"x\": 1.0144927536231894, \"y\": -1.0144927536231876, \"x2\": 1.304347826086957, \"y2\": -0.72463768115942, \"center_x\": 1.1594202898550732, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.002665844243253208}, {\"x\": 1.304347826086957, \"y\": -1.0144927536231876, \"x2\": 1.5942028985507246, \"y2\": -0.72463768115942, \"center_x\": 1.4492753623188408, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.002921230247827166}, {\"x\": 1.5942028985507246, \"y\": -1.0144927536231876, \"x2\": 1.8840579710144922, \"y2\": -0.72463768115942, \"center_x\": 1.7391304347826084, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0031713386535351415}, {\"x\": 1.884057971014494, \"y\": -1.0144927536231876, \"x2\": 2.1739130434782616, \"y2\": -0.72463768115942, \"center_x\": 2.028985507246378, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.00341087078736884}, {\"x\": 2.1739130434782616, \"y\": -1.0144927536231876, \"x2\": 2.4637681159420293, \"y2\": -0.72463768115942, \"center_x\": 2.3188405797101455, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0036344084090027826}, {\"x\": 2.4637681159420293, \"y\": -1.0144927536231876, \"x2\": 2.753623188405797, \"y2\": -0.72463768115942, \"center_x\": 2.608695652173913, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0038366130908341948}, {\"x\": 2.753623188405797, \"y\": -1.0144927536231876, \"x2\": 3.0434782608695645, \"y2\": -0.72463768115942, \"center_x\": 2.8985507246376807, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.004012435780324067}, {\"x\": 3.0434782608695663, \"y\": -1.0144927536231876, \"x2\": 3.333333333333334, \"y2\": -0.72463768115942, \"center_x\": 3.18840579710145, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.004157325213865357}, {\"x\": 3.333333333333334, \"y\": -1.0144927536231876, \"x2\": 3.6231884057971016, \"y2\": -0.72463768115942, \"center_x\": 3.4782608695652177, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.004267423245273602}, {\"x\": 3.6231884057971016, \"y\": -1.0144927536231876, \"x2\": 3.913043478260869, \"y2\": -0.72463768115942, \"center_x\": 3.7681159420289854, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.00433973541624538}, {\"x\": 3.913043478260871, \"y\": -1.0144927536231876, \"x2\": 4.202898550724639, \"y2\": -0.72463768115942, \"center_x\": 4.057971014492755, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.004372266252168516}, {\"x\": 4.202898550724639, \"y\": -1.0144927536231876, \"x2\": 4.492753623188406, \"y2\": -0.72463768115942, \"center_x\": 4.347826086956522, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.004364110753120658}, {\"x\": 4.492753623188406, \"y\": -1.0144927536231876, \"x2\": 4.782608695652174, \"y2\": -0.72463768115942, \"center_x\": 4.63768115942029, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.004315496225559185}, {\"x\": 4.782608695652174, \"y\": -1.0144927536231876, \"x2\": 5.0724637681159415, \"y2\": -0.72463768115942, \"center_x\": 4.927536231884058, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0042277717560458795}, {\"x\": 5.072463768115943, \"y\": -1.0144927536231876, \"x2\": 5.362318840579711, \"y2\": -0.72463768115942, \"center_x\": 5.217391304347827, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.004103346007338828}, {\"x\": 5.362318840579711, \"y\": -1.0144927536231876, \"x2\": 5.6521739130434785, \"y2\": -0.72463768115942, \"center_x\": 5.507246376811595, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.00394557733981317}, {\"x\": 5.6521739130434785, \"y\": -1.0144927536231876, \"x2\": 5.942028985507246, \"y2\": -0.72463768115942, \"center_x\": 5.797101449275362, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0037586232536219923}, {\"x\": 5.942028985507246, \"y\": -1.0144927536231876, \"x2\": 6.231884057971014, \"y2\": -0.72463768115942, \"center_x\": 6.08695652173913, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.003547258568643672}, {\"x\": 6.2318840579710155, \"y\": -1.0144927536231876, \"x2\": 6.521739130434783, \"y2\": -0.72463768115942, \"center_x\": 6.376811594202899, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0033166734261969566}, {\"x\": 6.521739130434785, \"y\": -1.0144927536231876, \"x2\": 6.8115942028985526, \"y2\": -0.72463768115942, \"center_x\": 6.666666666666669, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0030722629985238}, {\"x\": 6.811594202898551, \"y\": -1.0144927536231876, \"x2\": 7.101449275362318, \"y2\": -0.72463768115942, \"center_x\": 6.956521739130435, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0028194207010446017}, {\"x\": 7.10144927536232, \"y\": -1.0144927536231876, \"x2\": 7.391304347826088, \"y2\": -0.72463768115942, \"center_x\": 7.246376811594204, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.002563345771679815}, {\"x\": 7.391304347826086, \"y\": -1.0144927536231876, \"x2\": 7.681159420289854, \"y2\": -0.72463768115942, \"center_x\": 7.53623188405797, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0023088744363809113}, {\"x\": 7.681159420289855, \"y\": -1.0144927536231876, \"x2\": 7.971014492753623, \"y2\": -0.72463768115942, \"center_x\": 7.826086956521739, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0020603417010928485}, {\"x\": 7.971014492753625, \"y\": -1.0144927536231876, \"x2\": 8.260869565217392, \"y2\": -0.72463768115942, \"center_x\": 8.115942028985508, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.001821478312344528}, {\"x\": 8.26086956521739, \"y\": -1.0144927536231876, \"x2\": 8.550724637681158, \"y2\": -0.72463768115942, \"center_x\": 8.405797101449274, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0015953448367560417}, {\"x\": 8.55072463768116, \"y\": -1.0144927536231876, \"x2\": 8.840579710144928, \"y2\": -0.72463768115942, \"center_x\": 8.695652173913043, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0013843023371089397}, {\"x\": 8.84057971014493, \"y\": -1.0144927536231876, \"x2\": 9.130434782608697, \"y2\": -0.72463768115942, \"center_x\": 8.985507246376812, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.001190016950985169}, {\"x\": 9.130434782608695, \"y\": -1.0144927536231876, \"x2\": 9.420289855072463, \"y2\": -0.72463768115942, \"center_x\": 9.275362318840578, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0010134939435188506}, {\"x\": 9.420289855072465, \"y\": -1.0144927536231876, \"x2\": 9.710144927536232, \"y2\": -0.72463768115942, \"center_x\": 9.565217391304348, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0008551355912321872}, {\"x\": 9.710144927536234, \"y\": -1.0144927536231876, \"x2\": 10.000000000000002, \"y2\": -0.72463768115942, \"center_x\": 9.855072463768117, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0007148165870150437}, {\"x\": 10.0, \"y\": -1.0144927536231876, \"x2\": 10.289855072463768, \"y2\": -0.72463768115942, \"center_x\": 10.144927536231883, \"center_y\": -0.8695652173913038, \"value_uncond\": 0.0005919705142629914}, {\"x\": -10.0, \"y\": -0.72463768115942, \"x2\": -9.710144927536232, \"y2\": -0.43478260869565233, \"center_x\": -9.855072463768117, \"center_y\": -0.5797101449275361, \"value_uncond\": 9.550255627540823e-08}, {\"x\": -9.710144927536232, \"y\": -0.72463768115942, \"x2\": -9.420289855072465, \"y2\": -0.43478260869565233, \"center_x\": -9.565217391304348, \"center_y\": -0.5797101449275361, \"value_uncond\": 1.4921244997863546e-07}, {\"x\": -9.420289855072463, \"y\": -0.72463768115942, \"x2\": -9.130434782608695, \"y2\": -0.43478260869565233, \"center_x\": -9.275362318840578, \"center_y\": -0.5797101449275361, \"value_uncond\": 2.3096221759667814e-07}, {\"x\": -9.130434782608695, \"y\": -0.72463768115942, \"x2\": -8.840579710144928, \"y2\": -0.43478260869565233, \"center_x\": -8.985507246376812, \"center_y\": -0.5797101449275361, \"value_uncond\": 3.5417885927447224e-07}, {\"x\": -8.840579710144928, \"y\": -0.72463768115942, \"x2\": -8.55072463768116, \"y2\": -0.43478260869565233, \"center_x\": -8.695652173913043, \"center_y\": -0.5797101449275361, \"value_uncond\": 5.380840805434449e-07}, {\"x\": -8.55072463768116, \"y\": -0.72463768115942, \"x2\": -8.260869565217392, \"y2\": -0.43478260869565233, \"center_x\": -8.405797101449277, \"center_y\": -0.5797101449275361, \"value_uncond\": 8.098852073070005e-07}, {\"x\": -8.26086956521739, \"y\": -0.72463768115942, \"x2\": -7.971014492753623, \"y2\": -0.43478260869565233, \"center_x\": -8.115942028985508, \"center_y\": -0.5797101449275361, \"value_uncond\": 1.2076542226667024e-06}, {\"x\": -7.971014492753623, \"y\": -0.72463768115942, \"x2\": -7.681159420289855, \"y2\": -0.43478260869565233, \"center_x\": -7.826086956521739, \"center_y\": -0.5797101449275361, \"value_uncond\": 1.7840521963563896e-06}, {\"x\": -7.681159420289855, \"y\": -0.72463768115942, \"x2\": -7.391304347826088, \"y2\": -0.43478260869565233, \"center_x\": -7.536231884057972, \"center_y\": -0.5797101449275361, \"value_uncond\": 2.611068847258569e-06}, {\"x\": -7.391304347826087, \"y\": -0.72463768115942, \"x2\": -7.101449275362319, \"y2\": -0.43478260869565233, \"center_x\": -7.246376811594203, \"center_y\": -0.5797101449275361, \"value_uncond\": 3.785950265482027e-06}, {\"x\": -7.101449275362318, \"y\": -0.72463768115942, \"x2\": -6.811594202898551, \"y2\": -0.43478260869565233, \"center_x\": -6.956521739130435, \"center_y\": -0.5797101449275361, \"value_uncond\": 5.4384770520955155e-06}, {\"x\": -6.811594202898551, \"y\": -0.72463768115942, \"x2\": -6.521739130434783, \"y2\": -0.43478260869565233, \"center_x\": -6.666666666666667, \"center_y\": -0.5797101449275361, \"value_uncond\": 7.739724655570018e-06}, {\"x\": -6.521739130434782, \"y\": -0.72463768115942, \"x2\": -6.231884057971015, \"y2\": -0.43478260869565233, \"center_x\": -6.3768115942028984, \"center_y\": -0.5797101449275361, \"value_uncond\": 1.091238137437345e-05}, {\"x\": -6.231884057971014, \"y\": -0.72463768115942, \"x2\": -5.942028985507246, \"y2\": -0.43478260869565233, \"center_x\": -6.08695652173913, \"center_y\": -0.5797101449275361, \"value_uncond\": 1.5242611307532183e-05}, {\"x\": -5.942028985507246, \"y\": -0.72463768115942, \"x2\": -5.6521739130434785, \"y2\": -0.43478260869565233, \"center_x\": -5.797101449275362, \"center_y\": -0.5797101449275361, \"value_uncond\": 2.1093324266478302e-05}, {\"x\": -5.6521739130434785, \"y\": -0.72463768115942, \"x2\": -5.362318840579711, \"y2\": -0.43478260869565233, \"center_x\": -5.507246376811595, \"center_y\": -0.5797101449275361, \"value_uncond\": 2.8918548957470345e-05}, {\"x\": -5.36231884057971, \"y\": -0.72463768115942, \"x2\": -5.072463768115942, \"y2\": -0.43478260869565233, \"center_x\": -5.217391304347826, \"center_y\": -0.5797101449275361, \"value_uncond\": 3.927839929030012e-05}, {\"x\": -5.0724637681159415, \"y\": -0.72463768115942, \"x2\": -4.782608695652174, \"y2\": -0.43478260869565233, \"center_x\": -4.927536231884058, \"center_y\": -0.5797101449275361, \"value_uncond\": 5.285388048410386e-05}, {\"x\": -4.782608695652174, \"y\": -0.72463768115942, \"x2\": -4.492753623188406, \"y2\": -0.43478260869565233, \"center_x\": -4.63768115942029, \"center_y\": -0.5797101449275361, \"value_uncond\": 7.046051132351661e-05}, {\"x\": -4.492753623188405, \"y\": -0.72463768115942, \"x2\": -4.202898550724638, \"y2\": -0.43478260869565233, \"center_x\": -4.3478260869565215, \"center_y\": -0.5797101449275361, \"value_uncond\": 9.305945765838754e-05}, {\"x\": -4.202898550724638, \"y\": -0.72463768115942, \"x2\": -3.91304347826087, \"y2\": -0.43478260869565233, \"center_x\": -4.057971014492754, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.00012176460336035191}, {\"x\": -3.913043478260869, \"y\": -0.72463768115942, \"x2\": -3.6231884057971016, \"y2\": -0.43478260869565233, \"center_x\": -3.7681159420289854, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0001578437587237487}, {\"x\": -3.6231884057971016, \"y\": -0.72463768115942, \"x2\": -3.333333333333334, \"y2\": -0.43478260869565233, \"center_x\": -3.4782608695652177, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0002027120588148225}, {\"x\": -3.333333333333333, \"y\": -0.72463768115942, \"x2\": -3.0434782608695654, \"y2\": -0.43478260869565233, \"center_x\": -3.1884057971014492, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0002579155751652848}, {\"x\": -3.0434782608695645, \"y\": -0.72463768115942, \"x2\": -2.753623188405797, \"y2\": -0.43478260869565233, \"center_x\": -2.8985507246376807, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0003251032931855034}, {\"x\": -2.753623188405797, \"y\": -0.72463768115942, \"x2\": -2.4637681159420293, \"y2\": -0.43478260869565233, \"center_x\": -2.608695652173913, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.00040598592995069906}, {\"x\": -2.4637681159420284, \"y\": -0.72463768115942, \"x2\": -2.1739130434782608, \"y2\": -0.43478260869565233, \"center_x\": -2.3188405797101446, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0005022806078948621}, {\"x\": -2.1739130434782608, \"y\": -0.72463768115942, \"x2\": -1.8840579710144931, \"y2\": -0.43478260869565233, \"center_x\": -2.028985507246377, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0006156411690762544}, {\"x\": -1.8840579710144922, \"y\": -0.72463768115942, \"x2\": -1.5942028985507246, \"y2\": -0.43478260869565233, \"center_x\": -1.7391304347826084, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.000747574900622746}, {\"x\": -1.5942028985507246, \"y\": -0.72463768115942, \"x2\": -1.304347826086957, \"y2\": -0.43478260869565233, \"center_x\": -1.4492753623188408, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0008993476079530388}, {\"x\": -1.304347826086957, \"y\": -0.72463768115942, \"x2\": -1.0144927536231894, \"y2\": -0.43478260869565233, \"center_x\": -1.1594202898550732, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0010718802540591508}, {\"x\": -1.0144927536231876, \"y\": -0.72463768115942, \"x2\": -0.72463768115942, \"y2\": -0.43478260869565233, \"center_x\": -0.8695652173913038, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0012656416892218969}, {\"x\": -0.72463768115942, \"y\": -0.72463768115942, \"x2\": -0.43478260869565233, \"y2\": -0.43478260869565233, \"center_x\": -0.5797101449275361, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.001480543211796923}, {\"x\": -0.43478260869565233, \"y\": -0.72463768115942, \"x2\": -0.1449275362318847, \"y2\": -0.43478260869565233, \"center_x\": -0.2898550724637685, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.001715841697765436}, {\"x\": -0.14492753623188293, \"y\": -0.72463768115942, \"x2\": 0.1449275362318847, \"y2\": -0.43478260869565233, \"center_x\": 8.881784197001252e-16, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0019700586812547044}, {\"x\": 0.1449275362318847, \"y\": -0.72463768115942, \"x2\": 0.43478260869565233, \"y2\": -0.43478260869565233, \"center_x\": 0.2898550724637685, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.002240922936869036}, {\"x\": 0.43478260869565233, \"y\": -0.72463768115942, \"x2\": 0.72463768115942, \"y2\": -0.43478260869565233, \"center_x\": 0.5797101449275361, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.002525343709512413}, {\"x\": 0.72463768115942, \"y\": -0.72463768115942, \"x2\": 1.0144927536231876, \"y2\": -0.43478260869565233, \"center_x\": 0.8695652173913038, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0028194207010446004}, {\"x\": 1.0144927536231894, \"y\": -0.72463768115942, \"x2\": 1.304347826086957, \"y2\": -0.43478260869565233, \"center_x\": 1.1594202898550732, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0031184952515928535}, {\"x\": 1.304347826086957, \"y\": -0.72463768115942, \"x2\": 1.5942028985507246, \"y2\": -0.43478260869565233, \"center_x\": 1.4492753623188408, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0034172449045790543}, {\"x\": 1.5942028985507246, \"y\": -0.72463768115942, \"x2\": 1.8840579710144922, \"y2\": -0.43478260869565233, \"center_x\": 1.7391304347826084, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.003709820840910567}, {\"x\": 1.884057971014494, \"y\": -0.72463768115942, \"x2\": 2.1739130434782616, \"y2\": -0.43478260869565233, \"center_x\": 2.028985507246378, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.003990024691474894}, {\"x\": 2.1739130434782616, \"y\": -0.72463768115942, \"x2\": 2.4637681159420293, \"y2\": -0.43478260869565233, \"center_x\": 2.3188405797101455, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.004251518217730996}, {\"x\": 2.4637681159420293, \"y\": -0.72463768115942, \"x2\": 2.753623188405797, \"y2\": -0.43478260869565233, \"center_x\": 2.608695652173913, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.004488056545781097}, {\"x\": 2.753623188405797, \"y\": -0.72463768115942, \"x2\": 3.0434782608695645, \"y2\": -0.43478260869565233, \"center_x\": 2.8985507246376807, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.004693733311662716}, {\"x\": 3.0434782608695663, \"y\": -0.72463768115942, \"x2\": 3.333333333333334, \"y2\": -0.43478260869565233, \"center_x\": 3.18840579710145, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.004863224463161162}, {\"x\": 3.333333333333334, \"y\": -0.72463768115942, \"x2\": 3.6231884057971016, \"y2\": -0.43478260869565233, \"center_x\": 3.4782608695652177, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.004992016754393206}, {\"x\": 3.6231884057971016, \"y\": -0.72463768115942, \"x2\": 3.913043478260869, \"y2\": -0.43478260869565233, \"center_x\": 3.7681159420289854, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.005076607278531506}, {\"x\": 3.913043478260871, \"y\": -0.72463768115942, \"x2\": 4.202898550724639, \"y2\": -0.43478260869565233, \"center_x\": 4.057971014492755, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.005114661736369165}, {\"x\": 4.202898550724639, \"y\": -0.72463768115942, \"x2\": 4.492753623188406, \"y2\": -0.43478260869565233, \"center_x\": 4.347826086956522, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.005105121462169169}, {\"x\": 4.492753623188406, \"y\": -0.72463768115942, \"x2\": 4.782608695652174, \"y2\": -0.43478260869565233, \"center_x\": 4.63768115942029, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.005048252358228621}, {\"x\": 4.782608695652174, \"y\": -0.72463768115942, \"x2\": 5.0724637681159415, \"y2\": -0.43478260869565233, \"center_x\": 4.927536231884058, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.004945632581278748}, {\"x\": 5.072463768115943, \"y\": -0.72463768115942, \"x2\": 5.362318840579711, \"y2\": -0.43478260869565233, \"center_x\": 5.217391304347827, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.004800079776571257}, {\"x\": 5.362318840579711, \"y\": -0.72463768115942, \"x2\": 5.6521739130434785, \"y2\": -0.43478260869565233, \"center_x\": 5.507246376811595, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.004615522542301451}, {\"x\": 5.6521739130434785, \"y\": -0.72463768115942, \"x2\": 5.942028985507246, \"y2\": -0.43478260869565233, \"center_x\": 5.797101449275362, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.004396824307575779}, {\"x\": 5.942028985507246, \"y\": -0.72463768115942, \"x2\": 6.231884057971014, \"y2\": -0.43478260869565233, \"center_x\": 6.08695652173913, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.004149570639951542}, {\"x\": 6.2318840579710155, \"y\": -0.72463768115942, \"x2\": 6.521739130434783, \"y2\": -0.43478260869565233, \"center_x\": 6.376811594202899, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.003879832948551227}, {\"x\": 6.521739130434785, \"y\": -0.72463768115942, \"x2\": 6.8115942028985526, \"y2\": -0.43478260869565233, \"center_x\": 6.666666666666669, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0035939224869526182}, {\"x\": 6.811594202898551, \"y\": -0.72463768115942, \"x2\": 7.101449275362318, \"y2\": -0.43478260869565233, \"center_x\": 6.956521739130435, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.00329814845360981}, {\"x\": 7.10144927536232, \"y\": -0.72463768115942, \"x2\": 7.391304347826088, \"y2\": -0.43478260869565233, \"center_x\": 7.246376811594204, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0029985928988180773}, {\"x\": 7.391304347826086, \"y\": -0.72463768115942, \"x2\": 7.681159420289854, \"y2\": -0.43478260869565233, \"center_x\": 7.53623188405797, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.002700913222743788}, {\"x\": 7.681159420289855, \"y\": -0.72463768115942, \"x2\": 7.971014492753623, \"y2\": -0.43478260869565233, \"center_x\": 7.826086956521739, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0024101805001465392}, {\"x\": 7.971014492753625, \"y\": -0.72463768115942, \"x2\": 8.260869565217392, \"y2\": -0.43478260869565233, \"center_x\": 8.115942028985508, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.00213075894523904}, {\"x\": 8.26086956521739, \"y\": -0.72463768115942, \"x2\": 8.550724637681158, \"y2\": -0.43478260869565233, \"center_x\": 8.405797101449274, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0018662287981257527}, {\"x\": 8.55072463768116, \"y\": -0.72463768115942, \"x2\": 8.840579710144928, \"y2\": -0.43478260869565233, \"center_x\": 8.695652173913043, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0016193520217726706}, {\"x\": 8.84057971014493, \"y\": -0.72463768115942, \"x2\": 9.130434782608697, \"y2\": -0.43478260869565233, \"center_x\": 8.985507246376812, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0013920776580831054}, {\"x\": 9.130434782608695, \"y\": -0.72463768115942, \"x2\": 9.420289855072463, \"y2\": -0.43478260869565233, \"center_x\": 9.275362318840578, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0011855816626873544}, {\"x\": 9.420289855072465, \"y\": -0.72463768115942, \"x2\": 9.710144927536232, \"y2\": -0.43478260869565233, \"center_x\": 9.565217391304348, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0010003346172510537}, {\"x\": 9.710144927536234, \"y\": -0.72463768115942, \"x2\": 10.000000000000002, \"y2\": -0.43478260869565233, \"center_x\": 9.855072463768117, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0008361899379559863}, {\"x\": 10.0, \"y\": -0.72463768115942, \"x2\": 10.289855072463768, \"y2\": -0.43478260869565233, \"center_x\": 10.144927536231883, \"center_y\": -0.5797101449275361, \"value_uncond\": 0.0006924850326436628}, {\"x\": -10.0, \"y\": -0.43478260869565233, \"x2\": -9.710144927536232, \"y2\": -0.1449275362318847, \"center_x\": -9.855072463768117, \"center_y\": -0.2898550724637685, \"value_uncond\": 1.1068050361167863e-07}, {\"x\": -9.710144927536232, \"y\": -0.43478260869565233, \"x2\": -9.420289855072465, \"y2\": -0.1449275362318847, \"center_x\": -9.565217391304348, \"center_y\": -0.2898550724637685, \"value_uncond\": 1.7292635666361052e-07}, {\"x\": -9.420289855072463, \"y\": -0.43478260869565233, \"x2\": -9.130434782608695, \"y2\": -0.1449275362318847, \"center_x\": -9.275362318840578, \"center_y\": -0.2898550724637685, \"value_uncond\": 2.6766838036410634e-07}, {\"x\": -9.130434782608695, \"y\": -0.43478260869565233, \"x2\": -8.840579710144928, \"y2\": -0.1449275362318847, \"center_x\": -8.985507246376812, \"center_y\": -0.2898550724637685, \"value_uncond\": 4.1046748947810695e-07}, {\"x\": -8.840579710144928, \"y\": -0.43478260869565233, \"x2\": -8.55072463768116, \"y2\": -0.1449275362318847, \"center_x\": -8.695652173913043, \"center_y\": -0.2898550724637685, \"value_uncond\": 6.236002400630083e-07}, {\"x\": -8.55072463768116, \"y\": -0.43478260869565233, \"x2\": -8.260869565217392, \"y2\": -0.1449275362318847, \"center_x\": -8.405797101449277, \"center_y\": -0.2898550724637685, \"value_uncond\": 9.385979402885297e-07}, {\"x\": -8.26086956521739, \"y\": -0.43478260869565233, \"x2\": -7.971014492753623, \"y2\": -0.1449275362318847, \"center_x\": -8.115942028985508, \"center_y\": -0.2898550724637685, \"value_uncond\": 1.3995832443276615e-06}, {\"x\": -7.971014492753623, \"y\": -0.43478260869565233, \"x2\": -7.681159420289855, \"y2\": -0.1449275362318847, \"center_x\": -7.826086956521739, \"center_y\": -0.2898550724637685, \"value_uncond\": 2.067586494677862e-06}, {\"x\": -7.681159420289855, \"y\": -0.43478260869565233, \"x2\": -7.391304347826088, \"y2\": -0.1449275362318847, \"center_x\": -7.536231884057972, \"center_y\": -0.2898550724637685, \"value_uncond\": 3.0260385297535673e-06}, {\"x\": -7.391304347826087, \"y\": -0.43478260869565233, \"x2\": -7.101449275362319, \"y2\": -0.1449275362318847, \"center_x\": -7.246376811594203, \"center_y\": -0.2898550724637685, \"value_uncond\": 4.387640481830946e-06}, {\"x\": -7.101449275362318, \"y\": -0.43478260869565233, \"x2\": -6.811594202898551, \"y2\": -0.1449275362318847, \"center_x\": -6.956521739130435, \"center_y\": -0.2898550724637685, \"value_uncond\": 6.302798610653378e-06}, {\"x\": -6.811594202898551, \"y\": -0.43478260869565233, \"x2\": -6.521739130434783, \"y2\": -0.1449275362318847, \"center_x\": -6.666666666666667, \"center_y\": -0.2898550724637685, \"value_uncond\": 8.969776895016973e-06}, {\"x\": -6.521739130434782, \"y\": -0.43478260869565233, \"x2\": -6.231884057971015, \"y2\": -0.1449275362318847, \"center_x\": -6.3768115942028984, \"center_y\": -0.2898550724637685, \"value_uncond\": 1.2646654845922255e-05}, {\"x\": -6.231884057971014, \"y\": -0.43478260869565233, \"x2\": -5.942028985507246, \"y2\": -0.1449275362318847, \"center_x\": -6.08695652173913, \"center_y\": -0.2898550724637685, \"value_uncond\": 1.7665075801841584e-05}, {\"x\": -5.942028985507246, \"y\": -0.43478260869565233, \"x2\": -5.6521739130434785, \"y2\": -0.1449275362318847, \"center_x\": -5.797101449275362, \"center_y\": -0.2898550724637685, \"value_uncond\": 2.4445625789593858e-05}, {\"x\": -5.6521739130434785, \"y\": -0.43478260869565233, \"x2\": -5.362318840579711, \"y2\": -0.1449275362318847, \"center_x\": -5.507246376811595, \"center_y\": -0.2898550724637685, \"value_uncond\": 3.3514490995420406e-05}, {\"x\": -5.36231884057971, \"y\": -0.43478260869565233, \"x2\": -5.072463768115942, \"y2\": -0.1449275362318847, \"center_x\": -5.217391304347826, \"center_y\": -0.2898550724637685, \"value_uncond\": 4.5520802626206266e-05}, {\"x\": -5.0724637681159415, \"y\": -0.43478260869565233, \"x2\": -4.782608695652174, \"y2\": -0.1449275362318847, \"center_x\": -4.927536231884058, \"center_y\": -0.2898550724637685, \"value_uncond\": 6.125379610721919e-05}, {\"x\": -4.782608695652174, \"y\": -0.43478260869565233, \"x2\": -4.492753623188406, \"y2\": -0.1449275362318847, \"center_x\": -4.63768115942029, \"center_y\": -0.2898550724637685, \"value_uncond\": 8.165859828436157e-05}, {\"x\": -4.492753623188405, \"y\": -0.43478260869565233, \"x2\": -4.202898550724638, \"y2\": -0.1449275362318847, \"center_x\": -4.3478260869565215, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.00010784913033906096}, {\"x\": -4.202898550724638, \"y\": -0.43478260869565233, \"x2\": -3.91304347826087, \"y2\": -0.1449275362318847, \"center_x\": -4.057971014492754, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0001411163025116883}, {\"x\": -3.913043478260869, \"y\": -0.43478260869565233, \"x2\": -3.6231884057971016, \"y2\": -0.1449275362318847, \"center_x\": -3.7681159420289854, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.00018292941455016692}, {\"x\": -3.6231884057971016, \"y\": -0.43478260869565233, \"x2\": -3.333333333333334, \"y2\": -0.1449275362318847, \"center_x\": -3.4782608695652177, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.00023492850487774914}, {\"x\": -3.333333333333333, \"y\": -0.43478260869565233, \"x2\": -3.0434782608695654, \"y2\": -0.1449275362318847, \"center_x\": -3.1884057971014492, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.00029890535774004296}, {\"x\": -3.0434782608695645, \"y\": -0.43478260869565233, \"x2\": -2.753623188405797, \"y2\": -0.1449275362318847, \"center_x\": -2.8985507246376807, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.00037677102706885516}, {\"x\": -2.753623188405797, \"y\": -0.43478260869565233, \"x2\": -2.4637681159420293, \"y2\": -0.1449275362318847, \"center_x\": -2.608695652173913, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.00047050810929727627}, {\"x\": -2.4637681159420284, \"y\": -0.43478260869565233, \"x2\": -2.1739130434782608, \"y2\": -0.1449275362318847, \"center_x\": -2.3188405797101446, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0005821066242024608}, {\"x\": -2.1739130434782608, \"y\": -0.43478260869565233, \"x2\": -1.8840579710144931, \"y2\": -0.1449275362318847, \"center_x\": -2.028985507246377, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0007134832542172296}, {\"x\": -1.8840579710144922, \"y\": -0.43478260869565233, \"x2\": -1.5942028985507246, \"y2\": -0.1449275362318847, \"center_x\": -1.7391304347826084, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0008663848352892936}, {\"x\": -1.5942028985507246, \"y\": -0.43478260869565233, \"x2\": -1.304347826086957, \"y2\": -0.1449275362318847, \"center_x\": -1.4492753623188408, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.001042278343661805}, {\"x\": -1.304347826086957, \"y\": -0.43478260869565233, \"x2\": -1.0144927536231894, \"y2\": -0.1449275362318847, \"center_x\": -1.1594202898550732, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0012422311083334794}, {\"x\": -1.0144927536231876, \"y\": -0.43478260869565233, \"x2\": -0.72463768115942, \"y2\": -0.1449275362318847, \"center_x\": -0.8695652173913038, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0014667864926154442}, {\"x\": -0.72463768115942, \"y\": -0.43478260869565233, \"x2\": -0.43478260869565233, \"y2\": -0.1449275362318847, \"center_x\": -0.5797101449275361, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.001715841697765436}, {\"x\": -0.43478260869565233, \"y\": -0.43478260869565233, \"x2\": -0.1449275362318847, \"y2\": -0.1449275362318847, \"center_x\": -0.2898550724637685, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.001988535497195876}, {\"x\": -0.14492753623188293, \"y\": -0.43478260869565233, \"x2\": 0.1449275362318847, \"y2\": -0.1449275362318847, \"center_x\": 8.881784197001252e-16, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.002283154456693605}, {\"x\": 0.1449275362318847, \"y\": -0.43478260869565233, \"x2\": 0.43478260869565233, \"y2\": -0.1449275362318847, \"center_x\": 0.2898550724637685, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.002597066391525409}, {\"x\": 0.43478260869565233, \"y\": -0.43478260869565233, \"x2\": 0.72463768115942, \"y2\": -0.1449275362318847, \"center_x\": 0.5797101449275361, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0029266893417531576}, {\"x\": 0.72463768115942, \"y\": -0.43478260869565233, \"x2\": 1.0144927536231876, \"y2\": -0.1449275362318847, \"center_x\": 0.8695652173913038, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.003267503146040521}, {\"x\": 1.0144927536231894, \"y\": -0.43478260869565233, \"x2\": 1.304347826086957, \"y2\": -0.1449275362318847, \"center_x\": 1.1594202898550732, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.003614108757063738}, {\"x\": 1.304347826086957, \"y\": -0.43478260869565233, \"x2\": 1.5942028985507246, \"y2\": -0.1449275362318847, \"center_x\": 1.4492753623188408, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.003960337835487279}, {\"x\": 1.5942028985507246, \"y\": -0.43478260869565233, \"x2\": 1.8840579710144922, \"y2\": -0.1449275362318847, \"center_x\": 1.7391304347826084, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.004299412026176441}, {\"x\": 1.884057971014494, \"y\": -0.43478260869565233, \"x2\": 2.1739130434782616, \"y2\": -0.1449275362318847, \"center_x\": 2.028985507246378, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.004624147870994629}, {\"x\": 2.1739130434782616, \"y\": -0.43478260869565233, \"x2\": 2.4637681159420293, \"y2\": -0.1449275362318847, \"center_x\": 2.3188405797101455, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.004927199813329617}, {\"x\": 2.4637681159420293, \"y\": -0.43478260869565233, \"x2\": 2.753623188405797, \"y2\": -0.1449275362318847, \"center_x\": 2.608695652173913, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.005201330499387401}, {\"x\": 2.753623188405797, \"y\": -0.43478260869565233, \"x2\": 3.0434782608695645, \"y2\": -0.1449275362318847, \"center_x\": 2.8985507246376807, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.005439694883722322}, {\"x\": 3.0434782608695663, \"y\": -0.43478260869565233, \"x2\": 3.333333333333334, \"y2\": -0.1449275362318847, \"center_x\": 3.18840579710145, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.005636122777772336}, {\"x\": 3.333333333333334, \"y\": -0.43478260869565233, \"x2\": 3.6231884057971016, \"y2\": -0.1449275362318847, \"center_x\": 3.4782608695652177, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.005785383658431456}, {\"x\": 3.6231884057971016, \"y\": -0.43478260869565233, \"x2\": 3.913043478260869, \"y2\": -0.1449275362318847, \"center_x\": 3.7681159420289854, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.005883417911937755}, {\"x\": 3.913043478260871, \"y\": -0.43478260869565233, \"x2\": 4.202898550724639, \"y2\": -0.1449275362318847, \"center_x\": 4.057971014492755, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.005927520255606916}, {\"x\": 4.202898550724639, \"y\": -0.43478260869565233, \"x2\": 4.492753623188406, \"y2\": -0.1449275362318847, \"center_x\": 4.347826086956522, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.005916463772992943}, {\"x\": 4.492753623188406, \"y\": -0.43478260869565233, \"x2\": 4.782608695652174, \"y2\": -0.1449275362318847, \"center_x\": 4.63768115942029, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.005850556625482321}, {\"x\": 4.782608695652174, \"y\": -0.43478260869565233, \"x2\": 5.0724637681159415, \"y2\": -0.1449275362318847, \"center_x\": 4.927536231884058, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.005731627781728902}, {\"x\": 5.072463768115943, \"y\": -0.43478260869565233, \"x2\": 5.362318840579711, \"y2\": -0.1449275362318847, \"center_x\": 5.217391304347827, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.005562942687262318}, {\"x\": 5.362318840579711, \"y\": -0.43478260869565233, \"x2\": 5.6521739130434785, \"y2\": -0.1449275362318847, \"center_x\": 5.507246376811595, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0053490543011205476}, {\"x\": 5.6521739130434785, \"y\": -0.43478260869565233, \"x2\": 5.942028985507246, \"y2\": -0.1449275362318847, \"center_x\": 5.797101449275362, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.005095598983248022}, {\"x\": 5.942028985507246, \"y\": -0.43478260869565233, \"x2\": 6.231884057971014, \"y2\": -0.1449275362318847, \"center_x\": 6.08695652173913, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.004809049999432688}, {\"x\": 6.2318840579710155, \"y\": -0.43478260869565233, \"x2\": 6.521739130434783, \"y2\": -0.1449275362318847, \"center_x\": 6.376811594202899, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.004496443670434078}, {\"x\": 6.521739130434785, \"y\": -0.43478260869565233, \"x2\": 6.8115942028985526, \"y2\": -0.1449275362318847, \"center_x\": 6.666666666666669, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.004165094279258357}, {\"x\": 6.811594202898551, \"y\": -0.43478260869565233, \"x2\": 7.101449275362318, \"y2\": -0.1449275362318847, \"center_x\": 6.956521739130435, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0038223137271730825}, {\"x\": 7.10144927536232, \"y\": -0.43478260869565233, \"x2\": 7.391304347826088, \"y2\": -0.1449275362318847, \"center_x\": 7.246376811594204, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.003475150667281647}, {\"x\": 7.391304347826086, \"y\": -0.43478260869565233, \"x2\": 7.681159420289854, \"y2\": -0.1449275362318847, \"center_x\": 7.53623188405797, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.003130161614131584}, {\"x\": 7.681159420289855, \"y\": -0.43478260869565233, \"x2\": 7.971014492753623, \"y2\": -0.1449275362318847, \"center_x\": 7.826086956521739, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.002793223573848532}, {\"x\": 7.971014492753625, \"y\": -0.43478260869565233, \"x2\": 8.260869565217392, \"y2\": -0.1449275362318847, \"center_x\": 8.115942028985508, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.002469394352692033}, {\"x\": 8.26086956521739, \"y\": -0.43478260869565233, \"x2\": 8.550724637681158, \"y2\": -0.1449275362318847, \"center_x\": 8.405797101449274, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.002162823188057046}, {\"x\": 8.55072463768116, \"y\": -0.43478260869565233, \"x2\": 8.840579710144928, \"y2\": -0.1449275362318847, \"center_x\": 8.695652173913043, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0018767109937615424}, {\"x\": 8.84057971014493, \"y\": -0.43478260869565233, \"x2\": 9.130434782608697, \"y2\": -0.1449275362318847, \"center_x\": 8.985507246376812, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.001613316567348035}, {\"x\": 9.130434782608695, \"y\": -0.43478260869565233, \"x2\": 9.420289855072463, \"y2\": -0.1449275362318847, \"center_x\": 9.275362318840578, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0013740027557021192}, {\"x\": 9.420289855072465, \"y\": -0.43478260869565233, \"x2\": 9.710144927536232, \"y2\": -0.1449275362318847, \"center_x\": 9.565217391304348, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0011593149286837669}, {\"x\": 9.710144927536234, \"y\": -0.43478260869565233, \"x2\": 10.000000000000002, \"y2\": -0.1449275362318847, \"center_x\": 9.855072463768117, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0009690832063289839}, {\"x\": 10.0, \"y\": -0.43478260869565233, \"x2\": 10.289855072463768, \"y2\": -0.1449275362318847, \"center_x\": 10.144927536231883, \"center_y\": -0.2898550724637685, \"value_uncond\": 0.0008025396926080617}, {\"x\": -10.0, \"y\": -0.14492753623188293, \"x2\": -9.710144927536232, \"y2\": 0.1449275362318847, \"center_x\": -9.855072463768117, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 1.2707879011787393e-07}, {\"x\": -9.710144927536232, \"y\": -0.14492753623188293, \"x2\": -9.420289855072465, \"y2\": 0.1449275362318847, \"center_x\": -9.565217391304348, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 1.98546911761475e-07}, {\"x\": -9.420289855072463, \"y\": -0.14492753623188293, \"x2\": -9.130434782608695, \"y2\": 0.1449275362318847, \"center_x\": -9.275362318840578, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 3.073257965000113e-07}, {\"x\": -9.130434782608695, \"y\": -0.14492753623188293, \"x2\": -8.840579710144928, \"y2\": 0.1449275362318847, \"center_x\": -8.985507246376812, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 4.7128184498154966e-07}, {\"x\": -8.840579710144928, \"y\": -0.14492753623188293, \"x2\": -8.55072463768116, \"y2\": 0.1449275362318847, \"center_x\": -8.695652173913043, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 7.159920802534279e-07}, {\"x\": -8.55072463768116, \"y\": -0.14492753623188293, \"x2\": -8.260869565217392, \"y2\": 0.1449275362318847, \"center_x\": -8.405797101449277, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 1.077659450100381e-06}, {\"x\": -8.26086956521739, \"y\": -0.14492753623188293, \"x2\": -7.971014492753623, \"y2\": 0.1449275362318847, \"center_x\": -8.115942028985508, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 1.6069437665590913e-06}, {\"x\": -7.971014492753623, \"y\": -0.14492753623188293, \"x2\": -7.681159420289855, \"y2\": 0.1449275362318847, \"center_x\": -7.826086956521739, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 2.373917552178486e-06}, {\"x\": -7.681159420289855, \"y\": -0.14492753623188293, \"x2\": -7.391304347826088, \"y2\": 0.1449275362318847, \"center_x\": -7.536231884057972, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 3.4743726551907147e-06}, {\"x\": -7.391304347826087, \"y\": -0.14492753623188293, \"x2\": -7.101449275362319, \"y2\": 0.1449275362318847, \"center_x\": -7.246376811594203, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 5.037707868221594e-06}, {\"x\": -7.101449275362318, \"y\": -0.14492753623188293, \"x2\": -6.811594202898551, \"y2\": 0.1449275362318847, \"center_x\": -6.956521739130435, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 7.236613456409447e-06}, {\"x\": -6.811594202898551, \"y\": -0.14492753623188293, \"x2\": -6.521739130434783, \"y2\": 0.1449275362318847, \"center_x\": -6.666666666666667, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 1.0298727944401408e-05}, {\"x\": -6.521739130434782, \"y\": -0.14492753623188293, \"x2\": -6.231884057971015, \"y2\": 0.1449275362318847, \"center_x\": -6.3768115942028984, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 1.4520367584310195e-05}, {\"x\": -6.231884057971014, \"y\": -0.14492753623188293, \"x2\": -5.942028985507246, \"y2\": 0.1449275362318847, \"center_x\": -6.08695652173913, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 2.0282311581402023e-05}, {\"x\": -5.942028985507246, \"y\": -0.14492753623188293, \"x2\": -5.6521739130434785, \"y2\": 0.1449275362318847, \"center_x\": -5.797101449275362, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 2.80674594679753e-05}, {\"x\": -5.6521739130434785, \"y\": -0.14492753623188293, \"x2\": -5.362318840579711, \"y2\": 0.1449275362318847, \"center_x\": -5.507246376811595, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 3.8479956524746164e-05}, {\"x\": -5.36231884057971, \"y\": -0.14492753623188293, \"x2\": -5.072463768115942, \"y2\": 0.1449275362318847, \"center_x\": -5.217391304347826, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 5.226510843525332e-05}, {\"x\": -5.0724637681159415, \"y\": -0.14492753623188293, \"x2\": -4.782608695652174, \"y2\": 0.1449275362318847, \"center_x\": -4.927536231884058, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 7.032908276910843e-05}, {\"x\": -4.782608695652174, \"y\": -0.14492753623188293, \"x2\": -4.492753623188406, \"y2\": 0.1449275362318847, \"center_x\": -4.63768115942029, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 9.37570351966054e-05}, {\"x\": -4.492753623188405, \"y\": -0.14492753623188293, \"x2\": -4.202898550724638, \"y2\": 0.1449275362318847, \"center_x\": -4.3478260869565215, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0001238279240835204}, {\"x\": -4.202898550724638, \"y\": -0.14492753623188293, \"x2\": -3.91304347826087, \"y2\": 0.1449275362318847, \"center_x\": -4.057971014492754, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.00016202391933461542}, {\"x\": -3.913043478260869, \"y\": -0.14492753623188293, \"x2\": -3.6231884057971016, \"y2\": 0.1449275362318847, \"center_x\": -3.7681159420289854, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.00021003201033098035}, {\"x\": -3.6231884057971016, \"y\": -0.14492753623188293, \"x2\": -3.333333333333334, \"y2\": 0.1449275362318847, \"center_x\": -3.4782608695652177, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.00026973522155997187}, {\"x\": -3.333333333333333, \"y\": -0.14492753623188293, \"x2\": -3.0434782608695654, \"y2\": 0.1449275362318847, \"center_x\": -3.1884057971014492, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0003431908058046359}, {\"x\": -3.0434782608695645, \"y\": -0.14492753623188293, \"x2\": -2.753623188405797, \"y2\": 0.1449275362318847, \"center_x\": -2.8985507246376807, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0004325929563833926}, {\"x\": -2.753623188405797, \"y\": -0.14492753623188293, \"x2\": -2.4637681159420293, \"y2\": 0.1449275362318847, \"center_x\": -2.608695652173913, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0005402180087644379}, {\"x\": -2.4637681159420284, \"y\": -0.14492753623188293, \"x2\": -2.1739130434782608, \"y2\": 0.1449275362318847, \"center_x\": -2.3188405797101446, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0006683508215935073}, {\"x\": -2.1739130434782608, \"y\": -0.14492753623188293, \"x2\": -1.8840579710144931, \"y2\": 0.1449275362318847, \"center_x\": -2.028985507246377, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0008191920506017823}, {\"x\": -1.8840579710144922, \"y\": -0.14492753623188293, \"x2\": -1.5942028985507246, \"y2\": 0.1449275362318847, \"center_x\": -1.7391304347826084, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0009947473407901947}, {\"x\": -1.5942028985507246, \"y\": -0.14492753623188293, \"x2\": -1.304347826086957, \"y2\": 0.1449275362318847, \"center_x\": -1.4492753623188408, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0011967010137874715}, {\"x\": -1.304347826086957, \"y\": -0.14492753623188293, \"x2\": -1.0144927536231894, \"y2\": 0.1449275362318847, \"center_x\": -1.1594202898550732, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.001426278532736519}, {\"x\": -1.0144927536231876, \"y\": -0.14492753623188293, \"x2\": -0.72463768115942, \"y2\": 0.1449275362318847, \"center_x\": -0.8695652173913038, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0016841037649845162}, {\"x\": -0.72463768115942, \"y\": -0.14492753623188293, \"x2\": -0.43478260869565233, \"y2\": 0.1449275362318847, \"center_x\": -0.5797101449275361, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0019700586812547044}, {\"x\": -0.43478260869565233, \"y\": -0.14492753623188293, \"x2\": -0.1449275362318847, \"y2\": 0.1449275362318847, \"center_x\": -0.2898550724637685, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.002283154456693605}, {\"x\": -0.14492753623188293, \"y\": -0.14492753623188293, \"x2\": 0.1449275362318847, \"y2\": 0.1449275362318847, \"center_x\": 8.881784197001252e-16, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0026214237967945083}, {\"x\": 0.1449275362318847, \"y\": -0.14492753623188293, \"x2\": 0.43478260869565233, \"y2\": 0.1449275362318847, \"center_x\": 0.2898550724637685, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.002981844535590075}, {\"x\": 0.43478260869565233, \"y\": -0.14492753623188293, \"x2\": 0.72463768115942, \"y2\": 0.1449275362318847, \"center_x\": 0.5797101449275361, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.003360304014388531}, {\"x\": 0.72463768115942, \"y\": -0.14492753623188293, \"x2\": 1.0144927536231876, \"y2\": 0.1449275362318847, \"center_x\": 0.8695652173913038, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.003751612370341276}, {\"x\": 1.0144927536231894, \"y\": -0.14492753623188293, \"x2\": 1.304347826086957, \"y2\": 0.1449275362318847, \"center_x\": 1.1594202898550732, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.004149570639951545}, {\"x\": 1.304347826086957, \"y\": -0.14492753623188293, \"x2\": 1.5942028985507246, \"y2\": 0.1449275362318847, \"center_x\": 1.4492753623188408, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.004547096590357931}, {\"x\": 1.5942028985507246, \"y\": -0.14492753623188293, \"x2\": 1.8840579710144922, \"y2\": 0.1449275362318847, \"center_x\": 1.7391304347826084, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.004936407593713624}, {\"x\": 1.884057971014494, \"y\": -0.14492753623188293, \"x2\": 2.1739130434782616, \"y2\": 0.1449275362318847, \"center_x\": 2.028985507246378, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.005309255899610263}, {\"x\": 2.1739130434782616, \"y\": -0.14492753623188293, \"x2\": 2.4637681159420293, \"y2\": 0.1449275362318847, \"center_x\": 2.3188405797101455, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.005657207642854213}, {\"x\": 2.4637681159420293, \"y\": -0.14492753623188293, \"x2\": 2.753623188405797, \"y2\": 0.1449275362318847, \"center_x\": 2.608695652173913, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.005971953192265772}, {\"x\": 2.753623188405797, \"y\": -0.14492753623188293, \"x2\": 3.0434782608695645, \"y2\": 0.1449275362318847, \"center_x\": 2.8985507246376807, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.006245633348933196}, {\"x\": 3.0434782608695663, \"y\": -0.14492753623188293, \"x2\": 3.333333333333334, \"y2\": 0.1449275362318847, \"center_x\": 3.18840579710145, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0064711637567894525}, {\"x\": 3.333333333333334, \"y\": -0.14492753623188293, \"x2\": 3.6231884057971016, \"y2\": 0.1449275362318847, \"center_x\": 3.4782608695652177, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.00664253894489519}, {\"x\": 3.6231884057971016, \"y\": -0.14492753623188293, \"x2\": 3.913043478260869, \"y2\": 0.1449275362318847, \"center_x\": 3.7681159420289854, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.006755097832135153}, {\"x\": 3.913043478260871, \"y\": -0.14492753623188293, \"x2\": 4.202898550724639, \"y2\": 0.1449275362318847, \"center_x\": 4.057971014492755, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.006805734324488884}, {\"x\": 4.202898550724639, \"y\": -0.14492753623188293, \"x2\": 4.492753623188406, \"y2\": 0.1449275362318847, \"center_x\": 4.347826086956522, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.006793039727087408}, {\"x\": 4.492753623188406, \"y\": -0.14492753623188293, \"x2\": 4.782608695652174, \"y2\": 0.1449275362318847, \"center_x\": 4.63768115942029, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0067173678581270435}, {\"x\": 4.782608695652174, \"y\": -0.14492753623188293, \"x2\": 5.0724637681159415, \"y2\": 0.1449275362318847, \"center_x\": 4.927536231884058, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.006580818663995012}, {\"x\": 5.072463768115943, \"y\": -0.14492753623188293, \"x2\": 5.362318840579711, \"y2\": 0.1449275362318847, \"center_x\": 5.217391304347827, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.006387141394591343}, {\"x\": 5.362318840579711, \"y\": -0.14492753623188293, \"x2\": 5.6521739130434785, \"y2\": 0.1449275362318847, \"center_x\": 5.507246376811595, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.006141563569733192}, {\"x\": 5.6521739130434785, \"y\": -0.14492753623188293, \"x2\": 5.942028985507246, \"y2\": 0.1449275362318847, \"center_x\": 5.797101449275362, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.005850556625482325}, {\"x\": 5.942028985507246, \"y\": -0.14492753623188293, \"x2\": 6.231884057971014, \"y2\": 0.1449275362318847, \"center_x\": 6.08695652173913, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.005521552898678568}, {\"x\": 6.2318840579710155, \"y\": -0.14492753623188293, \"x2\": 6.521739130434783, \"y2\": 0.1449275362318847, \"center_x\": 6.376811594202899, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.005162631202661442}, {\"x\": 6.521739130434785, \"y\": -0.14492753623188293, \"x2\": 6.8115942028985526, \"y2\": 0.1449275362318847, \"center_x\": 6.666666666666669, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.004782189495559725}, {\"x\": 6.811594202898551, \"y\": -0.14492753623188293, \"x2\": 7.101449275362318, \"y2\": 0.1449275362318847, \"center_x\": 6.956521739130435, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.004388623000888145}, {\"x\": 7.10144927536232, \"y\": -0.14492753623188293, \"x2\": 7.391304347826088, \"y2\": 0.1449275362318847, \"center_x\": 7.246376811594204, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.003990024691474892}, {\"x\": 7.391304347826086, \"y\": -0.14492753623188293, \"x2\": 7.681159420289854, \"y2\": 0.1449275362318847, \"center_x\": 7.53623188405797, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.003593922486952622}, {\"x\": 7.681159420289855, \"y\": -0.14492753623188293, \"x2\": 7.971014492753623, \"y2\": 0.1449275362318847, \"center_x\": 7.826086956521739, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0032070641234048475}, {\"x\": 7.971014492753625, \"y\": -0.14492753623188293, \"x2\": 8.260869565217392, \"y2\": 0.1449275362318847, \"center_x\": 8.115942028985508, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.002835256765410144}, {\"x\": 8.26086956521739, \"y\": -0.14492753623188293, \"x2\": 8.550724637681158, \"y2\": 0.1449275362318847, \"center_x\": 8.405797101449274, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.002483264396243414}, {\"x\": 8.55072463768116, \"y\": -0.14492753623188293, \"x2\": 8.840579710144928, \"y2\": 0.1449275362318847, \"center_x\": 8.695652173913043, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0021547621731544497}, {\"x\": 8.84057971014493, \"y\": -0.14492753623188293, \"x2\": 9.130434782608697, \"y2\": 0.1449275362318847, \"center_x\": 8.985507246376812, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0018523435543355879}, {\"x\": 9.130434782608695, \"y\": -0.14492753623188293, \"x2\": 9.420289855072463, \"y2\": 0.1449275362318847, \"center_x\": 9.275362318840578, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0015775733043811879}, {\"x\": 9.420289855072465, \"y\": -0.14492753623188293, \"x2\": 9.710144927536232, \"y2\": 0.1449275362318847, \"center_x\": 9.565217391304348, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0013310775944750685}, {\"x\": 9.710144927536234, \"y\": -0.14492753623188293, \"x2\": 10.000000000000002, \"y2\": 0.1449275362318847, \"center_x\": 9.855072463768117, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.001112661375447905}, {\"x\": 10.0, \"y\": -0.14492753623188293, \"x2\": 10.289855072463768, \"y2\": 0.1449275362318847, \"center_x\": 10.144927536231883, \"center_y\": 8.881784197001252e-16, \"value_uncond\": 0.0009214429807440965}, {\"x\": -10.0, \"y\": 0.1449275362318847, \"x2\": -9.710144927536232, \"y2\": 0.43478260869565233, \"center_x\": -9.855072463768117, \"center_y\": 0.2898550724637685, \"value_uncond\": 1.445509102212839e-07}, {\"x\": -9.710144927536232, \"y\": 0.1449275362318847, \"x2\": -9.420289855072465, \"y2\": 0.43478260869565233, \"center_x\": -9.565217391304348, \"center_y\": 0.2898550724637685, \"value_uncond\": 2.258452161066759e-07}, {\"x\": -9.420289855072463, \"y\": 0.1449275362318847, \"x2\": -9.130434782608695, \"y2\": 0.43478260869565233, \"center_x\": -9.275362318840578, \"center_y\": 0.2898550724637685, \"value_uncond\": 3.4958015871375006e-07}, {\"x\": -9.130434782608695, \"y\": 0.1449275362318847, \"x2\": -8.840579710144928, \"y2\": 0.43478260869565233, \"center_x\": -8.985507246376812, \"center_y\": 0.2898550724637685, \"value_uncond\": 5.360785981646451e-07}, {\"x\": -8.840579710144928, \"y\": 0.1449275362318847, \"x2\": -8.55072463768116, \"y2\": 0.43478260869565233, \"center_x\": -8.695652173913043, \"center_y\": 0.2898550724637685, \"value_uncond\": 8.144341539281496e-07}, {\"x\": -8.55072463768116, \"y\": 0.1449275362318847, \"x2\": -8.260869565217392, \"y2\": 0.43478260869565233, \"center_x\": -8.405797101449277, \"center_y\": 0.2898550724637685, \"value_uncond\": 1.2258273333896651e-06}, {\"x\": -8.26086956521739, \"y\": 0.1449275362318847, \"x2\": -7.971014492753623, \"y2\": 0.43478260869565233, \"center_x\": -8.115942028985508, \"center_y\": 0.2898550724637685, \"value_uncond\": 1.8278831889654851e-06}, {\"x\": -7.971014492753623, \"y\": 0.1449275362318847, \"x2\": -7.681159420289855, \"y2\": 0.43478260869565233, \"center_x\": -7.826086956521739, \"center_y\": 0.2898550724637685, \"value_uncond\": 2.7003085458980758e-06}, {\"x\": -7.681159420289855, \"y\": 0.1449275362318847, \"x2\": -7.391304347826088, \"y2\": 0.43478260869565233, \"center_x\": -7.536231884057972, \"center_y\": 0.2898550724637685, \"value_uncond\": 3.952065716788075e-06}, {\"x\": -7.391304347826087, \"y\": 0.1449275362318847, \"x2\": -7.101449275362319, \"y2\": 0.43478260869565233, \"center_x\": -7.246376811594203, \"center_y\": 0.2898550724637685, \"value_uncond\": 5.73034459255472e-06}, {\"x\": -7.101449275362318, \"y\": 0.1449275362318847, \"x2\": -6.811594202898551, \"y2\": 0.43478260869565233, \"center_x\": -6.956521739130435, \"center_y\": 0.2898550724637685, \"value_uncond\": 8.23157870068867e-06}, {\"x\": -6.811594202898551, \"y\": 0.1449275362318847, \"x2\": -6.521739130434783, \"y2\": 0.43478260869565233, \"center_x\": -6.666666666666667, \"center_y\": 0.2898550724637685, \"value_uncond\": 1.1714704689143955e-05}, {\"x\": -6.521739130434782, \"y\": 0.1449275362318847, \"x2\": -6.231884057971015, \"y2\": 0.43478260869565233, \"center_x\": -6.3768115942028984, \"center_y\": 0.2898550724637685, \"value_uncond\": 1.6516779465029294e-05}, {\"x\": -6.231884057971014, \"y\": 0.1449275362318847, \"x2\": -5.942028985507246, \"y2\": 0.43478260869565233, \"center_x\": -6.08695652173913, \"center_y\": 0.2898550724637685, \"value_uncond\": 2.307093573808732e-05}, {\"x\": -5.942028985507246, \"y\": 0.1449275362318847, \"x2\": -5.6521739130434785, \"y2\": 0.43478260869565233, \"center_x\": -5.797101449275362, \"center_y\": 0.2898550724637685, \"value_uncond\": 3.192646711486255e-05}, {\"x\": -5.6521739130434785, \"y\": 0.1449275362318847, \"x2\": -5.362318840579711, \"y2\": 0.43478260869565233, \"center_x\": -5.507246376811595, \"center_y\": 0.2898550724637685, \"value_uncond\": 4.37705830828896e-05}, {\"x\": -5.36231884057971, \"y\": 0.1449275362318847, \"x2\": -5.072463768115942, \"y2\": 0.43478260869565233, \"center_x\": -5.217391304347826, \"center_y\": 0.2898550724637685, \"value_uncond\": 5.9451061739903565e-05}, {\"x\": -5.0724637681159415, \"y\": 0.1449275362318847, \"x2\": -4.782608695652174, \"y2\": 0.43478260869565233, \"center_x\": -4.927536231884058, \"center_y\": 0.2898550724637685, \"value_uncond\": 7.999866004289843e-05}, {\"x\": -4.782608695652174, \"y\": 0.1449275362318847, \"x2\": -4.492753623188406, \"y2\": 0.43478260869565233, \"center_x\": -4.63768115942029, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.00010664773220414889}, {\"x\": -4.492753623188405, \"y\": 0.1449275362318847, \"x2\": -4.202898550724638, \"y2\": 0.43478260869565233, \"center_x\": -4.3478260869565215, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0001408530811513238}, {\"x\": -4.202898550724638, \"y\": 0.1449275362318847, \"x2\": -3.91304347826087, \"y2\": 0.43478260869565233, \"center_x\": -4.057971014492754, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.00018430066099712087}, {\"x\": -3.913043478260869, \"y\": 0.1449275362318847, \"x2\": -3.6231884057971016, \"y2\": 0.43478260869565233, \"center_x\": -3.7681159420289854, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.00023890940605263985}, {\"x\": -3.6231884057971016, \"y\": 0.1449275362318847, \"x2\": -3.333333333333334, \"y2\": 0.43478260869565233, \"center_x\": -3.4782608695652177, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0003068212386903227}, {\"x\": -3.333333333333333, \"y\": 0.1449275362318847, \"x2\": -3.0434782608695654, \"y2\": 0.43478260869565233, \"center_x\": -3.1884057971014492, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0003903762643051674}, {\"x\": -3.0434782608695645, \"y\": 0.1449275362318847, \"x2\": -2.753623188405797, \"y2\": 0.43478260869565233, \"center_x\": -2.8985507246376807, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.000492070356843446}, {\"x\": -2.753623188405797, \"y\": 0.1449275362318847, \"x2\": -2.4637681159420293, \"y2\": 0.43478260869565233, \"center_x\": -2.608695652173913, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0006144928261623863}, {\"x\": -2.4637681159420284, \"y\": 0.1449275362318847, \"x2\": -2.1739130434782608, \"y2\": 0.43478260869565233, \"center_x\": -2.3188405797101446, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0007602426771522744}, {\"x\": -2.1739130434782608, \"y\": 0.1449275362318847, \"x2\": -1.8840579710144931, \"y2\": 0.43478260869565233, \"center_x\": -2.028985507246377, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0009318231346921867}, {\"x\": -1.8840579710144922, \"y\": 0.1449275362318847, \"x2\": -1.5942028985507246, \"y2\": 0.43478260869565233, \"center_x\": -1.7391304347826084, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.001131515600817794}, {\"x\": -1.5942028985507246, \"y\": 0.1449275362318847, \"x2\": -1.304347826086957, \"y2\": 0.43478260869565233, \"center_x\": -1.4492753623188408, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0013612359752973578}, {\"x\": -1.304347826086957, \"y\": 0.1449275362318847, \"x2\": -1.0144927536231894, \"y2\": 0.43478260869565233, \"center_x\": -1.1594202898550732, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.001622378210753385}, {\"x\": -1.0144927536231876, \"y\": 0.1449275362318847, \"x2\": -0.72463768115942, \"y2\": 0.43478260869565233, \"center_x\": -0.8695652173913038, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0019156519503356758}, {\"x\": -0.72463768115942, \"y\": 0.1449275362318847, \"x2\": -0.43478260869565233, \"y2\": 0.43478260869565233, \"center_x\": -0.5797101449275361, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.002240922936869036}, {\"x\": -0.43478260869565233, \"y\": 0.1449275362318847, \"x2\": -0.1449275362318847, \"y2\": 0.43478260869565233, \"center_x\": -0.2898550724637685, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.002597066391525409}, {\"x\": -0.14492753623188293, \"y\": 0.1449275362318847, \"x2\": 0.1449275362318847, \"y2\": 0.43478260869565233, \"center_x\": 8.881784197001252e-16, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.002981844535590075}, {\"x\": 0.1449275362318847, \"y\": 0.1449275362318847, \"x2\": 0.43478260869565233, \"y2\": 0.43478260869565233, \"center_x\": 0.2898550724637685, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0033918196841353316}, {\"x\": 0.43478260869565233, \"y\": 0.1449275362318847, \"x2\": 0.72463768115942, \"y2\": 0.43478260869565233, \"center_x\": 0.5797101449275361, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0038223137271730843}, {\"x\": 0.72463768115942, \"y\": 0.1449275362318847, \"x2\": 1.0144927536231876, \"y2\": 0.43478260869565233, \"center_x\": 0.8695652173913038, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0042674232452736}, {\"x\": 1.0144927536231894, \"y\": 0.1449275362318847, \"x2\": 1.304347826086957, \"y2\": 0.43478260869565233, \"center_x\": 1.1594202898550732, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.004720096976656257}, {\"x\": 1.304347826086957, \"y\": 0.1449275362318847, \"x2\": 1.5942028985507246, \"y2\": 0.43478260869565233, \"center_x\": 1.4492753623188408, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.005172278949072928}, {\"x\": 1.5942028985507246, \"y\": 0.1449275362318847, \"x2\": 1.8840579710144922, \"y2\": 0.43478260869565233, \"center_x\": 1.7391304347826084, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.005615116497667997}, {\"x\": 1.884057971014494, \"y\": 0.1449275362318847, \"x2\": 2.1739130434782616, \"y2\": 0.43478260869565233, \"center_x\": 2.028985507246378, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.006039227885113778}, {\"x\": 2.1739130434782616, \"y\": 0.1449275362318847, \"x2\": 2.4637681159420293, \"y2\": 0.43478260869565233, \"center_x\": 2.3188405797101455, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.006435019670291636}, {\"x\": 2.4637681159420293, \"y\": 0.1449275362318847, \"x2\": 2.753623188405797, \"y2\": 0.43478260869565233, \"center_x\": 2.608695652173913, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.006793039727087407}, {\"x\": 2.753623188405797, \"y\": 0.1449275362318847, \"x2\": 3.0434782608695645, \"y2\": 0.43478260869565233, \"center_x\": 2.8985507246376807, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.007104348291790332}, {\"x\": 3.0434782608695663, \"y\": 0.1449275362318847, \"x2\": 3.333333333333334, \"y2\": 0.43478260869565233, \"center_x\": 3.18840579710145, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.007360886977026161}, {\"x\": 3.333333333333334, \"y\": 0.1449275362318847, \"x2\": 3.6231884057971016, \"y2\": 0.43478260869565233, \"center_x\": 3.4782608695652177, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.007555824616950575}, {\"x\": 3.6231884057971016, \"y\": 0.1449275362318847, \"x2\": 3.913043478260869, \"y2\": 0.43478260869565233, \"center_x\": 3.7681159420289854, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.007683859276305922}, {\"x\": 3.913043478260871, \"y\": 0.1449275362318847, \"x2\": 4.202898550724639, \"y2\": 0.43478260869565233, \"center_x\": 4.057971014492755, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.007741457802805548}, {\"x\": 4.202898550724639, \"y\": 0.1449275362318847, \"x2\": 4.492753623188406, \"y2\": 0.43478260869565233, \"center_x\": 4.347826086956522, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.007727017819488317}, {\"x\": 4.492753623188406, \"y\": 0.1449275362318847, \"x2\": 4.782608695652174, \"y2\": 0.43478260869565233, \"center_x\": 4.63768115942029, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.007640941791173754}, {\"x\": 4.782608695652174, \"y\": 0.1449275362318847, \"x2\": 5.0724637681159415, \"y2\": 0.43478260869565233, \"center_x\": 4.927536231884058, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0074856183868239065}, {\"x\": 5.072463768115943, \"y\": 0.1449275362318847, \"x2\": 5.362318840579711, \"y2\": 0.43478260869565233, \"center_x\": 5.217391304347827, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.007265312342396628}, {\"x\": 5.362318840579711, \"y\": 0.1449275362318847, \"x2\": 5.6521739130434785, \"y2\": 0.43478260869565233, \"center_x\": 5.507246376811595, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.006985969911763776}, {\"x\": 5.6521739130434785, \"y\": 0.1449275362318847, \"x2\": 5.942028985507246, \"y2\": 0.43478260869565233, \"center_x\": 5.797101449275362, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.006654952291646691}, {\"x\": 5.942028985507246, \"y\": 0.1449275362318847, \"x2\": 6.231884057971014, \"y2\": 0.43478260869565233, \"center_x\": 6.08695652173913, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.006280713694225636}, {\"x\": 6.2318840579710155, \"y\": 0.1449275362318847, \"x2\": 6.521739130434783, \"y2\": 0.43478260869565233, \"center_x\": 6.376811594202899, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0058724436925257605}, {\"x\": 6.521739130434785, \"y\": 0.1449275362318847, \"x2\": 6.8115942028985526, \"y2\": 0.43478260869565233, \"center_x\": 6.666666666666669, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.005439694883722319}, {\"x\": 6.811594202898551, \"y\": 0.1449275362318847, \"x2\": 7.101449275362318, \"y2\": 0.43478260869565233, \"center_x\": 6.956521739130435, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.004992016754393205}, {\"x\": 7.10144927536232, \"y\": 0.1449275362318847, \"x2\": 7.391304347826088, \"y2\": 0.43478260869565233, \"center_x\": 7.246376811594204, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.004538614983846708}, {\"x\": 7.391304347826086, \"y\": 0.1449275362318847, \"x2\": 7.681159420289854, \"y2\": 0.43478260869565233, \"center_x\": 7.53623188405797, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.004088052508777173}, {\"x\": 7.681159420289855, \"y\": 0.1449275362318847, \"x2\": 7.971014492753623, \"y2\": 0.43478260869565233, \"center_x\": 7.826086956521739, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0036480048145421467}, {\"x\": 7.971014492753625, \"y\": 0.1449275362318847, \"x2\": 8.260869565217392, \"y2\": 0.43478260869565233, \"center_x\": 8.115942028985508, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0032250774953942927}, {\"x\": 8.26086956521739, \"y\": 0.1449275362318847, \"x2\": 8.550724637681158, \"y2\": 0.43478260869565233, \"center_x\": 8.405797101449274, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0028246895368151965}, {\"x\": 8.55072463768116, \"y\": 0.1449275362318847, \"x2\": 8.840579710144928, \"y2\": 0.43478260869565233, \"center_x\": 8.695652173913043, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.002451021395080612}, {\"x\": 8.84057971014493, \"y\": 0.1449275362318847, \"x2\": 9.130434782608697, \"y2\": 0.43478260869565233, \"center_x\": 8.985507246376812, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.002107023104118119}, {\"x\": 9.130434782608695, \"y\": 0.1449275362318847, \"x2\": 9.420289855072463, \"y2\": 0.43478260869565233, \"center_x\": 9.275362318840578, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.001794474568711094}, {\"x\": 9.420289855072465, \"y\": 0.1449275362318847, \"x2\": 9.710144927536232, \"y2\": 0.43478260869565233, \"center_x\": 9.565217391304348, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.0015140880526015143}, {\"x\": 9.710144927536234, \"y\": 0.1449275362318847, \"x2\": 10.000000000000002, \"y2\": 0.43478260869565233, \"center_x\": 9.855072463768117, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.001265641689221894}, {\"x\": 10.0, \"y\": 0.1449275362318847, \"x2\": 10.289855072463768, \"y2\": 0.43478260869565233, \"center_x\": 10.144927536231883, \"center_y\": 0.2898550724637685, \"value_uncond\": 0.001048132591284704}, {\"x\": -10.0, \"y\": 0.43478260869565233, \"x2\": -9.710144927536232, \"y2\": 0.72463768115942, \"center_x\": -9.855072463768117, \"center_y\": 0.5797101449275361, \"value_uncond\": 1.628974945214488e-07}, {\"x\": -9.710144927536232, \"y\": 0.43478260869565233, \"x2\": -9.420289855072465, \"y2\": 0.72463768115942, \"center_x\": -9.565217391304348, \"center_y\": 0.5797101449275361, \"value_uncond\": 2.545097765009833e-07}, {\"x\": -9.420289855072463, \"y\": 0.43478260869565233, \"x2\": -9.130434782608695, \"y2\": 0.72463768115942, \"center_x\": -9.275362318840578, \"center_y\": 0.5797101449275361, \"value_uncond\": 3.9394931447823936e-07}, {\"x\": -9.130434782608695, \"y\": 0.43478260869565233, \"x2\": -8.840579710144928, \"y2\": 0.72463768115942, \"center_x\": -8.985507246376812, \"center_y\": 0.5797101449275361, \"value_uncond\": 6.04118371678944e-07}, {\"x\": -8.840579710144928, \"y\": 0.43478260869565233, \"x2\": -8.55072463768116, \"y2\": 0.72463768115942, \"center_x\": -8.695652173913043, \"center_y\": 0.5797101449275361, \"value_uncond\": 9.178031665417845e-07}, {\"x\": -8.55072463768116, \"y\": 0.43478260869565233, \"x2\": -8.260869565217392, \"y2\": 0.72463768115942, \"center_x\": -8.405797101449277, \"center_y\": 0.5797101449275361, \"value_uncond\": 1.3814108885194928e-06}, {\"x\": -8.26086956521739, \"y\": 0.43478260869565233, \"x2\": -7.971014492753623, \"y2\": 0.72463768115942, \"center_x\": -8.115942028985508, \"center_y\": 0.5797101449275361, \"value_uncond\": 2.0598804345440314e-06}, {\"x\": -7.971014492753623, \"y\": 0.43478260869565233, \"x2\": -7.681159420289855, \"y2\": 0.72463768115942, \"center_x\": -7.826086956521739, \"center_y\": 0.5797101449275361, \"value_uncond\": 3.043035120901547e-06}, {\"x\": -7.681159420289855, \"y\": 0.43478260869565233, \"x2\": -7.391304347826088, \"y2\": 0.72463768115942, \"center_x\": -7.536231884057972, \"center_y\": 0.5797101449275361, \"value_uncond\": 4.453666894683446e-06}, {\"x\": -7.391304347826087, \"y\": 0.43478260869565233, \"x2\": -7.101449275362319, \"y2\": 0.72463768115942, \"center_x\": -7.246376811594203, \"center_y\": 0.5797101449275361, \"value_uncond\": 6.4576471738761325e-06}, {\"x\": -7.101449275362318, \"y\": 0.43478260869565233, \"x2\": -6.811594202898551, \"y2\": 0.72463768115942, \"center_x\": -6.956521739130435, \"center_y\": 0.5797101449275361, \"value_uncond\": 9.276341077656326e-06}, {\"x\": -6.811594202898551, \"y\": 0.43478260869565233, \"x2\": -6.521739130434783, \"y2\": 0.72463768115942, \"center_x\": -6.666666666666667, \"center_y\": 0.5797101449275361, \"value_uncond\": 1.3201549820744305e-05}, {\"x\": -6.521739130434782, \"y\": 0.43478260869565233, \"x2\": -6.231884057971015, \"y2\": 0.72463768115942, \"center_x\": -6.3768115942028984, \"center_y\": 0.5797101449275361, \"value_uncond\": 1.8613109999084778e-05}, {\"x\": -6.231884057971014, \"y\": 0.43478260869565233, \"x2\": -5.942028985507246, \"y2\": 0.72463768115942, \"center_x\": -6.08695652173913, \"center_y\": 0.5797101449275361, \"value_uncond\": 2.5999128073608017e-05}, {\"x\": -5.942028985507246, \"y\": 0.43478260869565233, \"x2\": -5.6521739130434785, \"y2\": 0.72463768115942, \"center_x\": -5.797101449275362, \"center_y\": 0.5797101449275361, \"value_uncond\": 3.5978614689945916e-05}, {\"x\": -5.6521739130434785, \"y\": 0.43478260869565233, \"x2\": -5.362318840579711, \"y2\": 0.72463768115942, \"center_x\": -5.507246376811595, \"center_y\": 0.5797101449275361, \"value_uncond\": 4.932600083272101e-05}, {\"x\": -5.36231884057971, \"y\": 0.43478260869565233, \"x2\": -5.072463768115942, \"y2\": 0.72463768115942, \"center_x\": -5.217391304347826, \"center_y\": 0.5797101449275361, \"value_uncond\": 6.699666566779119e-05}, {\"x\": -5.0724637681159415, \"y\": 0.43478260869565233, \"x2\": -4.782608695652174, \"y2\": 0.72463768115942, \"center_x\": -4.927536231884058, \"center_y\": 0.5797101449275361, \"value_uncond\": 9.015219112845478e-05}, {\"x\": -4.782608695652174, \"y\": 0.43478260869565233, \"x2\": -4.492753623188406, \"y2\": 0.72463768115942, \"center_x\": -4.63768115942029, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.00012018359722436608}, {\"x\": -4.492753623188405, \"y\": 0.43478260869565233, \"x2\": -4.202898550724638, \"y2\": 0.72463768115942, \"center_x\": -4.3478260869565215, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.00015873033231027375}, {\"x\": -4.202898550724638, \"y\": 0.43478260869565233, \"x2\": -3.91304347826087, \"y2\": 0.72463768115942, \"center_x\": -4.057971014492754, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.00020769233392663476}, {\"x\": -3.913043478260869, \"y\": 0.43478260869565233, \"x2\": -3.6231884057971016, \"y2\": 0.72463768115942, \"center_x\": -3.7681159420289854, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0002692320899536763}, {\"x\": -3.6231884057971016, \"y\": 0.43478260869565233, \"x2\": -3.333333333333334, \"y2\": 0.72463768115942, \"center_x\": -3.4782608695652177, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.00034576337825966737}, {\"x\": -3.333333333333333, \"y\": 0.43478260869565233, \"x2\": -3.0434782608695654, \"y2\": 0.72463768115942, \"center_x\": -3.1884057971014492, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0004399233133752442}, {\"x\": -3.0434782608695645, \"y\": 0.43478260869565233, \"x2\": -2.753623188405797, \"y2\": 0.72463768115942, \"center_x\": -2.8985507246376807, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0005545245487238045}, {\"x\": -2.753623188405797, \"y\": 0.43478260869565233, \"x2\": -2.4637681159420293, \"y2\": 0.72463768115942, \"center_x\": -2.608695652173913, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0006924850326436628}, {\"x\": -2.4637681159420284, \"y\": 0.43478260869565233, \"x2\": -2.1739130434782608, \"y2\": 0.72463768115942, \"center_x\": -2.3188405797101446, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0008567336390120467}, {\"x\": -2.1739130434782608, \"y\": 0.43478260869565233, \"x2\": -1.8840579710144931, \"y2\": 0.72463768115942, \"center_x\": -2.028985507246377, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0010500913051748446}, {\"x\": -1.8840579710144922, \"y\": 0.43478260869565233, \"x2\": -1.5942028985507246, \"y2\": 0.72463768115942, \"center_x\": -1.7391304347826084, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0012751289915987729}, {\"x\": -1.5942028985507246, \"y\": 0.43478260869565233, \"x2\": -1.304347826086957, \"y2\": 0.72463768115942, \"center_x\": -1.4492753623188408, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0015340057664732067}, {\"x\": -1.304347826086957, \"y\": 0.43478260869565233, \"x2\": -1.0144927536231894, \"y2\": 0.72463768115942, \"center_x\": -1.1594202898550732, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0018282925046500629}, {\"x\": -1.0144927536231876, \"y\": 0.43478260869565233, \"x2\": -0.72463768115942, \"y2\": 0.72463768115942, \"center_x\": -0.8695652173913038, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0021587889180850073}, {\"x\": -0.72463768115942, \"y\": 0.43478260869565233, \"x2\": -0.43478260869565233, \"y2\": 0.72463768115942, \"center_x\": -0.5797101449275361, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.002525343709512413}, {\"x\": -0.43478260869565233, \"y\": 0.43478260869565233, \"x2\": -0.1449275362318847, \"y2\": 0.72463768115942, \"center_x\": -0.2898550724637685, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0029266893417531576}, {\"x\": -0.14492753623188293, \"y\": 0.43478260869565233, \"x2\": 0.1449275362318847, \"y2\": 0.72463768115942, \"center_x\": 8.881784197001252e-16, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.003360304014388531}, {\"x\": 0.1449275362318847, \"y\": 0.43478260869565233, \"x2\": 0.43478260869565233, \"y2\": 0.72463768115942, \"center_x\": 0.2898550724637685, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0038223137271730843}, {\"x\": 0.43478260869565233, \"y\": 0.43478260869565233, \"x2\": 0.72463768115942, \"y2\": 0.72463768115942, \"center_x\": 0.5797101449275361, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.004307446618483878}, {\"x\": 0.72463768115942, \"y\": 0.43478260869565233, \"x2\": 1.0144927536231876, \"y2\": 0.72463768115942, \"center_x\": 0.8695652173913038, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.004809049999432688}, {\"x\": 1.0144927536231894, \"y\": 0.43478260869565233, \"x2\": 1.304347826086957, \"y2\": 0.72463768115942, \"center_x\": 1.1594202898550732, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.005319177653177842}, {\"x\": 1.304347826086957, \"y\": 0.43478260869565233, \"x2\": 1.5942028985507246, \"y2\": 0.72463768115942, \"center_x\": 1.4492753623188408, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.005828751133287251}, {\"x\": 1.5942028985507246, \"y\": 0.43478260869565233, \"x2\": 1.8840579710144922, \"y2\": 0.72463768115942, \"center_x\": 1.7391304347826084, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.00632779418348823}, {\"x\": 1.884057971014494, \"y\": 0.43478260869565233, \"x2\": 2.1739130434782616, \"y2\": 0.72463768115942, \"center_x\": 2.028985507246378, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.006805734324488883}, {\"x\": 2.1739130434782616, \"y\": 0.43478260869565233, \"x2\": 2.4637681159420293, \"y2\": 0.72463768115942, \"center_x\": 2.3188405797101455, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.007251760503493538}, {\"x\": 2.4637681159420293, \"y\": 0.43478260869565233, \"x2\": 2.753623188405797, \"y2\": 0.72463768115942, \"center_x\": 2.608695652173913, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.007655220918590051}, {\"x\": 2.753623188405797, \"y\": 0.43478260869565233, \"x2\": 3.0434782608695645, \"y2\": 0.72463768115942, \"center_x\": 2.8985507246376807, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.008006041159953762}, {\"x\": 3.0434782608695663, \"y\": 0.43478260869565233, \"x2\": 3.333333333333334, \"y2\": 0.72463768115942, \"center_x\": 3.18840579710145, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.008295140059495594}, {\"x\": 3.333333333333334, \"y\": 0.43478260869565233, \"x2\": 3.6231884057971016, \"y2\": 0.72463768115942, \"center_x\": 3.4782608695652177, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.008514819431164715}, {\"x\": 3.6231884057971016, \"y\": 0.43478260869565233, \"x2\": 3.913043478260869, \"y2\": 0.72463768115942, \"center_x\": 3.7681159420289854, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.008659104411376637}, {\"x\": 3.913043478260871, \"y\": 0.43478260869565233, \"x2\": 4.202898550724639, \"y2\": 0.72463768115942, \"center_x\": 4.057971014492755, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.008724013415689048}, {\"x\": 4.202898550724639, \"y\": 0.43478260869565233, \"x2\": 4.492753623188406, \"y2\": 0.72463768115942, \"center_x\": 4.347826086956522, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.008707740691430809}, {\"x\": 4.492753623188406, \"y\": 0.43478260869565233, \"x2\": 4.782608695652174, \"y2\": 0.72463768115942, \"center_x\": 4.63768115942029, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.008610739784765228}, {\"x\": 4.782608695652174, \"y\": 0.43478260869565233, \"x2\": 5.0724637681159415, \"y2\": 0.72463768115942, \"center_x\": 4.927536231884058, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.008435702537539325}, {\"x\": 5.072463768115943, \"y\": 0.43478260869565233, \"x2\": 5.362318840579711, \"y2\": 0.72463768115942, \"center_x\": 5.217391304347827, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.008187434971391197}, {\"x\": 5.362318840579711, \"y\": 0.43478260869565233, \"x2\": 5.6521739130434785, \"y2\": 0.72463768115942, \"center_x\": 5.507246376811595, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.007872638046252756}, {\"x\": 5.6521739130434785, \"y\": 0.43478260869565233, \"x2\": 5.942028985507246, \"y2\": 0.72463768115942, \"center_x\": 5.797101449275362, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0074996072512409475}, {\"x\": 5.942028985507246, \"y\": 0.43478260869565233, \"x2\": 6.231884057971014, \"y2\": 0.72463768115942, \"center_x\": 6.08695652173913, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.00707786981783574}, {\"x\": 6.2318840579710155, \"y\": 0.43478260869565233, \"x2\": 6.521739130434783, \"y2\": 0.72463768115942, \"center_x\": 6.376811594202899, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.006617781671290226}, {\"x\": 6.521739130434785, \"y\": 0.43478260869565233, \"x2\": 6.8115942028985526, \"y2\": 0.72463768115942, \"center_x\": 6.666666666666669, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.006130107836491764}, {\"x\": 6.811594202898551, \"y\": 0.43478260869565233, \"x2\": 7.101449275362318, \"y2\": 0.72463768115942, \"center_x\": 6.956521739130435, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.005625609832929387}, {\"x\": 7.10144927536232, \"y\": 0.43478260869565233, \"x2\": 7.391304347826088, \"y2\": 0.72463768115942, \"center_x\": 7.246376811594204, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.005114661736369161}, {\"x\": 7.391304347826086, \"y\": 0.43478260869565233, \"x2\": 7.681159420289854, \"y2\": 0.72463768115942, \"center_x\": 7.53623188405797, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.004606913302257929}, {\"x\": 7.681159420289855, \"y\": 0.43478260869565233, \"x2\": 7.971014492753623, \"y2\": 0.72463768115942, \"center_x\": 7.826086956521739, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.004111014198259955}, {\"x\": 7.971014492753625, \"y\": 0.43478260869565233, \"x2\": 8.260869565217392, \"y2\": 0.72463768115942, \"center_x\": 8.115942028985508, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0036344084090027774}, {\"x\": 8.26086956521739, \"y\": 0.43478260869565233, \"x2\": 8.550724637681158, \"y2\": 0.72463768115942, \"center_x\": 8.405797101449274, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0031832027044572447}, {\"x\": 8.55072463768116, \"y\": 0.43478260869565233, \"x2\": 8.840579710144928, \"y2\": 0.72463768115942, \"center_x\": 8.695652173913043, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0027621081296955365}, {\"x\": 8.84057971014493, \"y\": 0.43478260869565233, \"x2\": 9.130434782608697, \"y2\": 0.72463768115942, \"center_x\": 8.985507246376812, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0023744491406814394}, {\"x\": 9.130434782608695, \"y\": 0.43478260869565233, \"x2\": 9.420289855072463, \"y2\": 0.72463768115942, \"center_x\": 9.275362318840578, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.002022231549964005}, {\"x\": 9.420289855072465, \"y\": 0.43478260869565233, \"x2\": 9.710144927536232, \"y2\": 0.72463768115942, \"center_x\": 9.565217391304348, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0017062580226999535}, {\"x\": 9.710144927536234, \"y\": 0.43478260869565233, \"x2\": 10.000000000000002, \"y2\": 0.72463768115942, \"center_x\": 9.855072463768117, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0014262785327365166}, {\"x\": 10.0, \"y\": 0.43478260869565233, \"x2\": 10.289855072463768, \"y2\": 0.72463768115942, \"center_x\": 10.144927536231883, \"center_y\": 0.5797101449275361, \"value_uncond\": 0.0011811629050635496}, {\"x\": -10.0, \"y\": 0.72463768115942, \"x2\": -9.710144927536232, \"y2\": 1.0144927536231876, \"center_x\": -9.855072463768117, \"center_y\": 0.8695652173913038, \"value_uncond\": 1.8186695398019615e-07}, {\"x\": -9.710144927536232, \"y\": 0.72463768115942, \"x2\": -9.420289855072465, \"y2\": 1.0144927536231876, \"center_x\": -9.565217391304348, \"center_y\": 0.8695652173913038, \"value_uncond\": 2.841475121909858e-07}, {\"x\": -9.420289855072463, \"y\": 0.72463768115942, \"x2\": -9.130434782608695, \"y2\": 1.0144927536231876, \"center_x\": -9.275362318840578, \"center_y\": 0.8695652173913038, \"value_uncond\": 4.398248239312864e-07}, {\"x\": -9.130434782608695, \"y\": 0.72463768115942, \"x2\": -8.840579710144928, \"y2\": 1.0144927536231876, \"center_x\": -8.985507246376812, \"center_y\": 0.8695652173913038, \"value_uncond\": 6.744681274779165e-07}, {\"x\": -8.840579710144928, \"y\": 0.72463768115942, \"x2\": -8.55072463768116, \"y2\": 1.0144927536231876, \"center_x\": -8.695652173913043, \"center_y\": 0.8695652173913038, \"value_uncond\": 1.024681605709748e-06}, {\"x\": -8.55072463768116, \"y\": 0.72463768115942, \"x2\": -8.260869565217392, \"y2\": 1.0144927536231876, \"center_x\": -8.405797101449277, \"center_y\": 0.8695652173913038, \"value_uncond\": 1.5422765784592037e-06}, {\"x\": -8.26086956521739, \"y\": 0.72463768115942, \"x2\": -7.971014492753623, \"y2\": 1.0144927536231876, \"center_x\": -8.115942028985508, \"center_y\": 0.8695652173913038, \"value_uncond\": 2.2997540956322e-06}, {\"x\": -7.971014492753623, \"y\": 0.72463768115942, \"x2\": -7.681159420289855, \"y2\": 1.0144927536231876, \"center_x\": -7.826086956521739, \"center_y\": 0.8695652173913038, \"value_uncond\": 3.3973974241835387e-06}, {\"x\": -7.681159420289855, \"y\": 0.72463768115942, \"x2\": -7.391304347826088, \"y2\": 1.0144927536231876, \"center_x\": -7.536231884057972, \"center_y\": 0.8695652173913038, \"value_uncond\": 4.97229766828531e-06}, {\"x\": -7.391304347826087, \"y\": 0.72463768115942, \"x2\": -7.101449275362319, \"y2\": 1.0144927536231876, \"center_x\": -7.246376811594203, \"center_y\": 0.8695652173913038, \"value_uncond\": 7.209642019613979e-06}, {\"x\": -7.101449275362318, \"y\": 0.72463768115942, \"x2\": -6.811594202898551, \"y2\": 1.0144927536231876, \"center_x\": -6.956521739130435, \"center_y\": 0.8695652173913038, \"value_uncond\": 1.0356573628286171e-05}, {\"x\": -6.811594202898551, \"y\": 0.72463768115942, \"x2\": -6.521739130434783, \"y2\": 1.0144927536231876, \"center_x\": -6.666666666666667, \"center_y\": 0.8695652173913038, \"value_uncond\": 1.4738874043274142e-05}, {\"x\": -6.521739130434782, \"y\": 0.72463768115942, \"x2\": -6.231884057971015, \"y2\": 1.0144927536231876, \"center_x\": -6.3768115942028984, \"center_y\": 0.8695652173913038, \"value_uncond\": 2.078061193989797e-05}, {\"x\": -6.231884057971014, \"y\": 0.72463768115942, \"x2\": -5.942028985507246, \"y2\": 1.0144927536231876, \"center_x\": -6.08695652173913, \"center_y\": 0.8695652173913038, \"value_uncond\": 2.9026733914962152e-05}, {\"x\": -5.942028985507246, \"y\": 0.72463768115942, \"x2\": -5.6521739130434785, \"y2\": 1.0144927536231876, \"center_x\": -5.797101449275362, \"center_y\": 0.8695652173913038, \"value_uncond\": 4.0168334579425016e-05}, {\"x\": -5.6521739130434785, \"y\": 0.72463768115942, \"x2\": -5.362318840579711, \"y2\": 1.0144927536231876, \"center_x\": -5.507246376811595, \"center_y\": 0.8695652173913038, \"value_uncond\": 5.507002762581109e-05}, {\"x\": -5.36231884057971, \"y\": 0.72463768115942, \"x2\": -5.072463768115942, \"y2\": 1.0144927536231876, \"center_x\": -5.217391304347826, \"center_y\": 0.8695652173913038, \"value_uncond\": 7.47984463949287e-05}, {\"x\": -5.0724637681159415, \"y\": 0.72463768115942, \"x2\": -4.782608695652174, \"y2\": 1.0144927536231876, \"center_x\": -4.927536231884058, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.00010065043936580447}, {\"x\": -4.782608695652174, \"y\": 0.72463768115942, \"x2\": -4.492753623188406, \"y2\": 1.0144927536231876, \"center_x\": -4.63768115942029, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.00013417901122291513}, {\"x\": -4.492753623188405, \"y\": 0.72463768115942, \"x2\": -4.202898550724638, \"y2\": 1.0144927536231876, \"center_x\": -4.3478260869565215, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.00017721452454710887}, {\"x\": -4.202898550724638, \"y\": 0.72463768115942, \"x2\": -3.91304347826087, \"y2\": 1.0144927536231876, \"center_x\": -4.057971014492754, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.00023187816514453103}, {\"x\": -3.913043478260869, \"y\": 0.72463768115942, \"x2\": -3.6231884057971016, \"y2\": 1.0144927536231876, \"center_x\": -3.7681159420289854, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.00030058424322266115}, {\"x\": -3.6231884057971016, \"y\": 0.72463768115942, \"x2\": -3.333333333333334, \"y2\": 1.0144927536231876, \"center_x\": -3.4782608695652177, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0003860276217674317}, {\"x\": -3.333333333333333, \"y\": 0.72463768115942, \"x2\": -3.0434782608695654, \"y2\": 1.0144927536231876, \"center_x\": -3.1884057971014492, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.000491152508044845}, {\"x\": -3.0434782608695645, \"y\": 0.72463768115942, \"x2\": -2.753623188405797, \"y2\": 1.0144927536231876, \"center_x\": -2.8985507246376807, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0006190990897675365}, {\"x\": -2.753623188405797, \"y\": 0.72463768115942, \"x2\": -2.4637681159420293, \"y2\": 1.0144927536231876, \"center_x\": -2.608695652173913, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0007731251111857775}, {\"x\": -2.4637681159420284, \"y\": 0.72463768115942, \"x2\": -2.1739130434782608, \"y2\": 1.0144927536231876, \"center_x\": -2.3188405797101446, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0009565005143708588}, {\"x\": -2.1739130434782608, \"y\": 0.72463768115942, \"x2\": -1.8840579710144931, \"y2\": 1.0144927536231876, \"center_x\": -2.028985507246377, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.001172374735623031}, {\"x\": -1.8840579710144922, \"y\": 0.72463768115942, \"x2\": -1.5942028985507246, \"y2\": 1.0144927536231876, \"center_x\": -1.7391304347826084, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0014236181244848623}, {\"x\": -1.5942028985507246, \"y\": 0.72463768115942, \"x2\": -1.304347826086957, \"y2\": 1.0144927536231876, \"center_x\": -1.4492753623188408, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0017126411732490106}, {\"x\": -1.304347826086957, \"y\": 0.72463768115942, \"x2\": -1.0144927536231894, \"y2\": 1.0144927536231876, \"center_x\": -1.1594202898550732, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0020411976855896296}, {\"x\": -1.0144927536231876, \"y\": 0.72463768115942, \"x2\": -0.72463768115942, \"y2\": 1.0144927536231876, \"center_x\": -0.8695652173913038, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0024101805001465397}, {\"x\": -0.72463768115942, \"y\": 0.72463768115942, \"x2\": -0.43478260869565233, \"y2\": 1.0144927536231876, \"center_x\": -0.5797101449275361, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0028194207010446004}, {\"x\": -0.43478260869565233, \"y\": 0.72463768115942, \"x2\": -0.1449275362318847, \"y2\": 1.0144927536231876, \"center_x\": -0.2898550724637685, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.003267503146040521}, {\"x\": -0.14492753623188293, \"y\": 0.72463768115942, \"x2\": 0.1449275362318847, \"y2\": 1.0144927536231876, \"center_x\": 8.881784197001252e-16, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.003751612370341276}, {\"x\": 0.1449275362318847, \"y\": 0.72463768115942, \"x2\": 0.43478260869565233, \"y2\": 1.0144927536231876, \"center_x\": 0.2898550724637685, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0042674232452736}, {\"x\": 0.43478260869565233, \"y\": 0.72463768115942, \"x2\": 0.72463768115942, \"y2\": 1.0144927536231876, \"center_x\": 0.5797101449275361, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.004809049999432688}, {\"x\": 0.72463768115942, \"y\": 0.72463768115942, \"x2\": 1.0144927536231876, \"y2\": 1.0144927536231876, \"center_x\": 0.8695652173913038, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.00536906523642159}, {\"x\": 1.0144927536231894, \"y\": 0.72463768115942, \"x2\": 1.304347826086957, \"y2\": 1.0144927536231876, \"center_x\": 1.1594202898550732, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.005938597400192714}, {\"x\": 1.304347826086957, \"y\": 0.72463768115942, \"x2\": 1.5942028985507246, \"y2\": 1.0144927536231876, \"center_x\": 1.4492753623188408, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.006507510856650965}, {\"x\": 1.5942028985507246, \"y\": 0.72463768115942, \"x2\": 1.8840579710144922, \"y2\": 1.0144927536231876, \"center_x\": 1.7391304347826084, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.007064667611649967}, {\"x\": 1.884057971014494, \"y\": 0.72463768115942, \"x2\": 2.1739130434782616, \"y2\": 1.0144927536231876, \"center_x\": 2.028985507246378, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.007598264017684372}, {\"x\": 2.1739130434782616, \"y\": 0.72463768115942, \"x2\": 2.4637681159420293, \"y2\": 1.0144927536231876, \"center_x\": 2.3188405797101455, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.008096230071792845}, {\"x\": 2.4637681159420293, \"y\": 0.72463768115942, \"x2\": 2.753623188405797, \"y2\": 1.0144927536231876, \"center_x\": 2.608695652173913, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.008546673566708152}, {\"x\": 2.753623188405797, \"y\": 0.72463768115942, \"x2\": 3.0434782608695645, \"y2\": 1.0144927536231876, \"center_x\": 2.8985507246376807, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.008938346924722965}, {\"x\": 3.0434782608695663, \"y\": 0.72463768115942, \"x2\": 3.333333333333334, \"y2\": 1.0144927536231876, \"center_x\": 3.18840579710145, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.009261111473147475}, {\"x\": 3.333333333333334, \"y\": 0.72463768115942, \"x2\": 3.6231884057971016, \"y2\": 1.0144927536231876, \"center_x\": 3.4782608695652177, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.009506372569980895}, {\"x\": 3.6231884057971016, \"y\": 0.72463768115942, \"x2\": 3.913043478260869, \"y2\": 1.0144927536231876, \"center_x\": 3.7681159420289854, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.00966745957707897}, {\"x\": 3.913043478260871, \"y\": 0.72463768115942, \"x2\": 4.202898550724639, \"y2\": 1.0144927536231876, \"center_x\": 4.057971014492755, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.009739927253361315}, {\"x\": 4.202898550724639, \"y\": 0.72463768115942, \"x2\": 4.492753623188406, \"y2\": 1.0144927536231876, \"center_x\": 4.347826086956522, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.009721759565745862}, {\"x\": 4.492753623188406, \"y\": 0.72463768115942, \"x2\": 4.782608695652174, \"y2\": 1.0144927536231876, \"center_x\": 4.63768115942029, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.00961346287597533}, {\"x\": 4.782608695652174, \"y\": 0.72463768115942, \"x2\": 5.0724637681159415, \"y2\": 1.0144927536231876, \"center_x\": 4.927536231884058, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.009418042491643623}, {\"x\": 5.072463768115943, \"y\": 0.72463768115942, \"x2\": 5.362318840579711, \"y2\": 1.0144927536231876, \"center_x\": 5.217391304347827, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.009140864096972293}, {\"x\": 5.362318840579711, \"y\": 0.72463768115942, \"x2\": 5.6521739130434785, \"y2\": 1.0144927536231876, \"center_x\": 5.507246376811595, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.008789408980578704}, {\"x\": 5.6521739130434785, \"y\": 0.72463768115942, \"x2\": 5.942028985507246, \"y2\": 1.0144927536231876, \"center_x\": 5.797101449275362, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.008372938643641286}, {\"x\": 5.942028985507246, \"y\": 0.72463768115942, \"x2\": 6.231884057971014, \"y2\": 1.0144927536231876, \"center_x\": 6.08695652173913, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.007902089766449183}, {\"x\": 6.2318840579710155, \"y\": 0.72463768115942, \"x2\": 6.521739130434783, \"y2\": 1.0144927536231876, \"center_x\": 6.376811594202899, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.007388424224689674}, {\"x\": 6.521739130434785, \"y\": 0.72463768115942, \"x2\": 6.8115942028985526, \"y2\": 1.0144927536231876, \"center_x\": 6.666666666666669, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.006843960633452795}, {\"x\": 6.811594202898551, \"y\": 0.72463768115942, \"x2\": 7.101449275362318, \"y2\": 1.0144927536231876, \"center_x\": 6.956521739130435, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.006280713694225632}, {\"x\": 7.10144927536232, \"y\": 0.72463768115942, \"x2\": 7.391304347826088, \"y2\": 1.0144927536231876, \"center_x\": 7.246376811594204, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0057102655468408235}, {\"x\": 7.391304347826086, \"y\": 0.72463768115942, \"x2\": 7.681159420289854, \"y2\": 1.0144927536231876, \"center_x\": 7.53623188405797, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.00514338966350509}, {\"x\": 7.681159420289855, \"y\": 0.72463768115942, \"x2\": 7.971014492753623, \"y2\": 1.0144927536231876, \"center_x\": 7.826086956521739, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.004589742968136519}, {\"x\": 7.971014492753625, \"y\": 0.72463768115942, \"x2\": 8.260869565217392, \"y2\": 1.0144927536231876, \"center_x\": 8.115942028985508, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.004057636299484735}, {\"x\": 8.26086956521739, \"y\": 0.72463768115942, \"x2\": 8.550724637681158, \"y2\": 1.0144927536231876, \"center_x\": 8.405797101449274, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0035538875626164724}, {\"x\": 8.55072463768116, \"y\": 0.72463768115942, \"x2\": 8.840579710144928, \"y2\": 1.0144927536231876, \"center_x\": 8.695652173913043, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.003083756405139314}, {\"x\": 8.84057971014493, \"y\": 0.72463768115942, \"x2\": 9.130434782608697, \"y2\": 1.0144927536231876, \"center_x\": 8.985507246376812, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.002650954416857332}, {\"x\": 9.130434782608695, \"y\": 0.72463768115942, \"x2\": 9.420289855072463, \"y2\": 1.0144927536231876, \"center_x\": 9.275362318840578, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.002257720987760062}, {\"x\": 9.420289855072465, \"y\": 0.72463768115942, \"x2\": 9.710144927536232, \"y2\": 1.0144927536231876, \"center_x\": 9.565217391304348, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0019049522535894748}, {\"x\": 9.710144927536234, \"y\": 0.72463768115942, \"x2\": 10.000000000000002, \"y2\": 1.0144927536231876, \"center_x\": 9.855072463768117, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0015923690725763713}, {\"x\": 10.0, \"y\": 0.72463768115942, \"x2\": 10.289855072463768, \"y2\": 1.0144927536231876, \"center_x\": 10.144927536231883, \"center_y\": 0.8695652173913038, \"value_uncond\": 0.0013187096605099884}, {\"x\": -10.0, \"y\": 1.0144927536231894, \"x2\": -9.710144927536232, \"y2\": 1.304347826086957, \"center_x\": -9.855072463768117, \"center_y\": 1.1594202898550732, \"value_uncond\": 2.0115878137617703e-07}, {\"x\": -9.710144927536232, \"y\": 1.0144927536231894, \"x2\": -9.420289855072465, \"y2\": 1.304347826086957, \"center_x\": -9.565217391304348, \"center_y\": 1.1594202898550732, \"value_uncond\": 3.1428891303493833e-07}, {\"x\": -9.420289855072463, \"y\": 1.0144927536231894, \"x2\": -9.130434782608695, \"y2\": 1.304347826086957, \"center_x\": -9.275362318840578, \"center_y\": 1.1594202898550732, \"value_uncond\": 4.864799440729798e-07}, {\"x\": -9.130434782608695, \"y\": 1.0144927536231894, \"x2\": -8.840579710144928, \"y2\": 1.304347826086957, \"center_x\": -8.985507246376812, \"center_y\": 1.1594202898550732, \"value_uncond\": 7.460134105248357e-07}, {\"x\": -8.840579710144928, \"y\": 1.0144927536231894, \"x2\": -8.55072463768116, \"y2\": 1.304347826086957, \"center_x\": -8.695652173913043, \"center_y\": 1.1594202898550732, \"value_uncond\": 1.1333763423870968e-06}, {\"x\": -8.55072463768116, \"y\": 1.0144927536231894, \"x2\": -8.260869565217392, \"y2\": 1.304347826086957, \"center_x\": -8.405797101449277, \"center_y\": 1.1594202898550732, \"value_uncond\": 1.705876027932241e-06}, {\"x\": -8.26086956521739, \"y\": 1.0144927536231894, \"x2\": -7.971014492753623, \"y2\": 1.304347826086957, \"center_x\": -8.115942028985508, \"center_y\": 1.1594202898550732, \"value_uncond\": 2.5437041816438e-06}, {\"x\": -7.971014492753623, \"y\": 1.0144927536231894, \"x2\": -7.681159420289855, \"y2\": 1.304347826086957, \"center_x\": -7.826086956521739, \"center_y\": 1.1594202898550732, \"value_uncond\": 3.757781778066953e-06}, {\"x\": -7.681159420289855, \"y\": 1.0144927536231894, \"x2\": -7.391304347826088, \"y2\": 1.304347826086957, \"center_x\": -7.536231884057972, \"center_y\": 1.1594202898550732, \"value_uncond\": 5.499742079040889e-06}, {\"x\": -7.391304347826087, \"y\": 1.0144927536231894, \"x2\": -7.101449275362319, \"y2\": 1.304347826086957, \"center_x\": -7.246376811594203, \"center_y\": 1.1594202898550732, \"value_uncond\": 7.97441630315065e-06}, {\"x\": -7.101449275362318, \"y\": 1.0144927536231894, \"x2\": -6.811594202898551, \"y2\": 1.304347826086957, \"center_x\": -6.956521739130435, \"center_y\": 1.1594202898550732, \"value_uncond\": 1.1455163704592264e-05}, {\"x\": -6.811594202898551, \"y\": 1.0144927536231894, \"x2\": -6.521739130434783, \"y2\": 1.304347826086957, \"center_x\": -6.666666666666667, \"center_y\": 1.1594202898550732, \"value_uncond\": 1.6302323630079804e-05}, {\"x\": -6.521739130434782, \"y\": 1.0144927536231894, \"x2\": -6.231884057971015, \"y2\": 1.304347826086957, \"center_x\": -6.3768115942028984, \"center_y\": 1.1594202898550732, \"value_uncond\": 2.2984948516464915e-05}, {\"x\": -6.231884057971014, \"y\": 1.0144927536231894, \"x2\": -5.942028985507246, \"y2\": 1.304347826086957, \"center_x\": -6.08695652173913, \"center_y\": 1.1594202898550732, \"value_uncond\": 3.210579104052153e-05}, {\"x\": -5.942028985507246, \"y\": 1.0144927536231894, \"x2\": -5.6521739130434785, \"y2\": 1.304347826086957, \"center_x\": -5.797101449275362, \"center_y\": 1.1594202898550732, \"value_uncond\": 4.442925477702533e-05}, {\"x\": -5.6521739130434785, \"y\": 1.0144927536231894, \"x2\": -5.362318840579711, \"y2\": 1.304347826086957, \"center_x\": -5.507246376811595, \"center_y\": 1.1594202898550732, \"value_uncond\": 6.09116686958249e-05}, {\"x\": -5.36231884057971, \"y\": 1.0144927536231894, \"x2\": -5.072463768115942, \"y2\": 1.304347826086957, \"center_x\": -5.217391304347826, \"center_y\": 1.1594202898550732, \"value_uncond\": 8.273281097165984e-05}, {\"x\": -5.0724637681159415, \"y\": 1.0144927536231894, \"x2\": -4.782608695652174, \"y2\": 1.304347826086957, \"center_x\": -4.927536231884058, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.00011132709535568892}, {\"x\": -4.782608695652174, \"y\": 1.0144927536231894, \"x2\": -4.492753623188406, \"y2\": 1.304347826086957, \"center_x\": -4.63768115942029, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.00014841226398282928}, {\"x\": -4.492753623188405, \"y\": 1.0144927536231894, \"x2\": -4.202898550724638, \"y2\": 1.304347826086957, \"center_x\": -4.3478260869565215, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0001960128380658796}, {\"x\": -4.202898550724638, \"y\": 1.0144927536231894, \"x2\": -3.91304347826087, \"y2\": 1.304347826086957, \"center_x\": -4.057971014492754, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0002564750115807015}, {\"x\": -3.913043478260869, \"y\": 1.0144927536231894, \"x2\": -3.6231884057971016, \"y2\": 1.304347826086957, \"center_x\": -3.7681159420289854, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0003324691965431773}, {\"x\": -3.6231884057971016, \"y\": 1.0144927536231894, \"x2\": -3.333333333333334, \"y2\": 1.304347826086957, \"center_x\": -3.4782608695652177, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0004269761178313679}, {\"x\": -3.333333333333333, \"y\": 1.0144927536231894, \"x2\": -3.0434782608695654, \"y2\": 1.304347826086957, \"center_x\": -3.1884057971014492, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0005432522941958565}, {\"x\": -3.0434782608695645, \"y\": 1.0144927536231894, \"x2\": -2.753623188405797, \"y2\": 1.304347826086957, \"center_x\": -2.8985507246376807, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0006847710137725129}, {\"x\": -2.753623188405797, \"y\": 1.0144927536231894, \"x2\": -2.4637681159420293, \"y2\": 1.304347826086957, \"center_x\": -2.608695652173913, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0008551355912321876}, {\"x\": -2.4637681159420284, \"y\": 1.0144927536231894, \"x2\": -2.1739130434782608, \"y2\": 1.304347826086957, \"center_x\": -2.3188405797101446, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0010579628329700835}, {\"x\": -2.1739130434782608, \"y\": 1.0144927536231894, \"x2\": -1.8840579710144931, \"y2\": 1.304347826086957, \"center_x\": -2.028985507246377, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0012967362567683765}, {\"x\": -1.8840579710144922, \"y\": 1.0144927536231894, \"x2\": -1.5942028985507246, \"y2\": 1.304347826086957, \"center_x\": -1.7391304347826084, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.001574630689078329}, {\"x\": -1.5942028985507246, \"y\": 1.0144927536231894, \"x2\": -1.304347826086957, \"y2\": 1.304347826086957, \"center_x\": -1.4492753623188408, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0018943123190095946}, {\"x\": -1.304347826086957, \"y\": 1.0144927536231894, \"x2\": -1.0144927536231894, \"y2\": 1.304347826086957, \"center_x\": -1.1594202898550732, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.002257720987760061}, {\"x\": -1.0144927536231876, \"y\": 1.0144927536231894, \"x2\": -0.72463768115942, \"y2\": 1.304347826086957, \"center_x\": -0.8695652173913038, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.002665844243253208}, {\"x\": -0.72463768115942, \"y\": 1.0144927536231894, \"x2\": -0.43478260869565233, \"y2\": 1.304347826086957, \"center_x\": -0.5797101449275361, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0031184952515928535}, {\"x\": -0.43478260869565233, \"y\": 1.0144927536231894, \"x2\": -0.1449275362318847, \"y2\": 1.304347826086957, \"center_x\": -0.2898550724637685, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.003614108757063738}, {\"x\": -0.14492753623188293, \"y\": 1.0144927536231894, \"x2\": 0.1449275362318847, \"y2\": 1.304347826086957, \"center_x\": 8.881784197001252e-16, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.004149570639951545}, {\"x\": 0.1449275362318847, \"y\": 1.0144927536231894, \"x2\": 0.43478260869565233, \"y2\": 1.304347826086957, \"center_x\": 0.2898550724637685, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.004720096976656257}, {\"x\": 0.43478260869565233, \"y\": 1.0144927536231894, \"x2\": 0.72463768115942, \"y2\": 1.304347826086957, \"center_x\": 0.5797101449275361, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.005319177653177842}, {\"x\": 0.72463768115942, \"y\": 1.0144927536231894, \"x2\": 1.0144927536231876, \"y2\": 1.304347826086957, \"center_x\": 0.8695652173913038, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.005938597400192714}, {\"x\": 1.0144927536231894, \"y\": 1.0144927536231894, \"x2\": 1.304347826086957, \"y2\": 1.304347826086957, \"center_x\": 1.1594202898550732, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.006568543597186876}, {\"x\": 1.304347826086957, \"y\": 1.0144927536231894, \"x2\": 1.5942028985507246, \"y2\": 1.304347826086957, \"center_x\": 1.4492753623188408, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.007197805456502516}, {\"x\": 1.5942028985507246, \"y\": 1.0144927536231894, \"x2\": 1.8840579710144922, \"y2\": 1.304347826086957, \"center_x\": 1.7391304347826084, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.007814063503488382}, {\"x\": 1.884057971014494, \"y\": 1.0144927536231894, \"x2\": 2.1739130434782616, \"y2\": 1.304347826086957, \"center_x\": 2.028985507246378, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.00840426199989184}, {\"x\": 2.1739130434782616, \"y\": 1.0144927536231894, \"x2\": 2.4637681159420293, \"y2\": 1.304347826086957, \"center_x\": 2.3188405797101455, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.008955050597924176}, {\"x\": 2.4637681159420293, \"y\": 1.0144927536231894, \"x2\": 2.753623188405797, \"y2\": 1.304347826086957, \"center_x\": 2.608695652173913, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.00945327560545279}, {\"x\": 2.753623188405797, \"y\": 1.0144927536231894, \"x2\": 3.0434782608695645, \"y2\": 1.304347826086957, \"center_x\": 2.8985507246376807, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.009886496340014353}, {\"x\": 3.0434782608695663, \"y\": 1.0144927536231894, \"x2\": 3.333333333333334, \"y2\": 1.304347826086957, \"center_x\": 3.18840579710145, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.010243498653032564}, {\"x\": 3.333333333333334, \"y\": 1.0144927536231894, \"x2\": 3.6231884057971016, \"y2\": 1.304347826086957, \"center_x\": 3.4782608695652177, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.010514776212139686}, {\"x\": 3.6231884057971016, \"y\": 1.0144927536231894, \"x2\": 3.913043478260869, \"y2\": 1.304347826086957, \"center_x\": 3.7681159420289854, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.01069295078060424}, {\"x\": 3.913043478260871, \"y\": 1.0144927536231894, \"x2\": 4.202898550724639, \"y2\": 1.304347826086957, \"center_x\": 4.057971014492755, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.010773105581303807}, {\"x\": 4.202898550724639, \"y\": 1.0144927536231894, \"x2\": 4.492753623188406, \"y2\": 1.304347826086957, \"center_x\": 4.347826086956522, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.010753010727229628}, {\"x\": 4.492753623188406, \"y\": 1.0144927536231894, \"x2\": 4.782608695652174, \"y2\": 1.304347826086957, \"center_x\": 4.63768115942029, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.010633226293254413}, {\"x\": 4.782608695652174, \"y\": 1.0144927536231894, \"x2\": 5.0724637681159415, \"y2\": 1.304347826086957, \"center_x\": 4.927536231884058, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.010417076379771448}, {\"x\": 5.072463768115943, \"y\": 1.0144927536231894, \"x2\": 5.362318840579711, \"y2\": 1.304347826086957, \"center_x\": 5.217391304347827, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0101104958445195}, {\"x\": 5.362318840579711, \"y\": 1.0144927536231894, \"x2\": 5.6521739130434785, \"y2\": 1.304347826086957, \"center_x\": 5.507246376811595, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.009721759565745867}, {\"x\": 5.6521739130434785, \"y\": 1.0144927536231894, \"x2\": 5.942028985507246, \"y2\": 1.304347826086957, \"center_x\": 5.797101449275362, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.009261111473147477}, {\"x\": 5.942028985507246, \"y\": 1.0144927536231894, \"x2\": 6.231884057971014, \"y2\": 1.304347826086957, \"center_x\": 6.08695652173913, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.008740316549850866}, {\"x\": 6.2318840579710155, \"y\": 1.0144927536231894, \"x2\": 6.521739130434783, \"y2\": 1.304347826086957, \"center_x\": 6.376811594202899, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.008172163115959143}, {\"x\": 6.521739130434785, \"y\": 1.0144927536231894, \"x2\": 6.8115942028985526, \"y2\": 1.304347826086957, \"center_x\": 6.666666666666669, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0075699446803392575}, {\"x\": 6.811594202898551, \"y\": 1.0144927536231894, \"x2\": 7.101449275362318, \"y2\": 1.304347826086957, \"center_x\": 6.956521739130435, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.006946950423113533}, {\"x\": 7.10144927536232, \"y\": 1.0144927536231894, \"x2\": 7.391304347826088, \"y2\": 1.304347826086957, \"center_x\": 7.246376811594204, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.006315991078081992}, {\"x\": 7.391304347826086, \"y\": 1.0144927536231894, \"x2\": 7.681159420289854, \"y2\": 1.304347826086957, \"center_x\": 7.53623188405797, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0056889829307097284}, {\"x\": 7.681159420289855, \"y\": 1.0144927536231894, \"x2\": 7.971014492753623, \"y2\": 1.304347826086957, \"center_x\": 7.826086956521739, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0050766072785315055}, {\"x\": 7.971014492753625, \"y\": 1.0144927536231894, \"x2\": 8.260869565217392, \"y2\": 1.304347826086957, \"center_x\": 8.115942028985508, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.004488056545781094}, {\"x\": 8.26086956521739, \"y\": 1.0144927536231894, \"x2\": 8.550724637681158, \"y2\": 1.304347826086957, \"center_x\": 8.405797101449274, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.003930871857686288}, {\"x\": 8.55072463768116, \"y\": 1.0144927536231894, \"x2\": 8.840579710144928, \"y2\": 1.304347826086957, \"center_x\": 8.695652173913043, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0034108707873688375}, {\"x\": 8.84057971014493, \"y\": 1.0144927536231894, \"x2\": 9.130434782608697, \"y2\": 1.304347826086957, \"center_x\": 8.985507246376812, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0029321586374448324}, {\"x\": 9.130434782608695, \"y\": 1.0144927536231894, \"x2\": 9.420289855072463, \"y2\": 1.304347826086957, \"center_x\": 9.275362318840578, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0024972123447709275}, {\"x\": 9.420289855072465, \"y\": 1.0144927536231894, \"x2\": 9.710144927536232, \"y2\": 1.304347826086957, \"center_x\": 9.565217391304348, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.00210702310411812}, {\"x\": 9.710144927536234, \"y\": 1.0144927536231894, \"x2\": 10.000000000000002, \"y2\": 1.304347826086957, \"center_x\": 9.855072463768117, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0017612821633085447}, {\"x\": 10.0, \"y\": 1.0144927536231894, \"x2\": 10.289855072463768, \"y2\": 1.304347826086957, \"center_x\": 10.144927536231883, \"center_y\": 1.1594202898550732, \"value_uncond\": 0.0014585938923575234}, {\"x\": -10.0, \"y\": 1.304347826086957, \"x2\": -9.710144927536232, \"y2\": 1.5942028985507246, \"center_x\": -9.855072463768117, \"center_y\": 1.4492753623188408, \"value_uncond\": 2.2042965122937443e-07}, {\"x\": -9.710144927536232, \"y\": 1.304347826086957, \"x2\": -9.420289855072465, \"y2\": 1.5942028985507246, \"center_x\": -9.565217391304348, \"center_y\": 1.4492753623188408, \"value_uncond\": 3.4439756997730165e-07}, {\"x\": -9.420289855072463, \"y\": 1.304347826086957, \"x2\": -9.130434782608695, \"y2\": 1.5942028985507246, \"center_x\": -9.275362318840578, \"center_y\": 1.4492753623188408, \"value_uncond\": 5.330843807487501e-07}, {\"x\": -9.130434782608695, \"y\": 1.304347826086957, \"x2\": -8.840579710144928, \"y2\": 1.5942028985507246, \"center_x\": -8.985507246376812, \"center_y\": 1.4492753623188408, \"value_uncond\": 8.17480970850127e-07}, {\"x\": -8.840579710144928, \"y\": 1.304347826086957, \"x2\": -8.55072463768116, \"y2\": 1.5942028985507246, \"center_x\": -8.695652173913043, \"center_y\": 1.4492753623188408, \"value_uncond\": 1.241952999291727e-06}, {\"x\": -8.55072463768116, \"y\": 1.304347826086957, \"x2\": -8.260869565217392, \"y2\": 1.5942028985507246, \"center_x\": -8.405797101449277, \"center_y\": 1.4492753623188408, \"value_uncond\": 1.8692977522789205e-06}, {\"x\": -8.26086956521739, \"y\": 1.304347826086957, \"x2\": -7.971014492753623, \"y2\": 1.5942028985507246, \"center_x\": -8.115942028985508, \"center_y\": 1.4492753623188408, \"value_uncond\": 2.7873892541727638e-06}, {\"x\": -7.971014492753623, \"y\": 1.304347826086957, \"x2\": -7.681159420289855, \"y2\": 1.5942028985507246, \"center_x\": -7.826086956521739, \"center_y\": 1.4492753623188408, \"value_uncond\": 4.117774630909027e-06}, {\"x\": -7.681159420289855, \"y\": 1.304347826086957, \"x2\": -7.391304347826088, \"y2\": 1.5942028985507246, \"center_x\": -7.536231884057972, \"center_y\": 1.4492753623188408, \"value_uncond\": 6.026613504221936e-06}, {\"x\": -7.391304347826087, \"y\": 1.304347826086957, \"x2\": -7.101449275362319, \"y2\": 1.5942028985507246, \"center_x\": -7.246376811594203, \"center_y\": 1.4492753623188408, \"value_uncond\": 8.738359779452854e-06}, {\"x\": -7.101449275362318, \"y\": 1.304347826086957, \"x2\": -6.811594202898551, \"y2\": 1.5942028985507246, \"center_x\": -6.956521739130435, \"center_y\": 1.4492753623188408, \"value_uncond\": 1.2552560335194498e-05}, {\"x\": -6.811594202898551, \"y\": 1.304347826086957, \"x2\": -6.521739130434783, \"y2\": 1.5942028985507246, \"center_x\": -6.666666666666667, \"center_y\": 1.4492753623188408, \"value_uncond\": 1.7864074774279058e-05}, {\"x\": -6.521739130434782, \"y\": 1.304347826086957, \"x2\": -6.231884057971015, \"y2\": 1.5942028985507246, \"center_x\": -6.3768115942028984, \"center_y\": 1.4492753623188408, \"value_uncond\": 2.5186890427292652e-05}, {\"x\": -6.231884057971014, \"y\": 1.304347826086957, \"x2\": -5.942028985507246, \"y2\": 1.5942028985507246, \"center_x\": -6.08695652173913, \"center_y\": 1.4492753623188408, \"value_uncond\": 3.518150325374492e-05}, {\"x\": -5.942028985507246, \"y\": 1.304347826086957, \"x2\": -5.6521739130434785, \"y2\": 1.5942028985507246, \"center_x\": -5.797101449275362, \"center_y\": 1.4492753623188408, \"value_uncond\": 4.8685546153544873e-05}, {\"x\": -5.6521739130434785, \"y\": 1.304347826086957, \"x2\": -5.362318840579711, \"y2\": 1.5942028985507246, \"center_x\": -5.507246376811595, \"center_y\": 1.4492753623188408, \"value_uncond\": 6.674696373961032e-05}, {\"x\": -5.36231884057971, \"y\": 1.304347826086957, \"x2\": -5.072463768115942, \"y2\": 1.5942028985507246, \"center_x\": -5.217391304347826, \"center_y\": 1.4492753623188408, \"value_uncond\": 9.065855610650711e-05}, {\"x\": -5.0724637681159415, \"y\": 1.304347826086957, \"x2\": -4.782608695652174, \"y2\": 1.5942028985507246, \"center_x\": -4.927536231884058, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.00012199215283444759}, {\"x\": -4.782608695652174, \"y\": 1.304347826086957, \"x2\": -4.492753623188406, \"y2\": 1.5942028985507246, \"center_x\": -4.63768115942029, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.00016263005454740363}, {\"x\": -4.492753623188405, \"y\": 1.304347826086957, \"x2\": -4.202898550724638, \"y2\": 1.5942028985507246, \"center_x\": -4.3478260869565215, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0002147907301672421}, {\"x\": -4.202898550724638, \"y\": 1.304347826086957, \"x2\": -3.91304347826087, \"y2\": 1.5942028985507246, \"center_x\": -4.057971014492754, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0002810451374034776}, {\"x\": -3.913043478260869, \"y\": 1.304347826086957, \"x2\": -3.6231884057971016, \"y2\": 1.5942028985507246, \"center_x\": -3.7681159420289854, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.00036431951186597375}, {\"x\": -3.6231884057971016, \"y\": 1.304347826086957, \"x2\": -3.333333333333334, \"y2\": 1.5942028985507246, \"center_x\": -3.4782608695652177, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0004678801297808369}, {\"x\": -3.333333333333333, \"y\": 1.304347826086957, \"x2\": -3.0434782608695654, \"y2\": 1.5942028985507246, \"center_x\": -3.1884057971014492, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0005952954821058184}, {\"x\": -3.0434782608695645, \"y\": 1.304347826086957, \"x2\": -2.753623188405797, \"y2\": 1.5942028985507246, \"center_x\": -2.8985507246376807, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0007503715955386884}, {\"x\": -2.753623188405797, \"y\": 1.304347826086957, \"x2\": -2.4637681159420293, \"y2\": 1.5942028985507246, \"center_x\": -2.608695652173913, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0009370569797628511}, {\"x\": -2.4637681159420284, \"y\": 1.304347826086957, \"x2\": -2.1739130434782608, \"y2\": 1.5942028985507246, \"center_x\": -2.3188405797101446, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0011593149286837688}, {\"x\": -2.1739130434782608, \"y\": 1.304347826086957, \"x2\": -1.8840579710144931, \"y2\": 1.5942028985507246, \"center_x\": -2.028985507246377, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0014209626786384445}, {\"x\": -1.8840579710144922, \"y\": 1.304347826086957, \"x2\": -1.5942028985507246, \"y2\": 1.5942028985507246, \"center_x\": -1.7391304347826084, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0017254792022204585}, {\"x\": -1.5942028985507246, \"y\": 1.304347826086957, \"x2\": -1.304347826086957, \"y2\": 1.5942028985507246, \"center_x\": -1.4492753623188408, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0020757861075819967}, {\"x\": -1.304347826086957, \"y\": 1.304347826086957, \"x2\": -1.0144927536231894, \"y2\": 1.5942028985507246, \"center_x\": -1.1594202898550732, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.002474009071344113}, {\"x\": -1.0144927536231876, \"y\": 1.304347826086957, \"x2\": -0.72463768115942, \"y2\": 1.5942028985507246, \"center_x\": -0.8695652173913038, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.002921230247827166}, {\"x\": -0.72463768115942, \"y\": 1.304347826086957, \"x2\": -0.43478260869565233, \"y2\": 1.5942028985507246, \"center_x\": -0.5797101449275361, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0034172449045790543}, {\"x\": -0.43478260869565233, \"y\": 1.304347826086957, \"x2\": -0.1449275362318847, \"y2\": 1.5942028985507246, \"center_x\": -0.2898550724637685, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.003960337835487279}, {\"x\": -0.14492753623188293, \"y\": 1.304347826086957, \"x2\": 0.1449275362318847, \"y2\": 1.5942028985507246, \"center_x\": 8.881784197001252e-16, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.004547096590357931}, {\"x\": 0.1449275362318847, \"y\": 1.304347826086957, \"x2\": 0.43478260869565233, \"y2\": 1.5942028985507246, \"center_x\": 0.2898550724637685, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.005172278949072928}, {\"x\": 0.43478260869565233, \"y\": 1.304347826086957, \"x2\": 0.72463768115942, \"y2\": 1.5942028985507246, \"center_x\": 0.5797101449275361, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.005828751133287251}, {\"x\": 0.72463768115942, \"y\": 1.304347826086957, \"x2\": 1.0144927536231876, \"y2\": 1.5942028985507246, \"center_x\": 0.8695652173913038, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.006507510856650965}, {\"x\": 1.0144927536231894, \"y\": 1.304347826086957, \"x2\": 1.304347826086957, \"y2\": 1.5942028985507246, \"center_x\": 1.1594202898550732, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.007197805456502516}, {\"x\": 1.304347826086957, \"y\": 1.304347826086957, \"x2\": 1.5942028985507246, \"y2\": 1.5942028985507246, \"center_x\": 1.4492753623188408, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.007887350159606992}, {\"x\": 1.5942028985507246, \"y\": 1.304347826086957, \"x2\": 1.8840579710144922, \"y2\": 1.5942028985507246, \"center_x\": 1.7391304347826084, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.008562645294301409}, {\"x\": 1.884057971014494, \"y\": 1.304347826086957, \"x2\": 2.1739130434782616, \"y2\": 1.5942028985507246, \"center_x\": 2.028985507246378, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.009209384391785931}, {\"x\": 2.1739130434782616, \"y\": 1.304347826086957, \"x2\": 2.4637681159420293, \"y2\": 1.5942028985507246, \"center_x\": 2.3188405797101455, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.009812938150338193}, {\"x\": 2.4637681159420293, \"y\": 1.304347826086957, \"x2\": 2.753623188405797, \"y2\": 1.5942028985507246, \"center_x\": 2.608695652173913, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.010358892763365544}, {\"x\": 2.753623188405797, \"y\": 1.304347826086957, \"x2\": 3.0434782608695645, \"y2\": 1.5942028985507246, \"center_x\": 2.8985507246376807, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.010833615739769736}, {\"x\": 3.0434782608695663, \"y\": 1.304347826086957, \"x2\": 3.333333333333334, \"y2\": 1.5942028985507246, \"center_x\": 3.18840579710145, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.01122481862342373}, {\"x\": 3.333333333333334, \"y\": 1.304347826086957, \"x2\": 3.6231884057971016, \"y2\": 1.5942028985507246, \"center_x\": 3.4782608695652177, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.011522084382001354}, {\"x\": 3.6231884057971016, \"y\": 1.304347826086957, \"x2\": 3.913043478260869, \"y2\": 1.5942028985507246, \"center_x\": 3.7681159420289854, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.011717327948878703}, {\"x\": 3.913043478260871, \"y\": 1.304347826086957, \"x2\": 4.202898550724639, \"y2\": 1.5942028985507246, \"center_x\": 4.057971014492755, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.01180516152314124}, {\"x\": 4.202898550724639, \"y\": 1.304347826086957, \"x2\": 4.492753623188406, \"y2\": 1.5942028985507246, \"center_x\": 4.347826086956522, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.011783141596172239}, {\"x\": 4.492753623188406, \"y\": 1.304347826086957, \"x2\": 4.782608695652174, \"y2\": 1.5942028985507246, \"center_x\": 4.63768115942029, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.011651881897623518}, {\"x\": 4.782608695652174, \"y\": 1.304347826086957, \"x2\": 5.0724637681159415, \"y2\": 1.5942028985507246, \"center_x\": 4.927536231884058, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.011415024974369399}, {\"x\": 5.072463768115943, \"y\": 1.304347826086957, \"x2\": 5.362318840579711, \"y2\": 1.5942028985507246, \"center_x\": 5.217391304347827, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.01107907423934817}, {\"x\": 5.362318840579711, \"y\": 1.304347826086957, \"x2\": 5.6521739130434785, \"y2\": 1.5942028985507246, \"center_x\": 5.507246376811595, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.010653097298326468}, {\"x\": 5.6521739130434785, \"y\": 1.304347826086957, \"x2\": 5.942028985507246, \"y2\": 1.5942028985507246, \"center_x\": 5.797101449275362, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.010148319442265323}, {\"x\": 5.942028985507246, \"y\": 1.304347826086957, \"x2\": 6.231884057971014, \"y2\": 1.5942028985507246, \"center_x\": 6.08695652173913, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.009577632731404702}, {\"x\": 6.2318840579710155, \"y\": 1.304347826086957, \"x2\": 6.521739130434783, \"y2\": 1.5942028985507246, \"center_x\": 6.376811594202899, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.008955050597924173}, {\"x\": 6.521739130434785, \"y\": 1.304347826086957, \"x2\": 6.8115942028985526, \"y2\": 1.5942028985507246, \"center_x\": 6.666666666666669, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.008295140059495587}, {\"x\": 6.811594202898551, \"y\": 1.304347826086957, \"x2\": 7.101449275362318, \"y2\": 1.5942028985507246, \"center_x\": 6.956521739130435, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.007612463390355489}, {\"x\": 7.10144927536232, \"y\": 1.304347826086957, \"x2\": 7.391304347826088, \"y2\": 1.5942028985507246, \"center_x\": 7.246376811594204, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.00692105858359676}, {\"x\": 7.391304347826086, \"y\": 1.304347826086957, \"x2\": 7.681159420289854, \"y2\": 1.5942028985507246, \"center_x\": 7.53623188405797, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.00623398349645561}, {\"x\": 7.681159420289855, \"y\": 1.304347826086957, \"x2\": 7.971014492753623, \"y2\": 1.5942028985507246, \"center_x\": 7.826086956521739, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.005562942687262318}, {\"x\": 7.971014492753625, \"y\": 1.304347826086957, \"x2\": 8.260869565217392, \"y2\": 1.5942028985507246, \"center_x\": 8.115942028985508, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0049180092080305235}, {\"x\": 8.26086956521739, \"y\": 1.304347826086957, \"x2\": 8.550724637681158, \"y2\": 1.5942028985507246, \"center_x\": 8.405797101449274, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.004307446618483881}, {\"x\": 8.55072463768116, \"y\": 1.304347826086957, \"x2\": 8.840579710144928, \"y2\": 1.5942028985507246, \"center_x\": 8.695652173913043, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.003737629811159793}, {\"x\": 8.84057971014493, \"y\": 1.304347826086957, \"x2\": 9.130434782608697, \"y2\": 1.5942028985507246, \"center_x\": 8.985507246376812, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0032130573737791934}, {\"x\": 9.130434782608695, \"y\": 1.304347826086957, \"x2\": 9.420289855072463, \"y2\": 1.5942028985507246, \"center_x\": 9.275362318840578, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.002736443532008462}, {\"x\": 9.420289855072465, \"y\": 1.304347826086957, \"x2\": 9.710144927536232, \"y2\": 1.5942028985507246, \"center_x\": 9.565217391304348, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0023088744363809082}, {\"x\": 9.710144927536234, \"y\": 1.304347826086957, \"x2\": 10.000000000000002, \"y2\": 1.5942028985507246, \"center_x\": 9.855072463768117, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.0019300117564770617}, {\"x\": 10.0, \"y\": 1.304347826086957, \"x2\": 10.289855072463768, \"y2\": 1.5942028985507246, \"center_x\": 10.144927536231883, \"center_y\": 1.4492753623188408, \"value_uncond\": 0.001598326161940756}, {\"x\": -10.0, \"y\": 1.5942028985507246, \"x2\": -9.710144927536232, \"y2\": 1.8840579710144922, \"center_x\": -9.855072463768117, \"center_y\": 1.7391304347826084, \"value_uncond\": 2.3930228500439113e-07}, {\"x\": -9.710144927536232, \"y\": 1.5942028985507246, \"x2\": -9.420289855072465, \"y2\": 1.8840579710144922, \"center_x\": -9.565217391304348, \"center_y\": 1.7391304347826084, \"value_uncond\": 3.738840259732958e-07}, {\"x\": -9.420289855072463, \"y\": 1.5942028985507246, \"x2\": -9.130434782608695, \"y2\": 1.8840579710144922, \"center_x\": -9.275362318840578, \"center_y\": 1.7391304347826084, \"value_uncond\": 5.787257281488953e-07}, {\"x\": -9.130434782608695, \"y\": 1.5942028985507246, \"x2\": -8.840579710144928, \"y2\": 1.8840579710144922, \"center_x\": -8.985507246376812, \"center_y\": 1.7391304347826084, \"value_uncond\": 8.874716408659564e-07}, {\"x\": -8.840579710144928, \"y\": 1.5942028985507246, \"x2\": -8.55072463768116, \"y2\": 1.8840579710144922, \"center_x\": -8.695652173913043, \"center_y\": 1.7391304347826084, \"value_uncond\": 1.3482858995648677e-06}, {\"x\": -8.55072463768116, \"y\": 1.5942028985507246, \"x2\": -8.260869565217392, \"y2\": 1.8840579710144922, \"center_x\": -8.405797101449277, \"center_y\": 1.7391304347826084, \"value_uncond\": 2.0293423365645064e-06}, {\"x\": -8.26086956521739, \"y\": 1.5942028985507246, \"x2\": -7.971014492753623, \"y2\": 1.8840579710144922, \"center_x\": -8.115942028985508, \"center_y\": 1.7391304347826084, \"value_uncond\": 3.0260385297535673e-06}, {\"x\": -7.971014492753623, \"y\": 1.5942028985507246, \"x2\": -7.681159420289855, \"y2\": 1.8840579710144922, \"center_x\": -7.826086956521739, \"center_y\": 1.7391304347826084, \"value_uncond\": 4.470328165080958e-06}, {\"x\": -7.681159420289855, \"y\": 1.5942028985507246, \"x2\": -7.391304347826088, \"y2\": 1.8840579710144922, \"center_x\": -7.536231884057972, \"center_y\": 1.7391304347826084, \"value_uncond\": 6.5425970342707065e-06}, {\"x\": -7.391304347826087, \"y\": 1.5942028985507246, \"x2\": -7.101449275362319, \"y2\": 1.8840579710144922, \"center_x\": -7.246376811594203, \"center_y\": 1.7391304347826084, \"value_uncond\": 9.486516222981147e-06}, {\"x\": -7.101449275362318, \"y\": 1.5942028985507246, \"x2\": -6.811594202898551, \"y2\": 1.8840579710144922, \"center_x\": -6.956521739130435, \"center_y\": 1.7391304347826084, \"value_uncond\": 1.362727906211575e-05}, {\"x\": -6.811594202898551, \"y\": 1.5942028985507246, \"x2\": -6.521739130434783, \"y2\": 1.8840579710144922, \"center_x\": -6.666666666666667, \"center_y\": 1.7391304347826084, \"value_uncond\": 1.9393552043168186e-05}, {\"x\": -6.521739130434782, \"y\": 1.5942028985507246, \"x2\": -6.231884057971015, \"y2\": 1.8840579710144922, \"center_x\": -6.3768115942028984, \"center_y\": 1.7391304347826084, \"value_uncond\": 2.7343328802596077e-05}, {\"x\": -6.231884057971014, \"y\": 1.5942028985507246, \"x2\": -5.942028985507246, \"y2\": 1.8840579710144922, \"center_x\": -6.08695652173913, \"center_y\": 1.7391304347826084, \"value_uncond\": 3.819365530706185e-05}, {\"x\": -5.942028985507246, \"y\": 1.5942028985507246, \"x2\": -5.6521739130434785, \"y2\": 1.8840579710144922, \"center_x\": -5.797101449275362, \"center_y\": 1.7391304347826084, \"value_uncond\": 5.285388048410381e-05}, {\"x\": -5.6521739130434785, \"y\": 1.5942028985507246, \"x2\": -5.362318840579711, \"y2\": 1.8840579710144922, \"center_x\": -5.507246376811595, \"center_y\": 1.7391304347826084, \"value_uncond\": 7.246167133555524e-05}, {\"x\": -5.36231884057971, \"y\": 1.5942028985507246, \"x2\": -5.072463768115942, \"y2\": 1.8840579710144922, \"center_x\": -5.217391304347826, \"center_y\": 1.7391304347826084, \"value_uncond\": 9.8420514256999e-05}, {\"x\": -5.0724637681159415, \"y\": 1.5942028985507246, \"x2\": -4.782608695652174, \"y2\": 1.8840579710144922, \"center_x\": -4.927536231884058, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.00013243681493426047}, {\"x\": -4.782608695652174, \"y\": 1.5942028985507246, \"x2\": -4.492753623188406, \"y2\": 1.8840579710144922, \"center_x\": -4.63768115942029, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.00017655403184885278}, {\"x\": -4.492753623188405, \"y\": 1.5942028985507246, \"x2\": -4.202898550724638, \"y2\": 1.8840579710144922, \"center_x\": -4.3478260869565215, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.00023318057366654825}, {\"x\": -4.202898550724638, \"y\": 1.5942028985507246, \"x2\": -3.91304347826087, \"y2\": 1.8840579710144922, \"center_x\": -4.057971014492754, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.00030510751704652234}, {\"x\": -3.913043478260869, \"y\": 1.5942028985507246, \"x2\": -3.6231884057971016, \"y2\": 1.8840579710144922, \"center_x\": -3.7681159420289854, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.00039551163455088756}, {\"x\": -3.6231884057971016, \"y\": 1.5942028985507246, \"x2\": -3.333333333333334, \"y2\": 1.8840579710144922, \"center_x\": -3.4782608695652177, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0005079388527825471}, {\"x\": -3.333333333333333, \"y\": 1.5942028985507246, \"x2\": -3.0434782608695654, \"y2\": 1.8840579710144922, \"center_x\": -3.1884057971014492, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0006462631879432444}, {\"x\": -3.0434782608695645, \"y\": 1.5942028985507246, \"x2\": -2.753623188405797, \"y2\": 1.8840579710144922, \"center_x\": -2.8985507246376807, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0008146165291889287}, {\"x\": -2.753623188405797, \"y\": 1.5942028985507246, \"x2\": -2.4637681159420293, \"y2\": 1.8840579710144922, \"center_x\": -2.608695652173913, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0010172854476969823}, {\"x\": -2.4637681159420284, \"y\": 1.5942028985507246, \"x2\": -2.1739130434782608, \"y2\": 1.8840579710144922, \"center_x\": -2.3188405797101446, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0012585725646548536}, {\"x\": -2.1739130434782608, \"y\": 1.5942028985507246, \"x2\": -1.8840579710144931, \"y2\": 1.8840579710144922, \"center_x\": -2.028985507246377, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0015426219385989153}, {\"x\": -1.8840579710144922, \"y\": 1.5942028985507246, \"x2\": -1.5942028985507246, \"y2\": 1.8840579710144922, \"center_x\": -1.7391304347826084, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0018732104030289617}, {\"x\": -1.5942028985507246, \"y\": 1.5942028985507246, \"x2\": -1.304347826086957, \"y2\": 1.8840579710144922, \"center_x\": -1.4492753623188408, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0022535097068581106}, {\"x\": -1.304347826086957, \"y\": 1.5942028985507246, \"x2\": -1.0144927536231894, \"y2\": 1.8840579710144922, \"center_x\": -1.1594202898550732, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0026858275218073005}, {\"x\": -1.0144927536231876, \"y\": 1.5942028985507246, \"x2\": -0.72463768115942, \"y2\": 1.8840579710144922, \"center_x\": -0.8695652173913038, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0031713386535351415}, {\"x\": -0.72463768115942, \"y\": 1.5942028985507246, \"x2\": -0.43478260869565233, \"y2\": 1.8840579710144922, \"center_x\": -0.5797101449275361, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.003709820840910567}, {\"x\": -0.43478260869565233, \"y\": 1.5942028985507246, \"x2\": -0.1449275362318847, \"y2\": 1.8840579710144922, \"center_x\": -0.2898550724637685, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.004299412026176441}, {\"x\": -0.14492753623188293, \"y\": 1.5942028985507246, \"x2\": 0.1449275362318847, \"y2\": 1.8840579710144922, \"center_x\": 8.881784197001252e-16, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.004936407593713624}, {\"x\": 0.1449275362318847, \"y\": 1.5942028985507246, \"x2\": 0.43478260869565233, \"y2\": 1.8840579710144922, \"center_x\": 0.2898550724637685, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.005615116497667997}, {\"x\": 0.43478260869565233, \"y\": 1.5942028985507246, \"x2\": 0.72463768115942, \"y2\": 1.8840579710144922, \"center_x\": 0.5797101449275361, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.00632779418348823}, {\"x\": 0.72463768115942, \"y\": 1.5942028985507246, \"x2\": 1.0144927536231876, \"y2\": 1.8840579710144922, \"center_x\": 0.8695652173913038, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.007064667611649967}, {\"x\": 1.0144927536231894, \"y\": 1.5942028985507246, \"x2\": 1.304347826086957, \"y2\": 1.8840579710144922, \"center_x\": 1.1594202898550732, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.007814063503488382}, {\"x\": 1.304347826086957, \"y\": 1.5942028985507246, \"x2\": 1.5942028985507246, \"y2\": 1.8840579710144922, \"center_x\": 1.4492753623188408, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.008562645294301409}, {\"x\": 1.5942028985507246, \"y\": 1.5942028985507246, \"x2\": 1.8840579710144922, \"y2\": 1.8840579710144922, \"center_x\": 1.7391304347826084, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.009295757504403146}, {\"x\": 1.884057971014494, \"y\": 1.5942028985507246, \"x2\": 2.1739130434782616, \"y2\": 1.8840579710144922, \"center_x\": 2.028985507246378, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.009997868781023904}, {\"x\": 2.1739130434782616, \"y\": 1.5942028985507246, \"x2\": 2.4637681159420293, \"y2\": 1.8840579710144922, \"center_x\": 2.3188405797101455, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.010653097298326468}, {\"x\": 2.4637681159420293, \"y\": 1.5942028985507246, \"x2\": 2.753623188405797, \"y2\": 1.8840579710144922, \"center_x\": 2.608695652173913, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.011245795175755779}, {\"x\": 2.753623188405797, \"y\": 1.5942028985507246, \"x2\": 3.0434782608695645, \"y2\": 1.8840579710144922, \"center_x\": 2.8985507246376807, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.011761162742523815}, {\"x\": 3.0434782608695663, \"y\": 1.5942028985507246, \"x2\": 3.333333333333334, \"y2\": 1.8840579710144922, \"center_x\": 3.18840579710145, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.012185859435716389}, {\"x\": 3.333333333333334, \"y\": 1.5942028985507246, \"x2\": 3.6231884057971016, \"y2\": 1.8840579710144922, \"center_x\": 3.4782608695652177, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.01250857634283142}, {\"x\": 3.6231884057971016, \"y\": 1.5942028985507246, \"x2\": 3.913043478260869, \"y2\": 1.8840579710144922, \"center_x\": 3.7681159420289854, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.012720536174122625}, {\"x\": 3.913043478260871, \"y\": 1.5942028985507246, \"x2\": 4.202898550724639, \"y2\": 1.8840579710144922, \"center_x\": 4.057971014492755, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.012815889838676837}, {\"x\": 4.202898550724639, \"y\": 1.5942028985507246, \"x2\": 4.492753623188406, \"y2\": 1.8840579710144922, \"center_x\": 4.347826086956522, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.012791984620799281}, {\"x\": 4.492753623188406, \"y\": 1.5942028985507246, \"x2\": 4.782608695652174, \"y2\": 1.8840579710144922, \"center_x\": 4.63768115942029, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.012649486796134982}, {\"x\": 4.782608695652174, \"y\": 1.5942028985507246, \"x2\": 5.0724637681159415, \"y2\": 1.8840579710144922, \"center_x\": 4.927536231884058, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.012392350777284051}, {\"x\": 5.072463768115943, \"y\": 1.5942028985507246, \"x2\": 5.362318840579711, \"y2\": 1.8840579710144922, \"center_x\": 5.217391304347827, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.012027636783086286}, {\"x\": 5.362318840579711, \"y\": 1.5942028985507246, \"x2\": 5.6521739130434785, \"y2\": 1.8840579710144922, \"center_x\": 5.507246376811595, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.011565188764967345}, {\"x\": 5.6521739130434785, \"y\": 1.5942028985507246, \"x2\": 5.942028985507246, \"y2\": 1.8840579710144922, \"center_x\": 5.797101449275362, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.011017193095140902}, {\"x\": 5.942028985507246, \"y\": 1.5942028985507246, \"x2\": 6.231884057971014, \"y2\": 1.8840579710144922, \"center_x\": 6.08695652173913, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.010397645619704042}, {\"x\": 6.2318840579710155, \"y\": 1.5942028985507246, \"x2\": 6.521739130434783, \"y2\": 1.8840579710144922, \"center_x\": 6.376811594202899, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.00972175956574586}, {\"x\": 6.521739130434785, \"y\": 1.5942028985507246, \"x2\": 6.8115942028985526, \"y2\": 1.8840579710144922, \"center_x\": 6.666666666666669, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.009005349142448897}, {\"x\": 6.811594202898551, \"y\": 1.5942028985507246, \"x2\": 7.101449275362318, \"y2\": 1.8840579710144922, \"center_x\": 6.956521739130435, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.008264223409439334}, {\"x\": 7.10144927536232, \"y\": 1.5942028985507246, \"x2\": 7.391304347826088, \"y2\": 1.8840579710144922, \"center_x\": 7.246376811594204, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0075136222575633805}, {\"x\": 7.391304347826086, \"y\": 1.5942028985507246, \"x2\": 7.681159420289854, \"y2\": 1.8840579710144922, \"center_x\": 7.53623188405797, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.006767721525037255}, {\"x\": 7.681159420289855, \"y\": 1.5942028985507246, \"x2\": 7.971014492753623, \"y2\": 1.8840579710144922, \"center_x\": 7.826086956521739, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.006039227885113773}, {\"x\": 7.971014492753625, \"y\": 1.5942028985507246, \"x2\": 8.260869565217392, \"y2\": 1.8840579710144922, \"center_x\": 8.115942028985508, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.005339076819251023}, {\"x\": 8.26086956521739, \"y\": 1.5942028985507246, \"x2\": 8.550724637681158, \"y2\": 1.8840579710144922, \"center_x\": 8.405797101449274, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.004676239392426481}, {\"x\": 8.55072463768116, \"y\": 1.5942028985507246, \"x2\": 8.840579710144928, \"y2\": 1.8840579710144922, \"center_x\": 8.695652173913043, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.004057636299484736}, {\"x\": 8.84057971014493, \"y\": 1.5942028985507246, \"x2\": 9.130434782608697, \"y2\": 1.8840579710144922, \"center_x\": 8.985507246376812, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0034881512859423654}, {\"x\": 9.130434782608695, \"y\": 1.5942028985507246, \"x2\": 9.420289855072463, \"y2\": 1.8840579710144922, \"center_x\": 9.275362318840578, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.002970730962658479}, {\"x\": 9.420289855072465, \"y\": 1.5942028985507246, \"x2\": 9.710144927536232, \"y2\": 1.8840579710144922, \"center_x\": 9.565217391304348, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.002506554473650362}, {\"x\": 9.710144927536234, \"y\": 1.5942028985507246, \"x2\": 10.000000000000002, \"y2\": 1.8840579710144922, \"center_x\": 9.855072463768117, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.002095254521496756}, {\"x\": 10.0, \"y\": 1.5942028985507246, \"x2\": 10.289855072463768, \"y2\": 1.8840579710144922, \"center_x\": 10.144927536231883, \"center_y\": 1.7391304347826084, \"value_uncond\": 0.0017351708384128314}, {\"x\": -10.0, \"y\": 1.884057971014494, \"x2\": -9.710144927536232, \"y2\": 2.1739130434782616, \"center_x\": -9.855072463768117, \"center_y\": 2.028985507246378, \"value_uncond\": 2.573768564143178e-07}, {\"x\": -9.710144927536232, \"y\": 1.884057971014494, \"x2\": -9.420289855072465, \"y2\": 2.1739130434782616, \"center_x\": -9.565217391304348, \"center_y\": 2.028985507246378, \"value_uncond\": 4.021235955468218e-07}, {\"x\": -9.420289855072463, \"y\": 1.884057971014494, \"x2\": -9.130434782608695, \"y2\": 2.1739130434782616, \"center_x\": -9.275362318840578, \"center_y\": 2.028985507246378, \"value_uncond\": 6.224370512563913e-07}, {\"x\": -9.130434782608695, \"y\": 1.884057971014494, \"x2\": -8.840579710144928, \"y2\": 2.1739130434782616, \"center_x\": -8.985507246376812, \"center_y\": 2.028985507246378, \"value_uncond\": 9.54502632846757e-07}, {\"x\": -8.840579710144928, \"y\": 1.884057971014494, \"x2\": -8.55072463768116, \"y2\": 2.1739130434782616, \"center_x\": -8.695652173913043, \"center_y\": 2.028985507246378, \"value_uncond\": 1.4501223269614357e-06}, {\"x\": -8.55072463768116, \"y\": 1.884057971014494, \"x2\": -8.260869565217392, \"y2\": 2.1739130434782616, \"center_x\": -8.405797101449277, \"center_y\": 2.028985507246378, \"value_uncond\": 2.1826191553660887e-06}, {\"x\": -8.26086956521739, \"y\": 1.884057971014494, \"x2\": -7.971014492753623, \"y2\": 2.1739130434782616, \"center_x\": -8.115942028985508, \"center_y\": 2.028985507246378, \"value_uncond\": 3.2545961028424198e-06}, {\"x\": -7.971014492753623, \"y\": 1.884057971014494, \"x2\": -7.681159420289855, \"y2\": 2.1739130434782616, \"center_x\": -7.826086956521739, \"center_y\": 2.028985507246378, \"value_uncond\": 4.807973355740461e-06}, {\"x\": -7.681159420289855, \"y\": 1.884057971014494, \"x2\": -7.391304347826088, \"y2\": 2.1739130434782616, \"center_x\": -7.536231884057972, \"center_y\": 2.028985507246378, \"value_uncond\": 7.036761297266066e-06}, {\"x\": -7.391304347826087, \"y\": 1.884057971014494, \"x2\": -7.101449275362319, \"y2\": 2.1739130434782616, \"center_x\": -7.246376811594203, \"center_y\": 2.028985507246378, \"value_uncond\": 1.0203035561275618e-05}, {\"x\": -7.101449275362318, \"y\": 1.884057971014494, \"x2\": -6.811594202898551, \"y2\": 2.1739130434782616, \"center_x\": -6.956521739130435, \"center_y\": 2.028985507246378, \"value_uncond\": 1.465655142584053e-05}, {\"x\": -6.811594202898551, \"y\": 1.884057971014494, \"x2\": -6.521739130434783, \"y2\": 2.1739130434782616, \"center_x\": -6.666666666666667, \"center_y\": 2.028985507246378, \"value_uncond\": 2.0858352687633163e-05}, {\"x\": -6.521739130434782, \"y\": 1.884057971014494, \"x2\": -6.231884057971015, \"y2\": 2.1739130434782616, \"center_x\": -6.3768115942028984, \"center_y\": 2.028985507246378, \"value_uncond\": 2.9408578405283986e-05}, {\"x\": -6.231884057971014, \"y\": 1.884057971014494, \"x2\": -5.942028985507246, \"y2\": 2.1739130434782616, \"center_x\": -6.08695652173913, \"center_y\": 2.028985507246378, \"value_uncond\": 4.107843323653689e-05}, {\"x\": -5.942028985507246, \"y\": 1.884057971014494, \"x2\": -5.6521739130434785, \"y2\": 2.1739130434782616, \"center_x\": -5.797101449275362, \"center_y\": 2.028985507246378, \"value_uncond\": 5.684594949875671e-05}, {\"x\": -5.6521739130434785, \"y\": 1.884057971014494, \"x2\": -5.362318840579711, \"y2\": 2.1739130434782616, \"center_x\": -5.507246376811595, \"center_y\": 2.028985507246378, \"value_uncond\": 7.793472251437328e-05}, {\"x\": -5.36231884057971, \"y\": 1.884057971014494, \"x2\": -5.072463768115942, \"y2\": 2.1739130434782616, \"center_x\": -5.217391304347826, \"center_y\": 2.028985507246378, \"value_uncond\": 0.00010585424441593667}, {\"x\": -5.0724637681159415, \"y\": 1.884057971014494, \"x2\": -4.782608695652174, \"y2\": 2.1739130434782616, \"center_x\": -4.927536231884058, \"center_y\": 2.028985507246378, \"value_uncond\": 0.00014243980620861715}, {\"x\": -4.782608695652174, \"y\": 1.884057971014494, \"x2\": -4.492753623188406, \"y2\": 2.1739130434782616, \"center_x\": -4.63768115942029, \"center_y\": 2.028985507246378, \"value_uncond\": 0.00018988920938927623}, {\"x\": -4.492753623188405, \"y\": 1.884057971014494, \"x2\": -4.202898550724638, \"y2\": 2.1739130434782616, \"center_x\": -4.3478260869565215, \"center_y\": 2.028985507246378, \"value_uncond\": 0.0002507927704329367}, {\"x\": -4.202898550724638, \"y\": 1.884057971014494, \"x2\": -3.91304347826087, \"y2\": 2.1739130434782616, \"center_x\": -4.057971014492754, \"center_y\": 2.028985507246378, \"value_uncond\": 0.000328152376833221}, {\"x\": -3.913043478260869, \"y\": 1.884057971014494, \"x2\": -3.6231884057971016, \"y2\": 2.1739130434782616, \"center_x\": -3.7681159420289854, \"center_y\": 2.028985507246378, \"value_uncond\": 0.00042538474371077597}, {\"x\": -3.6231884057971016, \"y\": 1.884057971014494, \"x2\": -3.333333333333334, \"y2\": 2.1739130434782616, \"center_x\": -3.4782608695652177, \"center_y\": 2.028985507246378, \"value_uncond\": 0.000546303622539451}, {\"x\": -3.333333333333333, \"y\": 1.884057971014494, \"x2\": -3.0434782608695654, \"y2\": 2.1739130434782616, \"center_x\": -3.1884057971014492, \"center_y\": 2.028985507246378, \"value_uncond\": 0.0006950756350950666}, {\"x\": -3.0434782608695645, \"y\": 1.884057971014494, \"x2\": -2.753623188405797, \"y2\": 2.1739130434782616, \"center_x\": -2.8985507246376807, \"center_y\": 2.028985507246378, \"value_uncond\": 0.0008761447533271222}, {\"x\": -2.753623188405797, \"y\": 1.884057971014494, \"x2\": -2.4637681159420293, \"y2\": 2.1739130434782616, \"center_x\": -2.608695652173913, \"center_y\": 2.028985507246378, \"value_uncond\": 0.0010941213143847621}, {\"x\": -2.4637681159420284, \"y\": 1.884057971014494, \"x2\": -2.1739130434782608, \"y2\": 2.1739130434782616, \"center_x\": -2.3188405797101446, \"center_y\": 2.028985507246378, \"value_uncond\": 0.0013536329176891404}, {\"x\": -2.1739130434782608, \"y\": 1.884057971014494, \"x2\": -1.8840579710144931, \"y2\": 2.1739130434782616, \"center_x\": -2.028985507246377, \"center_y\": 2.028985507246378, \"value_uncond\": 0.0016591366237270336}, {\"x\": -1.8840579710144922, \"y\": 1.884057971014494, \"x2\": -1.5942028985507246, \"y2\": 2.1739130434782616, \"center_x\": -1.7391304347826084, \"center_y\": 2.028985507246378, \"value_uncond\": 0.002014694531334479}, {\"x\": -1.5942028985507246, \"y\": 1.884057971014494, \"x2\": -1.304347826086957, \"y2\": 2.1739130434782616, \"center_x\": -1.4492753623188408, \"center_y\": 2.028985507246378, \"value_uncond\": 0.0024237179525454533}, {\"x\": -1.304347826086957, \"y\": 1.884057971014494, \"x2\": -1.0144927536231894, \"y2\": 2.1739130434782616, \"center_x\": -1.1594202898550732, \"center_y\": 2.028985507246378, \"value_uncond\": 0.0028886888581993115}, {\"x\": -1.0144927536231876, \"y\": 1.884057971014494, \"x2\": -0.72463768115942, \"y2\": 2.1739130434782616, \"center_x\": -0.8695652173913038, \"center_y\": 2.028985507246378, \"value_uncond\": 0.00341087078736884}, {\"x\": -0.72463768115942, \"y\": 1.884057971014494, \"x2\": -0.43478260869565233, \"y2\": 2.1739130434782616, \"center_x\": -0.5797101449275361, \"center_y\": 2.028985507246378, \"value_uncond\": 0.003990024691474894}, {\"x\": -0.43478260869565233, \"y\": 1.884057971014494, \"x2\": -0.1449275362318847, \"y2\": 2.1739130434782616, \"center_x\": -0.2898550724637685, \"center_y\": 2.028985507246378, \"value_uncond\": 0.004624147870994629}, {\"x\": -0.14492753623188293, \"y\": 1.884057971014494, \"x2\": 0.1449275362318847, \"y2\": 2.1739130434782616, \"center_x\": 8.881784197001252e-16, \"center_y\": 2.028985507246378, \"value_uncond\": 0.005309255899610263}, {\"x\": 0.1449275362318847, \"y\": 1.884057971014494, \"x2\": 0.43478260869565233, \"y2\": 2.1739130434782616, \"center_x\": 0.2898550724637685, \"center_y\": 2.028985507246378, \"value_uncond\": 0.006039227885113778}, {\"x\": 0.43478260869565233, \"y\": 1.884057971014494, \"x2\": 0.72463768115942, \"y2\": 2.1739130434782616, \"center_x\": 0.5797101449275361, \"center_y\": 2.028985507246378, \"value_uncond\": 0.006805734324488883}, {\"x\": 0.72463768115942, \"y\": 1.884057971014494, \"x2\": 1.0144927536231876, \"y2\": 2.1739130434782616, \"center_x\": 0.8695652173913038, \"center_y\": 2.028985507246378, \"value_uncond\": 0.007598264017684372}, {\"x\": 1.0144927536231894, \"y\": 1.884057971014494, \"x2\": 1.304347826086957, \"y2\": 2.1739130434782616, \"center_x\": 1.1594202898550732, \"center_y\": 2.028985507246378, \"value_uncond\": 0.00840426199989184}, {\"x\": 1.304347826086957, \"y\": 1.884057971014494, \"x2\": 1.5942028985507246, \"y2\": 2.1739130434782616, \"center_x\": 1.4492753623188408, \"center_y\": 2.028985507246378, \"value_uncond\": 0.009209384391785931}, {\"x\": 1.5942028985507246, \"y\": 1.884057971014494, \"x2\": 1.8840579710144922, \"y2\": 2.1739130434782616, \"center_x\": 1.7391304347826084, \"center_y\": 2.028985507246378, \"value_uncond\": 0.009997868781023904}, {\"x\": 1.884057971014494, \"y\": 1.884057971014494, \"x2\": 2.1739130434782616, \"y2\": 2.1739130434782616, \"center_x\": 2.028985507246378, \"center_y\": 2.028985507246378, \"value_uncond\": 0.010753010727229631}, {\"x\": 2.1739130434782616, \"y\": 1.884057971014494, \"x2\": 2.4637681159420293, \"y2\": 2.1739130434782616, \"center_x\": 2.3188405797101455, \"center_y\": 2.028985507246378, \"value_uncond\": 0.01145772884562643}, {\"x\": 2.4637681159420293, \"y\": 1.884057971014494, \"x2\": 2.753623188405797, \"y2\": 2.1739130434782616, \"center_x\": 2.608695652173913, \"center_y\": 2.028985507246378, \"value_uncond\": 0.012095193366675175}, {\"x\": 2.753623188405797, \"y\": 1.884057971014494, \"x2\": 3.0434782608695645, \"y2\": 2.1739130434782616, \"center_x\": 2.8985507246376807, \"center_y\": 2.028985507246378, \"value_uncond\": 0.012649486796134986}, {\"x\": 3.0434782608695663, \"y\": 1.884057971014494, \"x2\": 3.333333333333334, \"y2\": 2.1739130434782616, \"center_x\": 3.18840579710145, \"center_y\": 2.028985507246378, \"value_uncond\": 0.013106260954482262}, {\"x\": 3.333333333333334, \"y\": 1.884057971014494, \"x2\": 3.6231884057971016, \"y2\": 2.1739130434782616, \"center_x\": 3.4782608695652177, \"center_y\": 2.028985507246378, \"value_uncond\": 0.013453352763753928}, {\"x\": 3.6231884057971016, \"y\": 1.884057971014494, \"x2\": 3.913043478260869, \"y2\": 2.1739130434782616, \"center_x\": 3.7681159420289854, \"center_y\": 2.028985507246378, \"value_uncond\": 0.013681321982948132}, {\"x\": 3.913043478260871, \"y\": 1.884057971014494, \"x2\": 4.202898550724639, \"y2\": 2.1739130434782616, \"center_x\": 4.057971014492755, \"center_y\": 2.028985507246378, \"value_uncond\": 0.013783877737608386}, {\"x\": 4.202898550724639, \"y\": 1.884057971014494, \"x2\": 4.492753623188406, \"y2\": 2.1739130434782616, \"center_x\": 4.347826086956522, \"center_y\": 2.028985507246378, \"value_uncond\": 0.013758166951649482}, {\"x\": 4.492753623188406, \"y\": 1.884057971014494, \"x2\": 4.782608695652174, \"y2\": 2.1739130434782616, \"center_x\": 4.63768115942029, \"center_y\": 2.028985507246378, \"value_uncond\": 0.013604906224710316}, {\"x\": 4.782608695652174, \"y\": 1.884057971014494, \"x2\": 5.0724637681159415, \"y2\": 2.1739130434782616, \"center_x\": 4.927536231884058, \"center_y\": 2.028985507246378, \"value_uncond\": 0.013328348647328505}, {\"x\": 5.072463768115943, \"y\": 1.884057971014494, \"x2\": 5.362318840579711, \"y2\": 2.1739130434782616, \"center_x\": 5.217391304347827, \"center_y\": 2.028985507246378, \"value_uncond\": 0.012936087698732852}, {\"x\": 5.362318840579711, \"y\": 1.884057971014494, \"x2\": 5.6521739130434785, \"y2\": 2.1739130434782616, \"center_x\": 5.507246376811595, \"center_y\": 2.028985507246378, \"value_uncond\": 0.01243871084687245}, {\"x\": 5.6521739130434785, \"y\": 1.884057971014494, \"x2\": 5.942028985507246, \"y2\": 2.1739130434782616, \"center_x\": 5.797101449275362, \"center_y\": 2.028985507246378, \"value_uncond\": 0.011849324904210014}, {\"x\": 5.942028985507246, \"y\": 1.884057971014494, \"x2\": 6.231884057971014, \"y2\": 2.1739130434782616, \"center_x\": 6.08695652173913, \"center_y\": 2.028985507246378, \"value_uncond\": 0.011182982827182043}, {\"x\": 6.2318840579710155, \"y\": 1.884057971014494, \"x2\": 6.521739130434783, \"y2\": 2.1739130434782616, \"center_x\": 6.376811594202899, \"center_y\": 2.028985507246378, \"value_uncond\": 0.010456046902358579}, {\"x\": 6.521739130434785, \"y\": 1.884057971014494, \"x2\": 6.8115942028985526, \"y2\": 2.1739130434782616, \"center_x\": 6.666666666666669, \"center_y\": 2.028985507246378, \"value_uncond\": 0.009685525790755987}, {\"x\": 6.811594202898551, \"y\": 1.884057971014494, \"x2\": 7.101449275362318, \"y2\": 2.1739130434782616, \"center_x\": 6.956521739130435, \"center_y\": 2.028985507246378, \"value_uncond\": 0.00888842261488678}, {\"x\": 7.10144927536232, \"y\": 1.884057971014494, \"x2\": 7.391304347826088, \"y2\": 2.1739130434782616, \"center_x\": 7.246376811594204, \"center_y\": 2.028985507246378, \"value_uncond\": 0.008081128338999469}, {\"x\": 7.391304347826086, \"y\": 1.884057971014494, \"x2\": 7.681159420289854, \"y2\": 2.1739130434782616, \"center_x\": 7.53623188405797, \"center_y\": 2.028985507246378, \"value_uncond\": 0.007278889506506966}, {\"x\": 7.681159420289855, \"y\": 1.884057971014494, \"x2\": 7.971014492753623, \"y2\": 2.1739130434782616, \"center_x\": 7.826086956521739, \"center_y\": 2.028985507246378, \"value_uncond\": 0.006495372529400421}, {\"x\": 7.971014492753625, \"y\": 1.884057971014494, \"x2\": 8.260869565217392, \"y2\": 2.1739130434782616, \"center_x\": 8.115942028985508, \"center_y\": 2.028985507246378, \"value_uncond\": 0.0057423388492432005}, {\"x\": 8.26086956521739, \"y\": 1.884057971014494, \"x2\": 8.550724637681158, \"y2\": 2.1739130434782616, \"center_x\": 8.405797101449274, \"center_y\": 2.028985507246378, \"value_uncond\": 0.005029437118168106}, {\"x\": 8.55072463768116, \"y\": 1.884057971014494, \"x2\": 8.840579710144928, \"y2\": 2.1739130434782616, \"center_x\": 8.695652173913043, \"center_y\": 2.028985507246378, \"value_uncond\": 0.004364110753120656}, {\"x\": 8.84057971014493, \"y\": 1.884057971014494, \"x2\": 9.130434782608697, \"y2\": 2.1739130434782616, \"center_x\": 8.985507246376812, \"center_y\": 2.028985507246378, \"value_uncond\": 0.003751612370341272}, {\"x\": 9.130434782608695, \"y\": 1.884057971014494, \"x2\": 9.420289855072463, \"y2\": 2.1739130434782616, \"center_x\": 9.275362318840578, \"center_y\": 2.028985507246378, \"value_uncond\": 0.0031951111390670145}, {\"x\": 9.420289855072465, \"y\": 1.884057971014494, \"x2\": 9.710144927536232, \"y2\": 2.1739130434782616, \"center_x\": 9.565217391304348, \"center_y\": 2.028985507246378, \"value_uncond\": 0.002695875264406846}, {\"x\": 9.710144927536234, \"y\": 1.884057971014494, \"x2\": 10.000000000000002, \"y2\": 2.1739130434782616, \"center_x\": 9.855072463768117, \"center_y\": 2.028985507246378, \"value_uncond\": 0.0022535097068581075}, {\"x\": 10.0, \"y\": 1.884057971014494, \"x2\": 10.289855072463768, \"y2\": 2.1739130434782616, \"center_x\": 10.144927536231883, \"center_y\": 2.028985507246378, \"value_uncond\": 0.001866228798125752}, {\"x\": -10.0, \"y\": 2.1739130434782616, \"x2\": -9.710144927536232, \"y2\": 2.4637681159420293, \"center_x\": -9.855072463768117, \"center_y\": 2.3188405797101455, \"value_uncond\": 2.742445168837601e-07}, {\"x\": -9.710144927536232, \"y\": 2.1739130434782616, \"x2\": -9.420289855072465, \"y2\": 2.4637681159420293, \"center_x\": -9.565217391304348, \"center_y\": 2.3188405797101455, \"value_uncond\": 4.284774968685328e-07}, {\"x\": -9.420289855072463, \"y\": 2.1739130434782616, \"x2\": -9.130434782608695, \"y2\": 2.4637681159420293, \"center_x\": -9.275362318840578, \"center_y\": 2.3188405797101455, \"value_uncond\": 6.632295956617537e-07}, {\"x\": -9.130434782608695, \"y\": 2.1739130434782616, \"x2\": -8.840579710144928, \"y2\": 2.4637681159420293, \"center_x\": -8.985507246376812, \"center_y\": 2.3188405797101455, \"value_uncond\": 1.0170576991893582e-06}, {\"x\": -8.840579710144928, \"y\": 2.1739130434782616, \"x2\": -8.55072463768116, \"y2\": 2.4637681159420293, \"center_x\": -8.695652173913043, \"center_y\": 2.3188405797101455, \"value_uncond\": 1.5451587315205457e-06}, {\"x\": -8.55072463768116, \"y\": 2.1739130434782616, \"x2\": -8.260869565217392, \"y2\": 2.4637681159420293, \"center_x\": -8.405797101449277, \"center_y\": 2.3188405797101455, \"value_uncond\": 2.325661072031476e-06}, {\"x\": -8.26086956521739, \"y\": 2.1739130434782616, \"x2\": -7.971014492753623, \"y2\": 2.4637681159420293, \"center_x\": -8.115942028985508, \"center_y\": 2.3188405797101455, \"value_uncond\": 3.4678919787526597e-06}, {\"x\": -7.971014492753623, \"y\": 2.1739130434782616, \"x2\": -7.681159420289855, \"y2\": 2.4637681159420293, \"center_x\": -7.826086956521739, \"center_y\": 2.3188405797101455, \"value_uncond\": 5.123072635608127e-06}, {\"x\": -7.681159420289855, \"y\": 2.1739130434782616, \"x2\": -7.391304347826088, \"y2\": 2.4637681159420293, \"center_x\": -7.536231884057972, \"center_y\": 2.3188405797101455, \"value_uncond\": 7.497928249183951e-06}, {\"x\": -7.391304347826087, \"y\": 2.1739130434782616, \"x2\": -7.101449275362319, \"y2\": 2.4637681159420293, \"center_x\": -7.246376811594203, \"center_y\": 2.3188405797101455, \"value_uncond\": 1.0871710056732976e-05}, {\"x\": -7.101449275362318, \"y\": 2.1739130434782616, \"x2\": -6.811594202898551, \"y2\": 2.4637681159420293, \"center_x\": -6.956521739130435, \"center_y\": 2.3188405797101455, \"value_uncond\": 1.5617095184701392e-05}, {\"x\": -6.811594202898551, \"y\": 2.1739130434782616, \"x2\": -6.521739130434783, \"y2\": 2.4637681159420293, \"center_x\": -6.666666666666667, \"center_y\": 2.3188405797101455, \"value_uncond\": 2.2225342773643506e-05}, {\"x\": -6.521739130434782, \"y\": 2.1739130434782616, \"x2\": -6.231884057971015, \"y2\": 2.4637681159420293, \"center_x\": -6.3768115942028984, \"center_y\": 2.3188405797101455, \"value_uncond\": 3.133592308708699e-05}, {\"x\": -6.231884057971014, \"y\": 2.1739130434782616, \"x2\": -5.942028985507246, \"y2\": 2.4637681159420293, \"center_x\": -6.08695652173913, \"center_y\": 2.3188405797101455, \"value_uncond\": 4.377058308288967e-05}, {\"x\": -5.942028985507246, \"y\": 2.1739130434782616, \"x2\": -5.6521739130434785, \"y2\": 2.4637681159420293, \"center_x\": -5.797101449275362, \"center_y\": 2.3188405797101455, \"value_uncond\": 6.057145220543583e-05}, {\"x\": -5.6521739130434785, \"y\": 2.1739130434782616, \"x2\": -5.362318840579711, \"y2\": 2.4637681159420293, \"center_x\": -5.507246376811595, \"center_y\": 2.3188405797101455, \"value_uncond\": 8.304231632240589e-05}, {\"x\": -5.36231884057971, \"y\": 2.1739130434782616, \"x2\": -5.072463768115942, \"y2\": 2.4637681159420293, \"center_x\": -5.217391304347826, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0001127915948791156}, {\"x\": -5.0724637681159415, \"y\": 2.1739130434782616, \"x2\": -4.782608695652174, \"y2\": 2.4637681159420293, \"center_x\": -4.927536231884058, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.00015177485801526626}, {\"x\": -4.782608695652174, \"y\": 2.1739130434782616, \"x2\": -4.492753623188406, \"y2\": 2.4637681159420293, \"center_x\": -4.63768115942029, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0002023339441467523}, {\"x\": -4.492753623188405, \"y\": 2.1739130434782616, \"x2\": -4.202898550724638, \"y2\": 2.4637681159420293, \"center_x\": -4.3478260869565215, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0002672289308507321}, {\"x\": -4.202898550724638, \"y\": 2.1739130434782616, \"x2\": -3.91304347826087, \"y2\": 2.4637681159420293, \"center_x\": -4.057971014492754, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.00034965843977834024}, {\"x\": -3.913043478260869, \"y\": 2.1739130434782616, \"x2\": -3.6231884057971016, \"y2\": 2.4637681159420293, \"center_x\": -3.7681159420289854, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.00045326310669087074}, {\"x\": -3.6231884057971016, \"y\": 2.1739130434782616, \"x2\": -3.333333333333334, \"y2\": 2.4637681159420293, \"center_x\": -3.4782608695652177, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0005821066242024599}, {\"x\": -3.333333333333333, \"y\": 2.1739130434782616, \"x2\": -3.0434782608695654, \"y2\": 2.4637681159420293, \"center_x\": -3.1884057971014492, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0007406286812263477}, {\"x\": -3.0434782608695645, \"y\": 2.1739130434782616, \"x2\": -2.753623188405797, \"y2\": 2.4637681159420293, \"center_x\": -2.8985507246376807, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0009335644934976026}, {\"x\": -2.753623188405797, \"y\": 2.1739130434782616, \"x2\": -2.4637681159420293, \"y2\": 2.4637681159420293, \"center_x\": -2.608695652173913, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0011658265449969248}, {\"x\": -2.4637681159420284, \"y\": 2.1739130434782616, \"x2\": -2.1739130434782608, \"y2\": 2.4637681159420293, \"center_x\": -2.3188405797101446, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0014423457132914212}, {\"x\": -2.1739130434782608, \"y\": 2.1739130434782616, \"x2\": -1.8840579710144931, \"y2\": 2.4637681159420293, \"center_x\": -2.028985507246377, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0017678711604345368}, {\"x\": -1.8840579710144922, \"y\": 2.1739130434782616, \"x2\": -1.5942028985507246, \"y2\": 2.4637681159420293, \"center_x\": -1.7391304347826084, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.002146731202298736}, {\"x\": -1.5942028985507246, \"y\": 2.1739130434782616, \"x2\": -1.304347826086957, \"y2\": 2.4637681159420293, \"center_x\": -1.4492753623188408, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0025825607174575303}, {\"x\": -1.304347826086957, \"y\": 2.1739130434782616, \"x2\": -1.0144927536231894, \"y2\": 2.4637681159420293, \"center_x\": -1.1594202898550732, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0030780043372240864}, {\"x\": -1.0144927536231876, \"y\": 2.1739130434782616, \"x2\": -0.72463768115942, \"y2\": 2.4637681159420293, \"center_x\": -0.8695652173913038, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0036344084090027826}, {\"x\": -0.72463768115942, \"y\": 2.1739130434782616, \"x2\": -0.43478260869565233, \"y2\": 2.4637681159420293, \"center_x\": -0.5797101449275361, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.004251518217730996}, {\"x\": -0.43478260869565233, \"y\": 2.1739130434782616, \"x2\": -0.1449275362318847, \"y2\": 2.4637681159420293, \"center_x\": -0.2898550724637685, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.004927199813329617}, {\"x\": -0.14492753623188293, \"y\": 2.1739130434782616, \"x2\": 0.1449275362318847, \"y2\": 2.4637681159420293, \"center_x\": 8.881784197001252e-16, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.005657207642854213}, {\"x\": 0.1449275362318847, \"y\": 2.1739130434782616, \"x2\": 0.43478260869565233, \"y2\": 2.4637681159420293, \"center_x\": 0.2898550724637685, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.006435019670291636}, {\"x\": 0.43478260869565233, \"y\": 2.1739130434782616, \"x2\": 0.72463768115942, \"y2\": 2.4637681159420293, \"center_x\": 0.5797101449275361, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.007251760503493538}, {\"x\": 0.72463768115942, \"y\": 2.1739130434782616, \"x2\": 1.0144927536231876, \"y2\": 2.4637681159420293, \"center_x\": 0.8695652173913038, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.008096230071792845}, {\"x\": 1.0144927536231894, \"y\": 2.1739130434782616, \"x2\": 1.304347826086957, \"y2\": 2.4637681159420293, \"center_x\": 1.1594202898550732, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.008955050597924176}, {\"x\": 1.304347826086957, \"y\": 2.1739130434782616, \"x2\": 1.5942028985507246, \"y2\": 2.4637681159420293, \"center_x\": 1.4492753623188408, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.009812938150338193}, {\"x\": 1.5942028985507246, \"y\": 2.1739130434782616, \"x2\": 1.8840579710144922, \"y2\": 2.4637681159420293, \"center_x\": 1.7391304347826084, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.010653097298326468}, {\"x\": 1.884057971014494, \"y\": 2.1739130434782616, \"x2\": 2.1739130434782616, \"y2\": 2.4637681159420293, \"center_x\": 2.028985507246378, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.01145772884562643}, {\"x\": 2.1739130434782616, \"y\": 2.1739130434782616, \"x2\": 2.4637681159420293, \"y2\": 2.4637681159420293, \"center_x\": 2.3188405797101455, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.012208631947837958}, {\"x\": 2.4637681159420293, \"y\": 2.1739130434782616, \"x2\": 2.753623188405797, \"y2\": 2.4637681159420293, \"center_x\": 2.608695652173913, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.012887873865860803}, {\"x\": 2.753623188405797, \"y\": 2.1739130434782616, \"x2\": 3.0434782608695645, \"y2\": 2.4637681159420293, \"center_x\": 2.8985507246376807, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.013478493923514094}, {\"x\": 3.0434782608695663, \"y\": 2.1739130434782616, \"x2\": 3.333333333333334, \"y2\": 2.4637681159420293, \"center_x\": 3.18840579710145, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.013965203607228947}, {\"x\": 3.333333333333334, \"y\": 2.1739130434782616, \"x2\": 3.6231884057971016, \"y2\": 2.4637681159420293, \"center_x\": 3.4782608695652177, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.014335042709602577}, {\"x\": 3.6231884057971016, \"y\": 2.1739130434782616, \"x2\": 3.913043478260869, \"y2\": 2.4637681159420293, \"center_x\": 3.7681159420289854, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.014577952306266703}, {\"x\": 3.913043478260871, \"y\": 2.1739130434782616, \"x2\": 4.202898550724639, \"y2\": 2.4637681159420293, \"center_x\": 4.057971014492755, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.01468722923886384}, {\"x\": 4.202898550724639, \"y\": 2.1739130434782616, \"x2\": 4.492753623188406, \"y2\": 2.4637681159420293, \"center_x\": 4.347826086956522, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.014659833449777619}, {\"x\": 4.492753623188406, \"y\": 2.1739130434782616, \"x2\": 4.782608695652174, \"y2\": 2.4637681159420293, \"center_x\": 4.63768115942029, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.014496528502307806}, {\"x\": 4.782608695652174, \"y\": 2.1739130434782616, \"x2\": 5.0724637681159415, \"y2\": 2.4637681159420293, \"center_x\": 4.927536231884058, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.014201846221017042}, {\"x\": 5.072463768115943, \"y\": 2.1739130434782616, \"x2\": 5.362318840579711, \"y2\": 2.4637681159420293, \"center_x\": 5.217391304347827, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.013783877737608382}, {\"x\": 5.362318840579711, \"y\": 2.1739130434782616, \"x2\": 5.6521739130434785, \"y2\": 2.4637681159420293, \"center_x\": 5.507246376811595, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.013253904389002227}, {\"x\": 5.6521739130434785, \"y\": 2.1739130434782616, \"x2\": 5.942028985507246, \"y2\": 2.4637681159420293, \"center_x\": 5.797101449275362, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.012625891966458132}, {\"x\": 5.942028985507246, \"y\": 2.1739130434782616, \"x2\": 6.231884057971014, \"y2\": 2.4637681159420293, \"center_x\": 6.08695652173913, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.011915879949294914}, {\"x\": 6.2318840579710155, \"y\": 2.1739130434782616, \"x2\": 6.521739130434783, \"y2\": 2.4637681159420293, \"center_x\": 6.376811594202899, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.011141302956296993}, {\"x\": 6.521739130434785, \"y\": 2.1739130434782616, \"x2\": 6.8115942028985526, \"y2\": 2.4637681159420293, \"center_x\": 6.666666666666669, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.01032028434202024}, {\"x\": 6.811594202898551, \"y\": 2.1739130434782616, \"x2\": 7.101449275362318, \"y2\": 2.4637681159420293, \"center_x\": 6.956521739130435, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.009470941559540745}, {\"x\": 7.10144927536232, \"y\": 2.1739130434782616, \"x2\": 7.391304347826088, \"y2\": 2.4637681159420293, \"center_x\": 7.246376811594204, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.008610739784765224}, {\"x\": 7.391304347826086, \"y\": 2.1739130434782616, \"x2\": 7.681159420289854, \"y2\": 2.4637681159420293, \"center_x\": 7.53623188405797, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.007755924771063552}, {\"x\": 7.681159420289855, \"y\": 2.1739130434782616, \"x2\": 7.971014492753623, \"y2\": 2.4637681159420293, \"center_x\": 7.826086956521739, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.006921058583596764}, {\"x\": 7.971014492753625, \"y\": 2.1739130434782616, \"x2\": 8.260869565217392, \"y2\": 2.4637681159420293, \"center_x\": 8.115942028985508, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.006118673471395866}, {\"x\": 8.26086956521739, \"y\": 2.1739130434782616, \"x2\": 8.550724637681158, \"y2\": 2.4637681159420293, \"center_x\": 8.405797101449274, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.005359050428562672}, {\"x\": 8.55072463768116, \"y\": 2.1739130434782616, \"x2\": 8.840579710144928, \"y2\": 2.4637681159420293, \"center_x\": 8.695652173913043, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.004650120689912263}, {\"x\": 8.84057971014493, \"y\": 2.1739130434782616, \"x2\": 9.130434782608697, \"y2\": 2.4637681159420293, \"center_x\": 8.985507246376812, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.003997481111445207}, {\"x\": 9.130434782608695, \"y\": 2.1739130434782616, \"x2\": 9.420289855072463, \"y2\": 2.4637681159420293, \"center_x\": 9.275362318840578, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0034045085596694277}, {\"x\": 9.420289855072465, \"y\": 2.1739130434782616, \"x2\": 9.710144927536232, \"y2\": 2.4637681159420293, \"center_x\": 9.565217391304348, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0028725543538226468}, {\"x\": 9.710144927536234, \"y\": 2.1739130434782616, \"x2\": 10.000000000000002, \"y2\": 2.4637681159420293, \"center_x\": 9.855072463768117, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.0024011975647697976}, {\"x\": 10.0, \"y\": 2.1739130434782616, \"x2\": 10.289855072463768, \"y2\": 2.4637681159420293, \"center_x\": 10.144927536231883, \"center_y\": 2.3188405797101455, \"value_uncond\": 0.001988535497195876}, {\"x\": -10.0, \"y\": 2.4637681159420293, \"x2\": -9.710144927536232, \"y2\": 2.753623188405797, \"center_x\": -9.855072463768117, \"center_y\": 2.608695652173913, \"value_uncond\": 2.8950244033097844e-07}, {\"x\": -9.710144927536232, \"y\": 2.4637681159420293, \"x2\": -9.420289855072465, \"y2\": 2.753623188405797, \"center_x\": -9.565217391304348, \"center_y\": 2.608695652173913, \"value_uncond\": 4.523163576062548e-07}, {\"x\": -9.420289855072463, \"y\": 2.4637681159420293, \"x2\": -9.130434782608695, \"y2\": 2.753623188405797, \"center_x\": -9.275362318840578, \"center_y\": 2.608695652173913, \"value_uncond\": 7.001291716807186e-07}, {\"x\": -9.130434782608695, \"y\": 2.4637681159420293, \"x2\": -8.840579710144928, \"y2\": 2.753623188405797, \"center_x\": -8.985507246376812, \"center_y\": 2.608695652173913, \"value_uncond\": 1.0736429271894232e-06}, {\"x\": -8.840579710144928, \"y\": 2.4637681159420293, \"x2\": -8.55072463768116, \"y2\": 2.753623188405797, \"center_x\": -8.695652173913043, \"center_y\": 2.608695652173913, \"value_uncond\": 1.6311254954406947e-06}, {\"x\": -8.55072463768116, \"y\": 2.4637681159420293, \"x2\": -8.260869565217392, \"y2\": 2.753623188405797, \"center_x\": -8.405797101449277, \"center_y\": 2.608695652173913, \"value_uncond\": 2.455052022138501e-06}, {\"x\": -8.26086956521739, \"y\": 2.4637681159420293, \"x2\": -7.971014492753623, \"y2\": 2.753623188405797, \"center_x\": -8.115942028985508, \"center_y\": 2.608695652173913, \"value_uncond\": 3.660832318768493e-06}, {\"x\": -7.971014492753623, \"y\": 2.4637681159420293, \"x2\": -7.681159420289855, \"y2\": 2.753623188405797, \"center_x\": -7.826086956521739, \"center_y\": 2.608695652173913, \"value_uncond\": 5.4081009416499825e-06}, {\"x\": -7.681159420289855, \"y\": 2.4637681159420293, \"x2\": -7.391304347826088, \"y2\": 2.753623188405797, \"center_x\": -7.536231884057972, \"center_y\": 2.608695652173913, \"value_uncond\": 7.915084502802953e-06}, {\"x\": -7.391304347826087, \"y\": 2.4637681159420293, \"x2\": -7.101449275362319, \"y2\": 2.753623188405797, \"center_x\": -7.246376811594203, \"center_y\": 2.608695652173913, \"value_uncond\": 1.1476570717835243e-05}, {\"x\": -7.101449275362318, \"y\": 2.4637681159420293, \"x2\": -6.811594202898551, \"y2\": 2.753623188405797, \"center_x\": -6.956521739130435, \"center_y\": 2.608695652173913, \"value_uncond\": 1.6485971053228203e-05}, {\"x\": -6.811594202898551, \"y\": 2.4637681159420293, \"x2\": -6.521739130434783, \"y2\": 2.753623188405797, \"center_x\": -6.666666666666667, \"center_y\": 2.608695652173913, \"value_uncond\": 2.346187644250868e-05}, {\"x\": -6.521739130434782, \"y\": 2.4637681159420293, \"x2\": -6.231884057971015, \"y2\": 2.753623188405797, \"center_x\": -6.3768115942028984, \"center_y\": 2.608695652173913, \"value_uncond\": 3.3079334846211935e-05}, {\"x\": -6.231884057971014, \"y\": 2.4637681159420293, \"x2\": -5.942028985507246, \"y2\": 2.753623188405797, \"center_x\": -6.08695652173913, \"center_y\": 2.608695652173913, \"value_uncond\": 4.62058121022611e-05}, {\"x\": -5.942028985507246, \"y\": 2.4637681159420293, \"x2\": -5.6521739130434785, \"y2\": 2.753623188405797, \"center_x\": -5.797101449275362, \"center_y\": 2.608695652173913, \"value_uncond\": 6.394141777973059e-05}, {\"x\": -5.6521739130434785, \"y\": 2.4637681159420293, \"x2\": -5.362318840579711, \"y2\": 2.753623188405797, \"center_x\": -5.507246376811595, \"center_y\": 2.608695652173913, \"value_uncond\": 8.766247544071558e-05}, {\"x\": -5.36231884057971, \"y\": 2.4637681159420293, \"x2\": -5.072463768115942, \"y2\": 2.753623188405797, \"center_x\": -5.217391304347826, \"center_y\": 2.608695652173913, \"value_uncond\": 0.00011906689088032833}, {\"x\": -5.0724637681159415, \"y\": 2.4637681159420293, \"x2\": -4.782608695652174, \"y2\": 2.753623188405797, \"center_x\": -4.927536231884058, \"center_y\": 2.608695652173913, \"value_uncond\": 0.00016021903473436135}, {\"x\": -4.782608695652174, \"y\": 2.4637681159420293, \"x2\": -4.492753623188406, \"y2\": 2.753623188405797, \"center_x\": -4.63768115942029, \"center_y\": 2.608695652173913, \"value_uncond\": 0.00021359103641479342}, {\"x\": -4.492753623188405, \"y\": 2.4637681159420293, \"x2\": -4.202898550724638, \"y2\": 2.753623188405797, \"center_x\": -4.3478260869565215, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0002820965337334932}, {\"x\": -4.202898550724638, \"y\": 2.4637681159420293, \"x2\": -3.91304347826087, \"y2\": 2.753623188405797, \"center_x\": -4.057971014492754, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0003691121075031647}, {\"x\": -3.913043478260869, \"y\": 2.4637681159420293, \"x2\": -3.6231884057971016, \"y2\": 2.753623188405797, \"center_x\": -3.7681159420289854, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0004784809446331656}, {\"x\": -3.6231884057971016, \"y\": 2.4637681159420293, \"x2\": -3.333333333333334, \"y2\": 2.753623188405797, \"center_x\": -3.4782608695652177, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0006144928261623858}, {\"x\": -3.333333333333333, \"y\": 2.4637681159420293, \"x2\": -3.0434782608695654, \"y2\": 2.753623188405797, \"center_x\": -3.1884057971014492, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0007818344484350156}, {\"x\": -3.0434782608695645, \"y\": 2.4637681159420293, \"x2\": -2.753623188405797, \"y2\": 2.753623188405797, \"center_x\": -2.8985507246376807, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0009855044766071462}, {\"x\": -2.753623188405797, \"y\": 2.4637681159420293, \"x2\": -2.4637681159420293, \"y2\": 2.753623188405797, \"center_x\": -2.608695652173913, \"center_y\": 2.608695652173913, \"value_uncond\": 0.001230688706612493}, {\"x\": -2.4637681159420284, \"y\": 2.4637681159420293, \"x2\": -2.1739130434782608, \"y2\": 2.753623188405797, \"center_x\": -2.3188405797101446, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0015225923513204752}, {\"x\": -2.1739130434782608, \"y\": 2.4637681159420293, \"x2\": -1.8840579710144931, \"y2\": 2.753623188405797, \"center_x\": -2.028985507246377, \"center_y\": 2.608695652173913, \"value_uncond\": 0.001866228798125751}, {\"x\": -1.8840579710144922, \"y\": 2.4637681159420293, \"x2\": -1.5942028985507246, \"y2\": 2.753623188405797, \"center_x\": -1.7391304347826084, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0022661671739586985}, {\"x\": -1.5942028985507246, \"y\": 2.4637681159420293, \"x2\": -1.304347826086957, \"y2\": 2.753623188405797, \"center_x\": -1.4492753623188408, \"center_y\": 2.608695652173913, \"value_uncond\": 0.002726244588232826}, {\"x\": -1.304347826086957, \"y\": 2.4637681159420293, \"x2\": -1.0144927536231894, \"y2\": 2.753623188405797, \"center_x\": -1.1594202898550732, \"center_y\": 2.608695652173913, \"value_uncond\": 0.003249252809504304}, {\"x\": -1.0144927536231876, \"y\": 2.4637681159420293, \"x2\": -0.72463768115942, \"y2\": 2.753623188405797, \"center_x\": -0.8695652173913038, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0038366130908341948}, {\"x\": -0.72463768115942, \"y\": 2.4637681159420293, \"x2\": -0.43478260869565233, \"y2\": 2.753623188405797, \"center_x\": -0.5797101449275361, \"center_y\": 2.608695652173913, \"value_uncond\": 0.004488056545781097}, {\"x\": -0.43478260869565233, \"y\": 2.4637681159420293, \"x2\": -0.1449275362318847, \"y2\": 2.753623188405797, \"center_x\": -0.2898550724637685, \"center_y\": 2.608695652173913, \"value_uncond\": 0.005201330499387401}, {\"x\": -0.14492753623188293, \"y\": 2.4637681159420293, \"x2\": 0.1449275362318847, \"y2\": 2.753623188405797, \"center_x\": 8.881784197001252e-16, \"center_y\": 2.608695652173913, \"value_uncond\": 0.005971953192265772}, {\"x\": 0.1449275362318847, \"y\": 2.4637681159420293, \"x2\": 0.43478260869565233, \"y2\": 2.753623188405797, \"center_x\": 0.2898550724637685, \"center_y\": 2.608695652173913, \"value_uncond\": 0.006793039727087407}, {\"x\": 0.43478260869565233, \"y\": 2.4637681159420293, \"x2\": 0.72463768115942, \"y2\": 2.753623188405797, \"center_x\": 0.5797101449275361, \"center_y\": 2.608695652173913, \"value_uncond\": 0.007655220918590051}, {\"x\": 0.72463768115942, \"y\": 2.4637681159420293, \"x2\": 1.0144927536231876, \"y2\": 2.753623188405797, \"center_x\": 0.8695652173913038, \"center_y\": 2.608695652173913, \"value_uncond\": 0.008546673566708152}, {\"x\": 1.0144927536231894, \"y\": 2.4637681159420293, \"x2\": 1.304347826086957, \"y2\": 2.753623188405797, \"center_x\": 1.1594202898550732, \"center_y\": 2.608695652173913, \"value_uncond\": 0.00945327560545279}, {\"x\": 1.304347826086957, \"y\": 2.4637681159420293, \"x2\": 1.5942028985507246, \"y2\": 2.753623188405797, \"center_x\": 1.4492753623188408, \"center_y\": 2.608695652173913, \"value_uncond\": 0.010358892763365544}, {\"x\": 1.5942028985507246, \"y\": 2.4637681159420293, \"x2\": 1.8840579710144922, \"y2\": 2.753623188405797, \"center_x\": 1.7391304347826084, \"center_y\": 2.608695652173913, \"value_uncond\": 0.011245795175755779}, {\"x\": 1.884057971014494, \"y\": 2.4637681159420293, \"x2\": 2.1739130434782616, \"y2\": 2.753623188405797, \"center_x\": 2.028985507246378, \"center_y\": 2.608695652173913, \"value_uncond\": 0.012095193366675175}, {\"x\": 2.1739130434782616, \"y\": 2.4637681159420293, \"x2\": 2.4637681159420293, \"y2\": 2.753623188405797, \"center_x\": 2.3188405797101455, \"center_y\": 2.608695652173913, \"value_uncond\": 0.012887873865860803}, {\"x\": 2.4637681159420293, \"y\": 2.4637681159420293, \"x2\": 2.753623188405797, \"y2\": 2.753623188405797, \"center_x\": 2.608695652173913, \"center_y\": 2.608695652173913, \"value_uncond\": 0.013604906224710313}, {\"x\": 2.753623188405797, \"y\": 2.4637681159420293, \"x2\": 3.0434782608695645, \"y2\": 2.753623188405797, \"center_x\": 2.8985507246376807, \"center_y\": 2.608695652173913, \"value_uncond\": 0.014228386139430085}, {\"x\": 3.0434782608695663, \"y\": 2.4637681159420293, \"x2\": 3.333333333333334, \"y2\": 2.753623188405797, \"center_x\": 3.18840579710145, \"center_y\": 2.608695652173913, \"value_uncond\": 0.014742174501615976}, {\"x\": 3.333333333333334, \"y\": 2.4637681159420293, \"x2\": 3.6231884057971016, \"y2\": 2.753623188405797, \"center_x\": 3.4782608695652177, \"center_y\": 2.608695652173913, \"value_uncond\": 0.01513259004714306}, {\"x\": 3.6231884057971016, \"y\": 2.4637681159420293, \"x2\": 3.913043478260869, \"y2\": 2.753623188405797, \"center_x\": 3.7681159420289854, \"center_y\": 2.608695652173913, \"value_uncond\": 0.015389014211291014}, {\"x\": 3.913043478260871, \"y\": 2.4637681159420293, \"x2\": 4.202898550724639, \"y2\": 2.753623188405797, \"center_x\": 4.057971014492755, \"center_y\": 2.608695652173913, \"value_uncond\": 0.015504370897427292}, {\"x\": 4.202898550724639, \"y\": 2.4637681159420293, \"x2\": 4.492753623188406, \"y2\": 2.753623188405797, \"center_x\": 4.347826086956522, \"center_y\": 2.608695652173913, \"value_uncond\": 0.015475450910674683}, {\"x\": 4.492753623188406, \"y\": 2.4637681159420293, \"x2\": 4.782608695652174, \"y2\": 2.753623188405797, \"center_x\": 4.63768115942029, \"center_y\": 2.608695652173913, \"value_uncond\": 0.015303060296095244}, {\"x\": 4.782608695652174, \"y\": 2.4637681159420293, \"x2\": 5.0724637681159415, \"y2\": 2.753623188405797, \"center_x\": 4.927536231884058, \"center_y\": 2.608695652173913, \"value_uncond\": 0.014991983011760199}, {\"x\": 5.072463768115943, \"y\": 2.4637681159420293, \"x2\": 5.362318840579711, \"y2\": 2.753623188405797, \"center_x\": 5.217391304347827, \"center_y\": 2.608695652173913, \"value_uncond\": 0.014550760349213649}, {\"x\": 5.362318840579711, \"y\": 2.4637681159420293, \"x2\": 5.6521739130434785, \"y2\": 2.753623188405797, \"center_x\": 5.507246376811595, \"center_y\": 2.608695652173913, \"value_uncond\": 0.013991301296120189}, {\"x\": 5.6521739130434785, \"y\": 2.4637681159420293, \"x2\": 5.942028985507246, \"y2\": 2.753623188405797, \"center_x\": 5.797101449275362, \"center_y\": 2.608695652173913, \"value_uncond\": 0.013328348647328502}, {\"x\": 5.942028985507246, \"y\": 2.4637681159420293, \"x2\": 6.231884057971014, \"y2\": 2.753623188405797, \"center_x\": 6.08695652173913, \"center_y\": 2.608695652173913, \"value_uncond\": 0.012578834257875109}, {\"x\": 6.2318840579710155, \"y\": 2.4637681159420293, \"x2\": 6.521739130434783, \"y2\": 2.753623188405797, \"center_x\": 6.376811594202899, \"center_y\": 2.608695652173913, \"value_uncond\": 0.011761162742523812}, {\"x\": 6.521739130434785, \"y\": 2.4637681159420293, \"x2\": 6.8115942028985526, \"y2\": 2.753623188405797, \"center_x\": 6.666666666666669, \"center_y\": 2.608695652173913, \"value_uncond\": 0.010894465770452633}, {\"x\": 6.811594202898551, \"y\": 2.4637681159420293, \"x2\": 7.101449275362318, \"y2\": 2.753623188405797, \"center_x\": 6.956521739130435, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0099978687810239}, {\"x\": 7.10144927536232, \"y\": 2.4637681159420293, \"x2\": 7.391304347826088, \"y2\": 2.753623188405797, \"center_x\": 7.246376811594204, \"center_y\": 2.608695652173913, \"value_uncond\": 0.009089808646205944}, {\"x\": 7.391304347826086, \"y\": 2.4637681159420293, \"x2\": 7.681159420289854, \"y2\": 2.753623188405797, \"center_x\": 7.53623188405797, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0081874349713912}, {\"x\": 7.681159420289855, \"y\": 2.4637681159420293, \"x2\": 7.971014492753623, \"y2\": 2.753623188405797, \"center_x\": 7.826086956521739, \"center_y\": 2.608695652173913, \"value_uncond\": 0.007306119999745298}, {\"x\": 7.971014492753625, \"y\": 2.4637681159420293, \"x2\": 8.260869565217392, \"y2\": 2.753623188405797, \"center_x\": 8.115942028985508, \"center_y\": 2.608695652173913, \"value_uncond\": 0.006459093227042803}, {\"x\": 8.26086956521739, \"y\": 2.4637681159420293, \"x2\": 8.550724637681158, \"y2\": 2.753623188405797, \"center_x\": 8.405797101449274, \"center_y\": 2.608695652173913, \"value_uncond\": 0.005657207642854211}, {\"x\": 8.55072463768116, \"y\": 2.4637681159420293, \"x2\": 8.840579710144928, \"y2\": 2.753623188405797, \"center_x\": 8.695652173913043, \"center_y\": 2.608695652173913, \"value_uncond\": 0.004908835745780014}, {\"x\": 8.84057971014493, \"y\": 2.4637681159420293, \"x2\": 9.130434782608697, \"y2\": 2.753623188405797, \"center_x\": 8.985507246376812, \"center_y\": 2.608695652173913, \"value_uncond\": 0.004219885779634011}, {\"x\": 9.130434782608695, \"y\": 2.4637681159420293, \"x2\": 9.420289855072463, \"y2\": 2.753623188405797, \"center_x\": 9.275362318840578, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0035939224869526204}, {\"x\": 9.420289855072465, \"y\": 2.4637681159420293, \"x2\": 9.710144927536232, \"y2\": 2.753623188405797, \"center_x\": 9.565217391304348, \"center_y\": 2.608695652173913, \"value_uncond\": 0.003032372369244177}, {\"x\": 9.710144927536234, \"y\": 2.4637681159420293, \"x2\": 10.000000000000002, \"y2\": 2.753623188405797, \"center_x\": 9.855072463768117, \"center_y\": 2.608695652173913, \"value_uncond\": 0.0025347910784750617}, {\"x\": 10.0, \"y\": 2.4637681159420293, \"x2\": 10.289855072463768, \"y2\": 2.753623188405797, \"center_x\": 10.144927536231883, \"center_y\": 2.608695652173913, \"value_uncond\": 0.002099170060588627}, {\"x\": -10.0, \"y\": 2.753623188405797, \"x2\": -9.710144927536232, \"y2\": 3.0434782608695645, \"center_x\": -9.855072463768117, \"center_y\": 2.8985507246376807, \"value_uncond\": 3.027696362842212e-07}, {\"x\": -9.710144927536232, \"y\": 2.753623188405797, \"x2\": -9.420289855072465, \"y2\": 3.0434782608695645, \"center_x\": -9.565217391304348, \"center_y\": 2.8985507246376807, \"value_uncond\": 4.7304492121476363e-07}, {\"x\": -9.420289855072463, \"y\": 2.753623188405797, \"x2\": -9.130434782608695, \"y2\": 3.0434782608695645, \"center_x\": -9.275362318840578, \"center_y\": 2.8985507246376807, \"value_uncond\": 7.322143966019667e-07}, {\"x\": -9.130434782608695, \"y\": 2.753623188405797, \"x2\": -8.840579710144928, \"y2\": 3.0434782608695645, \"center_x\": -8.985507246376812, \"center_y\": 2.8985507246376807, \"value_uncond\": 1.1228453832466169e-06}, {\"x\": -8.840579710144928, \"y\": 2.753623188405797, \"x2\": -8.55072463768116, \"y2\": 3.0434782608695645, \"center_x\": -8.695652173913043, \"center_y\": 2.8985507246376807, \"value_uncond\": 1.7058760279322381e-06}, {\"x\": -8.55072463768116, \"y\": 2.753623188405797, \"x2\": -8.260869565217392, \"y2\": 3.0434782608695645, \"center_x\": -8.405797101449277, \"center_y\": 2.8985507246376807, \"value_uncond\": 2.567561112617595e-06}, {\"x\": -8.26086956521739, \"y\": 2.753623188405797, \"x2\": -7.971014492753623, \"y2\": 3.0434782608695645, \"center_x\": -8.115942028985508, \"center_y\": 2.8985507246376807, \"value_uncond\": 3.828599401040885e-06}, {\"x\": -7.971014492753623, \"y\": 2.753623188405797, \"x2\": -7.681159420289855, \"y2\": 3.0434782608695645, \"center_x\": -7.826086956521739, \"center_y\": 2.8985507246376807, \"value_uncond\": 5.65594111476133e-06}, {\"x\": -7.681159420289855, \"y\": 2.753623188405797, \"x2\": -7.391304347826088, \"y2\": 3.0434782608695645, \"center_x\": -7.536231884057972, \"center_y\": 2.8985507246376807, \"value_uncond\": 8.277813663099864e-06}, {\"x\": -7.391304347826087, \"y\": 2.753623188405797, \"x2\": -7.101449275362319, \"y2\": 3.0434782608695645, \"center_x\": -7.246376811594203, \"center_y\": 2.8985507246376807, \"value_uncond\": 1.2002514168987824e-05}, {\"x\": -7.101449275362318, \"y\": 2.753623188405797, \"x2\": -6.811594202898551, \"y2\": 3.0434782608695645, \"center_x\": -6.956521739130435, \"center_y\": 2.8985507246376807, \"value_uncond\": 1.7241483193963902e-05}, {\"x\": -6.811594202898551, \"y\": 2.753623188405797, \"x2\": -6.521739130434783, \"y2\": 3.0434782608695645, \"center_x\": -6.666666666666667, \"center_y\": 2.8985507246376807, \"value_uncond\": 2.4537077438526764e-05}, {\"x\": -6.521739130434782, \"y\": 2.753623188405797, \"x2\": -6.231884057971015, \"y2\": 3.0434782608695645, \"center_x\": -6.3768115942028984, \"center_y\": 2.8985507246376807, \"value_uncond\": 3.459528067694787e-05}, {\"x\": -6.231884057971014, \"y\": 2.753623188405797, \"x2\": -5.942028985507246, \"y2\": 3.0434782608695645, \"center_x\": -6.08695652173913, \"center_y\": 2.8985507246376807, \"value_uncond\": 4.832331260636244e-05}, {\"x\": -5.942028985507246, \"y\": 2.753623188405797, \"x2\": -5.6521739130434785, \"y2\": 3.0434782608695645, \"center_x\": -5.797101449275362, \"center_y\": 2.8985507246376807, \"value_uncond\": 6.687169815402376e-05}, {\"x\": -5.6521739130434785, \"y\": 2.753623188405797, \"x2\": -5.362318840579711, \"y2\": 3.0434782608695645, \"center_x\": -5.507246376811595, \"center_y\": 2.8985507246376807, \"value_uncond\": 9.167983445879034e-05}, {\"x\": -5.36231884057971, \"y\": 2.753623188405797, \"x2\": -5.072463768115942, \"y2\": 3.0434782608695645, \"center_x\": -5.217391304347826, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.00012452343822772443}, {\"x\": -5.0724637681159415, \"y\": 2.753623188405797, \"x2\": -4.782608695652174, \"y2\": 3.0434782608695645, \"center_x\": -4.927536231884058, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.00016756148520500328}, {\"x\": -4.782608695652174, \"y\": 2.753623188405797, \"x2\": -4.492753623188406, \"y2\": 3.0434782608695645, \"center_x\": -4.63768115942029, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.0002233793965085168}, {\"x\": -4.492753623188405, \"y\": 2.753623188405797, \"x2\": -4.202898550724638, \"y2\": 3.0434782608695645, \"center_x\": -4.3478260869565215, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.000295024334917117}, {\"x\": -4.202898550724638, \"y\": 2.753623188405797, \"x2\": -3.91304347826087, \"y2\": 3.0434782608695645, \"center_x\": -4.057971014492754, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.0003860276217674322}, {\"x\": -3.913043478260869, \"y\": 2.753623188405797, \"x2\": -3.6231884057971016, \"y2\": 3.0434782608695645, \"center_x\": -3.7681159420289854, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.0005004085679204973}, {\"x\": -3.6231884057971016, \"y\": 2.753623188405797, \"x2\": -3.333333333333334, \"y2\": 3.0434782608695645, \"center_x\": -3.4782608695652177, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.0006426535446946294}, {\"x\": -3.333333333333333, \"y\": 2.753623188405797, \"x2\": -3.0434782608695654, \"y2\": 3.0434782608695645, \"center_x\": -3.1884057971014492, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.0008176640283809533}, {\"x\": -3.0434782608695645, \"y\": 2.753623188405797, \"x2\": -2.753623188405797, \"y2\": 3.0434782608695645, \"center_x\": -2.8985507246376807, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.001030667760857866}, {\"x\": -2.753623188405797, \"y\": 2.753623188405797, \"x2\": -2.4637681159420293, \"y2\": 3.0434782608695645, \"center_x\": -2.608695652173913, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.001287088190531882}, {\"x\": -2.4637681159420284, \"y\": 2.753623188405797, \"x2\": -2.1739130434782608, \"y2\": 3.0434782608695645, \"center_x\": -2.3188405797101446, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.001592369072576375}, {\"x\": -2.1739130434782608, \"y\": 2.753623188405797, \"x2\": -1.8840579710144931, \"y2\": 3.0434782608695645, \"center_x\": -2.028985507246377, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.00195175354579286}, {\"x\": -1.8840579710144922, \"y\": 2.753623188405797, \"x2\": -1.5942028985507246, \"y2\": 3.0434782608695645, \"center_x\": -1.7391304347826084, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.0023700201291370505}, {\"x\": -1.5942028985507246, \"y\": 2.753623188405797, \"x2\": -1.304347826086957, \"y2\": 3.0434782608695645, \"center_x\": -1.4492753623188408, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.0028511817774572105}, {\"x\": -1.304347826086957, \"y\": 2.753623188405797, \"x2\": -1.0144927536231894, \"y2\": 3.0434782608695645, \"center_x\": -1.1594202898550732, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.0033981581993035538}, {\"x\": -1.0144927536231876, \"y\": 2.753623188405797, \"x2\": -0.72463768115942, \"y2\": 3.0434782608695645, \"center_x\": -0.8695652173913038, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.004012435780324067}, {\"x\": -0.72463768115942, \"y\": 2.753623188405797, \"x2\": -0.43478260869565233, \"y2\": 3.0434782608695645, \"center_x\": -0.5797101449275361, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.004693733311662716}, {\"x\": -0.43478260869565233, \"y\": 2.753623188405797, \"x2\": -0.1449275362318847, \"y2\": 3.0434782608695645, \"center_x\": -0.2898550724637685, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.005439694883722322}, {\"x\": -0.14492753623188293, \"y\": 2.753623188405797, \"x2\": 0.1449275362318847, \"y2\": 3.0434782608695645, \"center_x\": 8.881784197001252e-16, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.006245633348933196}, {\"x\": 0.1449275362318847, \"y\": 2.753623188405797, \"x2\": 0.43478260869565233, \"y2\": 3.0434782608695645, \"center_x\": 0.2898550724637685, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.007104348291790332}, {\"x\": 0.43478260869565233, \"y\": 2.753623188405797, \"x2\": 0.72463768115942, \"y2\": 3.0434782608695645, \"center_x\": 0.5797101449275361, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.008006041159953762}, {\"x\": 0.72463768115942, \"y\": 2.753623188405797, \"x2\": 1.0144927536231876, \"y2\": 3.0434782608695645, \"center_x\": 0.8695652173913038, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.008938346924722965}, {\"x\": 1.0144927536231894, \"y\": 2.753623188405797, \"x2\": 1.304347826086957, \"y2\": 3.0434782608695645, \"center_x\": 1.1594202898550732, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.009886496340014353}, {\"x\": 1.304347826086957, \"y\": 2.753623188405797, \"x2\": 1.5942028985507246, \"y2\": 3.0434782608695645, \"center_x\": 1.4492753623188408, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.010833615739769736}, {\"x\": 1.5942028985507246, \"y\": 2.753623188405797, \"x2\": 1.8840579710144922, \"y2\": 3.0434782608695645, \"center_x\": 1.7391304347826084, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.011761162742523815}, {\"x\": 1.884057971014494, \"y\": 2.753623188405797, \"x2\": 2.1739130434782616, \"y2\": 3.0434782608695645, \"center_x\": 2.028985507246378, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.012649486796134986}, {\"x\": 2.1739130434782616, \"y\": 2.753623188405797, \"x2\": 2.4637681159420293, \"y2\": 3.0434782608695645, \"center_x\": 2.3188405797101455, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.013478493923514094}, {\"x\": 2.4637681159420293, \"y\": 2.753623188405797, \"x2\": 2.753623188405797, \"y2\": 3.0434782608695645, \"center_x\": 2.608695652173913, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.014228386139430085}, {\"x\": 2.753623188405797, \"y\": 2.753623188405797, \"x2\": 3.0434782608695645, \"y2\": 3.0434782608695645, \"center_x\": 2.8985507246376807, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.01488043862919289}, {\"x\": 3.0434782608695663, \"y\": 2.753623188405797, \"x2\": 3.333333333333334, \"y2\": 3.0434782608695645, \"center_x\": 3.18840579710145, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.015417772668133087}, {\"x\": 3.333333333333334, \"y\": 2.753623188405797, \"x2\": 3.6231884057971016, \"y2\": 3.0434782608695645, \"center_x\": 3.4782608695652177, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.015826080012913326}, {\"x\": 3.6231884057971016, \"y\": 2.753623188405797, \"x2\": 3.913043478260869, \"y2\": 3.0434782608695645, \"center_x\": 3.7681159420289854, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.016094255475699756}, {\"x\": 3.913043478260871, \"y\": 2.753623188405797, \"x2\": 4.202898550724639, \"y2\": 3.0434782608695645, \"center_x\": 4.057971014492755, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.01621489867948244}, {\"x\": 4.202898550724639, \"y\": 2.753623188405797, \"x2\": 4.492753623188406, \"y2\": 3.0434782608695645, \"center_x\": 4.347826086956522, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.01618465335975242}, {\"x\": 4.492753623188406, \"y\": 2.753623188405797, \"x2\": 4.782608695652174, \"y2\": 3.0434782608695645, \"center_x\": 4.63768115942029, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.016004362500665503}, {\"x\": 4.782608695652174, \"y\": 2.753623188405797, \"x2\": 5.0724637681159415, \"y2\": 3.0434782608695645, \"center_x\": 4.927536231884058, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.015679029297509334}, {\"x\": 5.072463768115943, \"y\": 2.753623188405797, \"x2\": 5.362318840579711, \"y2\": 3.0434782608695645, \"center_x\": 5.217391304347827, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.01521758646854096}, {\"x\": 5.362318840579711, \"y\": 2.753623188405797, \"x2\": 5.6521739130434785, \"y2\": 3.0434782608695645, \"center_x\": 5.507246376811595, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.014632488761497914}, {\"x\": 5.6521739130434785, \"y\": 2.753623188405797, \"x2\": 5.942028985507246, \"y2\": 3.0434782608695645, \"center_x\": 5.797101449275362, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.013939154597824402}, {\"x\": 5.942028985507246, \"y\": 2.753623188405797, \"x2\": 6.231884057971014, \"y2\": 3.0434782608695645, \"center_x\": 6.08695652173913, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.013155291778481145}, {\"x\": 6.2318840579710155, \"y\": 2.753623188405797, \"x2\": 6.521739130434783, \"y2\": 3.0434782608695645, \"center_x\": 6.376811594202899, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.012300148357168889}, {\"x\": 6.521739130434785, \"y\": 2.753623188405797, \"x2\": 6.8115942028985526, \"y2\": 3.0434782608695645, \"center_x\": 6.666666666666669, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.011393732761146198}, {\"x\": 6.811594202898551, \"y\": 2.753623188405797, \"x2\": 7.101449275362318, \"y2\": 3.0434782608695645, \"center_x\": 6.956521739130435, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.010456046902358577}, {\"x\": 7.10144927536232, \"y\": 2.753623188405797, \"x2\": 7.391304347826088, \"y2\": 3.0434782608695645, \"center_x\": 7.246376811594204, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.00950637256998089}, {\"x\": 7.391304347826086, \"y\": 2.753623188405797, \"x2\": 7.681159420289854, \"y2\": 3.0434782608695645, \"center_x\": 7.53623188405797, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.008562645294301409}, {\"x\": 7.681159420289855, \"y\": 2.753623188405797, \"x2\": 7.971014492753623, \"y2\": 3.0434782608695645, \"center_x\": 7.826086956521739, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.00764094179117375}, {\"x\": 7.971014492753625, \"y\": 2.753623188405797, \"x2\": 8.260869565217392, \"y2\": 3.0434782608695645, \"center_x\": 8.115942028985508, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.0067550978321351445}, {\"x\": 8.26086956521739, \"y\": 2.753623188405797, \"x2\": 8.550724637681158, \"y2\": 3.0434782608695645, \"center_x\": 8.405797101449274, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.005916463772992945}, {\"x\": 8.55072463768116, \"y\": 2.753623188405797, \"x2\": 8.840579710144928, \"y2\": 3.0434782608695645, \"center_x\": 8.695652173913043, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.0051337958036886434}, {\"x\": 8.84057971014493, \"y\": 2.753623188405797, \"x2\": 9.130434782608697, \"y2\": 3.0434782608695645, \"center_x\": 8.985507246376812, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.004413272928546124}, {\"x\": 9.130434782608695, \"y\": 2.753623188405797, \"x2\": 9.420289855072463, \"y2\": 3.0434782608695645, \"center_x\": 9.275362318840578, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.0037586232536219915}, {\"x\": 9.420289855072465, \"y\": 2.753623188405797, \"x2\": 9.710144927536232, \"y2\": 3.0434782608695645, \"center_x\": 9.565217391304348, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.003171338653535138}, {\"x\": 9.710144927536234, \"y\": 2.753623188405797, \"x2\": 10.000000000000002, \"y2\": 3.0434782608695645, \"center_x\": 9.855072463768117, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.002650954416857331}, {\"x\": 10.0, \"y\": 2.753623188405797, \"x2\": 10.289855072463768, \"y2\": 3.0434782608695645, \"center_x\": 10.144927536231883, \"center_y\": 2.8985507246376807, \"value_uncond\": 0.0021953699423622308}, {\"x\": -10.0, \"y\": 3.0434782608695663, \"x2\": -9.710144927536232, \"y2\": 3.333333333333334, \"center_x\": -9.855072463768117, \"center_y\": 3.18840579710145, \"value_uncond\": 3.137026763368097e-07}, {\"x\": -9.710144927536232, \"y\": 3.0434782608695663, \"x2\": -9.420289855072465, \"y2\": 3.333333333333334, \"center_x\": -9.565217391304348, \"center_y\": 3.18840579710145, \"value_uncond\": 4.901266178267039e-07}, {\"x\": -9.420289855072463, \"y\": 3.0434782608695663, \"x2\": -9.130434782608695, \"y2\": 3.333333333333334, \"center_x\": -9.275362318840578, \"center_y\": 3.18840579710145, \"value_uncond\": 7.586547273543421e-07}, {\"x\": -9.130434782608695, \"y\": 3.0434782608695663, \"x2\": -8.840579710144928, \"y2\": 3.333333333333334, \"center_x\": -8.985507246376812, \"center_y\": 3.18840579710145, \"value_uncond\": 1.1633914356796134e-06}, {\"x\": -8.840579710144928, \"y\": 3.0434782608695663, \"x2\": -8.55072463768116, \"y2\": 3.333333333333334, \"center_x\": -8.695652173913043, \"center_y\": 3.18840579710145, \"value_uncond\": 1.7674753717998176e-06}, {\"x\": -8.55072463768116, \"y\": 3.0434782608695663, \"x2\": -8.260869565217392, \"y2\": 3.333333333333334, \"center_x\": -8.405797101449277, \"center_y\": 3.18840579710145, \"value_uncond\": 2.6602759859656123e-06}, {\"x\": -8.26086956521739, \"y\": 3.0434782608695663, \"x2\": -7.971014492753623, \"y2\": 3.333333333333334, \"center_x\": -8.115942028985508, \"center_y\": 3.18840579710145, \"value_uncond\": 3.966850485629838e-06}, {\"x\": -7.971014492753623, \"y\": 3.0434782608695663, \"x2\": -7.681159420289855, \"y2\": 3.333333333333334, \"center_x\": -7.826086956521739, \"center_y\": 3.18840579710145, \"value_uncond\": 5.860177680559899e-06}, {\"x\": -7.681159420289855, \"y\": 3.0434782608695663, \"x2\": -7.391304347826088, \"y2\": 3.333333333333334, \"center_x\": -7.536231884057972, \"center_y\": 3.18840579710145, \"value_uncond\": 8.57672629330027e-06}, {\"x\": -7.391304347826087, \"y\": 3.0434782608695663, \"x2\": -7.101449275362319, \"y2\": 3.333333333333334, \"center_x\": -7.246376811594203, \"center_y\": 3.18840579710145, \"value_uncond\": 1.2435926084897789e-05}, {\"x\": -7.101449275362318, \"y\": 3.0434782608695663, \"x2\": -6.811594202898551, \"y2\": 3.333333333333334, \"center_x\": -6.956521739130435, \"center_y\": 3.18840579710145, \"value_uncond\": 1.7864074774279074e-05}, {\"x\": -6.811594202898551, \"y\": 3.0434782608695663, \"x2\": -6.521739130434783, \"y2\": 3.333333333333334, \"center_x\": -6.666666666666667, \"center_y\": 3.18840579710145, \"value_uncond\": 2.542311361342594e-05}, {\"x\": -6.521739130434782, \"y\": 3.0434782608695663, \"x2\": -6.231884057971015, \"y2\": 3.333333333333334, \"center_x\": -6.3768115942028984, \"center_y\": 3.18840579710145, \"value_uncond\": 3.5844519517121926e-05}, {\"x\": -6.231884057971014, \"y\": 3.0434782608695663, \"x2\": -5.942028985507246, \"y2\": 3.333333333333334, \"center_x\": -6.08695652173913, \"center_y\": 3.18840579710145, \"value_uncond\": 5.006827197112243e-05}, {\"x\": -5.942028985507246, \"y\": 3.0434782608695663, \"x2\": -5.6521739130434785, \"y2\": 3.333333333333334, \"center_x\": -5.797101449275362, \"center_y\": 3.18840579710145, \"value_uncond\": 6.928644146605207e-05}, {\"x\": -5.6521739130434785, \"y\": 3.0434782608695663, \"x2\": -5.362318840579711, \"y2\": 3.333333333333334, \"center_x\": -5.507246376811595, \"center_y\": 3.18840579710145, \"value_uncond\": 9.499040190688058e-05}, {\"x\": -5.36231884057971, \"y\": 3.0434782608695663, \"x2\": -5.072463768115942, \"y2\": 3.333333333333334, \"center_x\": -5.217391304347826, \"center_y\": 3.18840579710145, \"value_uncond\": 0.00012901999129803215}, {\"x\": -5.0724637681159415, \"y\": 3.0434782608695663, \"x2\": -4.782608695652174, \"y2\": 3.333333333333334, \"center_x\": -4.927536231884058, \"center_y\": 3.18840579710145, \"value_uncond\": 0.00017361214620093563}, {\"x\": -4.782608695652174, \"y\": 3.0434782608695663, \"x2\": -4.492753623188406, \"y2\": 3.333333333333334, \"center_x\": -4.63768115942029, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0002314456475332996}, {\"x\": -4.492753623188405, \"y\": 3.0434782608695663, \"x2\": -4.202898550724638, \"y2\": 3.333333333333334, \"center_x\": -4.3478260869565215, \"center_y\": 3.18840579710145, \"value_uncond\": 0.00030567769140861566}, {\"x\": -4.202898550724638, \"y\": 3.0434782608695663, \"x2\": -3.91304347826087, \"y2\": 3.333333333333334, \"center_x\": -4.057971014492754, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0003999671155092253}, {\"x\": -3.913043478260869, \"y\": 3.0434782608695663, \"x2\": -3.6231884057971016, \"y2\": 3.333333333333334, \"center_x\": -3.7681159420289854, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0005184783683895163}, {\"x\": -3.6231884057971016, \"y\": 3.0434782608695663, \"x2\": -3.333333333333334, \"y2\": 3.333333333333334, \"center_x\": -3.4782608695652177, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0006658598246582143}, {\"x\": -3.333333333333333, \"y\": 3.0434782608695663, \"x2\": -3.0434782608695654, \"y2\": 3.333333333333334, \"center_x\": -3.1884057971014492, \"center_y\": 3.18840579710145, \"value_uncond\": 0.000847189953376477}, {\"x\": -3.0434782608695645, \"y\": 3.0434782608695663, \"x2\": -2.753623188405797, \"y2\": 3.333333333333334, \"center_x\": -2.8985507246376807, \"center_y\": 3.18840579710145, \"value_uncond\": 0.001067885270673787}, {\"x\": -2.753623188405797, \"y\": 3.0434782608695663, \"x2\": -2.4637681159420293, \"y2\": 3.333333333333334, \"center_x\": -2.608695652173913, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0013335650661888887}, {\"x\": -2.4637681159420284, \"y\": 3.0434782608695663, \"x2\": -2.1739130434782608, \"y2\": 3.333333333333334, \"center_x\": -2.3188405797101446, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0016498696696066464}, {\"x\": -2.1739130434782608, \"y\": 3.0434782608695663, \"x2\": -1.8840579710144931, \"y2\": 3.333333333333334, \"center_x\": -2.028985507246377, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0020222315499640042}, {\"x\": -1.8840579710144922, \"y\": 3.0434782608695663, \"x2\": -1.5942028985507246, \"y2\": 3.333333333333334, \"center_x\": -1.7391304347826084, \"center_y\": 3.18840579710145, \"value_uncond\": 0.002455601778985758}, {\"x\": -1.5942028985507246, \"y\": 3.0434782608695663, \"x2\": -1.304347826086957, \"y2\": 3.333333333333334, \"center_x\": -1.4492753623188408, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0029541382196973053}, {\"x\": -1.304347826086957, \"y\": 3.0434782608695663, \"x2\": -1.0144927536231894, \"y2\": 3.333333333333334, \"center_x\": -1.1594202898550732, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0035208660115993097}, {\"x\": -1.0144927536231876, \"y\": 3.0434782608695663, \"x2\": -0.72463768115942, \"y2\": 3.333333333333334, \"center_x\": -0.8695652173913038, \"center_y\": 3.18840579710145, \"value_uncond\": 0.004157325213865357}, {\"x\": -0.72463768115942, \"y\": 3.0434782608695663, \"x2\": -0.43478260869565233, \"y2\": 3.333333333333334, \"center_x\": -0.5797101449275361, \"center_y\": 3.18840579710145, \"value_uncond\": 0.004863224463161162}, {\"x\": -0.43478260869565233, \"y\": 3.0434782608695663, \"x2\": -0.1449275362318847, \"y2\": 3.333333333333334, \"center_x\": -0.2898550724637685, \"center_y\": 3.18840579710145, \"value_uncond\": 0.005636122777772336}, {\"x\": -0.14492753623188293, \"y\": 3.0434782608695663, \"x2\": 0.1449275362318847, \"y2\": 3.333333333333334, \"center_x\": 8.881784197001252e-16, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0064711637567894525}, {\"x\": 0.1449275362318847, \"y\": 3.0434782608695663, \"x2\": 0.43478260869565233, \"y2\": 3.333333333333334, \"center_x\": 0.2898550724637685, \"center_y\": 3.18840579710145, \"value_uncond\": 0.007360886977026161}, {\"x\": 0.43478260869565233, \"y\": 3.0434782608695663, \"x2\": 0.72463768115942, \"y2\": 3.333333333333334, \"center_x\": 0.5797101449275361, \"center_y\": 3.18840579710145, \"value_uncond\": 0.008295140059495594}, {\"x\": 0.72463768115942, \"y\": 3.0434782608695663, \"x2\": 1.0144927536231876, \"y2\": 3.333333333333334, \"center_x\": 0.8695652173913038, \"center_y\": 3.18840579710145, \"value_uncond\": 0.009261111473147475}, {\"x\": 1.0144927536231894, \"y\": 3.0434782608695663, \"x2\": 1.304347826086957, \"y2\": 3.333333333333334, \"center_x\": 1.1594202898550732, \"center_y\": 3.18840579710145, \"value_uncond\": 0.010243498653032564}, {\"x\": 1.304347826086957, \"y\": 3.0434782608695663, \"x2\": 1.5942028985507246, \"y2\": 3.333333333333334, \"center_x\": 1.4492753623188408, \"center_y\": 3.18840579710145, \"value_uncond\": 0.01122481862342373}, {\"x\": 1.5942028985507246, \"y\": 3.0434782608695663, \"x2\": 1.8840579710144922, \"y2\": 3.333333333333334, \"center_x\": 1.7391304347826084, \"center_y\": 3.18840579710145, \"value_uncond\": 0.012185859435716389}, {\"x\": 1.884057971014494, \"y\": 3.0434782608695663, \"x2\": 2.1739130434782616, \"y2\": 3.333333333333334, \"center_x\": 2.028985507246378, \"center_y\": 3.18840579710145, \"value_uncond\": 0.013106260954482262}, {\"x\": 2.1739130434782616, \"y\": 3.0434782608695663, \"x2\": 2.4637681159420293, \"y2\": 3.333333333333334, \"center_x\": 2.3188405797101455, \"center_y\": 3.18840579710145, \"value_uncond\": 0.013965203607228947}, {\"x\": 2.4637681159420293, \"y\": 3.0434782608695663, \"x2\": 2.753623188405797, \"y2\": 3.333333333333334, \"center_x\": 2.608695652173913, \"center_y\": 3.18840579710145, \"value_uncond\": 0.014742174501615976}, {\"x\": 2.753623188405797, \"y\": 3.0434782608695663, \"x2\": 3.0434782608695645, \"y2\": 3.333333333333334, \"center_x\": 2.8985507246376807, \"center_y\": 3.18840579710145, \"value_uncond\": 0.015417772668133087}, {\"x\": 3.0434782608695663, \"y\": 3.0434782608695663, \"x2\": 3.333333333333334, \"y2\": 3.333333333333334, \"center_x\": 3.18840579710145, \"center_y\": 3.18840579710145, \"value_uncond\": 0.015974509889774988}, {\"x\": 3.333333333333334, \"y\": 3.0434782608695663, \"x2\": 3.6231884057971016, \"y2\": 3.333333333333334, \"center_x\": 3.4782608695652177, \"center_y\": 3.18840579710145, \"value_uncond\": 0.016397561251191222}, {\"x\": 3.6231884057971016, \"y\": 3.0434782608695663, \"x2\": 3.913043478260869, \"y2\": 3.333333333333334, \"center_x\": 3.7681159420289854, \"center_y\": 3.18840579710145, \"value_uncond\": 0.016675420555170413}, {\"x\": 3.913043478260871, \"y\": 3.0434782608695663, \"x2\": 4.202898550724639, \"y2\": 3.333333333333334, \"center_x\": 4.057971014492755, \"center_y\": 3.18840579710145, \"value_uncond\": 0.016800420196392517}, {\"x\": 4.202898550724639, \"y\": 3.0434782608695663, \"x2\": 4.492753623188406, \"y2\": 3.333333333333334, \"center_x\": 4.347826086956522, \"center_y\": 3.18840579710145, \"value_uncond\": 0.016769082715321383}, {\"x\": 4.492753623188406, \"y\": 3.0434782608695663, \"x2\": 4.782608695652174, \"y2\": 3.333333333333334, \"center_x\": 4.63768115942029, \"center_y\": 3.18840579710145, \"value_uncond\": 0.01658228153635001}, {\"x\": 4.782608695652174, \"y\": 3.0434782608695663, \"x2\": 5.0724637681159415, \"y2\": 3.333333333333334, \"center_x\": 4.927536231884058, \"center_y\": 3.18840579710145, \"value_uncond\": 0.016245200520618588}, {\"x\": 5.072463768115943, \"y\": 3.0434782608695663, \"x2\": 5.362318840579711, \"y2\": 3.333333333333334, \"center_x\": 5.217391304347827, \"center_y\": 3.18840579710145, \"value_uncond\": 0.015767094947680884}, {\"x\": 5.362318840579711, \"y\": 3.0434782608695663, \"x2\": 5.6521739130434785, \"y2\": 3.333333333333334, \"center_x\": 5.507246376811595, \"center_y\": 3.18840579710145, \"value_uncond\": 0.015160869307387047}, {\"x\": 5.6521739130434785, \"y\": 3.0434782608695663, \"x2\": 5.942028985507246, \"y2\": 3.333333333333334, \"center_x\": 5.797101449275362, \"center_y\": 3.18840579710145, \"value_uncond\": 0.01444249878183029}, {\"x\": 5.942028985507246, \"y\": 3.0434782608695663, \"x2\": 6.231884057971014, \"y2\": 3.333333333333334, \"center_x\": 6.08695652173913, \"center_y\": 3.18840579710145, \"value_uncond\": 0.013630330602330078}, {\"x\": 6.2318840579710155, \"y\": 3.0434782608695663, \"x2\": 6.521739130434783, \"y2\": 3.333333333333334, \"center_x\": 6.376811594202899, \"center_y\": 3.18840579710145, \"value_uncond\": 0.012744307871617264}, {\"x\": 6.521739130434785, \"y\": 3.0434782608695663, \"x2\": 6.8115942028985526, \"y2\": 3.333333333333334, \"center_x\": 6.666666666666669, \"center_y\": 3.18840579710145, \"value_uncond\": 0.011805161523141232}, {\"x\": 6.811594202898551, \"y\": 3.0434782608695663, \"x2\": 7.101449275362318, \"y2\": 3.333333333333334, \"center_x\": 6.956521739130435, \"center_y\": 3.18840579710145, \"value_uncond\": 0.010833615739769736}, {\"x\": 7.10144927536232, \"y\": 3.0434782608695663, \"x2\": 7.391304347826088, \"y2\": 3.333333333333334, \"center_x\": 7.246376811594204, \"center_y\": 3.18840579710145, \"value_uncond\": 0.00984964857789889}, {\"x\": 7.391304347826086, \"y\": 3.0434782608695663, \"x2\": 7.681159420289854, \"y2\": 3.333333333333334, \"center_x\": 7.53623188405797, \"center_y\": 3.18840579710145, \"value_uncond\": 0.008871843221503157}, {\"x\": 7.681159420289855, \"y\": 3.0434782608695663, \"x2\": 7.971014492753623, \"y2\": 3.333333333333334, \"center_x\": 7.826086956521739, \"center_y\": 3.18840579710145, \"value_uncond\": 0.007916856918158218}, {\"x\": 7.971014492753625, \"y\": 3.0434782608695663, \"x2\": 8.260869565217392, \"y2\": 3.333333333333334, \"center_x\": 8.115942028985508, \"center_y\": 3.18840579710145, \"value_uncond\": 0.006999025050413267}, {\"x\": 8.26086956521739, \"y\": 3.0434782608695663, \"x2\": 8.550724637681158, \"y2\": 3.333333333333334, \"center_x\": 8.405797101449274, \"center_y\": 3.18840579710145, \"value_uncond\": 0.00613010783649177}, {\"x\": 8.55072463768116, \"y\": 3.0434782608695663, \"x2\": 8.840579710144928, \"y2\": 3.333333333333334, \"center_x\": 8.695652173913043, \"center_y\": 3.18840579710145, \"value_uncond\": 0.005319177653177839}, {\"x\": 8.84057971014493, \"y\": 3.0434782608695663, \"x2\": 9.130434782608697, \"y2\": 3.333333333333334, \"center_x\": 8.985507246376812, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0045726366292228515}, {\"x\": 9.130434782608695, \"y\": 3.0434782608695663, \"x2\": 9.420289855072463, \"y2\": 3.333333333333334, \"center_x\": 9.275362318840578, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0038943474929438796}, {\"x\": 9.420289855072465, \"y\": 3.0434782608695663, \"x2\": 9.710144927536232, \"y2\": 3.333333333333334, \"center_x\": 9.565217391304348, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0032858559906926666}, {\"x\": 9.710144927536234, \"y\": 3.0434782608695663, \"x2\": 10.000000000000002, \"y2\": 3.333333333333334, \"center_x\": 9.855072463768117, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0027466806302675847}, {\"x\": 10.0, \"y\": 3.0434782608695663, \"x2\": 10.289855072463768, \"y2\": 3.333333333333334, \"center_x\": 10.144927536231883, \"center_y\": 3.18840579710145, \"value_uncond\": 0.0022746449575343722}, {\"x\": -10.0, \"y\": 3.333333333333334, \"x2\": -9.710144927536232, \"y2\": 3.6231884057971016, \"center_x\": -9.855072463768117, \"center_y\": 3.4782608695652177, \"value_uncond\": 3.2201043320822097e-07}, {\"x\": -9.710144927536232, \"y\": 3.333333333333334, \"x2\": -9.420289855072465, \"y2\": 3.6231884057971016, \"center_x\": -9.565217391304348, \"center_y\": 3.4782608695652177, \"value_uncond\": 5.031065924468107e-07}, {\"x\": -9.420289855072463, \"y\": 3.333333333333334, \"x2\": -9.130434782608695, \"y2\": 3.6231884057971016, \"center_x\": -9.275362318840578, \"center_y\": 3.4782608695652177, \"value_uncond\": 7.787461052724562e-07}, {\"x\": -9.130434782608695, \"y\": 3.333333333333334, \"x2\": -8.840579710144928, \"y2\": 3.6231884057971016, \"center_x\": -8.985507246376812, \"center_y\": 3.4782608695652177, \"value_uncond\": 1.1942014157115696e-06}, {\"x\": -8.840579710144928, \"y\": 3.333333333333334, \"x2\": -8.55072463768116, \"y2\": 3.6231884057971016, \"center_x\": -8.695652173913043, \"center_y\": 3.4782608695652177, \"value_uncond\": 1.814283246812509e-06}, {\"x\": -8.55072463768116, \"y\": 3.333333333333334, \"x2\": -8.260869565217392, \"y2\": 3.6231884057971016, \"center_x\": -8.405797101449277, \"center_y\": 3.4782608695652177, \"value_uncond\": 2.7307278111152564e-06}, {\"x\": -8.26086956521739, \"y\": 3.333333333333334, \"x2\": -7.971014492753623, \"y2\": 3.6231884057971016, \"center_x\": -8.115942028985508, \"center_y\": 3.4782608695652177, \"value_uncond\": 4.071904193697249e-06}, {\"x\": -7.971014492753623, \"y\": 3.333333333333334, \"x2\": -7.681159420289855, \"y2\": 3.6231884057971016, \"center_x\": -7.826086956521739, \"center_y\": 3.4782608695652177, \"value_uncond\": 6.015372184992783e-06}, {\"x\": -7.681159420289855, \"y\": 3.333333333333334, \"x2\": -7.391304347826088, \"y2\": 3.6231884057971016, \"center_x\": -7.536231884057972, \"center_y\": 3.4782608695652177, \"value_uncond\": 8.803862885277813e-06}, {\"x\": -7.391304347826087, \"y\": 3.333333333333334, \"x2\": -7.101449275362319, \"y2\": 3.6231884057971016, \"center_x\": -7.246376811594203, \"center_y\": 3.4782608695652177, \"value_uncond\": 1.2765265482287069e-05}, {\"x\": -7.101449275362318, \"y\": 3.333333333333334, \"x2\": -6.811594202898551, \"y2\": 3.6231884057971016, \"center_x\": -6.956521739130435, \"center_y\": 3.4782608695652177, \"value_uncond\": 1.833716729516683e-05}, {\"x\": -6.811594202898551, \"y\": 3.333333333333334, \"x2\": -6.521739130434783, \"y2\": 3.6231884057971016, \"center_x\": -6.666666666666667, \"center_y\": 3.4782608695652177, \"value_uncond\": 2.6096391410354376e-05}, {\"x\": -6.521739130434782, \"y\": 3.333333333333334, \"x2\": -6.231884057971015, \"y2\": 3.6231884057971016, \"center_x\": -6.3768115942028984, \"center_y\": 3.4782608695652177, \"value_uncond\": 3.679378637323594e-05}, {\"x\": -6.231884057971014, \"y\": 3.333333333333334, \"x2\": -5.942028985507246, \"y2\": 3.6231884057971016, \"center_x\": -6.08695652173913, \"center_y\": 3.4782608695652177, \"value_uncond\": 5.1394225053082035e-05}, {\"x\": -5.942028985507246, \"y\": 3.333333333333334, \"x2\": -5.6521739130434785, \"y2\": 3.6231884057971016, \"center_x\": -5.797101449275362, \"center_y\": 3.4782608695652177, \"value_uncond\": 7.112134742511759e-05}, {\"x\": -5.6521739130434785, \"y\": 3.333333333333334, \"x2\": -5.362318840579711, \"y2\": 3.6231884057971016, \"center_x\": -5.507246376811595, \"center_y\": 3.4782608695652177, \"value_uncond\": 9.75060233015565e-05}, {\"x\": -5.36231884057971, \"y\": 3.333333333333334, \"x2\": -5.072463768115942, \"y2\": 3.6231884057971016, \"center_x\": -5.217391304347826, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.00013243681493426023}, {\"x\": -5.0724637681159415, \"y\": 3.333333333333334, \"x2\": -4.782608695652174, \"y2\": 3.6231884057971016, \"center_x\": -4.927536231884058, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.00017820989945380452}, {\"x\": -4.782608695652174, \"y\": 3.333333333333334, \"x2\": -4.492753623188406, \"y2\": 3.6231884057971016, \"center_x\": -4.63768115942029, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.00023757499966732003}, {\"x\": -4.492753623188405, \"y\": 3.333333333333334, \"x2\": -4.202898550724638, \"y2\": 3.6231884057971016, \"center_x\": -4.3478260869565215, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.0003137729233999119}, {\"x\": -4.202898550724638, \"y\": 3.333333333333334, \"x2\": -3.91304347826087, \"y2\": 3.6231884057971016, \"center_x\": -4.057971014492754, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.0004105594049694614}, {\"x\": -3.913043478260869, \"y\": 3.333333333333334, \"x2\": -3.6231884057971016, \"y2\": 3.6231884057971016, \"center_x\": -3.7681159420289854, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.0005322091796084853}, {\"x\": -3.6231884057971016, \"y\": 3.333333333333334, \"x2\": -3.333333333333334, \"y2\": 3.6231884057971016, \"center_x\": -3.4782608695652177, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.0006834937243695501}, {\"x\": -3.333333333333333, \"y\": 3.333333333333334, \"x2\": -3.0434782608695654, \"y2\": 3.6231884057971016, \"center_x\": -3.1884057971014492, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.000869626000906391}, {\"x\": -3.0434782608695645, \"y\": 3.333333333333334, \"x2\": -2.753623188405797, \"y2\": 3.6231884057971016, \"center_x\": -2.8985507246376807, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.001096165970408059}, {\"x\": -2.753623188405797, \"y\": 3.333333333333334, \"x2\": -2.4637681159420293, \"y2\": 3.6231884057971016, \"center_x\": -2.608695652173913, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.0013688817376036064}, {\"x\": -2.4637681159420284, \"y\": 3.333333333333334, \"x2\": -2.1739130434782608, \"y2\": 3.6231884057971016, \"center_x\": -2.3188405797101446, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.001693563004469659}, {\"x\": -2.1739130434782608, \"y\": 3.333333333333334, \"x2\": -1.8840579710144931, \"y2\": 3.6231884057971016, \"center_x\": -2.028985507246377, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.002075786107581996}, {\"x\": -1.8840579710144922, \"y\": 3.333333333333334, \"x2\": -1.5942028985507246, \"y2\": 3.6231884057971016, \"center_x\": -1.7391304347826084, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.0025206332374069643}, {\"x\": -1.5942028985507246, \"y\": 3.333333333333334, \"x2\": -1.304347826086957, \"y2\": 3.6231884057971016, \"center_x\": -1.4492753623188408, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.0030323723692441797}, {\"x\": -1.304347826086957, \"y\": 3.333333333333334, \"x2\": -1.0144927536231894, \"y2\": 3.6231884057971016, \"center_x\": -1.1594202898550732, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.0036141087570637355}, {\"x\": -1.0144927536231876, \"y\": 3.333333333333334, \"x2\": -0.72463768115942, \"y2\": 3.6231884057971016, \"center_x\": -0.8695652173913038, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.004267423245273602}, {\"x\": -0.72463768115942, \"y\": 3.333333333333334, \"x2\": -0.43478260869565233, \"y2\": 3.6231884057971016, \"center_x\": -0.5797101449275361, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.004992016754393206}, {\"x\": -0.43478260869565233, \"y\": 3.333333333333334, \"x2\": -0.1449275362318847, \"y2\": 3.6231884057971016, \"center_x\": -0.2898550724637685, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.005785383658431456}, {\"x\": -0.14492753623188293, \"y\": 3.333333333333334, \"x2\": 0.1449275362318847, \"y2\": 3.6231884057971016, \"center_x\": 8.881784197001252e-16, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.00664253894489519}, {\"x\": 0.1449275362318847, \"y\": 3.333333333333334, \"x2\": 0.43478260869565233, \"y2\": 3.6231884057971016, \"center_x\": 0.2898550724637685, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.007555824616950575}, {\"x\": 0.43478260869565233, \"y\": 3.333333333333334, \"x2\": 0.72463768115942, \"y2\": 3.6231884057971016, \"center_x\": 0.5797101449275361, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.008514819431164715}, {\"x\": 0.72463768115942, \"y\": 3.333333333333334, \"x2\": 1.0144927536231876, \"y2\": 3.6231884057971016, \"center_x\": 0.8695652173913038, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.009506372569980895}, {\"x\": 1.0144927536231894, \"y\": 3.333333333333334, \"x2\": 1.304347826086957, \"y2\": 3.6231884057971016, \"center_x\": 1.1594202898550732, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.010514776212139686}, {\"x\": 1.304347826086957, \"y\": 3.333333333333334, \"x2\": 1.5942028985507246, \"y2\": 3.6231884057971016, \"center_x\": 1.4492753623188408, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.011522084382001354}, {\"x\": 1.5942028985507246, \"y\": 3.333333333333334, \"x2\": 1.8840579710144922, \"y2\": 3.6231884057971016, \"center_x\": 1.7391304347826084, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.01250857634283142}, {\"x\": 1.884057971014494, \"y\": 3.333333333333334, \"x2\": 2.1739130434782616, \"y2\": 3.6231884057971016, \"center_x\": 2.028985507246378, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.013453352763753928}, {\"x\": 2.1739130434782616, \"y\": 3.333333333333334, \"x2\": 2.4637681159420293, \"y2\": 3.6231884057971016, \"center_x\": 2.3188405797101455, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.014335042709602577}, {\"x\": 2.4637681159420293, \"y\": 3.333333333333334, \"x2\": 2.753623188405797, \"y2\": 3.6231884057971016, \"center_x\": 2.608695652173913, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.01513259004714306}, {\"x\": 2.753623188405797, \"y\": 3.333333333333334, \"x2\": 3.0434782608695645, \"y2\": 3.6231884057971016, \"center_x\": 2.8985507246376807, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.015826080012913326}, {\"x\": 3.0434782608695663, \"y\": 3.333333333333334, \"x2\": 3.333333333333334, \"y2\": 3.6231884057971016, \"center_x\": 3.18840579710145, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.016397561251191222}, {\"x\": 3.333333333333334, \"y\": 3.333333333333334, \"x2\": 3.6231884057971016, \"y2\": 3.6231884057971016, \"center_x\": 3.4782608695652177, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.01683181623986307}, {\"x\": 3.6231884057971016, \"y\": 3.333333333333334, \"x2\": 3.913043478260869, \"y2\": 3.6231884057971016, \"center_x\": 3.7681159420289854, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.017117034064237667}, {\"x\": 3.913043478260871, \"y\": 3.333333333333334, \"x2\": 4.202898550724639, \"y2\": 3.6231884057971016, \"center_x\": 4.057971014492755, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.017245344058563587}, {\"x\": 4.202898550724639, \"y\": 3.333333333333334, \"x2\": 4.492753623188406, \"y2\": 3.6231884057971016, \"center_x\": 4.347826086956522, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.0172131766700886}, {\"x\": 4.492753623188406, \"y\": 3.333333333333334, \"x2\": 4.782608695652174, \"y2\": 3.6231884057971016, \"center_x\": 4.63768115942029, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.017021428454017287}, {\"x\": 4.782608695652174, \"y\": 3.333333333333334, \"x2\": 5.0724637681159415, \"y2\": 3.6231884057971016, \"center_x\": 4.927536231884058, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.01667542055517041}, {\"x\": 5.072463768115943, \"y\": 3.333333333333334, \"x2\": 5.362318840579711, \"y2\": 3.6231884057971016, \"center_x\": 5.217391304347827, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.016184653359752416}, {\"x\": 5.362318840579711, \"y\": 3.333333333333334, \"x2\": 5.6521739130434785, \"y2\": 3.6231884057971016, \"center_x\": 5.507246376811595, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.01556237310593858}, {\"x\": 5.6521739130434785, \"y\": 3.333333333333334, \"x2\": 5.942028985507246, \"y2\": 3.6231884057971016, \"center_x\": 5.797101449275362, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.014824978044985428}, {\"x\": 5.942028985507246, \"y\": 3.333333333333334, \"x2\": 6.231884057971014, \"y2\": 3.6231884057971016, \"center_x\": 6.08695652173913, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.01399130129612019}, {\"x\": 6.2318840579710155, \"y\": 3.333333333333334, \"x2\": 6.521739130434783, \"y2\": 3.6231884057971016, \"center_x\": 6.376811594202899, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.01308181411328583}, {\"x\": 6.521739130434785, \"y\": 3.333333333333334, \"x2\": 6.8115942028985526, \"y2\": 3.6231884057971016, \"center_x\": 6.666666666666669, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.012117796445186641}, {\"x\": 6.811594202898551, \"y\": 3.333333333333334, \"x2\": 7.101449275362318, \"y2\": 3.6231884057971016, \"center_x\": 6.956521739130435, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.011120521311170306}, {\"x\": 7.10144927536232, \"y\": 3.333333333333334, \"x2\": 7.391304347826088, \"y2\": 3.6231884057971016, \"center_x\": 7.246376811594204, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.010110495844519491}, {\"x\": 7.391304347826086, \"y\": 3.333333333333334, \"x2\": 7.681159420289854, \"y2\": 3.6231884057971016, \"center_x\": 7.53623188405797, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.0091067953658272}, {\"x\": 7.681159420289855, \"y\": 3.333333333333334, \"x2\": 7.971014492753623, \"y2\": 3.6231884057971016, \"center_x\": 7.826086956521739, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.008126518254904964}, {\"x\": 7.971014492753625, \"y\": 3.333333333333334, \"x2\": 8.260869565217392, \"y2\": 3.6231884057971016, \"center_x\": 8.115942028985508, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.007184379536816565}, {\"x\": 8.26086956521739, \"y\": 3.333333333333334, \"x2\": 8.550724637681158, \"y2\": 3.6231884057971016, \"center_x\": 8.405797101449274, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.006292450874478565}, {\"x\": 8.55072463768116, \"y\": 3.333333333333334, \"x2\": 8.840579710144928, \"y2\": 3.6231884057971016, \"center_x\": 8.695652173913043, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.005460044907529852}, {\"x\": 8.84057971014493, \"y\": 3.333333333333334, \"x2\": 9.130434782608697, \"y2\": 3.6231884057971016, \"center_x\": 8.985507246376812, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.00469373331166271}, {\"x\": 9.130434782608695, \"y\": 3.333333333333334, \"x2\": 9.420289855072463, \"y2\": 3.6231884057971016, \"center_x\": 9.275362318840578, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.003997481111445211}, {\"x\": 9.420289855072465, \"y\": 3.333333333333334, \"x2\": 9.710144927536232, \"y2\": 3.6231884057971016, \"center_x\": 9.565217391304348, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.00337287498907646}, {\"x\": 9.710144927536234, \"y\": 3.333333333333334, \"x2\": 10.000000000000002, \"y2\": 3.6231884057971016, \"center_x\": 9.855072463768117, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.002819420701044596}, {\"x\": 10.0, \"y\": 3.333333333333334, \"x2\": 10.289855072463768, \"y2\": 3.6231884057971016, \"center_x\": 10.144927536231883, \"center_y\": 3.4782608695652177, \"value_uncond\": 0.0023348841543963327}, {\"x\": -10.0, \"y\": 3.6231884057971016, \"x2\": -9.710144927536232, \"y2\": 3.913043478260869, \"center_x\": -9.855072463768117, \"center_y\": 3.7681159420289854, \"value_uncond\": 3.2746695161816275e-07}, {\"x\": -9.710144927536232, \"y\": 3.6231884057971016, \"x2\": -9.420289855072465, \"y2\": 3.913043478260869, \"center_x\": -9.565217391304348, \"center_y\": 3.7681159420289854, \"value_uncond\": 5.116318143053023e-07}, {\"x\": -9.420289855072463, \"y\": 3.6231884057971016, \"x2\": -9.130434782608695, \"y2\": 3.913043478260869, \"center_x\": -9.275362318840578, \"center_y\": 3.7681159420289854, \"value_uncond\": 7.919420828616108e-07}, {\"x\": -9.130434782608695, \"y\": 3.6231884057971016, \"x2\": -8.840579710144928, \"y2\": 3.913043478260869, \"center_x\": -8.985507246376812, \"center_y\": 3.7681159420289854, \"value_uncond\": 1.2144373501348344e-06}, {\"x\": -8.840579710144928, \"y\": 3.6231884057971016, \"x2\": -8.55072463768116, \"y2\": 3.913043478260869, \"center_x\": -8.695652173913043, \"center_y\": 3.7681159420289854, \"value_uncond\": 1.8450265672647379e-06}, {\"x\": -8.55072463768116, \"y\": 3.6231884057971016, \"x2\": -8.260869565217392, \"y2\": 3.913043478260869, \"center_x\": -8.405797101449277, \"center_y\": 3.7681159420289854, \"value_uncond\": 2.7770004316183796e-06}, {\"x\": -8.26086956521739, \"y\": 3.6231884057971016, \"x2\": -7.971014492753623, \"y2\": 3.913043478260869, \"center_x\": -8.115942028985508, \"center_y\": 3.7681159420289854, \"value_uncond\": 4.14090326299778e-06}, {\"x\": -7.971014492753623, \"y\": 3.6231884057971016, \"x2\": -7.681159420289855, \"y2\": 3.913043478260869, \"center_x\": -7.826086956521739, \"center_y\": 3.7681159420289854, \"value_uncond\": 6.117303630949506e-06}, {\"x\": -7.681159420289855, \"y\": 3.6231884057971016, \"x2\": -7.391304347826088, \"y2\": 3.913043478260869, \"center_x\": -7.536231884057972, \"center_y\": 3.7681159420289854, \"value_uncond\": 8.953045753154204e-06}, {\"x\": -7.391304347826087, \"y\": 3.6231884057971016, \"x2\": -7.101449275362319, \"y2\": 3.913043478260869, \"center_x\": -7.246376811594203, \"center_y\": 3.7681159420289854, \"value_uncond\": 1.2981574952194378e-05}, {\"x\": -7.101449275362318, \"y\": 3.6231884057971016, \"x2\": -6.811594202898551, \"y2\": 3.913043478260869, \"center_x\": -6.956521739130435, \"center_y\": 3.7681159420289854, \"value_uncond\": 1.8647893534485788e-05}, {\"x\": -6.811594202898551, \"y\": 3.6231884057971016, \"x2\": -6.521739130434783, \"y2\": 3.913043478260869, \"center_x\": -6.666666666666667, \"center_y\": 3.7681159420289854, \"value_uncond\": 2.6538598946131853e-05}, {\"x\": -6.521739130434782, \"y\": 3.6231884057971016, \"x2\": -6.231884057971015, \"y2\": 3.913043478260869, \"center_x\": -6.3768115942028984, \"center_y\": 3.7681159420289854, \"value_uncond\": 3.741726298148362e-05}, {\"x\": -6.231884057971014, \"y\": 3.6231884057971016, \"x2\": -5.942028985507246, \"y2\": 3.913043478260869, \"center_x\": -6.08695652173913, \"center_y\": 3.7681159420289854, \"value_uncond\": 5.2265108435253366e-05}, {\"x\": -5.942028985507246, \"y\": 3.6231884057971016, \"x2\": -5.6521739130434785, \"y2\": 3.913043478260869, \"center_x\": -5.797101449275362, \"center_y\": 3.7681159420289854, \"value_uncond\": 7.232651005819936e-05}, {\"x\": -5.6521739130434785, \"y\": 3.6231884057971016, \"x2\": -5.362318840579711, \"y2\": 3.913043478260869, \"center_x\": -5.507246376811595, \"center_y\": 3.7681159420289854, \"value_uncond\": 9.91582784969064e-05}, {\"x\": -5.36231884057971, \"y\": 3.6231884057971016, \"x2\": -5.072463768115942, \"y2\": 3.913043478260869, \"center_x\": -5.217391304347826, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0001346809779933359}, {\"x\": -5.0724637681159415, \"y\": 3.6231884057971016, \"x2\": -4.782608695652174, \"y2\": 3.913043478260869, \"center_x\": -4.927536231884058, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0001812296947676252}, {\"x\": -4.782608695652174, \"y\": 3.6231884057971016, \"x2\": -4.492753623188406, \"y2\": 3.913043478260869, \"center_x\": -4.63768115942029, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.00024160074612066055}, {\"x\": -4.492753623188405, \"y\": 3.6231884057971016, \"x2\": -4.202898550724638, \"y2\": 3.913043478260869, \"center_x\": -4.3478260869565215, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.00031908985588565455}, {\"x\": -4.202898550724638, \"y\": 3.6231884057971016, \"x2\": -3.91304347826087, \"y2\": 3.913043478260869, \"center_x\": -4.057971014492754, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.00041751639990056063}, {\"x\": -3.913043478260869, \"y\": 3.6231884057971016, \"x2\": -3.6231884057971016, \"y2\": 3.913043478260869, \"center_x\": -3.7681159420289854, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0005412275494716628}, {\"x\": -3.6231884057971016, \"y\": 3.6231884057971016, \"x2\": -3.333333333333334, \"y2\": 3.913043478260869, \"center_x\": -3.4782608695652177, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0006950756350950657}, {\"x\": -3.333333333333333, \"y\": 3.6231884057971016, \"x2\": -3.0434782608695654, \"y2\": 3.913043478260869, \"center_x\": -3.1884057971014492, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0008843619528953801}, {\"x\": -3.0434782608695645, \"y\": 3.6231884057971016, \"x2\": -2.753623188405797, \"y2\": 3.913043478260869, \"center_x\": -2.8985507246376807, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0011147406784952837}, {\"x\": -2.753623188405797, \"y\": 3.6231884057971016, \"x2\": -2.4637681159420293, \"y2\": 3.913043478260869, \"center_x\": -2.608695652173913, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0013920776580831067}, {\"x\": -2.4637681159420284, \"y\": 3.6231884057971016, \"x2\": -2.1739130434782608, \"y2\": 3.913043478260869, \"center_x\": -2.3188405797101446, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0017222607010635757}, {\"x\": -2.1739130434782608, \"y\": 3.6231884057971016, \"x2\": -1.8840579710144931, \"y2\": 3.913043478260869, \"center_x\": -2.028985507246377, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0021109606359296495}, {\"x\": -1.8840579710144922, \"y\": 3.6231884057971016, \"x2\": -1.5942028985507246, \"y2\": 3.913043478260869, \"center_x\": -1.7391304347826084, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.002563345771679817}, {\"x\": -1.5942028985507246, \"y\": 3.6231884057971016, \"x2\": -1.304347826086957, \"y2\": 3.913043478260869, \"center_x\": -1.4492753623188408, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0030837564051393158}, {\"x\": -1.304347826086957, \"y\": 3.6231884057971016, \"x2\": -1.0144927536231894, \"y2\": 3.913043478260869, \"center_x\": -1.1594202898550732, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0036753504093045447}, {\"x\": -1.0144927536231876, \"y\": 3.6231884057971016, \"x2\": -0.72463768115942, \"y2\": 3.913043478260869, \"center_x\": -0.8695652173913038, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.00433973541624538}, {\"x\": -0.72463768115942, \"y\": 3.6231884057971016, \"x2\": -0.43478260869565233, \"y2\": 3.913043478260869, \"center_x\": -0.5797101449275361, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.005076607278531506}, {\"x\": -0.43478260869565233, \"y\": 3.6231884057971016, \"x2\": -0.1449275362318847, \"y2\": 3.913043478260869, \"center_x\": -0.2898550724637685, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.005883417911937755}, {\"x\": -0.14492753623188293, \"y\": 3.6231884057971016, \"x2\": 0.1449275362318847, \"y2\": 3.913043478260869, \"center_x\": 8.881784197001252e-16, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.006755097832135153}, {\"x\": 0.1449275362318847, \"y\": 3.6231884057971016, \"x2\": 0.43478260869565233, \"y2\": 3.913043478260869, \"center_x\": 0.2898550724637685, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.007683859276305922}, {\"x\": 0.43478260869565233, \"y\": 3.6231884057971016, \"x2\": 0.72463768115942, \"y2\": 3.913043478260869, \"center_x\": 0.5797101449275361, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.008659104411376637}, {\"x\": 0.72463768115942, \"y\": 3.6231884057971016, \"x2\": 1.0144927536231876, \"y2\": 3.913043478260869, \"center_x\": 0.8695652173913038, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.00966745957707897}, {\"x\": 1.0144927536231894, \"y\": 3.6231884057971016, \"x2\": 1.304347826086957, \"y2\": 3.913043478260869, \"center_x\": 1.1594202898550732, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.01069295078060424}, {\"x\": 1.304347826086957, \"y\": 3.6231884057971016, \"x2\": 1.5942028985507246, \"y2\": 3.913043478260869, \"center_x\": 1.4492753623188408, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.011717327948878703}, {\"x\": 1.5942028985507246, \"y\": 3.6231884057971016, \"x2\": 1.8840579710144922, \"y2\": 3.913043478260869, \"center_x\": 1.7391304347826084, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.012720536174122625}, {\"x\": 1.884057971014494, \"y\": 3.6231884057971016, \"x2\": 2.1739130434782616, \"y2\": 3.913043478260869, \"center_x\": 2.028985507246378, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.013681321982948132}, {\"x\": 2.1739130434782616, \"y\": 3.6231884057971016, \"x2\": 2.4637681159420293, \"y2\": 3.913043478260869, \"center_x\": 2.3188405797101455, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.014577952306266703}, {\"x\": 2.4637681159420293, \"y\": 3.6231884057971016, \"x2\": 2.753623188405797, \"y2\": 3.913043478260869, \"center_x\": 2.608695652173913, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.015389014211291014}, {\"x\": 2.753623188405797, \"y\": 3.6231884057971016, \"x2\": 3.0434782608695645, \"y2\": 3.913043478260869, \"center_x\": 2.8985507246376807, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.016094255475699756}, {\"x\": 3.0434782608695663, \"y\": 3.6231884057971016, \"x2\": 3.333333333333334, \"y2\": 3.913043478260869, \"center_x\": 3.18840579710145, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.016675420555170413}, {\"x\": 3.333333333333334, \"y\": 3.6231884057971016, \"x2\": 3.6231884057971016, \"y2\": 3.913043478260869, \"center_x\": 3.4782608695652177, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.017117034064237667}, {\"x\": 3.6231884057971016, \"y\": 3.6231884057971016, \"x2\": 3.913043478260869, \"y2\": 3.913043478260869, \"center_x\": 3.7681159420289854, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.017407084950367555}, {\"x\": 3.913043478260871, \"y\": 3.6231884057971016, \"x2\": 4.202898550724639, \"y2\": 3.913043478260869, \"center_x\": 4.057971014492755, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.017537569178115803}, {\"x\": 4.202898550724639, \"y\": 3.6231884057971016, \"x2\": 4.492753623188406, \"y2\": 3.913043478260869, \"center_x\": 4.347826086956522, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.017504856708086578}, {\"x\": 4.492753623188406, \"y\": 3.6231884057971016, \"x2\": 4.782608695652174, \"y2\": 3.913043478260869, \"center_x\": 4.63768115942029, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.01730985928775613}, {\"x\": 4.782608695652174, \"y\": 3.6231884057971016, \"x2\": 5.0724637681159415, \"y2\": 3.913043478260869, \"center_x\": 4.927536231884058, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0169579882295972}, {\"x\": 5.072463768115943, \"y\": 3.6231884057971016, \"x2\": 5.362318840579711, \"y2\": 3.913043478260869, \"center_x\": 5.217391304347827, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.01645890490538141}, {\"x\": 5.362318840579711, \"y\": 3.6231884057971016, \"x2\": 5.6521739130434785, \"y2\": 3.913043478260869, \"center_x\": 5.507246376811595, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.015826080012913323}, {\"x\": 5.6521739130434785, \"y\": 3.6231884057971016, \"x2\": 5.942028985507246, \"y2\": 3.913043478260869, \"center_x\": 5.797101449275362, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.015076189674445703}, {\"x\": 5.942028985507246, \"y\": 3.6231884057971016, \"x2\": 6.231884057971014, \"y2\": 3.913043478260869, \"center_x\": 6.08695652173913, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.014228386139430086}, {\"x\": 6.2318840579710155, \"y\": 3.6231884057971016, \"x2\": 6.521739130434783, \"y2\": 3.913043478260869, \"center_x\": 6.376811594202899, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.013303487550489101}, {\"x\": 6.521739130434785, \"y\": 3.6231884057971016, \"x2\": 6.8115942028985526, \"y2\": 3.913043478260869, \"center_x\": 6.666666666666669, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.012323134448469077}, {\"x\": 6.811594202898551, \"y\": 3.6231884057971016, \"x2\": 7.101449275362318, \"y2\": 3.913043478260869, \"center_x\": 6.956521739130435, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.011308960327440668}, {\"x\": 7.10144927536232, \"y\": 3.6231884057971016, \"x2\": 7.391304347826088, \"y2\": 3.913043478260869, \"center_x\": 7.246376811594204, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.010281819817347378}, {\"x\": 7.391304347826086, \"y\": 3.6231884057971016, \"x2\": 7.681159420289854, \"y2\": 3.913043478260869, \"center_x\": 7.53623188405797, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.009261111473147477}, {\"x\": 7.681159420289855, \"y\": 3.6231884057971016, \"x2\": 7.971014492753623, \"y2\": 3.913043478260869, \"center_x\": 7.826086956521739, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.008264223409439334}, {\"x\": 7.971014492753625, \"y\": 3.6231884057971016, \"x2\": 8.260869565217392, \"y2\": 3.913043478260869, \"center_x\": 8.115942028985508, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0073061199997452924}, {\"x\": 8.26086956521739, \"y\": 3.6231884057971016, \"x2\": 8.550724637681158, \"y2\": 3.913043478260869, \"center_x\": 8.405797101449274, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.006399077463245162}, {\"x\": 8.55072463768116, \"y\": 3.6231884057971016, \"x2\": 8.840579710144928, \"y2\": 3.913043478260869, \"center_x\": 8.695652173913043, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.005552566243749356}, {\"x\": 8.84057971014493, \"y\": 3.6231884057971016, \"x2\": 9.130434782608697, \"y2\": 3.913043478260869, \"center_x\": 8.985507246376812, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.004773269375048221}, {\"x\": 9.130434782608695, \"y\": 3.6231884057971016, \"x2\": 9.420289855072463, \"y2\": 3.913043478260869, \"center_x\": 9.275362318840578, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.004065219069686742}, {\"x\": 9.420289855072465, \"y\": 3.6231884057971016, \"x2\": 9.710144927536232, \"y2\": 3.913043478260869, \"center_x\": 9.565217391304348, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.003430028896448236}, {\"x\": 9.710144927536234, \"y\": 3.6231884057971016, \"x2\": 10.000000000000002, \"y2\": 3.913043478260869, \"center_x\": 9.855072463768117, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.0028671962367853064}, {\"x\": 10.0, \"y\": 3.6231884057971016, \"x2\": 10.289855072463768, \"y2\": 3.913043478260869, \"center_x\": 10.144927536231883, \"center_y\": 3.7681159420289854, \"value_uncond\": 0.002374449140681441}, {\"x\": -10.0, \"y\": 3.913043478260871, \"x2\": -9.710144927536232, \"y2\": 4.202898550724639, \"center_x\": -9.855072463768117, \"center_y\": 4.057971014492755, \"value_uncond\": 3.2992165741277494e-07}, {\"x\": -9.710144927536232, \"y\": 3.913043478260871, \"x2\": -9.420289855072465, \"y2\": 4.202898550724639, \"center_x\": -9.565217391304348, \"center_y\": 4.057971014492755, \"value_uncond\": 5.154670275171308e-07}, {\"x\": -9.420289855072463, \"y\": 3.913043478260871, \"x2\": -9.130434782608695, \"y2\": 4.202898550724639, \"center_x\": -9.275362318840578, \"center_y\": 4.057971014492755, \"value_uncond\": 7.978785134241195e-07}, {\"x\": -9.130434782608695, \"y\": 3.913043478260871, \"x2\": -8.840579710144928, \"y2\": 4.202898550724639, \"center_x\": -8.985507246376812, \"center_y\": 4.057971014492755, \"value_uncond\": 1.2235408226710357e-06}, {\"x\": -8.840579710144928, \"y\": 3.913043478260871, \"x2\": -8.55072463768116, \"y2\": 4.202898550724639, \"center_x\": -8.695652173913043, \"center_y\": 4.057971014492755, \"value_uncond\": 1.8588569626176071e-06}, {\"x\": -8.55072463768116, \"y\": 3.913043478260871, \"x2\": -8.260869565217392, \"y2\": 4.202898550724639, \"center_x\": -8.405797101449277, \"center_y\": 4.057971014492755, \"value_uncond\": 2.7978169415515185e-06}, {\"x\": -8.26086956521739, \"y\": 3.913043478260871, \"x2\": -7.971014492753623, \"y2\": 4.202898550724639, \"center_x\": -8.115942028985508, \"center_y\": 4.057971014492755, \"value_uncond\": 4.171943644887863e-06}, {\"x\": -7.971014492753623, \"y\": 3.913043478260871, \"x2\": -7.681159420289855, \"y2\": 4.202898550724639, \"center_x\": -7.826086956521739, \"center_y\": 4.057971014492755, \"value_uncond\": 6.1631591916285006e-06}, {\"x\": -7.681159420289855, \"y\": 3.913043478260871, \"x2\": -7.391304347826088, \"y2\": 4.202898550724639, \"center_x\": -7.536231884057972, \"center_y\": 4.057971014492755, \"value_uncond\": 9.020158153905162e-06}, {\"x\": -7.391304347826087, \"y\": 3.913043478260871, \"x2\": -7.101449275362319, \"y2\": 4.202898550724639, \"center_x\": -7.246376811594203, \"center_y\": 4.057971014492755, \"value_uncond\": 1.3078885374210632e-05}, {\"x\": -7.101449275362318, \"y\": 3.913043478260871, \"x2\": -6.811594202898551, \"y2\": 4.202898550724639, \"center_x\": -6.956521739130435, \"center_y\": 4.057971014492755, \"value_uncond\": 1.878767891462938e-05}, {\"x\": -6.811594202898551, \"y\": 3.913043478260871, \"x2\": -6.521739130434783, \"y2\": 4.202898550724639, \"center_x\": -6.666666666666667, \"center_y\": 4.057971014492755, \"value_uncond\": 2.673753337994889e-05}, {\"x\": -6.521739130434782, \"y\": 3.913043478260871, \"x2\": -6.231884057971015, \"y2\": 4.202898550724639, \"center_x\": -6.3768115942028984, \"center_y\": 4.057971014492755, \"value_uncond\": 3.769774433022827e-05}, {\"x\": -6.231884057971014, \"y\": 3.913043478260871, \"x2\": -5.942028985507246, \"y2\": 4.202898550724639, \"center_x\": -6.08695652173913, \"center_y\": 4.057971014492755, \"value_uncond\": 5.265688984677617e-05}, {\"x\": -5.942028985507246, \"y\": 3.913043478260871, \"x2\": -5.6521739130434785, \"y2\": 4.202898550724639, \"center_x\": -5.797101449275362, \"center_y\": 4.057971014492755, \"value_uncond\": 7.28686725648786e-05}, {\"x\": -5.6521739130434785, \"y\": 3.913043478260871, \"x2\": -5.362318840579711, \"y2\": 4.202898550724639, \"center_x\": -5.507246376811595, \"center_y\": 4.057971014492755, \"value_uncond\": 9.990157304802774e-05}, {\"x\": -5.36231884057971, \"y\": 3.913043478260871, \"x2\": -5.072463768115942, \"y2\": 4.202898550724639, \"center_x\": -5.217391304347826, \"center_y\": 4.057971014492755, \"value_uncond\": 0.00013569055216706725}, {\"x\": -5.0724637681159415, \"y\": 3.913043478260871, \"x2\": -4.782608695652174, \"y2\": 4.202898550724639, \"center_x\": -4.927536231884058, \"center_y\": 4.057971014492755, \"value_uncond\": 0.0001825882000448861}, {\"x\": -4.782608695652174, \"y\": 3.913043478260871, \"x2\": -4.492753623188406, \"y2\": 4.202898550724639, \"center_x\": -4.63768115942029, \"center_y\": 4.057971014492755, \"value_uncond\": 0.00024341179529235364}, {\"x\": -4.492753623188405, \"y\": 3.913043478260871, \"x2\": -4.202898550724638, \"y2\": 4.202898550724639, \"center_x\": -4.3478260869565215, \"center_y\": 4.057971014492755, \"value_uncond\": 0.0003214817666246586}, {\"x\": -4.202898550724638, \"y\": 3.913043478260871, \"x2\": -3.91304347826087, \"y2\": 4.202898550724639, \"center_x\": -4.057971014492754, \"center_y\": 4.057971014492755, \"value_uncond\": 0.0004206461200787862}, {\"x\": -3.913043478260869, \"y\": 3.913043478260871, \"x2\": -3.6231884057971016, \"y2\": 4.202898550724639, \"center_x\": -3.7681159420289854, \"center_y\": 4.057971014492755, \"value_uncond\": 0.0005452846135366828}, {\"x\": -3.6231884057971016, \"y\": 3.913043478260871, \"x2\": -3.333333333333334, \"y2\": 4.202898550724639, \"center_x\": -3.4782608695652177, \"center_y\": 4.057971014492755, \"value_uncond\": 0.0007002859507642661}, {\"x\": -3.333333333333333, \"y\": 3.913043478260871, \"x2\": -3.0434782608695654, \"y2\": 4.202898550724639, \"center_x\": -3.1884057971014492, \"center_y\": 4.057971014492755, \"value_uncond\": 0.000890991166620855}, {\"x\": -3.0434782608695645, \"y\": 3.913043478260871, \"x2\": -2.753623188405797, \"y2\": 4.202898550724639, \"center_x\": -2.8985507246376807, \"center_y\": 4.057971014492755, \"value_uncond\": 0.001123096820663128}, {\"x\": -2.753623188405797, \"y\": 3.913043478260871, \"x2\": -2.4637681159420293, \"y2\": 4.202898550724639, \"center_x\": -2.608695652173913, \"center_y\": 4.057971014492755, \"value_uncond\": 0.0014025127297047182}, {\"x\": -2.4637681159420284, \"y\": 3.913043478260871, \"x2\": -2.1739130434782608, \"y2\": 4.202898550724639, \"center_x\": -2.3188405797101446, \"center_y\": 4.057971014492755, \"value_uncond\": 0.001735170838412833}, {\"x\": -2.1739130434782608, \"y\": 3.913043478260871, \"x2\": -1.8840579710144931, \"y2\": 4.202898550724639, \"center_x\": -2.028985507246377, \"center_y\": 4.057971014492755, \"value_uncond\": 0.002126784484045035}, {\"x\": -1.8840579710144922, \"y\": 3.913043478260871, \"x2\": -1.5942028985507246, \"y2\": 4.202898550724639, \"center_x\": -1.7391304347826084, \"center_y\": 4.057971014492755, \"value_uncond\": 0.002582560717457531}, {\"x\": -1.5942028985507246, \"y\": 3.913043478260871, \"x2\": -1.304347826086957, \"y2\": 4.202898550724639, \"center_x\": -1.4492753623188408, \"center_y\": 4.057971014492755, \"value_uncond\": 0.003106872370519827}, {\"x\": -1.304347826086957, \"y\": 3.913043478260871, \"x2\": -1.0144927536231894, \"y2\": 4.202898550724639, \"center_x\": -1.1594202898550732, \"center_y\": 4.057971014492755, \"value_uncond\": 0.0037029009877747312}, {\"x\": -1.0144927536231876, \"y\": 3.913043478260871, \"x2\": -0.72463768115942, \"y2\": 4.202898550724639, \"center_x\": -0.8695652173913038, \"center_y\": 4.057971014492755, \"value_uncond\": 0.004372266252168516}, {\"x\": -0.72463768115942, \"y\": 3.913043478260871, \"x2\": -0.43478260869565233, \"y2\": 4.202898550724639, \"center_x\": -0.5797101449275361, \"center_y\": 4.057971014492755, \"value_uncond\": 0.005114661736369165}, {\"x\": -0.43478260869565233, \"y\": 3.913043478260871, \"x2\": -0.1449275362318847, \"y2\": 4.202898550724639, \"center_x\": -0.2898550724637685, \"center_y\": 4.057971014492755, \"value_uncond\": 0.005927520255606916}, {\"x\": -0.14492753623188293, \"y\": 3.913043478260871, \"x2\": 0.1449275362318847, \"y2\": 4.202898550724639, \"center_x\": 8.881784197001252e-16, \"center_y\": 4.057971014492755, \"value_uncond\": 0.006805734324488884}, {\"x\": 0.1449275362318847, \"y\": 3.913043478260871, \"x2\": 0.43478260869565233, \"y2\": 4.202898550724639, \"center_x\": 0.2898550724637685, \"center_y\": 4.057971014492755, \"value_uncond\": 0.007741457802805548}, {\"x\": 0.43478260869565233, \"y\": 3.913043478260871, \"x2\": 0.72463768115942, \"y2\": 4.202898550724639, \"center_x\": 0.5797101449275361, \"center_y\": 4.057971014492755, \"value_uncond\": 0.008724013415689048}, {\"x\": 0.72463768115942, \"y\": 3.913043478260871, \"x2\": 1.0144927536231876, \"y2\": 4.202898550724639, \"center_x\": 0.8695652173913038, \"center_y\": 4.057971014492755, \"value_uncond\": 0.009739927253361315}, {\"x\": 1.0144927536231894, \"y\": 3.913043478260871, \"x2\": 1.304347826086957, \"y2\": 4.202898550724639, \"center_x\": 1.1594202898550732, \"center_y\": 4.057971014492755, \"value_uncond\": 0.010773105581303807}, {\"x\": 1.304347826086957, \"y\": 3.913043478260871, \"x2\": 1.5942028985507246, \"y2\": 4.202898550724639, \"center_x\": 1.4492753623188408, \"center_y\": 4.057971014492755, \"value_uncond\": 0.01180516152314124}, {\"x\": 1.5942028985507246, \"y\": 3.913043478260871, \"x2\": 1.8840579710144922, \"y2\": 4.202898550724639, \"center_x\": 1.7391304347826084, \"center_y\": 4.057971014492755, \"value_uncond\": 0.012815889838676837}, {\"x\": 1.884057971014494, \"y\": 3.913043478260871, \"x2\": 2.1739130434782616, \"y2\": 4.202898550724639, \"center_x\": 2.028985507246378, \"center_y\": 4.057971014492755, \"value_uncond\": 0.013783877737608386}, {\"x\": 2.1739130434782616, \"y\": 3.913043478260871, \"x2\": 2.4637681159420293, \"y2\": 4.202898550724639, \"center_x\": 2.3188405797101455, \"center_y\": 4.057971014492755, \"value_uncond\": 0.01468722923886384}, {\"x\": 2.4637681159420293, \"y\": 3.913043478260871, \"x2\": 2.753623188405797, \"y2\": 4.202898550724639, \"center_x\": 2.608695652173913, \"center_y\": 4.057971014492755, \"value_uncond\": 0.015504370897427292}, {\"x\": 2.753623188405797, \"y\": 3.913043478260871, \"x2\": 3.0434782608695645, \"y2\": 4.202898550724639, \"center_x\": 2.8985507246376807, \"center_y\": 4.057971014492755, \"value_uncond\": 0.01621489867948244}, {\"x\": 3.0434782608695663, \"y\": 3.913043478260871, \"x2\": 3.333333333333334, \"y2\": 4.202898550724639, \"center_x\": 3.18840579710145, \"center_y\": 4.057971014492755, \"value_uncond\": 0.016800420196392517}, {\"x\": 3.333333333333334, \"y\": 3.913043478260871, \"x2\": 3.6231884057971016, \"y2\": 4.202898550724639, \"center_x\": 3.4782608695652177, \"center_y\": 4.057971014492755, \"value_uncond\": 0.017245344058563587}, {\"x\": 3.6231884057971016, \"y\": 3.913043478260871, \"x2\": 3.913043478260869, \"y2\": 4.202898550724639, \"center_x\": 3.7681159420289854, \"center_y\": 4.057971014492755, \"value_uncond\": 0.017537569178115803}, {\"x\": 3.913043478260871, \"y\": 3.913043478260871, \"x2\": 4.202898550724639, \"y2\": 4.202898550724639, \"center_x\": 4.057971014492755, \"center_y\": 4.057971014492755, \"value_uncond\": 0.017669031521024604}, {\"x\": 4.202898550724639, \"y\": 3.913043478260871, \"x2\": 4.492753623188406, \"y2\": 4.202898550724639, \"center_x\": 4.347826086956522, \"center_y\": 4.057971014492755, \"value_uncond\": 0.017636073836968927}, {\"x\": 4.492753623188406, \"y\": 3.913043478260871, \"x2\": 4.782608695652174, \"y2\": 4.202898550724639, \"center_x\": 4.63768115942029, \"center_y\": 4.057971014492755, \"value_uncond\": 0.017439614707921755}, {\"x\": 4.782608695652174, \"y\": 3.913043478260871, \"x2\": 5.0724637681159415, \"y2\": 4.202898550724639, \"center_x\": 4.927536231884058, \"center_y\": 4.057971014492755, \"value_uncond\": 0.017085106009777626}, {\"x\": 5.072463768115943, \"y\": 3.913043478260871, \"x2\": 5.362318840579711, \"y2\": 4.202898550724639, \"center_x\": 5.217391304347827, \"center_y\": 4.057971014492755, \"value_uncond\": 0.016582281536350007}, {\"x\": 5.362318840579711, \"y\": 3.913043478260871, \"x2\": 5.6521739130434785, \"y2\": 4.202898550724639, \"center_x\": 5.507246376811595, \"center_y\": 4.057971014492755, \"value_uncond\": 0.015944712962350577}, {\"x\": 5.6521739130434785, \"y\": 3.913043478260871, \"x2\": 5.942028985507246, \"y2\": 4.202898550724639, \"center_x\": 5.797101449275362, \"center_y\": 4.057971014492755, \"value_uncond\": 0.01518920141493328}, {\"x\": 5.942028985507246, \"y\": 3.913043478260871, \"x2\": 6.231884057971014, \"y2\": 4.202898550724639, \"center_x\": 6.08695652173913, \"center_y\": 4.057971014492755, \"value_uncond\": 0.014335042709602576}, {\"x\": 6.2318840579710155, \"y\": 3.913043478260871, \"x2\": 6.521739130434783, \"y2\": 4.202898550724639, \"center_x\": 6.376811594202899, \"center_y\": 4.057971014492755, \"value_uncond\": 0.013403211042638046}, {\"x\": 6.521739130434785, \"y\": 3.913043478260871, \"x2\": 6.8115942028985526, \"y2\": 4.202898550724639, \"center_x\": 6.666666666666669, \"center_y\": 4.057971014492755, \"value_uncond\": 0.012415509173274013}, {\"x\": 6.811594202898551, \"y\": 3.913043478260871, \"x2\": 7.101449275362318, \"y2\": 4.202898550724639, \"center_x\": 6.956521739130435, \"center_y\": 4.057971014492755, \"value_uncond\": 0.011393732761146204}, {\"x\": 7.10144927536232, \"y\": 3.913043478260871, \"x2\": 7.391304347826088, \"y2\": 4.202898550724639, \"center_x\": 7.246376811594204, \"center_y\": 4.057971014492755, \"value_uncond\": 0.010358892763365537}, {\"x\": 7.391304347826086, \"y\": 3.913043478260871, \"x2\": 7.681159420289854, \"y2\": 4.202898550724639, \"center_x\": 7.53623188405797, \"center_y\": 4.057971014492755, \"value_uncond\": 0.009330533147259464}, {\"x\": 7.681159420289855, \"y\": 3.913043478260871, \"x2\": 7.971014492753623, \"y2\": 4.202898550724639, \"center_x\": 7.826086956521739, \"center_y\": 4.057971014492755, \"value_uncond\": 0.008326172369451556}, {\"x\": 7.971014492753625, \"y\": 3.913043478260871, \"x2\": 8.260869565217392, \"y2\": 4.202898550724639, \"center_x\": 8.115942028985508, \"center_y\": 4.057971014492755, \"value_uncond\": 0.007360886977026152}, {\"x\": 8.26086956521739, \"y\": 3.913043478260871, \"x2\": 8.550724637681158, \"y2\": 4.202898550724639, \"center_x\": 8.405797101449274, \"center_y\": 4.057971014492755, \"value_uncond\": 0.006447045212209076}, {\"x\": 8.55072463768116, \"y\": 3.913043478260871, \"x2\": 8.840579710144928, \"y2\": 4.202898550724639, \"center_x\": 8.695652173913043, \"center_y\": 4.057971014492755, \"value_uncond\": 0.005594188509648697}, {\"x\": 8.84057971014493, \"y\": 3.913043478260871, \"x2\": 9.130434782608697, \"y2\": 4.202898550724639, \"center_x\": 8.985507246376812, \"center_y\": 4.057971014492755, \"value_uncond\": 0.004809049999432683}, {\"x\": 9.130434782608695, \"y\": 3.913043478260871, \"x2\": 9.420289855072463, \"y2\": 4.202898550724639, \"center_x\": 9.275362318840578, \"center_y\": 4.057971014492755, \"value_uncond\": 0.004095692119737797}, {\"x\": 9.420289855072465, \"y\": 3.913043478260871, \"x2\": 9.710144927536232, \"y2\": 4.202898550724639, \"center_x\": 9.565217391304348, \"center_y\": 4.057971014492755, \"value_uncond\": 0.003455740534725601}, {\"x\": 9.710144927536234, \"y\": 3.913043478260871, \"x2\": 10.000000000000002, \"y2\": 4.202898550724639, \"center_x\": 9.855072463768117, \"center_y\": 4.057971014492755, \"value_uncond\": 0.0028886888581993076}, {\"x\": 10.0, \"y\": 3.913043478260871, \"x2\": 10.289855072463768, \"y2\": 4.202898550724639, \"center_x\": 10.144927536231883, \"center_y\": 4.057971014492755, \"value_uncond\": 0.002392248109511243}, {\"x\": -10.0, \"y\": 4.202898550724639, \"x2\": -9.710144927536232, \"y2\": 4.492753623188406, \"center_x\": -9.855072463768117, \"center_y\": 4.347826086956522, \"value_uncond\": 3.2930626127546e-07}, {\"x\": -9.710144927536232, \"y\": 4.202898550724639, \"x2\": -9.420289855072465, \"y2\": 4.492753623188406, \"center_x\": -9.565217391304348, \"center_y\": 4.347826086956522, \"value_uncond\": 5.145055373860044e-07}, {\"x\": -9.420289855072463, \"y\": 4.202898550724639, \"x2\": -9.130434782608695, \"y2\": 4.492753623188406, \"center_x\": -9.275362318840578, \"center_y\": 4.347826086956522, \"value_uncond\": 7.963902469094011e-07}, {\"x\": -9.130434782608695, \"y\": 4.202898550724639, \"x2\": -8.840579710144928, \"y2\": 4.492753623188406, \"center_x\": -8.985507246376812, \"center_y\": 4.347826086956522, \"value_uncond\": 1.2212585769342034e-06}, {\"x\": -8.840579710144928, \"y\": 4.202898550724639, \"x2\": -8.55072463768116, \"y2\": 4.492753623188406, \"center_x\": -8.695652173913043, \"center_y\": 4.347826086956522, \"value_uncond\": 1.8553896746451031e-06}, {\"x\": -8.55072463768116, \"y\": 4.202898550724639, \"x2\": -8.260869565217392, \"y2\": 4.492753623188406, \"center_x\": -8.405797101449277, \"center_y\": 4.347826086956522, \"value_uncond\": 2.7925982306846808e-06}, {\"x\": -8.26086956521739, \"y\": 4.202898550724639, \"x2\": -7.971014492753623, \"y2\": 4.492753623188406, \"center_x\": -8.115942028985508, \"center_y\": 4.347826086956522, \"value_uncond\": 4.164161803512874e-06}, {\"x\": -7.971014492753623, \"y\": 4.202898550724639, \"x2\": -7.681159420289855, \"y2\": 4.492753623188406, \"center_x\": -7.826086956521739, \"center_y\": 4.347826086956522, \"value_uncond\": 6.1516631765141e-06}, {\"x\": -7.681159420289855, \"y\": 4.202898550724639, \"x2\": -7.391304347826088, \"y2\": 4.492753623188406, \"center_x\": -7.536231884057972, \"center_y\": 4.347826086956522, \"value_uncond\": 9.003333036907952e-06}, {\"x\": -7.391304347826087, \"y\": 4.202898550724639, \"x2\": -7.101449275362319, \"y2\": 4.492753623188406, \"center_x\": -7.246376811594203, \"center_y\": 4.347826086956522, \"value_uncond\": 1.3054489596125642e-05}, {\"x\": -7.101449275362318, \"y\": 4.202898550724639, \"x2\": -6.811594202898551, \"y2\": 4.492753623188406, \"center_x\": -6.956521739130435, \"center_y\": 4.347826086956522, \"value_uncond\": 1.8752634640410333e-05}, {\"x\": -6.811594202898551, \"y\": 4.202898550724639, \"x2\": -6.521739130434783, \"y2\": 4.492753623188406, \"center_x\": -6.666666666666667, \"center_y\": 4.347826086956522, \"value_uncond\": 2.6687660404369222e-05}, {\"x\": -6.521739130434782, \"y\": 4.202898550724639, \"x2\": -6.231884057971015, \"y2\": 4.492753623188406, \"center_x\": -6.3768115942028984, \"center_y\": 4.347826086956522, \"value_uncond\": 3.762742749674654e-05}, {\"x\": -6.231884057971014, \"y\": 4.202898550724639, \"x2\": -5.942028985507246, \"y2\": 4.492753623188406, \"center_x\": -6.08695652173913, \"center_y\": 4.347826086956522, \"value_uncond\": 5.2558670024322436e-05}, {\"x\": -5.942028985507246, \"y\": 4.202898550724639, \"x2\": -5.6521739130434785, \"y2\": 4.492753623188406, \"center_x\": -5.797101449275362, \"center_y\": 4.347826086956522, \"value_uncond\": 7.273275211643228e-05}, {\"x\": -5.6521739130434785, \"y\": 4.202898550724639, \"x2\": -5.362318840579711, \"y2\": 4.492753623188406, \"center_x\": -5.507246376811595, \"center_y\": 4.347826086956522, \"value_uncond\": 9.971522868176951e-05}, {\"x\": -5.36231884057971, \"y\": 4.202898550724639, \"x2\": -5.072463768115942, \"y2\": 4.492753623188406, \"center_x\": -5.217391304347826, \"center_y\": 4.347826086956522, \"value_uncond\": 0.00013543745134813776}, {\"x\": -5.0724637681159415, \"y\": 4.202898550724639, \"x2\": -4.782608695652174, \"y2\": 4.492753623188406, \"center_x\": -4.927536231884058, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0001822476220000616}, {\"x\": -4.782608695652174, \"y\": 4.202898550724639, \"x2\": -4.492753623188406, \"y2\": 4.492753623188406, \"center_x\": -4.63768115942029, \"center_y\": 4.347826086956522, \"value_uncond\": 0.00024295776423608866}, {\"x\": -4.492753623188405, \"y\": 4.202898550724639, \"x2\": -4.202898550724638, \"y2\": 4.492753623188406, \"center_x\": -4.3478260869565215, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0003208821132434606}, {\"x\": -4.202898550724638, \"y\": 4.202898550724639, \"x2\": -3.91304347826087, \"y2\": 4.492753623188406, \"center_x\": -4.057971014492754, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0004198614974519994}, {\"x\": -3.913043478260869, \"y\": 4.202898550724639, \"x2\": -3.6231884057971016, \"y2\": 4.492753623188406, \"center_x\": -3.7681159420289854, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0005442675052706195}, {\"x\": -3.6231884057971016, \"y\": 4.202898550724639, \"x2\": -3.333333333333334, \"y2\": 4.492753623188406, \"center_x\": -3.4782608695652177, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0006989797216658312}, {\"x\": -3.333333333333333, \"y\": 4.202898550724639, \"x2\": -3.0434782608695654, \"y2\": 4.492753623188406, \"center_x\": -3.1884057971014492, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0008893292189735857}, {\"x\": -3.0434782608695645, \"y\": 4.202898550724639, \"x2\": -2.753623188405797, \"y2\": 4.492753623188406, \"center_x\": -2.8985507246376807, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0011210019310742272}, {\"x\": -2.753623188405797, \"y\": 4.202898550724639, \"x2\": -2.4637681159420293, \"y2\": 4.492753623188406, \"center_x\": -2.608695652173913, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0013998966513206438}, {\"x\": -2.4637681159420284, \"y\": 4.202898550724639, \"x2\": -2.1739130434782608, \"y2\": 4.492753623188406, \"center_x\": -2.3188405797101446, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0017319342596446646}, {\"x\": -2.1739130434782608, \"y\": 4.202898550724639, \"x2\": -1.8840579710144931, \"y2\": 4.492753623188406, \"center_x\": -2.028985507246377, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0021228174363324154}, {\"x\": -1.8840579710144922, \"y\": 4.202898550724639, \"x2\": -1.5942028985507246, \"y2\": 4.492753623188406, \"center_x\": -1.7391304347826084, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0025777435196343624}, {\"x\": -1.5942028985507246, \"y\": 4.202898550724639, \"x2\": -1.304347826086957, \"y2\": 4.492753623188406, \"center_x\": -1.4492753623188408, \"center_y\": 4.347826086956522, \"value_uncond\": 0.003101077184865929}, {\"x\": -1.304347826086957, \"y\": 4.202898550724639, \"x2\": -1.0144927536231894, \"y2\": 4.492753623188406, \"center_x\": -1.1594202898550732, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0036959940420997896}, {\"x\": -1.0144927536231876, \"y\": 4.202898550724639, \"x2\": -0.72463768115942, \"y2\": 4.492753623188406, \"center_x\": -0.8695652173913038, \"center_y\": 4.347826086956522, \"value_uncond\": 0.004364110753120658}, {\"x\": -0.72463768115942, \"y\": 4.202898550724639, \"x2\": -0.43478260869565233, \"y2\": 4.492753623188406, \"center_x\": -0.5797101449275361, \"center_y\": 4.347826086956522, \"value_uncond\": 0.005105121462169169}, {\"x\": -0.43478260869565233, \"y\": 4.202898550724639, \"x2\": -0.1449275362318847, \"y2\": 4.492753623188406, \"center_x\": -0.2898550724637685, \"center_y\": 4.347826086956522, \"value_uncond\": 0.005916463772992943}, {\"x\": -0.14492753623188293, \"y\": 4.202898550724639, \"x2\": 0.1449275362318847, \"y2\": 4.492753623188406, \"center_x\": 8.881784197001252e-16, \"center_y\": 4.347826086956522, \"value_uncond\": 0.006793039727087408}, {\"x\": 0.1449275362318847, \"y\": 4.202898550724639, \"x2\": 0.43478260869565233, \"y2\": 4.492753623188406, \"center_x\": 0.2898550724637685, \"center_y\": 4.347826086956522, \"value_uncond\": 0.007727017819488317}, {\"x\": 0.43478260869565233, \"y\": 4.202898550724639, \"x2\": 0.72463768115942, \"y2\": 4.492753623188406, \"center_x\": 0.5797101449275361, \"center_y\": 4.347826086956522, \"value_uncond\": 0.008707740691430809}, {\"x\": 0.72463768115942, \"y\": 4.202898550724639, \"x2\": 1.0144927536231876, \"y2\": 4.492753623188406, \"center_x\": 0.8695652173913038, \"center_y\": 4.347826086956522, \"value_uncond\": 0.009721759565745862}, {\"x\": 1.0144927536231894, \"y\": 4.202898550724639, \"x2\": 1.304347826086957, \"y2\": 4.492753623188406, \"center_x\": 1.1594202898550732, \"center_y\": 4.347826086956522, \"value_uncond\": 0.010753010727229628}, {\"x\": 1.304347826086957, \"y\": 4.202898550724639, \"x2\": 1.5942028985507246, \"y2\": 4.492753623188406, \"center_x\": 1.4492753623188408, \"center_y\": 4.347826086956522, \"value_uncond\": 0.011783141596172239}, {\"x\": 1.5942028985507246, \"y\": 4.202898550724639, \"x2\": 1.8840579710144922, \"y2\": 4.492753623188406, \"center_x\": 1.7391304347826084, \"center_y\": 4.347826086956522, \"value_uncond\": 0.012791984620799281}, {\"x\": 1.884057971014494, \"y\": 4.202898550724639, \"x2\": 2.1739130434782616, \"y2\": 4.492753623188406, \"center_x\": 2.028985507246378, \"center_y\": 4.347826086956522, \"value_uncond\": 0.013758166951649482}, {\"x\": 2.1739130434782616, \"y\": 4.202898550724639, \"x2\": 2.4637681159420293, \"y2\": 4.492753623188406, \"center_x\": 2.3188405797101455, \"center_y\": 4.347826086956522, \"value_uncond\": 0.014659833449777619}, {\"x\": 2.4637681159420293, \"y\": 4.202898550724639, \"x2\": 2.753623188405797, \"y2\": 4.492753623188406, \"center_x\": 2.608695652173913, \"center_y\": 4.347826086956522, \"value_uncond\": 0.015475450910674683}, {\"x\": 2.753623188405797, \"y\": 4.202898550724639, \"x2\": 3.0434782608695645, \"y2\": 4.492753623188406, \"center_x\": 2.8985507246376807, \"center_y\": 4.347826086956522, \"value_uncond\": 0.01618465335975242}, {\"x\": 3.0434782608695663, \"y\": 4.202898550724639, \"x2\": 3.333333333333334, \"y2\": 4.492753623188406, \"center_x\": 3.18840579710145, \"center_y\": 4.347826086956522, \"value_uncond\": 0.016769082715321383}, {\"x\": 3.333333333333334, \"y\": 4.202898550724639, \"x2\": 3.6231884057971016, \"y2\": 4.492753623188406, \"center_x\": 3.4782608695652177, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0172131766700886}, {\"x\": 3.6231884057971016, \"y\": 4.202898550724639, \"x2\": 3.913043478260869, \"y2\": 4.492753623188406, \"center_x\": 3.7681159420289854, \"center_y\": 4.347826086956522, \"value_uncond\": 0.017504856708086578}, {\"x\": 3.913043478260871, \"y\": 4.202898550724639, \"x2\": 4.202898550724639, \"y2\": 4.492753623188406, \"center_x\": 4.057971014492755, \"center_y\": 4.347826086956522, \"value_uncond\": 0.017636073836968927}, {\"x\": 4.202898550724639, \"y\": 4.202898550724639, \"x2\": 4.492753623188406, \"y2\": 4.492753623188406, \"center_x\": 4.347826086956522, \"center_y\": 4.347826086956522, \"value_uncond\": 0.017603177628208996}, {\"x\": 4.492753623188406, \"y\": 4.202898550724639, \"x2\": 4.782608695652174, \"y2\": 4.492753623188406, \"center_x\": 4.63768115942029, \"center_y\": 4.347826086956522, \"value_uncond\": 0.017407084950367555}, {\"x\": 4.782608695652174, \"y\": 4.202898550724639, \"x2\": 5.0724637681159415, \"y2\": 4.492753623188406, \"center_x\": 4.927536231884058, \"center_y\": 4.347826086956522, \"value_uncond\": 0.017053237510066252}, {\"x\": 5.072463768115943, \"y\": 4.202898550724639, \"x2\": 5.362318840579711, \"y2\": 4.492753623188406, \"center_x\": 5.217391304347827, \"center_y\": 4.347826086956522, \"value_uncond\": 0.016551350944871517}, {\"x\": 5.362318840579711, \"y\": 4.202898550724639, \"x2\": 5.6521739130434785, \"y2\": 4.492753623188406, \"center_x\": 5.507246376811595, \"center_y\": 4.347826086956522, \"value_uncond\": 0.01591497161452705}, {\"x\": 5.6521739130434785, \"y\": 4.202898550724639, \"x2\": 5.942028985507246, \"y2\": 4.492753623188406, \"center_x\": 5.797101449275362, \"center_y\": 4.347826086956522, \"value_uncond\": 0.015160869307387045}, {\"x\": 5.942028985507246, \"y\": 4.202898550724639, \"x2\": 6.231884057971014, \"y2\": 4.492753623188406, \"center_x\": 6.08695652173913, \"center_y\": 4.347826086956522, \"value_uncond\": 0.014308303846864935}, {\"x\": 6.2318840579710155, \"y\": 4.202898550724639, \"x2\": 6.521739130434783, \"y2\": 4.492753623188406, \"center_x\": 6.376811594202899, \"center_y\": 4.347826086956522, \"value_uncond\": 0.013378210306499836}, {\"x\": 6.521739130434785, \"y\": 4.202898550724639, \"x2\": 6.8115942028985526, \"y2\": 4.492753623188406, \"center_x\": 6.666666666666669, \"center_y\": 4.347826086956522, \"value_uncond\": 0.01239235077728404}, {\"x\": 6.811594202898551, \"y\": 4.202898550724639, \"x2\": 7.101449275362318, \"y2\": 4.492753623188406, \"center_x\": 6.956521739130435, \"center_y\": 4.347826086956522, \"value_uncond\": 0.011372480263853986}, {\"x\": 7.10144927536232, \"y\": 4.202898550724639, \"x2\": 7.391304347826088, \"y2\": 4.492753623188406, \"center_x\": 7.246376811594204, \"center_y\": 4.347826086956522, \"value_uncond\": 0.010339570532010896}, {\"x\": 7.391304347826086, \"y\": 4.202898550724639, \"x2\": 7.681159420289854, \"y2\": 4.492753623188406, \"center_x\": 7.53623188405797, \"center_y\": 4.347826086956522, \"value_uncond\": 0.009313129094118662}, {\"x\": 7.681159420289855, \"y\": 4.202898550724639, \"x2\": 7.971014492753623, \"y2\": 4.492753623188406, \"center_x\": 7.826086956521739, \"center_y\": 4.347826086956522, \"value_uncond\": 0.00831064172998108}, {\"x\": 7.971014492753625, \"y\": 4.202898550724639, \"x2\": 8.260869565217392, \"y2\": 4.492753623188406, \"center_x\": 8.115942028985508, \"center_y\": 4.347826086956522, \"value_uncond\": 0.007347156864706769}, {\"x\": 8.26086956521739, \"y\": 4.202898550724639, \"x2\": 8.550724637681158, \"y2\": 4.492753623188406, \"center_x\": 8.405797101449274, \"center_y\": 4.347826086956522, \"value_uncond\": 0.006435019670291634}, {\"x\": 8.55072463768116, \"y\": 4.202898550724639, \"x2\": 8.840579710144928, \"y2\": 4.492753623188406, \"center_x\": 8.695652173913043, \"center_y\": 4.347826086956522, \"value_uncond\": 0.005583753783940638}, {\"x\": 8.84057971014493, \"y\": 4.202898550724639, \"x2\": 9.130434782608697, \"y2\": 4.492753623188406, \"center_x\": 8.985507246376812, \"center_y\": 4.347826086956522, \"value_uncond\": 0.00480007977657125}, {\"x\": 9.130434782608695, \"y\": 4.202898550724639, \"x2\": 9.420289855072463, \"y2\": 4.492753623188406, \"center_x\": 9.275362318840578, \"center_y\": 4.347826086956522, \"value_uncond\": 0.004088052508777171}, {\"x\": 9.420289855072465, \"y\": 4.202898550724639, \"x2\": 9.710144927536232, \"y2\": 4.492753623188406, \"center_x\": 9.565217391304348, \"center_y\": 4.347826086956522, \"value_uncond\": 0.003449294612401767}, {\"x\": 9.710144927536234, \"y\": 4.202898550724639, \"x2\": 10.000000000000002, \"y2\": 4.492753623188406, \"center_x\": 9.855072463768117, \"center_y\": 4.347826086956522, \"value_uncond\": 0.0028833006458000928}, {\"x\": 10.0, \"y\": 4.202898550724639, \"x2\": 10.289855072463768, \"y2\": 4.492753623188406, \"center_x\": 10.144927536231883, \"center_y\": 4.347826086956522, \"value_uncond\": 0.002387785897913383}, {\"x\": -10.0, \"y\": 4.492753623188406, \"x2\": -9.710144927536232, \"y2\": 4.782608695652174, \"center_x\": -9.855072463768117, \"center_y\": 4.63768115942029, \"value_uncond\": 3.256379152547972e-07}, {\"x\": -9.710144927536232, \"y\": 4.492753623188406, \"x2\": -9.420289855072465, \"y2\": 4.782608695652174, \"center_x\": -9.565217391304348, \"center_y\": 4.63768115942029, \"value_uncond\": 5.087741421390123e-07}, {\"x\": -9.420289855072463, \"y\": 4.492753623188406, \"x2\": -9.130434782608695, \"y2\": 4.782608695652174, \"center_x\": -9.275362318840578, \"center_y\": 4.63768115942029, \"value_uncond\": 7.875187636225984e-07}, {\"x\": -9.130434782608695, \"y\": 4.492753623188406, \"x2\": -8.840579710144928, \"y2\": 4.782608695652174, \"center_x\": -8.985507246376812, \"center_y\": 4.63768115942029, \"value_uncond\": 1.2076542226667046e-06}, {\"x\": -8.840579710144928, \"y\": 4.492753623188406, \"x2\": -8.55072463768116, \"y2\": 4.782608695652174, \"center_x\": -8.695652173913043, \"center_y\": 4.63768115942029, \"value_uncond\": 1.834721342061928e-06}, {\"x\": -8.55072463768116, \"y\": 4.492753623188406, \"x2\": -8.260869565217392, \"y2\": 4.782608695652174, \"center_x\": -8.405797101449277, \"center_y\": 4.63768115942029, \"value_uncond\": 2.761489752615771e-06}, {\"x\": -8.26086956521739, \"y\": 4.492753623188406, \"x2\": -7.971014492753623, \"y2\": 4.782608695652174, \"center_x\": -8.115942028985508, \"center_y\": 4.63768115942029, \"value_uncond\": 4.117774630909027e-06}, {\"x\": -7.971014492753623, \"y\": 4.492753623188406, \"x2\": -7.681159420289855, \"y2\": 4.782608695652174, \"center_x\": -7.826086956521739, \"center_y\": 4.63768115942029, \"value_uncond\": 6.08313599744797e-06}, {\"x\": -7.681159420289855, \"y\": 4.492753623188406, \"x2\": -7.391304347826088, \"y2\": 4.782608695652174, \"center_x\": -7.536231884057972, \"center_y\": 4.63768115942029, \"value_uncond\": 8.90303934437165e-06}, {\"x\": -7.391304347826087, \"y\": 4.492753623188406, \"x2\": -7.101449275362319, \"y2\": 4.782608695652174, \"center_x\": -7.246376811594203, \"center_y\": 4.63768115942029, \"value_uncond\": 1.2909067566261262e-05}, {\"x\": -7.101449275362318, \"y\": 4.492753623188406, \"x2\": -6.811594202898551, \"y2\": 4.782608695652174, \"center_x\": -6.956521739130435, \"center_y\": 4.63768115942029, \"value_uncond\": 1.8543737450318508e-05}, {\"x\": -6.811594202898551, \"y\": 4.492753623188406, \"x2\": -6.521739130434783, \"y2\": 4.782608695652174, \"center_x\": -6.666666666666667, \"center_y\": 4.63768115942029, \"value_uncond\": 2.639037005687939e-05}, {\"x\": -6.521739130434782, \"y\": 4.492753623188406, \"x2\": -6.231884057971015, \"y2\": 4.782608695652174, \"center_x\": -6.3768115942028984, \"center_y\": 4.63768115942029, \"value_uncond\": 3.72082723206778e-05}, {\"x\": -6.231884057971014, \"y\": 4.492753623188406, \"x2\": -5.942028985507246, \"y2\": 4.782608695652174, \"center_x\": -6.08695652173913, \"center_y\": 4.63768115942029, \"value_uncond\": 5.197318650728187e-05}, {\"x\": -5.942028985507246, \"y\": 4.492753623188406, \"x2\": -5.6521739130434785, \"y2\": 4.782608695652174, \"center_x\": -5.797101449275362, \"center_y\": 4.63768115942029, \"value_uncond\": 7.192253702740012e-05}, {\"x\": -5.6521739130434785, \"y\": 4.492753623188406, \"x2\": -5.362318840579711, \"y2\": 4.782608695652174, \"center_x\": -5.507246376811595, \"center_y\": 4.63768115942029, \"value_uncond\": 9.860443910577588e-05}, {\"x\": -5.36231884057971, \"y\": 4.492753623188406, \"x2\": -5.072463768115942, \"y2\": 4.782608695652174, \"center_x\": -5.217391304347826, \"center_y\": 4.63768115942029, \"value_uncond\": 0.00013392872985047388}, {\"x\": -5.0724637681159415, \"y\": 4.492753623188406, \"x2\": -4.782608695652174, \"y2\": 4.782608695652174, \"center_x\": -4.927536231884058, \"center_y\": 4.63768115942029, \"value_uncond\": 0.00018021745307357436}, {\"x\": -4.782608695652174, \"y\": 4.492753623188406, \"x2\": -4.492753623188406, \"y2\": 4.782608695652174, \"center_x\": -4.63768115942029, \"center_y\": 4.63768115942029, \"value_uncond\": 0.00024025130750437475}, {\"x\": -4.492753623188405, \"y\": 4.492753623188406, \"x2\": -4.202898550724638, \"y2\": 4.782608695652174, \"center_x\": -4.3478260869565215, \"center_y\": 4.63768115942029, \"value_uncond\": 0.00031730760901551403}, {\"x\": -4.202898550724638, \"y\": 4.492753623188406, \"x2\": -3.91304347826087, \"y2\": 4.782608695652174, \"center_x\": -4.057971014492754, \"center_y\": 4.63768115942029, \"value_uncond\": 0.0004151844006745436}, {\"x\": -3.913043478260869, \"y\": 4.492753623188406, \"x2\": -3.6231884057971016, \"y2\": 4.782608695652174, \"center_x\": -3.7681159420289854, \"center_y\": 4.63768115942029, \"value_uncond\": 0.000538204573064586}, {\"x\": -3.6231884057971016, \"y\": 4.492753623188406, \"x2\": -3.333333333333334, \"y2\": 4.782608695652174, \"center_x\": -3.4782608695652177, \"center_y\": 4.63768115942029, \"value_uncond\": 0.0006911933544386626}, {\"x\": -3.333333333333333, \"y\": 4.492753623188406, \"x2\": -3.0434782608695654, \"y2\": 4.782608695652174, \"center_x\": -3.1884057971014492, \"center_y\": 4.63768115942029, \"value_uncond\": 0.0008794224310223179}, {\"x\": -3.0434782608695645, \"y\": 4.492753623188406, \"x2\": -2.753623188405797, \"y2\": 4.782608695652174, \"center_x\": -2.8985507246376807, \"center_y\": 4.63768115942029, \"value_uncond\": 0.0011085143975633734}, {\"x\": -2.753623188405797, \"y\": 4.492753623188406, \"x2\": -2.4637681159420293, \"y2\": 4.782608695652174, \"center_x\": -2.608695652173913, \"center_y\": 4.63768115942029, \"value_uncond\": 0.0013843023371089397}, {\"x\": -2.4637681159420284, \"y\": 4.492753623188406, \"x2\": -2.1739130434782608, \"y2\": 4.782608695652174, \"center_x\": -2.3188405797101446, \"center_y\": 4.63768115942029, \"value_uncond\": 0.0017126411732490121}, {\"x\": -2.1739130434782608, \"y\": 4.492753623188406, \"x2\": -1.8840579710144931, \"y2\": 4.782608695652174, \"center_x\": -2.028985507246377, \"center_y\": 4.63768115942029, \"value_uncond\": 0.002099170060588626}, {\"x\": -1.8840579710144922, \"y\": 4.492753623188406, \"x2\": -1.5942028985507246, \"y2\": 4.782608695652174, \"center_x\": -1.7391304347826084, \"center_y\": 4.63768115942029, \"value_uncond\": 0.0025490284410144945}, {\"x\": -1.5942028985507246, \"y\": 4.492753623188406, \"x2\": -1.304347826086957, \"y2\": 4.782608695652174, \"center_x\": -1.4492753623188408, \"center_y\": 4.63768115942029, \"value_uncond\": 0.00306653236902547}, {\"x\": -1.304347826086957, \"y\": 4.492753623188406, \"x2\": -1.0144927536231894, \"y2\": 4.782608695652174, \"center_x\": -1.1594202898550732, \"center_y\": 4.63768115942029, \"value_uncond\": 0.003654822079610475}, {\"x\": -1.0144927536231876, \"y\": 4.492753623188406, \"x2\": -0.72463768115942, \"y2\": 4.782608695652174, \"center_x\": -0.8695652173913038, \"center_y\": 4.63768115942029, \"value_uncond\": 0.004315496225559185}, {\"x\": -0.72463768115942, \"y\": 4.492753623188406, \"x2\": -0.43478260869565233, \"y2\": 4.782608695652174, \"center_x\": -0.5797101449275361, \"center_y\": 4.63768115942029, \"value_uncond\": 0.005048252358228621}, {\"x\": -0.43478260869565233, \"y\": 4.492753623188406, \"x2\": -0.1449275362318847, \"y2\": 4.782608695652174, \"center_x\": -0.2898550724637685, \"center_y\": 4.63768115942029, \"value_uncond\": 0.005850556625482321}, {\"x\": -0.14492753623188293, \"y\": 4.492753623188406, \"x2\": 0.1449275362318847, \"y2\": 4.782608695652174, \"center_x\": 8.881784197001252e-16, \"center_y\": 4.63768115942029, \"value_uncond\": 0.0067173678581270435}, {\"x\": 0.1449275362318847, \"y\": 4.492753623188406, \"x2\": 0.43478260869565233, \"y2\": 4.782608695652174, \"center_x\": 0.2898550724637685, \"center_y\": 4.63768115942029, \"value_uncond\": 0.007640941791173754}, {\"x\": 0.43478260869565233, \"y\": 4.492753623188406, \"x2\": 0.72463768115942, \"y2\": 4.782608695652174, \"center_x\": 0.5797101449275361, \"center_y\": 4.63768115942029, \"value_uncond\": 0.008610739784765228}, {\"x\": 0.72463768115942, \"y\": 4.492753623188406, \"x2\": 1.0144927536231876, \"y2\": 4.782608695652174, \"center_x\": 0.8695652173913038, \"center_y\": 4.63768115942029, \"value_uncond\": 0.00961346287597533}, {\"x\": 1.0144927536231894, \"y\": 4.492753623188406, \"x2\": 1.304347826086957, \"y2\": 4.782608695652174, \"center_x\": 1.1594202898550732, \"center_y\": 4.63768115942029, \"value_uncond\": 0.010633226293254413}, {\"x\": 1.304347826086957, \"y\": 4.492753623188406, \"x2\": 1.5942028985507246, \"y2\": 4.782608695652174, \"center_x\": 1.4492753623188408, \"center_y\": 4.63768115942029, \"value_uncond\": 0.011651881897623518}, {\"x\": 1.5942028985507246, \"y\": 4.492753623188406, \"x2\": 1.8840579710144922, \"y2\": 4.782608695652174, \"center_x\": 1.7391304347826084, \"center_y\": 4.63768115942029, \"value_uncond\": 0.012649486796134982}, {\"x\": 1.884057971014494, \"y\": 4.492753623188406, \"x2\": 2.1739130434782616, \"y2\": 4.782608695652174, \"center_x\": 2.028985507246378, \"center_y\": 4.63768115942029, \"value_uncond\": 0.013604906224710316}, {\"x\": 2.1739130434782616, \"y\": 4.492753623188406, \"x2\": 2.4637681159420293, \"y2\": 4.782608695652174, \"center_x\": 2.3188405797101455, \"center_y\": 4.63768115942029, \"value_uncond\": 0.014496528502307806}, {\"x\": 2.4637681159420293, \"y\": 4.492753623188406, \"x2\": 2.753623188405797, \"y2\": 4.782608695652174, \"center_x\": 2.608695652173913, \"center_y\": 4.63768115942029, \"value_uncond\": 0.015303060296095244}, {\"x\": 2.753623188405797, \"y\": 4.492753623188406, \"x2\": 3.0434782608695645, \"y2\": 4.782608695652174, \"center_x\": 2.8985507246376807, \"center_y\": 4.63768115942029, \"value_uncond\": 0.016004362500665503}, {\"x\": 3.0434782608695663, \"y\": 4.492753623188406, \"x2\": 3.333333333333334, \"y2\": 4.782608695652174, \"center_x\": 3.18840579710145, \"center_y\": 4.63768115942029, \"value_uncond\": 0.01658228153635001}, {\"x\": 3.333333333333334, \"y\": 4.492753623188406, \"x2\": 3.6231884057971016, \"y2\": 4.782608695652174, \"center_x\": 3.4782608695652177, \"center_y\": 4.63768115942029, \"value_uncond\": 0.017021428454017287}, {\"x\": 3.6231884057971016, \"y\": 4.492753623188406, \"x2\": 3.913043478260869, \"y2\": 4.782608695652174, \"center_x\": 3.7681159420289854, \"center_y\": 4.63768115942029, \"value_uncond\": 0.01730985928775613}, {\"x\": 3.913043478260871, \"y\": 4.492753623188406, \"x2\": 4.202898550724639, \"y2\": 4.782608695652174, \"center_x\": 4.057971014492755, \"center_y\": 4.63768115942029, \"value_uncond\": 0.017439614707921755}, {\"x\": 4.202898550724639, \"y\": 4.492753623188406, \"x2\": 4.492753623188406, \"y2\": 4.782608695652174, \"center_x\": 4.347826086956522, \"center_y\": 4.63768115942029, \"value_uncond\": 0.017407084950367555}, {\"x\": 4.492753623188406, \"y\": 4.492753623188406, \"x2\": 4.782608695652174, \"y2\": 4.782608695652174, \"center_x\": 4.63768115942029, \"center_y\": 4.63768115942029, \"value_uncond\": 0.017213176670088596}, {\"x\": 4.782608695652174, \"y\": 4.492753623188406, \"x2\": 5.0724637681159415, \"y2\": 4.782608695652174, \"center_x\": 4.927536231884058, \"center_y\": 4.63768115942029, \"value_uncond\": 0.016863270955172423}, {\"x\": 5.072463768115943, \"y\": 4.492753623188406, \"x2\": 5.362318840579711, \"y2\": 4.782608695652174, \"center_x\": 5.217391304347827, \"center_y\": 4.63768115942029, \"value_uncond\": 0.016366975214692422}, {\"x\": 5.362318840579711, \"y\": 4.492753623188406, \"x2\": 5.6521739130434785, \"y2\": 4.782608695652174, \"center_x\": 5.507246376811595, \"center_y\": 4.63768115942029, \"value_uncond\": 0.015737684907116793}, {\"x\": 5.6521739130434785, \"y\": 4.492753623188406, \"x2\": 5.942028985507246, \"y2\": 4.782608695652174, \"center_x\": 5.797101449275362, \"center_y\": 4.63768115942029, \"value_uncond\": 0.014991983011760197}, {\"x\": 5.942028985507246, \"y\": 4.492753623188406, \"x2\": 6.231884057971014, \"y2\": 4.782608695652174, \"center_x\": 6.08695652173913, \"center_y\": 4.63768115942029, \"value_uncond\": 0.014148914804956699}, {\"x\": 6.2318840579710155, \"y\": 4.492753623188406, \"x2\": 6.521739130434783, \"y2\": 4.782608695652174, \"center_x\": 6.376811594202899, \"center_y\": 4.63768115942029, \"value_uncond\": 0.01322918215151925}, {\"x\": 6.521739130434785, \"y\": 4.492753623188406, \"x2\": 6.8115942028985526, \"y2\": 4.782608695652174, \"center_x\": 6.666666666666669, \"center_y\": 4.63768115942029, \"value_uncond\": 0.01225430472105531}, {\"x\": 6.811594202898551, \"y\": 4.492753623188406, \"x2\": 7.101449275362318, \"y2\": 4.782608695652174, \"center_x\": 6.956521739130435, \"center_y\": 4.63768115942029, \"value_uncond\": 0.011245795175755779}, {\"x\": 7.10144927536232, \"y\": 4.492753623188406, \"x2\": 7.391304347826088, \"y2\": 4.782608695652174, \"center_x\": 7.246376811594204, \"center_y\": 4.63768115942029, \"value_uncond\": 0.01022439166395793}, {\"x\": 7.391304347826086, \"y\": 4.492753623188406, \"x2\": 7.681159420289854, \"y2\": 4.782608695652174, \"center_x\": 7.53623188405797, \"center_y\": 4.63768115942029, \"value_uncond\": 0.009209384391785931}, {\"x\": 7.681159420289855, \"y\": 4.492753623188406, \"x2\": 7.971014492753623, \"y2\": 4.782608695652174, \"center_x\": 7.826086956521739, \"center_y\": 4.63768115942029, \"value_uncond\": 0.008218064354132682}, {\"x\": 7.971014492753625, \"y\": 4.492753623188406, \"x2\": 8.260869565217392, \"y2\": 4.782608695652174, \"center_x\": 8.115942028985508, \"center_y\": 4.63768115942029, \"value_uncond\": 0.00726531234239662}, {\"x\": 8.26086956521739, \"y\": 4.492753623188406, \"x2\": 8.550724637681158, \"y2\": 4.782608695652174, \"center_x\": 8.405797101449274, \"center_y\": 4.63768115942029, \"value_uncond\": 0.00636333600807103}, {\"x\": 8.55072463768116, \"y\": 4.492753623188406, \"x2\": 8.840579710144928, \"y2\": 4.782608695652174, \"center_x\": 8.695652173913043, \"center_y\": 4.63768115942029, \"value_uncond\": 0.005521552898678561}, {\"x\": 8.84057971014493, \"y\": 4.492753623188406, \"x2\": 9.130434782608697, \"y2\": 4.782608695652174, \"center_x\": 8.985507246376812, \"center_y\": 4.63768115942029, \"value_uncond\": 0.004746608720542591}, {\"x\": 9.130434782608695, \"y\": 4.492753623188406, \"x2\": 9.420289855072463, \"y2\": 4.782608695652174, \"center_x\": 9.275362318840578, \"center_y\": 4.63768115942029, \"value_uncond\": 0.004042513164657964}, {\"x\": 9.420289855072465, \"y\": 4.492753623188406, \"x2\": 9.710144927536232, \"y2\": 4.782608695652174, \"center_x\": 9.565217391304348, \"center_y\": 4.63768115942029, \"value_uncond\": 0.0034108707873688354}, {\"x\": 9.710144927536234, \"y\": 4.492753623188406, \"x2\": 10.000000000000002, \"y2\": 4.782608695652174, \"center_x\": 9.855072463768117, \"center_y\": 4.63768115942029, \"value_uncond\": 0.002851181777457206}, {\"x\": 10.0, \"y\": 4.492753623188406, \"x2\": 10.289855072463768, \"y2\": 4.782608695652174, \"center_x\": 10.144927536231883, \"center_y\": 4.63768115942029, \"value_uncond\": 0.0023611868746731966}, {\"x\": -10.0, \"y\": 4.782608695652174, \"x2\": -9.710144927536232, \"y2\": 5.0724637681159415, \"center_x\": -9.855072463768117, \"center_y\": 4.927536231884058, \"value_uncond\": 3.1901841847480727e-07}, {\"x\": -9.710144927536232, \"y\": 4.782608695652174, \"x2\": -9.420289855072465, \"y2\": 5.0724637681159415, \"center_x\": -9.565217391304348, \"center_y\": 4.927536231884058, \"value_uncond\": 4.984318919345294e-07}, {\"x\": -9.420289855072463, \"y\": 4.782608695652174, \"x2\": -9.130434782608695, \"y2\": 5.0724637681159415, \"center_x\": -9.275362318840578, \"center_y\": 4.927536231884058, \"value_uncond\": 7.715102533239665e-07}, {\"x\": -9.130434782608695, \"y\": 4.782608695652174, \"x2\": -8.840579710144928, \"y2\": 5.0724637681159415, \"center_x\": -8.985507246376812, \"center_y\": 4.927536231884058, \"value_uncond\": 1.1831052900523056e-06}, {\"x\": -8.840579710144928, \"y\": 4.782608695652174, \"x2\": -8.55072463768116, \"y2\": 5.0724637681159415, \"center_x\": -8.695652173913043, \"center_y\": 4.927536231884058, \"value_uncond\": 1.7974255253065148e-06}, {\"x\": -8.55072463768116, \"y\": 4.782608695652174, \"x2\": -8.260869565217392, \"y2\": 5.0724637681159415, \"center_x\": -8.405797101449277, \"center_y\": 4.927536231884058, \"value_uncond\": 2.705354788997938e-06}, {\"x\": -8.26086956521739, \"y\": 4.782608695652174, \"x2\": -7.971014492753623, \"y2\": 5.0724637681159415, \"center_x\": -8.115942028985508, \"center_y\": 4.927536231884058, \"value_uncond\": 4.034069403006746e-06}, {\"x\": -7.971014492753623, \"y\": 4.782608695652174, \"x2\": -7.681159420289855, \"y2\": 5.0724637681159415, \"center_x\": -7.826086956521739, \"center_y\": 4.927536231884058, \"value_uncond\": 5.9594793307608665e-06}, {\"x\": -7.681159420289855, \"y\": 4.782608695652174, \"x2\": -7.391304347826088, \"y2\": 5.0724637681159415, \"center_x\": -7.536231884057972, \"center_y\": 4.927536231884058, \"value_uncond\": 8.72206029521493e-06}, {\"x\": -7.391304347826087, \"y\": 4.782608695652174, \"x2\": -7.101449275362319, \"y2\": 5.0724637681159415, \"center_x\": -7.246376811594203, \"center_y\": 4.927536231884058, \"value_uncond\": 1.2646654845922255e-05}, {\"x\": -7.101449275362318, \"y\": 4.782608695652174, \"x2\": -6.811594202898551, \"y2\": 5.0724637681159415, \"center_x\": -6.956521739130435, \"center_y\": 4.927536231884058, \"value_uncond\": 1.8166784384993456e-05}, {\"x\": -6.811594202898551, \"y\": 4.782608695652174, \"x2\": -6.521739130434783, \"y2\": 5.0724637681159415, \"center_x\": -6.666666666666667, \"center_y\": 4.927536231884058, \"value_uncond\": 2.585391234900603e-05}, {\"x\": -6.521739130434782, \"y\": 4.782608695652174, \"x2\": -6.231884057971015, \"y2\": 5.0724637681159415, \"center_x\": -6.3768115942028984, \"center_y\": 4.927536231884058, \"value_uncond\": 3.6451910646322456e-05}, {\"x\": -6.231884057971014, \"y\": 4.782608695652174, \"x2\": -5.942028985507246, \"y2\": 5.0724637681159415, \"center_x\": -6.08695652173913, \"center_y\": 4.927536231884058, \"value_uncond\": 5.0916686865765747e-05}, {\"x\": -5.942028985507246, \"y\": 4.782608695652174, \"x2\": -5.6521739130434785, \"y2\": 5.0724637681159415, \"center_x\": -5.797101449275362, \"center_y\": 4.927536231884058, \"value_uncond\": 7.046051132351661e-05}, {\"x\": -5.6521739130434785, \"y\": 4.782608695652174, \"x2\": -5.362318840579711, \"y2\": 5.0724637681159415, \"center_x\": -5.507246376811595, \"center_y\": 4.927536231884058, \"value_uncond\": 9.66000294944361e-05}, {\"x\": -5.36231884057971, \"y\": 4.782608695652174, \"x2\": -5.072463768115942, \"y2\": 5.0724637681159415, \"center_x\": -5.217391304347826, \"center_y\": 4.927536231884058, \"value_uncond\": 0.00013120625573286498}, {\"x\": -5.0724637681159415, \"y\": 4.782608695652174, \"x2\": -4.782608695652174, \"y2\": 5.0724637681159415, \"center_x\": -4.927536231884058, \"center_y\": 4.927536231884058, \"value_uncond\": 0.00017655403184885295}, {\"x\": -4.782608695652174, \"y\": 4.782608695652174, \"x2\": -4.492753623188406, \"y2\": 5.0724637681159415, \"center_x\": -4.63768115942029, \"center_y\": 4.927536231884058, \"value_uncond\": 0.00023536753113217578}, {\"x\": -4.492753623188405, \"y\": 4.782608695652174, \"x2\": -4.202898550724638, \"y2\": 5.0724637681159415, \"center_x\": -4.3478260869565215, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0003108574488905761}, {\"x\": -4.202898550724638, \"y\": 4.782608695652174, \"x2\": -3.91304347826087, \"y2\": 5.0724637681159415, \"center_x\": -4.057971014492754, \"center_y\": 4.927536231884058, \"value_uncond\": 0.00040674462239744533}, {\"x\": -3.913043478260869, \"y\": 4.782608695652174, \"x2\": -3.6231884057971016, \"y2\": 5.0724637681159415, \"center_x\": -3.7681159420289854, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0005272640674554986}, {\"x\": -3.6231884057971016, \"y\": 4.782608695652174, \"x2\": -3.333333333333334, \"y2\": 5.0724637681159415, \"center_x\": -3.4782608695652177, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0006771429261263549}, {\"x\": -3.333333333333333, \"y\": 4.782608695652174, \"x2\": -3.0434782608695654, \"y2\": 5.0724637681159415, \"center_x\": -3.1884057971014492, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0008615457229435064}, {\"x\": -3.0434782608695645, \"y\": 4.782608695652174, \"x2\": -2.753623188405797, \"y2\": 5.0724637681159415, \"center_x\": -2.8985507246376807, \"center_y\": 4.927536231884058, \"value_uncond\": 0.001085980757770534}, {\"x\": -2.753623188405797, \"y\": 4.782608695652174, \"x2\": -2.4637681159420293, \"y2\": 5.0724637681159415, \"center_x\": -2.608695652173913, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0013561625400098994}, {\"x\": -2.4637681159420284, \"y\": 4.782608695652174, \"x2\": -2.1739130434782608, \"y2\": 5.0724637681159415, \"center_x\": -2.3188405797101446, \"center_y\": 4.927536231884058, \"value_uncond\": 0.001677826975637138}, {\"x\": -2.1739130434782608, \"y\": 4.782608695652174, \"x2\": -1.8840579710144931, \"y2\": 5.0724637681159415, \"center_x\": -2.028985507246377, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0020564985877478664}, {\"x\": -1.8840579710144922, \"y\": 4.782608695652174, \"x2\": -1.5942028985507246, \"y2\": 5.0724637681159415, \"center_x\": -1.7391304347826084, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0024972123447709275}, {\"x\": -1.5942028985507246, \"y\": 4.782608695652174, \"x2\": -1.304347826086957, \"y2\": 5.0724637681159415, \"center_x\": -1.4492753623188408, \"center_y\": 4.927536231884058, \"value_uncond\": 0.003004196565387203}, {\"x\": -1.304347826086957, \"y\": 4.782608695652174, \"x2\": -1.0144927536231894, \"y2\": 5.0724637681159415, \"center_x\": -1.1594202898550732, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0035805276505711356}, {\"x\": -1.0144927536231876, \"y\": 4.782608695652174, \"x2\": -0.72463768115942, \"y2\": 5.0724637681159415, \"center_x\": -0.8695652173913038, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0042277717560458795}, {\"x\": -0.72463768115942, \"y\": 4.782608695652174, \"x2\": -0.43478260869565233, \"y2\": 5.0724637681159415, \"center_x\": -0.5797101449275361, \"center_y\": 4.927536231884058, \"value_uncond\": 0.004945632581278748}, {\"x\": -0.43478260869565233, \"y\": 4.782608695652174, \"x2\": -0.1449275362318847, \"y2\": 5.0724637681159415, \"center_x\": -0.2898550724637685, \"center_y\": 4.927536231884058, \"value_uncond\": 0.005731627781728902}, {\"x\": -0.14492753623188293, \"y\": 4.782608695652174, \"x2\": 0.1449275362318847, \"y2\": 5.0724637681159415, \"center_x\": 8.881784197001252e-16, \"center_y\": 4.927536231884058, \"value_uncond\": 0.006580818663995012}, {\"x\": 0.1449275362318847, \"y\": 4.782608695652174, \"x2\": 0.43478260869565233, \"y2\": 5.0724637681159415, \"center_x\": 0.2898550724637685, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0074856183868239065}, {\"x\": 0.43478260869565233, \"y\": 4.782608695652174, \"x2\": 0.72463768115942, \"y2\": 5.0724637681159415, \"center_x\": 0.5797101449275361, \"center_y\": 4.927536231884058, \"value_uncond\": 0.008435702537539325}, {\"x\": 0.72463768115942, \"y\": 4.782608695652174, \"x2\": 1.0144927536231876, \"y2\": 5.0724637681159415, \"center_x\": 0.8695652173913038, \"center_y\": 4.927536231884058, \"value_uncond\": 0.009418042491643623}, {\"x\": 1.0144927536231894, \"y\": 4.782608695652174, \"x2\": 1.304347826086957, \"y2\": 5.0724637681159415, \"center_x\": 1.1594202898550732, \"center_y\": 4.927536231884058, \"value_uncond\": 0.010417076379771448}, {\"x\": 1.304347826086957, \"y\": 4.782608695652174, \"x2\": 1.5942028985507246, \"y2\": 5.0724637681159415, \"center_x\": 1.4492753623188408, \"center_y\": 4.927536231884058, \"value_uncond\": 0.011415024974369399}, {\"x\": 1.5942028985507246, \"y\": 4.782608695652174, \"x2\": 1.8840579710144922, \"y2\": 5.0724637681159415, \"center_x\": 1.7391304347826084, \"center_y\": 4.927536231884058, \"value_uncond\": 0.012392350777284051}, {\"x\": 1.884057971014494, \"y\": 4.782608695652174, \"x2\": 2.1739130434782616, \"y2\": 5.0724637681159415, \"center_x\": 2.028985507246378, \"center_y\": 4.927536231884058, \"value_uncond\": 0.013328348647328505}, {\"x\": 2.1739130434782616, \"y\": 4.782608695652174, \"x2\": 2.4637681159420293, \"y2\": 5.0724637681159415, \"center_x\": 2.3188405797101455, \"center_y\": 4.927536231884058, \"value_uncond\": 0.014201846221017042}, {\"x\": 2.4637681159420293, \"y\": 4.782608695652174, \"x2\": 2.753623188405797, \"y2\": 5.0724637681159415, \"center_x\": 2.608695652173913, \"center_y\": 4.927536231884058, \"value_uncond\": 0.014991983011760199}, {\"x\": 2.753623188405797, \"y\": 4.782608695652174, \"x2\": 3.0434782608695645, \"y2\": 5.0724637681159415, \"center_x\": 2.8985507246376807, \"center_y\": 4.927536231884058, \"value_uncond\": 0.015679029297509334}, {\"x\": 3.0434782608695663, \"y\": 4.782608695652174, \"x2\": 3.333333333333334, \"y2\": 5.0724637681159415, \"center_x\": 3.18840579710145, \"center_y\": 4.927536231884058, \"value_uncond\": 0.016245200520618588}, {\"x\": 3.333333333333334, \"y\": 4.782608695652174, \"x2\": 3.6231884057971016, \"y2\": 5.0724637681159415, \"center_x\": 3.4782608695652177, \"center_y\": 4.927536231884058, \"value_uncond\": 0.01667542055517041}, {\"x\": 3.6231884057971016, \"y\": 4.782608695652174, \"x2\": 3.913043478260869, \"y2\": 5.0724637681159415, \"center_x\": 3.7681159420289854, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0169579882295972}, {\"x\": 3.913043478260871, \"y\": 4.782608695652174, \"x2\": 4.202898550724639, \"y2\": 5.0724637681159415, \"center_x\": 4.057971014492755, \"center_y\": 4.927536231884058, \"value_uncond\": 0.017085106009777626}, {\"x\": 4.202898550724639, \"y\": 4.782608695652174, \"x2\": 4.492753623188406, \"y2\": 5.0724637681159415, \"center_x\": 4.347826086956522, \"center_y\": 4.927536231884058, \"value_uncond\": 0.017053237510066252}, {\"x\": 4.492753623188406, \"y\": 4.782608695652174, \"x2\": 4.782608695652174, \"y2\": 5.0724637681159415, \"center_x\": 4.63768115942029, \"center_y\": 4.927536231884058, \"value_uncond\": 0.016863270955172423}, {\"x\": 4.782608695652174, \"y\": 4.782608695652174, \"x2\": 5.0724637681159415, \"y2\": 5.0724637681159415, \"center_x\": 4.927536231884058, \"center_y\": 4.927536231884058, \"value_uncond\": 0.016520478047594347}, {\"x\": 5.072463768115943, \"y\": 4.782608695652174, \"x2\": 5.362318840579711, \"y2\": 5.0724637681159415, \"center_x\": 5.217391304347827, \"center_y\": 4.927536231884058, \"value_uncond\": 0.01603427089908147}, {\"x\": 5.362318840579711, \"y\": 4.782608695652174, \"x2\": 5.6521739130434785, \"y2\": 5.0724637681159415, \"center_x\": 5.507246376811595, \"center_y\": 4.927536231884058, \"value_uncond\": 0.015417772668133083}, {\"x\": 5.6521739130434785, \"y\": 4.782608695652174, \"x2\": 5.942028985507246, \"y2\": 5.0724637681159415, \"center_x\": 5.797101449275362, \"center_y\": 4.927536231884058, \"value_uncond\": 0.014687229238863838}, {\"x\": 5.942028985507246, \"y\": 4.782608695652174, \"x2\": 6.231884057971014, \"y2\": 5.0724637681159415, \"center_x\": 6.08695652173913, \"center_y\": 4.927536231884058, \"value_uncond\": 0.013861298739369025}, {\"x\": 6.2318840579710155, \"y\": 4.782608695652174, \"x2\": 6.521739130434783, \"y2\": 5.0724637681159415, \"center_x\": 6.376811594202899, \"center_y\": 4.927536231884058, \"value_uncond\": 0.012960262211452207}, {\"x\": 6.521739130434785, \"y\": 4.782608695652174, \"x2\": 6.8115942028985526, \"y2\": 5.0724637681159415, \"center_x\": 6.666666666666669, \"center_y\": 4.927536231884058, \"value_uncond\": 0.012005201877553301}, {\"x\": 6.811594202898551, \"y\": 4.782608695652174, \"x2\": 7.101449275362318, \"y2\": 5.0724637681159415, \"center_x\": 6.956521739130435, \"center_y\": 4.927536231884058, \"value_uncond\": 0.011017193095140902}, {\"x\": 7.10144927536232, \"y\": 4.782608695652174, \"x2\": 7.391304347826088, \"y2\": 5.0724637681159415, \"center_x\": 7.246376811594204, \"center_y\": 4.927536231884058, \"value_uncond\": 0.010016552451979297}, {\"x\": 7.391304347826086, \"y\": 4.782608695652174, \"x2\": 7.681159420289854, \"y2\": 5.0724637681159415, \"center_x\": 7.53623188405797, \"center_y\": 4.927536231884058, \"value_uncond\": 0.009022178027074335}, {\"x\": 7.681159420289855, \"y\": 4.782608695652174, \"x2\": 7.971014492753623, \"y2\": 5.0724637681159415, \"center_x\": 7.826086956521739, \"center_y\": 4.927536231884058, \"value_uncond\": 0.008051009327732077}, {\"x\": 7.971014492753625, \"y\": 4.782608695652174, \"x2\": 8.260869565217392, \"y2\": 5.0724637681159415, \"center_x\": 8.115942028985508, \"center_y\": 4.927536231884058, \"value_uncond\": 0.007117624651857015}, {\"x\": 8.26086956521739, \"y\": 4.782608695652174, \"x2\": 8.550724637681158, \"y2\": 5.0724637681159415, \"center_x\": 8.405797101449274, \"center_y\": 4.927536231884058, \"value_uncond\": 0.00623398349645561}, {\"x\": 8.55072463768116, \"y\": 4.782608695652174, \"x2\": 8.840579710144928, \"y2\": 5.0724637681159415, \"center_x\": 8.695652173913043, \"center_y\": 4.927536231884058, \"value_uncond\": 0.005409311971190908}, {\"x\": 8.84057971014493, \"y\": 4.782608695652174, \"x2\": 9.130434782608697, \"y2\": 5.0724637681159415, \"center_x\": 8.985507246376812, \"center_y\": 4.927536231884058, \"value_uncond\": 0.004650120689912261}, {\"x\": 9.130434782608695, \"y\": 4.782608695652174, \"x2\": 9.420289855072463, \"y2\": 5.0724637681159415, \"center_x\": 9.275362318840578, \"center_y\": 4.927536231884058, \"value_uncond\": 0.003960337835487279}, {\"x\": 9.420289855072465, \"y\": 4.782608695652174, \"x2\": 9.710144927536232, \"y2\": 5.0724637681159415, \"center_x\": 9.565217391304348, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0033415353471874256}, {\"x\": 9.710144927536234, \"y\": 4.782608695652174, \"x2\": 10.000000000000002, \"y2\": 5.0724637681159415, \"center_x\": 9.855072463768117, \"center_y\": 4.927536231884058, \"value_uncond\": 0.0027932235738485287}, {\"x\": 10.0, \"y\": 4.782608695652174, \"x2\": 10.289855072463768, \"y2\": 5.0724637681159415, \"center_x\": 10.144927536231883, \"center_y\": 4.927536231884058, \"value_uncond\": 0.002313189180972133}, {\"x\": -10.0, \"y\": 5.072463768115943, \"x2\": -9.710144927536232, \"y2\": 5.362318840579711, \"center_x\": -9.855072463768117, \"center_y\": 5.217391304347827, \"value_uncond\": 3.096295233639719e-07}, {\"x\": -9.710144927536232, \"y\": 5.072463768115943, \"x2\": -9.420289855072465, \"y2\": 5.362318840579711, \"center_x\": -9.565217391304348, \"center_y\": 5.217391304347827, \"value_uncond\": 4.837627553509998e-07}, {\"x\": -9.420289855072463, \"y\": 5.072463768115943, \"x2\": -9.130434782608695, \"y2\": 5.362318840579711, \"center_x\": -9.275362318840578, \"center_y\": 5.217391304347827, \"value_uncond\": 7.488042638703676e-07}, {\"x\": -9.130434782608695, \"y\": 5.072463768115943, \"x2\": -8.840579710144928, \"y2\": 5.362318840579711, \"center_x\": -8.985507246376812, \"center_y\": 5.217391304347827, \"value_uncond\": 1.1482858224915232e-06}, {\"x\": -8.840579710144928, \"y\": 5.072463768115943, \"x2\": -8.55072463768116, \"y2\": 5.362318840579711, \"center_x\": -8.695652173913043, \"center_y\": 5.217391304347827, \"value_uncond\": 1.7445262607207185e-06}, {\"x\": -8.55072463768116, \"y\": 5.072463768115943, \"x2\": -8.260869565217392, \"y2\": 5.362318840579711, \"center_x\": -8.405797101449277, \"center_y\": 5.217391304347827, \"value_uncond\": 2.625734645205194e-06}, {\"x\": -8.26086956521739, \"y\": 5.072463768115943, \"x2\": -7.971014492753623, \"y2\": 5.362318840579711, \"center_x\": -8.115942028985508, \"center_y\": 5.217391304347827, \"value_uncond\": 3.915344425697475e-06}, {\"x\": -7.971014492753623, \"y\": 5.072463768115943, \"x2\": -7.681159420289855, \"y2\": 5.362318840579711, \"center_x\": -7.826086956521739, \"center_y\": 5.217391304347827, \"value_uncond\": 5.7840884344633715e-06}, {\"x\": -7.681159420289855, \"y\": 5.072463768115943, \"x2\": -7.391304347826088, \"y2\": 5.362318840579711, \"center_x\": -7.536231884057972, \"center_y\": 5.217391304347827, \"value_uncond\": 8.465365055944217e-06}, {\"x\": -7.391304347826087, \"y\": 5.072463768115943, \"x2\": -7.101449275362319, \"y2\": 5.362318840579711, \"center_x\": -7.246376811594203, \"center_y\": 5.217391304347827, \"value_uncond\": 1.227445653706292e-05}, {\"x\": -7.101449275362318, \"y\": 5.072463768115943, \"x2\": -6.811594202898551, \"y2\": 5.362318840579711, \"center_x\": -6.956521739130435, \"center_y\": 5.217391304347827, \"value_uncond\": 1.7632125496308203e-05}, {\"x\": -6.811594202898551, \"y\": 5.072463768115943, \"x2\": -6.521739130434783, \"y2\": 5.362318840579711, \"center_x\": -6.666666666666667, \"center_y\": 5.217391304347827, \"value_uncond\": 2.5093016873409156e-05}, {\"x\": -6.521739130434782, \"y\": 5.072463768115943, \"x2\": -6.231884057971015, \"y2\": 5.362318840579711, \"center_x\": -6.3768115942028984, \"center_y\": 5.217391304347827, \"value_uncond\": 3.537910999962595e-05}, {\"x\": -6.231884057971014, \"y\": 5.072463768115943, \"x2\": -5.942028985507246, \"y2\": 5.362318840579711, \"center_x\": -6.08695652173913, \"center_y\": 5.217391304347827, \"value_uncond\": 4.941817955493573e-05}, {\"x\": -5.942028985507246, \"y\": 5.072463768115943, \"x2\": -5.6521739130434785, \"y2\": 5.362318840579711, \"center_x\": -5.797101449275362, \"center_y\": 5.217391304347827, \"value_uncond\": 6.838681804450433e-05}, {\"x\": -5.6521739130434785, \"y\": 5.072463768115943, \"x2\": -5.362318840579711, \"y2\": 5.362318840579711, \"center_x\": -5.507246376811595, \"center_y\": 5.217391304347827, \"value_uncond\": 9.37570351966053e-05}, {\"x\": -5.36231884057971, \"y\": 5.072463768115943, \"x2\": -5.072463768115942, \"y2\": 5.362318840579711, \"center_x\": -5.217391304347826, \"center_y\": 5.217391304347827, \"value_uncond\": 0.00012734478033952931}, {\"x\": -5.0724637681159415, \"y\": 5.072463768115943, \"x2\": -4.782608695652174, \"y2\": 5.362318840579711, \"center_x\": -4.927536231884058, \"center_y\": 5.217391304347827, \"value_uncond\": 0.00017135794538353534}, {\"x\": -4.782608695652174, \"y\": 5.072463768115943, \"x2\": -4.492753623188406, \"y2\": 5.362318840579711, \"center_x\": -4.63768115942029, \"center_y\": 5.217391304347827, \"value_uncond\": 0.00022844052963533022}, {\"x\": -4.492753623188405, \"y\": 5.072463768115943, \"x2\": -4.202898550724638, \"y2\": 5.362318840579711, \"center_x\": -4.3478260869565215, \"center_y\": 5.217391304347827, \"value_uncond\": 0.00030170873579742915}, {\"x\": -4.202898550724638, \"y\": 5.072463768115943, \"x2\": -3.91304347826087, \"y2\": 5.362318840579711, \"center_x\": -4.057971014492754, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0003947738947672235}, {\"x\": -3.913043478260869, \"y\": 5.072463768115943, \"x2\": -3.6231884057971016, \"y2\": 5.362318840579711, \"center_x\": -3.7681159420289854, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0005117463834022716}, {\"x\": -3.6231884057971016, \"y\": 5.072463768115943, \"x2\": -3.333333333333334, \"y2\": 5.362318840579711, \"center_x\": -3.4782608695652177, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0006572142212608497}, {\"x\": -3.333333333333333, \"y\": 5.072463768115943, \"x2\": -3.0434782608695654, \"y2\": 5.362318840579711, \"center_x\": -3.1884057971014492, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0008361899379559874}, {\"x\": -3.0434782608695645, \"y\": 5.072463768115943, \"x2\": -2.753623188405797, \"y2\": 5.362318840579711, \"center_x\": -2.8985507246376807, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0010540197209255768}, {\"x\": -2.753623188405797, \"y\": 5.072463768115943, \"x2\": -2.4637681159420293, \"y2\": 5.362318840579711, \"center_x\": -2.608695652173913, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0013162498982813378}, {\"x\": -2.4637681159420284, \"y\": 5.072463768115943, \"x2\": -2.1739130434782608, \"y2\": 5.362318840579711, \"center_x\": -2.3188405797101446, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0016284475649946408}, {\"x\": -2.1739130434782608, \"y\": 5.072463768115943, \"x2\": -1.8840579710144931, \"y2\": 5.362318840579711, \"center_x\": -2.028985507246377, \"center_y\": 5.217391304347827, \"value_uncond\": 0.001995974654276386}, {\"x\": -1.8840579710144922, \"y\": 5.072463768115943, \"x2\": -1.5942028985507246, \"y2\": 5.362318840579711, \"center_x\": -1.7391304347826084, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0024237179525454537}, {\"x\": -1.5942028985507246, \"y\": 5.072463768115943, \"x2\": -1.304347826086957, \"y2\": 5.362318840579711, \"center_x\": -1.4492753623188408, \"center_y\": 5.217391304347827, \"value_uncond\": 0.002915781336637707}, {\"x\": -1.304347826086957, \"y\": 5.072463768115943, \"x2\": -1.0144927536231894, \"y2\": 5.362318840579711, \"center_x\": -1.1594202898550732, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0034751506672816477}, {\"x\": -1.0144927536231876, \"y\": 5.072463768115943, \"x2\": -0.72463768115942, \"y2\": 5.362318840579711, \"center_x\": -0.8695652173913038, \"center_y\": 5.217391304347827, \"value_uncond\": 0.004103346007338828}, {\"x\": -0.72463768115942, \"y\": 5.072463768115943, \"x2\": -0.43478260869565233, \"y2\": 5.362318840579711, \"center_x\": -0.5797101449275361, \"center_y\": 5.217391304347827, \"value_uncond\": 0.004800079776571257}, {\"x\": -0.43478260869565233, \"y\": 5.072463768115943, \"x2\": -0.1449275362318847, \"y2\": 5.362318840579711, \"center_x\": -0.2898550724637685, \"center_y\": 5.217391304347827, \"value_uncond\": 0.005562942687262318}, {\"x\": -0.14492753623188293, \"y\": 5.072463768115943, \"x2\": 0.1449275362318847, \"y2\": 5.362318840579711, \"center_x\": 8.881784197001252e-16, \"center_y\": 5.217391304347827, \"value_uncond\": 0.006387141394591343}, {\"x\": 0.1449275362318847, \"y\": 5.072463768115943, \"x2\": 0.43478260869565233, \"y2\": 5.362318840579711, \"center_x\": 0.2898550724637685, \"center_y\": 5.217391304347827, \"value_uncond\": 0.007265312342396628}, {\"x\": 0.43478260869565233, \"y\": 5.072463768115943, \"x2\": 0.72463768115942, \"y2\": 5.362318840579711, \"center_x\": 0.5797101449275361, \"center_y\": 5.217391304347827, \"value_uncond\": 0.008187434971391197}, {\"x\": 0.72463768115942, \"y\": 5.072463768115943, \"x2\": 1.0144927536231876, \"y2\": 5.362318840579711, \"center_x\": 0.8695652173913038, \"center_y\": 5.217391304347827, \"value_uncond\": 0.009140864096972293}, {\"x\": 1.0144927536231894, \"y\": 5.072463768115943, \"x2\": 1.304347826086957, \"y2\": 5.362318840579711, \"center_x\": 1.1594202898550732, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0101104958445195}, {\"x\": 1.304347826086957, \"y\": 5.072463768115943, \"x2\": 1.5942028985507246, \"y2\": 5.362318840579711, \"center_x\": 1.4492753623188408, \"center_y\": 5.217391304347827, \"value_uncond\": 0.01107907423934817}, {\"x\": 1.5942028985507246, \"y\": 5.072463768115943, \"x2\": 1.8840579710144922, \"y2\": 5.362318840579711, \"center_x\": 1.7391304347826084, \"center_y\": 5.217391304347827, \"value_uncond\": 0.012027636783086286}, {\"x\": 1.884057971014494, \"y\": 5.072463768115943, \"x2\": 2.1739130434782616, \"y2\": 5.362318840579711, \"center_x\": 2.028985507246378, \"center_y\": 5.217391304347827, \"value_uncond\": 0.012936087698732852}, {\"x\": 2.1739130434782616, \"y\": 5.072463768115943, \"x2\": 2.4637681159420293, \"y2\": 5.362318840579711, \"center_x\": 2.3188405797101455, \"center_y\": 5.217391304347827, \"value_uncond\": 0.013783877737608382}, {\"x\": 2.4637681159420293, \"y\": 5.072463768115943, \"x2\": 2.753623188405797, \"y2\": 5.362318840579711, \"center_x\": 2.608695652173913, \"center_y\": 5.217391304347827, \"value_uncond\": 0.014550760349213649}, {\"x\": 2.753623188405797, \"y\": 5.072463768115943, \"x2\": 3.0434782608695645, \"y2\": 5.362318840579711, \"center_x\": 2.8985507246376807, \"center_y\": 5.217391304347827, \"value_uncond\": 0.01521758646854096}, {\"x\": 3.0434782608695663, \"y\": 5.072463768115943, \"x2\": 3.333333333333334, \"y2\": 5.362318840579711, \"center_x\": 3.18840579710145, \"center_y\": 5.217391304347827, \"value_uncond\": 0.015767094947680884}, {\"x\": 3.333333333333334, \"y\": 5.072463768115943, \"x2\": 3.6231884057971016, \"y2\": 5.362318840579711, \"center_x\": 3.4782608695652177, \"center_y\": 5.217391304347827, \"value_uncond\": 0.016184653359752416}, {\"x\": 3.6231884057971016, \"y\": 5.072463768115943, \"x2\": 3.913043478260869, \"y2\": 5.362318840579711, \"center_x\": 3.7681159420289854, \"center_y\": 5.217391304347827, \"value_uncond\": 0.01645890490538141}, {\"x\": 3.913043478260871, \"y\": 5.072463768115943, \"x2\": 4.202898550724639, \"y2\": 5.362318840579711, \"center_x\": 4.057971014492755, \"center_y\": 5.217391304347827, \"value_uncond\": 0.016582281536350007}, {\"x\": 4.202898550724639, \"y\": 5.072463768115943, \"x2\": 4.492753623188406, \"y2\": 5.362318840579711, \"center_x\": 4.347826086956522, \"center_y\": 5.217391304347827, \"value_uncond\": 0.016551350944871517}, {\"x\": 4.492753623188406, \"y\": 5.072463768115943, \"x2\": 4.782608695652174, \"y2\": 5.362318840579711, \"center_x\": 4.63768115942029, \"center_y\": 5.217391304347827, \"value_uncond\": 0.016366975214692422}, {\"x\": 4.782608695652174, \"y\": 5.072463768115943, \"x2\": 5.0724637681159415, \"y2\": 5.362318840579711, \"center_x\": 4.927536231884058, \"center_y\": 5.217391304347827, \"value_uncond\": 0.01603427089908147}, {\"x\": 5.072463768115943, \"y\": 5.072463768115943, \"x2\": 5.362318840579711, \"y2\": 5.362318840579711, \"center_x\": 5.217391304347827, \"center_y\": 5.217391304347827, \"value_uncond\": 0.015562373105938575}, {\"x\": 5.362318840579711, \"y\": 5.072463768115943, \"x2\": 5.6521739130434785, \"y2\": 5.362318840579711, \"center_x\": 5.507246376811595, \"center_y\": 5.217391304347827, \"value_uncond\": 0.014964018771678233}, {\"x\": 5.6521739130434785, \"y\": 5.072463768115943, \"x2\": 5.942028985507246, \"y2\": 5.362318840579711, \"center_x\": 5.797101449275362, \"center_y\": 5.217391304347827, \"value_uncond\": 0.014254975654723591}, {\"x\": 5.942028985507246, \"y\": 5.072463768115943, \"x2\": 6.231884057971014, \"y2\": 5.362318840579711, \"center_x\": 6.08695652173913, \"center_y\": 5.217391304347827, \"value_uncond\": 0.013453352763753925}, {\"x\": 6.2318840579710155, \"y\": 5.072463768115943, \"x2\": 6.521739130434783, \"y2\": 5.362318840579711, \"center_x\": 6.376811594202899, \"center_y\": 5.217391304347827, \"value_uncond\": 0.012578834257875104}, {\"x\": 6.521739130434785, \"y\": 5.072463768115943, \"x2\": 6.8115942028985526, \"y2\": 5.362318840579711, \"center_x\": 6.666666666666669, \"center_y\": 5.217391304347827, \"value_uncond\": 0.011651881897623508}, {\"x\": 6.811594202898551, \"y\": 5.072463768115943, \"x2\": 7.101449275362318, \"y2\": 5.362318840579711, \"center_x\": 6.956521739130435, \"center_y\": 5.217391304347827, \"value_uncond\": 0.010692950780604234}, {\"x\": 7.10144927536232, \"y\": 5.072463768115943, \"x2\": 7.391304347826088, \"y2\": 5.362318840579711, \"center_x\": 7.246376811594204, \"center_y\": 5.217391304347827, \"value_uncond\": 0.009721759565745856}, {\"x\": 7.391304347826086, \"y\": 5.072463768115943, \"x2\": 7.681159420289854, \"y2\": 5.362318840579711, \"center_x\": 7.53623188405797, \"center_y\": 5.217391304347827, \"value_uncond\": 0.00875665015074523}, {\"x\": 7.681159420289855, \"y\": 5.072463768115943, \"x2\": 7.971014492753623, \"y2\": 5.362318840579711, \"center_x\": 7.826086956521739, \"center_y\": 5.217391304347827, \"value_uncond\": 0.007814063503488377}, {\"x\": 7.971014492753625, \"y\": 5.072463768115943, \"x2\": 8.260869565217392, \"y2\": 5.362318840579711, \"center_x\": 8.115942028985508, \"center_y\": 5.217391304347827, \"value_uncond\": 0.006908148874207331}, {\"x\": 8.26086956521739, \"y\": 5.072463768115943, \"x2\": 8.550724637681158, \"y2\": 5.362318840579711, \"center_x\": 8.405797101449274, \"center_y\": 5.217391304347827, \"value_uncond\": 0.006050513785049202}, {\"x\": 8.55072463768116, \"y\": 5.072463768115943, \"x2\": 8.840579710144928, \"y2\": 5.362318840579711, \"center_x\": 8.695652173913043, \"center_y\": 5.217391304347827, \"value_uncond\": 0.005250112815975646}, {\"x\": 8.84057971014493, \"y\": 5.072463768115943, \"x2\": 9.130434782608697, \"y2\": 5.362318840579711, \"center_x\": 8.985507246376812, \"center_y\": 5.217391304347827, \"value_uncond\": 0.004513264969734587}, {\"x\": 9.130434782608695, \"y\": 5.072463768115943, \"x2\": 9.420289855072463, \"y2\": 5.362318840579711, \"center_x\": 9.275362318840578, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0038437828205178234}, {\"x\": 9.420289855072465, \"y\": 5.072463768115943, \"x2\": 9.710144927536232, \"y2\": 5.362318840579711, \"center_x\": 9.565217391304348, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0032431920445220664}, {\"x\": 9.710144927536234, \"y\": 5.072463768115943, \"x2\": 10.000000000000002, \"y2\": 5.362318840579711, \"center_x\": 9.855072463768117, \"center_y\": 5.217391304347827, \"value_uncond\": 0.0027110174012978747}, {\"x\": 10.0, \"y\": 5.072463768115943, \"x2\": 10.289855072463768, \"y2\": 5.362318840579711, \"center_x\": 10.144927536231883, \"center_y\": 5.217391304347827, \"value_uncond\": 0.002245110696051106}, {\"x\": -10.0, \"y\": 5.362318840579711, \"x2\": -9.710144927536232, \"y2\": 5.6521739130434785, \"center_x\": -9.855072463768117, \"center_y\": 5.507246376811595, \"value_uncond\": 2.977246444577404e-07}, {\"x\": -9.710144927536232, \"y\": 5.362318840579711, \"x2\": -9.420289855072465, \"y2\": 5.6521739130434785, \"center_x\": -9.565217391304348, \"center_y\": 5.507246376811595, \"value_uncond\": 4.6516266528456056e-07}, {\"x\": -9.420289855072463, \"y\": 5.362318840579711, \"x2\": -9.130434782608695, \"y2\": 5.6521739130434785, \"center_x\": -9.275362318840578, \"center_y\": 5.507246376811595, \"value_uncond\": 7.200136498843506e-07}, {\"x\": -9.130434782608695, \"y\": 5.362318840579711, \"x2\": -8.840579710144928, \"y2\": 5.6521739130434785, \"center_x\": -8.985507246376812, \"center_y\": 5.507246376811595, \"value_uncond\": 1.1041356280333723e-06}, {\"x\": -8.840579710144928, \"y\": 5.362318840579711, \"x2\": -8.55072463768116, \"y2\": 5.6521739130434785, \"center_x\": -8.695652173913043, \"center_y\": 5.507246376811595, \"value_uncond\": 1.6774513459742732e-06}, {\"x\": -8.55072463768116, \"y\": 5.362318840579711, \"x2\": -8.260869565217392, \"y2\": 5.6521739130434785, \"center_x\": -8.405797101449277, \"center_y\": 5.507246376811595, \"value_uncond\": 2.52477833893488e-06}, {\"x\": -8.26086956521739, \"y\": 5.362318840579711, \"x2\": -7.971014492753623, \"y2\": 5.6521739130434785, \"center_x\": -8.115942028985508, \"center_y\": 5.507246376811595, \"value_uncond\": 3.7648041905231814e-06}, {\"x\": -7.971014492753623, \"y\": 5.362318840579711, \"x2\": -7.681159420289855, \"y2\": 5.6521739130434785, \"center_x\": -7.826086956521739, \"center_y\": 5.507246376811595, \"value_uncond\": 5.561697263081826e-06}, {\"x\": -7.681159420289855, \"y\": 5.362318840579711, \"x2\": -7.391304347826088, \"y2\": 5.6521739130434785, \"center_x\": -7.536231884057972, \"center_y\": 5.507246376811595, \"value_uncond\": 8.139882056800119e-06}, {\"x\": -7.391304347826087, \"y\": 5.362318840579711, \"x2\": -7.101449275362319, \"y2\": 5.6521739130434785, \"center_x\": -7.246376811594203, \"center_y\": 5.507246376811595, \"value_uncond\": 1.1802518599343171e-05}, {\"x\": -7.101449275362318, \"y\": 5.362318840579711, \"x2\": -6.811594202898551, \"y2\": 5.6521739130434785, \"center_x\": -6.956521739130435, \"center_y\": 5.507246376811595, \"value_uncond\": 1.6954191697836777e-05}, {\"x\": -6.811594202898551, \"y\": 5.362318840579711, \"x2\": -6.521739130434783, \"y2\": 5.6521739130434785, \"center_x\": -6.666666666666667, \"center_y\": 5.507246376811595, \"value_uncond\": 2.4128220868091493e-05}, {\"x\": -6.521739130434782, \"y\": 5.362318840579711, \"x2\": -6.231884057971015, \"y2\": 5.6521739130434785, \"center_x\": -6.3768115942028984, \"center_y\": 5.507246376811595, \"value_uncond\": 3.4018826213442224e-05}, {\"x\": -6.231884057971014, \"y\": 5.362318840579711, \"x2\": -5.942028985507246, \"y2\": 5.6521739130434785, \"center_x\": -6.08695652173913, \"center_y\": 5.507246376811595, \"value_uncond\": 4.7518110604868697e-05}, {\"x\": -5.942028985507246, \"y\": 5.362318840579711, \"x2\": -5.6521739130434785, \"y2\": 5.6521739130434785, \"center_x\": -5.797101449275362, \"center_y\": 5.507246376811595, \"value_uncond\": 6.575742799552855e-05}, {\"x\": -5.6521739130434785, \"y\": 5.362318840579711, \"x2\": -5.362318840579711, \"y2\": 5.6521739130434785, \"center_x\": -5.507246376811595, \"center_y\": 5.507246376811595, \"value_uncond\": 9.01521911284547e-05}, {\"x\": -5.36231884057971, \"y\": 5.362318840579711, \"x2\": -5.072463768115942, \"y2\": 5.6521739130434785, \"center_x\": -5.217391304347826, \"center_y\": 5.507246376811595, \"value_uncond\": 0.00012244852828703783}, {\"x\": -5.0724637681159415, \"y\": 5.362318840579711, \"x2\": -4.782608695652174, \"y2\": 5.6521739130434785, \"center_x\": -4.927536231884058, \"center_y\": 5.507246376811595, \"value_uncond\": 0.00016476944062065562}, {\"x\": -4.782608695652174, \"y\": 5.362318840579711, \"x2\": -4.492753623188406, \"y2\": 5.6521739130434785, \"center_x\": -4.63768115942029, \"center_y\": 5.507246376811595, \"value_uncond\": 0.00021965726887570545}, {\"x\": -4.492753623188405, \"y\": 5.362318840579711, \"x2\": -4.202898550724638, \"y2\": 5.6521739130434785, \"center_x\": -4.3478260869565215, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0002901084015476537}, {\"x\": -4.202898550724638, \"y\": 5.362318840579711, \"x2\": -3.91304347826087, \"y2\": 5.6521739130434785, \"center_x\": -4.057971014492754, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0003795953182494388}, {\"x\": -3.913043478260869, \"y\": 5.362318840579711, \"x2\": -3.6231884057971016, \"y2\": 5.6521739130434785, \"center_x\": -3.7681159420289854, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0004920703568434459}, {\"x\": -3.6231884057971016, \"y\": 5.362318840579711, \"x2\": -3.333333333333334, \"y2\": 5.6521739130434785, \"center_x\": -3.4782608695652177, \"center_y\": 5.507246376811595, \"value_uncond\": 0.000631945133111376}, {\"x\": -3.333333333333333, \"y\": 5.362318840579711, \"x2\": -3.0434782608695654, \"y2\": 5.6521739130434785, \"center_x\": -3.1884057971014492, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0008040394509939493}, {\"x\": -3.0434782608695645, \"y\": 5.362318840579711, \"x2\": -2.753623188405797, \"y2\": 5.6521739130434785, \"center_x\": -2.8985507246376807, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0010134939435188506}, {\"x\": -2.753623188405797, \"y\": 5.362318840579711, \"x2\": -2.4637681159420293, \"y2\": 5.6521739130434785, \"center_x\": -2.608695652173913, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0012656416892218962}, {\"x\": -2.4637681159420284, \"y\": 5.362318840579711, \"x2\": -2.1739130434782608, \"y2\": 5.6521739130434785, \"center_x\": -2.3188405797101446, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0015658357350380376}, {\"x\": -2.1739130434782608, \"y\": 5.362318840579711, \"x2\": -1.8840579710144931, \"y2\": 5.6521739130434785, \"center_x\": -2.028985507246377, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0019192318543621285}, {\"x\": -1.8840579710144922, \"y\": 5.362318840579711, \"x2\": -1.5942028985507246, \"y2\": 5.6521739130434785, \"center_x\": -1.7391304347826084, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0023305289426137506}, {\"x\": -1.5942028985507246, \"y\": 5.362318840579711, \"x2\": -1.304347826086957, \"y2\": 5.6521739130434785, \"center_x\": -1.4492753623188408, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0028036730875515294}, {\"x\": -1.304347826086957, \"y\": 5.362318840579711, \"x2\": -1.0144927536231894, \"y2\": 5.6521739130434785, \"center_x\": -1.1594202898550732, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0033415353471874256}, {\"x\": -1.0144927536231876, \"y\": 5.362318840579711, \"x2\": -0.72463768115942, \"y2\": 5.6521739130434785, \"center_x\": -0.8695652173913038, \"center_y\": 5.507246376811595, \"value_uncond\": 0.00394557733981317}, {\"x\": -0.72463768115942, \"y\": 5.362318840579711, \"x2\": -0.43478260869565233, \"y2\": 5.6521739130434785, \"center_x\": -0.5797101449275361, \"center_y\": 5.507246376811595, \"value_uncond\": 0.004615522542301451}, {\"x\": -0.43478260869565233, \"y\": 5.362318840579711, \"x2\": -0.1449275362318847, \"y2\": 5.6521739130434785, \"center_x\": -0.2898550724637685, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0053490543011205476}, {\"x\": -0.14492753623188293, \"y\": 5.362318840579711, \"x2\": 0.1449275362318847, \"y2\": 5.6521739130434785, \"center_x\": 8.881784197001252e-16, \"center_y\": 5.507246376811595, \"value_uncond\": 0.006141563569733192}, {\"x\": 0.1449275362318847, \"y\": 5.362318840579711, \"x2\": 0.43478260869565233, \"y2\": 5.6521739130434785, \"center_x\": 0.2898550724637685, \"center_y\": 5.507246376811595, \"value_uncond\": 0.006985969911763776}, {\"x\": 0.43478260869565233, \"y\": 5.362318840579711, \"x2\": 0.72463768115942, \"y2\": 5.6521739130434785, \"center_x\": 0.5797101449275361, \"center_y\": 5.507246376811595, \"value_uncond\": 0.007872638046252756}, {\"x\": 0.72463768115942, \"y\": 5.362318840579711, \"x2\": 1.0144927536231876, \"y2\": 5.6521739130434785, \"center_x\": 0.8695652173913038, \"center_y\": 5.507246376811595, \"value_uncond\": 0.008789408980578704}, {\"x\": 1.0144927536231894, \"y\": 5.362318840579711, \"x2\": 1.304347826086957, \"y2\": 5.6521739130434785, \"center_x\": 1.1594202898550732, \"center_y\": 5.507246376811595, \"value_uncond\": 0.009721759565745867}, {\"x\": 1.304347826086957, \"y\": 5.362318840579711, \"x2\": 1.5942028985507246, \"y2\": 5.6521739130434785, \"center_x\": 1.4492753623188408, \"center_y\": 5.507246376811595, \"value_uncond\": 0.010653097298326468}, {\"x\": 1.5942028985507246, \"y\": 5.362318840579711, \"x2\": 1.8840579710144922, \"y2\": 5.6521739130434785, \"center_x\": 1.7391304347826084, \"center_y\": 5.507246376811595, \"value_uncond\": 0.011565188764967345}, {\"x\": 1.884057971014494, \"y\": 5.362318840579711, \"x2\": 2.1739130434782616, \"y2\": 5.6521739130434785, \"center_x\": 2.028985507246378, \"center_y\": 5.507246376811595, \"value_uncond\": 0.01243871084687245}, {\"x\": 2.1739130434782616, \"y\": 5.362318840579711, \"x2\": 2.4637681159420293, \"y2\": 5.6521739130434785, \"center_x\": 2.3188405797101455, \"center_y\": 5.507246376811595, \"value_uncond\": 0.013253904389002227}, {\"x\": 2.4637681159420293, \"y\": 5.362318840579711, \"x2\": 2.753623188405797, \"y2\": 5.6521739130434785, \"center_x\": 2.608695652173913, \"center_y\": 5.507246376811595, \"value_uncond\": 0.013991301296120189}, {\"x\": 2.753623188405797, \"y\": 5.362318840579711, \"x2\": 3.0434782608695645, \"y2\": 5.6521739130434785, \"center_x\": 2.8985507246376807, \"center_y\": 5.507246376811595, \"value_uncond\": 0.014632488761497914}, {\"x\": 3.0434782608695663, \"y\": 5.362318840579711, \"x2\": 3.333333333333334, \"y2\": 5.6521739130434785, \"center_x\": 3.18840579710145, \"center_y\": 5.507246376811595, \"value_uncond\": 0.015160869307387047}, {\"x\": 3.333333333333334, \"y\": 5.362318840579711, \"x2\": 3.6231884057971016, \"y2\": 5.6521739130434785, \"center_x\": 3.4782608695652177, \"center_y\": 5.507246376811595, \"value_uncond\": 0.01556237310593858}, {\"x\": 3.6231884057971016, \"y\": 5.362318840579711, \"x2\": 3.913043478260869, \"y2\": 5.6521739130434785, \"center_x\": 3.7681159420289854, \"center_y\": 5.507246376811595, \"value_uncond\": 0.015826080012913323}, {\"x\": 3.913043478260871, \"y\": 5.362318840579711, \"x2\": 4.202898550724639, \"y2\": 5.6521739130434785, \"center_x\": 4.057971014492755, \"center_y\": 5.507246376811595, \"value_uncond\": 0.015944712962350577}, {\"x\": 4.202898550724639, \"y\": 5.362318840579711, \"x2\": 4.492753623188406, \"y2\": 5.6521739130434785, \"center_x\": 4.347826086956522, \"center_y\": 5.507246376811595, \"value_uncond\": 0.01591497161452705}, {\"x\": 4.492753623188406, \"y\": 5.362318840579711, \"x2\": 4.782608695652174, \"y2\": 5.6521739130434785, \"center_x\": 4.63768115942029, \"center_y\": 5.507246376811595, \"value_uncond\": 0.015737684907116793}, {\"x\": 4.782608695652174, \"y\": 5.362318840579711, \"x2\": 5.0724637681159415, \"y2\": 5.6521739130434785, \"center_x\": 4.927536231884058, \"center_y\": 5.507246376811595, \"value_uncond\": 0.015417772668133083}, {\"x\": 5.072463768115943, \"y\": 5.362318840579711, \"x2\": 5.362318840579711, \"y2\": 5.6521739130434785, \"center_x\": 5.217391304347827, \"center_y\": 5.507246376811595, \"value_uncond\": 0.014964018771678233}, {\"x\": 5.362318840579711, \"y\": 5.362318840579711, \"x2\": 5.6521739130434785, \"y2\": 5.6521739130434785, \"center_x\": 5.507246376811595, \"center_y\": 5.507246376811595, \"value_uncond\": 0.014388670434439739}, {\"x\": 5.6521739130434785, \"y\": 5.362318840579711, \"x2\": 5.942028985507246, \"y2\": 5.6521739130434785, \"center_x\": 5.797101449275362, \"center_y\": 5.507246376811595, \"value_uncond\": 0.013706889163690632}, {\"x\": 5.942028985507246, \"y\": 5.362318840579711, \"x2\": 6.231884057971014, \"y2\": 5.6521739130434785, \"center_x\": 6.08695652173913, \"center_y\": 5.507246376811595, \"value_uncond\": 0.01293608769873285}, {\"x\": 6.2318840579710155, \"y\": 5.362318840579711, \"x2\": 6.521739130434783, \"y2\": 5.6521739130434785, \"center_x\": 6.376811594202899, \"center_y\": 5.507246376811595, \"value_uncond\": 0.012095193366675168}, {\"x\": 6.521739130434785, \"y\": 5.362318840579711, \"x2\": 6.8115942028985526, \"y2\": 5.6521739130434785, \"center_x\": 6.666666666666669, \"center_y\": 5.507246376811595, \"value_uncond\": 0.011203881198226821}, {\"x\": 6.811594202898551, \"y\": 5.362318840579711, \"x2\": 7.101449275362318, \"y2\": 5.6521739130434785, \"center_x\": 6.956521739130435, \"center_y\": 5.507246376811595, \"value_uncond\": 0.010281819817347382}, {\"x\": 7.10144927536232, \"y\": 5.362318840579711, \"x2\": 7.391304347826088, \"y2\": 5.6521739130434785, \"center_x\": 7.246376811594204, \"center_y\": 5.507246376811595, \"value_uncond\": 0.00934796972449207}, {\"x\": 7.391304347826086, \"y\": 5.362318840579711, \"x2\": 7.681159420289854, \"y2\": 5.6521739130434785, \"center_x\": 7.53623188405797, \"center_y\": 5.507246376811595, \"value_uncond\": 0.008419967593680685}, {\"x\": 7.681159420289855, \"y\": 5.362318840579711, \"x2\": 7.971014492753623, \"y2\": 5.6521739130434785, \"center_x\": 7.826086956521739, \"center_y\": 5.507246376811595, \"value_uncond\": 0.007513622257563381}, {\"x\": 7.971014492753625, \"y\": 5.362318840579711, \"x2\": 8.260869565217392, \"y2\": 5.6521739130434785, \"center_x\": 8.115942028985508, \"center_y\": 5.507246376811595, \"value_uncond\": 0.00664253894489518}, {\"x\": 8.26086956521739, \"y\": 5.362318840579711, \"x2\": 8.550724637681158, \"y2\": 5.6521739130434785, \"center_x\": 8.405797101449274, \"center_y\": 5.507246376811595, \"value_uncond\": 0.005817878882702297}, {\"x\": 8.55072463768116, \"y\": 5.362318840579711, \"x2\": 8.840579710144928, \"y2\": 5.6521739130434785, \"center_x\": 8.695652173913043, \"center_y\": 5.507246376811595, \"value_uncond\": 0.005048252358228618}, {\"x\": 8.84057971014493, \"y\": 5.362318840579711, \"x2\": 9.130434782608697, \"y2\": 5.6521739130434785, \"center_x\": 8.985507246376812, \"center_y\": 5.507246376811595, \"value_uncond\": 0.004339735416245373}, {\"x\": 9.130434782608695, \"y\": 5.362318840579711, \"x2\": 9.420289855072463, \"y2\": 5.6521739130434785, \"center_x\": 9.275362318840578, \"center_y\": 5.507246376811595, \"value_uncond\": 0.003695994042099792}, {\"x\": 9.420289855072465, \"y\": 5.362318840579711, \"x2\": 9.710144927536232, \"y2\": 5.6521739130434785, \"center_x\": 9.565217391304348, \"center_y\": 5.507246376811595, \"value_uncond\": 0.003118495251592849}, {\"x\": 9.710144927536234, \"y\": 5.362318840579711, \"x2\": 10.000000000000002, \"y2\": 5.6521739130434785, \"center_x\": 9.855072463768117, \"center_y\": 5.507246376811595, \"value_uncond\": 0.002606782076692864}, {\"x\": 10.0, \"y\": 5.362318840579711, \"x2\": 10.289855072463768, \"y2\": 5.6521739130434785, \"center_x\": 10.144927536231883, \"center_y\": 5.507246376811595, \"value_uncond\": 0.0021587889180850065}, {\"x\": -10.0, \"y\": 5.6521739130434785, \"x2\": -9.710144927536232, \"y2\": 5.942028985507246, \"center_x\": -9.855072463768117, \"center_y\": 5.797101449275362, \"value_uncond\": 2.8361749763298007e-07}, {\"x\": -9.710144927536232, \"y\": 5.6521739130434785, \"x2\": -9.420289855072465, \"y2\": 5.942028985507246, \"center_x\": -9.565217391304348, \"center_y\": 5.797101449275362, \"value_uncond\": 4.4312176897744417e-07}, {\"x\": -9.420289855072463, \"y\": 5.6521739130434785, \"x2\": -9.130434782608695, \"y2\": 5.942028985507246, \"center_x\": -9.275362318840578, \"center_y\": 5.797101449275362, \"value_uncond\": 6.858970980172719e-07}, {\"x\": -9.130434782608695, \"y\": 5.6521739130434785, \"x2\": -8.840579710144928, \"y2\": 5.942028985507246, \"center_x\": -8.985507246376812, \"center_y\": 5.797101449275362, \"value_uncond\": 1.0518181470687534e-06}, {\"x\": -8.840579710144928, \"y\": 5.6521739130434785, \"x2\": -8.55072463768116, \"y2\": 5.942028985507246, \"center_x\": -8.695652173913043, \"center_y\": 5.797101449275362, \"value_uncond\": 1.5979683308139013e-06}, {\"x\": -8.55072463768116, \"y\": 5.6521739130434785, \"x2\": -8.260869565217392, \"y2\": 5.942028985507246, \"center_x\": -8.405797101449277, \"center_y\": 5.797101449275362, \"value_uncond\": 2.4051462581167118e-06}, {\"x\": -8.26086956521739, \"y\": 5.6521739130434785, \"x2\": -7.971014492753623, \"y2\": 5.942028985507246, \"center_x\": -8.115942028985508, \"center_y\": 5.797101449275362, \"value_uncond\": 3.586415714893573e-06}, {\"x\": -7.971014492753623, \"y\": 5.6521739130434785, \"x2\": -7.681159420289855, \"y2\": 5.942028985507246, \"center_x\": -7.826086956521739, \"center_y\": 5.797101449275362, \"value_uncond\": 5.2981662408916325e-06}, {\"x\": -7.681159420289855, \"y\": 5.6521739130434785, \"x2\": -7.391304347826088, \"y2\": 5.942028985507246, \"center_x\": -7.536231884057972, \"center_y\": 5.797101449275362, \"value_uncond\": 7.754188384982478e-06}, {\"x\": -7.391304347826087, \"y\": 5.6521739130434785, \"x2\": -7.101449275362319, \"y2\": 5.942028985507246, \"center_x\": -7.246376811594203, \"center_y\": 5.797101449275362, \"value_uncond\": 1.1243277482148635e-05}, {\"x\": -7.101449275362318, \"y\": 5.6521739130434785, \"x2\": -6.811594202898551, \"y2\": 5.942028985507246, \"center_x\": -6.956521739130435, \"center_y\": 5.797101449275362, \"value_uncond\": 1.6150847816069353e-05}, {\"x\": -6.811594202898551, \"y\": 5.6521739130434785, \"x2\": -6.521739130434783, \"y2\": 5.942028985507246, \"center_x\": -6.666666666666667, \"center_y\": 5.797101449275362, \"value_uncond\": 2.2984948516464874e-05}, {\"x\": -6.521739130434782, \"y\": 5.6521739130434785, \"x2\": -6.231884057971015, \"y2\": 5.942028985507246, \"center_x\": -6.3768115942028984, \"center_y\": 5.797101449275362, \"value_uncond\": 3.2406905315616995e-05}, {\"x\": -6.231884057971014, \"y\": 5.6521739130434785, \"x2\": -5.942028985507246, \"y2\": 5.942028985507246, \"center_x\": -6.08695652173913, \"center_y\": 5.797101449275362, \"value_uncond\": 4.52665503943964e-05}, {\"x\": -5.942028985507246, \"y\": 5.6521739130434785, \"x2\": -5.6521739130434785, \"y2\": 5.942028985507246, \"center_x\": -5.797101449275362, \"center_y\": 5.797101449275362, \"value_uncond\": 6.26416305336118e-05}, {\"x\": -5.6521739130434785, \"y\": 5.6521739130434785, \"x2\": -5.362318840579711, \"y2\": 5.942028985507246, \"center_x\": -5.507246376811595, \"center_y\": 5.797101449275362, \"value_uncond\": 8.588049168906403e-05}, {\"x\": -5.36231884057971, \"y\": 5.6521739130434785, \"x2\": -5.072463768115942, \"y2\": 5.942028985507246, \"center_x\": -5.217391304347826, \"center_y\": 5.797101449275362, \"value_uncond\": 0.00011664652499581822}, {\"x\": -5.0724637681159415, \"y\": 5.6521739130434785, \"x2\": -4.782608695652174, \"y2\": 5.942028985507246, \"center_x\": -4.927536231884058, \"center_y\": 5.797101449275362, \"value_uncond\": 0.00015696213701197142}, {\"x\": -4.782608695652174, \"y\": 5.6521739130434785, \"x2\": -4.492753623188406, \"y2\": 5.942028985507246, \"center_x\": -4.63768115942029, \"center_y\": 5.797101449275362, \"value_uncond\": 0.00020924920424001095}, {\"x\": -4.492753623188405, \"y\": 5.6521739130434785, \"x2\": -4.202898550724638, \"y2\": 5.942028985507246, \"center_x\": -4.3478260869565215, \"center_y\": 5.797101449275362, \"value_uncond\": 0.0002763621366955009}, {\"x\": -4.202898550724638, \"y\": 5.6521739130434785, \"x2\": -3.91304347826087, \"y2\": 5.942028985507246, \"center_x\": -4.057971014492754, \"center_y\": 5.797101449275362, \"value_uncond\": 0.00036160887679011775}, {\"x\": -3.913043478260869, \"y\": 5.6521739130434785, \"x2\": -3.6231884057971016, \"y2\": 5.942028985507246, \"center_x\": -3.7681159420289854, \"center_y\": 5.797101449275362, \"value_uncond\": 0.0004687544879648525}, {\"x\": -3.6231884057971016, \"y\": 5.6521739130434785, \"x2\": -3.333333333333334, \"y2\": 5.942028985507246, \"center_x\": -3.4782608695652177, \"center_y\": 5.797101449275362, \"value_uncond\": 0.0006020015495218082}, {\"x\": -3.333333333333333, \"y\": 5.6521739130434785, \"x2\": -3.0434782608695654, \"y2\": 5.942028985507246, \"center_x\": -3.1884057971014492, \"center_y\": 5.797101449275362, \"value_uncond\": 0.0007659414876603125}, {\"x\": -3.0434782608695645, \"y\": 5.6521739130434785, \"x2\": -2.753623188405797, \"y2\": 5.942028985507246, \"center_x\": -2.8985507246376807, \"center_y\": 5.797101449275362, \"value_uncond\": 0.0009654713557573767}, {\"x\": -2.753623188405797, \"y\": 5.6521739130434785, \"x2\": -2.4637681159420293, \"y2\": 5.942028985507246, \"center_x\": -2.608695652173913, \"center_y\": 5.797101449275362, \"value_uncond\": 0.001205671534013852}, {\"x\": -2.4637681159420284, \"y\": 5.6521739130434785, \"x2\": -2.1739130434782608, \"y2\": 5.942028985507246, \"center_x\": -2.3188405797101446, \"center_y\": 5.797101449275362, \"value_uncond\": 0.0014916414248630431}, {\"x\": -2.1739130434782608, \"y\": 5.6521739130434785, \"x2\": -1.8840579710144931, \"y2\": 5.942028985507246, \"center_x\": -2.028985507246377, \"center_y\": 5.797101449275362, \"value_uncond\": 0.0018282925046500629}, {\"x\": -1.8840579710144922, \"y\": 5.6521739130434785, \"x2\": -1.5942028985507246, \"y2\": 5.942028985507246, \"center_x\": -1.7391304347826084, \"center_y\": 5.797101449275362, \"value_uncond\": 0.002220101020085922}, {\"x\": -1.5942028985507246, \"y\": 5.6521739130434785, \"x2\": -1.304347826086957, \"y2\": 5.942028985507246, \"center_x\": -1.4492753623188408, \"center_y\": 5.797101449275362, \"value_uncond\": 0.0026708260806577767}, {\"x\": -1.304347826086957, \"y\": 5.6521739130434785, \"x2\": -1.0144927536231894, \"y2\": 5.942028985507246, \"center_x\": -1.1594202898550732, \"center_y\": 5.797101449275362, \"value_uncond\": 0.003183202704457242}, {\"x\": -1.0144927536231876, \"y\": 5.6521739130434785, \"x2\": -0.72463768115942, \"y2\": 5.942028985507246, \"center_x\": -0.8695652173913038, \"center_y\": 5.797101449275362, \"value_uncond\": 0.0037586232536219923}, {\"x\": -0.72463768115942, \"y\": 5.6521739130434785, \"x2\": -0.43478260869565233, \"y2\": 5.942028985507246, \"center_x\": -0.5797101449275361, \"center_y\": 5.797101449275362, \"value_uncond\": 0.004396824307575779}, {\"x\": -0.43478260869565233, \"y\": 5.6521739130434785, \"x2\": -0.1449275362318847, \"y2\": 5.942028985507246, \"center_x\": -0.2898550724637685, \"center_y\": 5.797101449275362, \"value_uncond\": 0.005095598983248022}, {\"x\": -0.14492753623188293, \"y\": 5.6521739130434785, \"x2\": 0.1449275362318847, \"y2\": 5.942028985507246, \"center_x\": 8.881784197001252e-16, \"center_y\": 5.797101449275362, \"value_uncond\": 0.005850556625482325}, {\"x\": 0.1449275362318847, \"y\": 5.6521739130434785, \"x2\": 0.43478260869565233, \"y2\": 5.942028985507246, \"center_x\": 0.2898550724637685, \"center_y\": 5.797101449275362, \"value_uncond\": 0.006654952291646691}, {\"x\": 0.43478260869565233, \"y\": 5.6521739130434785, \"x2\": 0.72463768115942, \"y2\": 5.942028985507246, \"center_x\": 0.5797101449275361, \"center_y\": 5.797101449275362, \"value_uncond\": 0.0074996072512409475}, {\"x\": 0.72463768115942, \"y\": 5.6521739130434785, \"x2\": 1.0144927536231876, \"y2\": 5.942028985507246, \"center_x\": 0.8695652173913038, \"center_y\": 5.797101449275362, \"value_uncond\": 0.008372938643641286}, {\"x\": 1.0144927536231894, \"y\": 5.6521739130434785, \"x2\": 1.304347826086957, \"y2\": 5.942028985507246, \"center_x\": 1.1594202898550732, \"center_y\": 5.797101449275362, \"value_uncond\": 0.009261111473147477}, {\"x\": 1.304347826086957, \"y\": 5.6521739130434785, \"x2\": 1.5942028985507246, \"y2\": 5.942028985507246, \"center_x\": 1.4492753623188408, \"center_y\": 5.797101449275362, \"value_uncond\": 0.010148319442265323}, {\"x\": 1.5942028985507246, \"y\": 5.6521739130434785, \"x2\": 1.8840579710144922, \"y2\": 5.942028985507246, \"center_x\": 1.7391304347826084, \"center_y\": 5.797101449275362, \"value_uncond\": 0.011017193095140902}, {\"x\": 1.884057971014494, \"y\": 5.6521739130434785, \"x2\": 2.1739130434782616, \"y2\": 5.942028985507246, \"center_x\": 2.028985507246378, \"center_y\": 5.797101449275362, \"value_uncond\": 0.011849324904210014}, {\"x\": 2.1739130434782616, \"y\": 5.6521739130434785, \"x2\": 2.4637681159420293, \"y2\": 5.942028985507246, \"center_x\": 2.3188405797101455, \"center_y\": 5.797101449275362, \"value_uncond\": 0.012625891966458132}, {\"x\": 2.4637681159420293, \"y\": 5.6521739130434785, \"x2\": 2.753623188405797, \"y2\": 5.942028985507246, \"center_x\": 2.608695652173913, \"center_y\": 5.797101449275362, \"value_uncond\": 0.013328348647328502}, {\"x\": 2.753623188405797, \"y\": 5.6521739130434785, \"x2\": 3.0434782608695645, \"y2\": 5.942028985507246, \"center_x\": 2.8985507246376807, \"center_y\": 5.797101449275362, \"value_uncond\": 0.013939154597824402}, {\"x\": 3.0434782608695663, \"y\": 5.6521739130434785, \"x2\": 3.333333333333334, \"y2\": 5.942028985507246, \"center_x\": 3.18840579710145, \"center_y\": 5.797101449275362, \"value_uncond\": 0.01444249878183029}, {\"x\": 3.333333333333334, \"y\": 5.6521739130434785, \"x2\": 3.6231884057971016, \"y2\": 5.942028985507246, \"center_x\": 3.4782608695652177, \"center_y\": 5.797101449275362, \"value_uncond\": 0.014824978044985428}, {\"x\": 3.6231884057971016, \"y\": 5.6521739130434785, \"x2\": 3.913043478260869, \"y2\": 5.942028985507246, \"center_x\": 3.7681159420289854, \"center_y\": 5.797101449275362, \"value_uncond\": 0.015076189674445703}, {\"x\": 3.913043478260871, \"y\": 5.6521739130434785, \"x2\": 4.202898550724639, \"y2\": 5.942028985507246, \"center_x\": 4.057971014492755, \"center_y\": 5.797101449275362, \"value_uncond\": 0.01518920141493328}, {\"x\": 4.202898550724639, \"y\": 5.6521739130434785, \"x2\": 4.492753623188406, \"y2\": 5.942028985507246, \"center_x\": 4.347826086956522, \"center_y\": 5.797101449275362, \"value_uncond\": 0.015160869307387045}, {\"x\": 4.492753623188406, \"y\": 5.6521739130434785, \"x2\": 4.782608695652174, \"y2\": 5.942028985507246, \"center_x\": 4.63768115942029, \"center_y\": 5.797101449275362, \"value_uncond\": 0.014991983011760197}, {\"x\": 4.782608695652174, \"y\": 5.6521739130434785, \"x2\": 5.0724637681159415, \"y2\": 5.942028985507246, \"center_x\": 4.927536231884058, \"center_y\": 5.797101449275362, \"value_uncond\": 0.014687229238863838}, {\"x\": 5.072463768115943, \"y\": 5.6521739130434785, \"x2\": 5.362318840579711, \"y2\": 5.942028985507246, \"center_x\": 5.217391304347827, \"center_y\": 5.797101449275362, \"value_uncond\": 0.014254975654723591}, {\"x\": 5.362318840579711, \"y\": 5.6521739130434785, \"x2\": 5.6521739130434785, \"y2\": 5.942028985507246, \"center_x\": 5.507246376811595, \"center_y\": 5.797101449275362, \"value_uncond\": 0.013706889163690632}, {\"x\": 5.6521739130434785, \"y\": 5.6521739130434785, \"x2\": 5.942028985507246, \"y2\": 5.942028985507246, \"center_x\": 5.797101449275362, \"center_y\": 5.797101449275362, \"value_uncond\": 0.013057412872283585}, {\"x\": 5.942028985507246, \"y\": 5.6521739130434785, \"x2\": 6.231884057971014, \"y2\": 5.942028985507246, \"center_x\": 6.08695652173913, \"center_y\": 5.797101449275362, \"value_uncond\": 0.012323134448469086}, {\"x\": 6.2318840579710155, \"y\": 5.6521739130434785, \"x2\": 6.521739130434783, \"y2\": 5.942028985507246, \"center_x\": 6.376811594202899, \"center_y\": 5.797101449275362, \"value_uncond\": 0.011522084382001349}, {\"x\": 6.521739130434785, \"y\": 5.6521739130434785, \"x2\": 6.8115942028985526, \"y2\": 5.942028985507246, \"center_x\": 6.666666666666669, \"center_y\": 5.797101449275362, \"value_uncond\": 0.010673005437644672}, {\"x\": 6.811594202898551, \"y\": 5.6521739130434785, \"x2\": 7.101449275362318, \"y2\": 5.942028985507246, \"center_x\": 6.956521739130435, \"center_y\": 5.797101449275362, \"value_uncond\": 0.009794634276985995}, {\"x\": 7.10144927536232, \"y\": 5.6521739130434785, \"x2\": 7.391304347826088, \"y2\": 5.942028985507246, \"center_x\": 7.246376811594204, \"center_y\": 5.797101449275362, \"value_uncond\": 0.00890503299126662}, {\"x\": 7.391304347826086, \"y\": 5.6521739130434785, \"x2\": 7.681159420289854, \"y2\": 5.942028985507246, \"center_x\": 7.53623188405797, \"center_y\": 5.797101449275362, \"value_uncond\": 0.008021002572427181}, {\"x\": 7.681159420289855, \"y\": 5.6521739130434785, \"x2\": 7.971014492753623, \"y2\": 5.942028985507246, \"center_x\": 7.826086956521739, \"center_y\": 5.797101449275362, \"value_uncond\": 0.007157602780014635}, {\"x\": 7.971014492753625, \"y\": 5.6521739130434785, \"x2\": 8.260869565217392, \"y2\": 5.942028985507246, \"center_x\": 8.115942028985508, \"center_y\": 5.797101449275362, \"value_uncond\": 0.006327794183488224}, {\"x\": 8.26086956521739, \"y\": 5.6521739130434785, \"x2\": 8.550724637681158, \"y2\": 5.942028985507246, \"center_x\": 8.405797101449274, \"center_y\": 5.797101449275362, \"value_uncond\": 0.005542209155204808}, {\"x\": 8.55072463768116, \"y\": 5.6521739130434785, \"x2\": 8.840579710144928, \"y2\": 5.942028985507246, \"center_x\": 8.695652173913043, \"center_y\": 5.797101449275362, \"value_uncond\": 0.004809049999432685}, {\"x\": 8.84057971014493, \"y\": 5.6521739130434785, \"x2\": 9.130434782608697, \"y2\": 5.942028985507246, \"center_x\": 8.985507246376812, \"center_y\": 5.797101449275362, \"value_uncond\": 0.004134104858489265}, {\"x\": 9.130434782608695, \"y\": 5.6521739130434785, \"x2\": 9.420289855072463, \"y2\": 5.942028985507246, \"center_x\": 9.275362318840578, \"center_y\": 5.797101449275362, \"value_uncond\": 0.003520866011599312}, {\"x\": 9.420289855072465, \"y\": 5.6521739130434785, \"x2\": 9.710144927536232, \"y2\": 5.942028985507246, \"center_x\": 9.565217391304348, \"center_y\": 5.797101449275362, \"value_uncond\": 0.002970730962658476}, {\"x\": 9.710144927536234, \"y\": 5.6521739130434785, \"x2\": 10.000000000000002, \"y2\": 5.942028985507246, \"center_x\": 9.855072463768117, \"center_y\": 5.797101449275362, \"value_uncond\": 0.0024832643962434085}, {\"x\": 10.0, \"y\": 5.6521739130434785, \"x2\": 10.289855072463768, \"y2\": 5.942028985507246, \"center_x\": 10.144927536231883, \"center_y\": 5.797101449275362, \"value_uncond\": 0.0020564985877478664}, {\"x\": -10.0, \"y\": 5.942028985507246, \"x2\": -9.710144927536232, \"y2\": 6.231884057971014, \"center_x\": -9.855072463768117, \"center_y\": 6.08695652173913, \"value_uncond\": 2.6766838036410634e-07}, {\"x\": -9.710144927536232, \"y\": 5.942028985507246, \"x2\": -9.420289855072465, \"y2\": 6.231884057971014, \"center_x\": -9.565217391304348, \"center_y\": 6.08695652173913, \"value_uncond\": 4.182029923970312e-07}, {\"x\": -9.420289855072463, \"y\": 5.942028985507246, \"x2\": -9.130434782608695, \"y2\": 6.231884057971014, \"center_x\": -9.275362318840578, \"center_y\": 6.08695652173913, \"value_uncond\": 6.473259472880103e-07}, {\"x\": -9.130434782608695, \"y\": 5.942028985507246, \"x2\": -8.840579710144928, \"y2\": 6.231884057971014, \"center_x\": -8.985507246376812, \"center_y\": 6.08695652173913, \"value_uncond\": 9.926695715642979e-07}, {\"x\": -8.840579710144928, \"y\": 5.942028985507246, \"x2\": -8.55072463768116, \"y2\": 6.231884057971014, \"center_x\": -8.695652173913043, \"center_y\": 6.08695652173913, \"value_uncond\": 1.5081072167683986e-06}, {\"x\": -8.55072463768116, \"y\": 5.942028985507246, \"x2\": -8.260869565217392, \"y2\": 6.231884057971014, \"center_x\": -8.405797101449277, \"center_y\": 6.08695652173913, \"value_uncond\": 2.2698938141044712e-06}, {\"x\": -8.26086956521739, \"y\": 5.942028985507246, \"x2\": -7.971014492753623, \"y2\": 6.231884057971014, \"center_x\": -8.115942028985508, \"center_y\": 6.08695652173913, \"value_uncond\": 3.3847350524198137e-06}, {\"x\": -7.971014492753623, \"y\": 5.942028985507246, \"x2\": -7.681159420289855, \"y2\": 6.231884057971014, \"center_x\": -7.826086956521739, \"center_y\": 6.08695652173913, \"value_uncond\": 5.0002259678435955e-06}, {\"x\": -7.681159420289855, \"y\": 5.942028985507246, \"x2\": -7.391304347826088, \"y2\": 6.231884057971014, \"center_x\": -7.536231884057972, \"center_y\": 6.08695652173913, \"value_uncond\": 7.318134682692684e-06}, {\"x\": -7.391304347826087, \"y\": 5.942028985507246, \"x2\": -7.101449275362319, \"y2\": 6.231884057971014, \"center_x\": -7.246376811594203, \"center_y\": 6.08695652173913, \"value_uncond\": 1.0611016241055063e-05}, {\"x\": -7.101449275362318, \"y\": 5.942028985507246, \"x2\": -6.811594202898551, \"y2\": 6.231884057971014, \"center_x\": -6.956521739130435, \"center_y\": 6.08695652173913, \"value_uncond\": 1.524261130753217e-05}, {\"x\": -6.811594202898551, \"y\": 5.942028985507246, \"x2\": -6.521739130434783, \"y2\": 6.231884057971014, \"center_x\": -6.666666666666667, \"center_y\": 6.08695652173913, \"value_uncond\": 2.1692399070934804e-05}, {\"x\": -6.521739130434782, \"y\": 5.942028985507246, \"x2\": -6.231884057971015, \"y2\": 6.231884057971014, \"center_x\": -6.3768115942028984, \"center_y\": 6.08695652173913, \"value_uncond\": 3.0584515873802894e-05}, {\"x\": -6.231884057971014, \"y\": 5.942028985507246, \"x2\": -5.942028985507246, \"y2\": 6.231884057971014, \"center_x\": -6.08695652173913, \"center_y\": 6.08695652173913, \"value_uncond\": 4.272100392204194e-05}, {\"x\": -5.942028985507246, \"y\": 5.942028985507246, \"x2\": -5.6521739130434785, \"y2\": 6.231884057971014, \"center_x\": -5.797101449275362, \"center_y\": 6.08695652173913, \"value_uncond\": 5.911900333454195e-05}, {\"x\": -5.6521739130434785, \"y\": 5.942028985507246, \"x2\": -5.362318840579711, \"y2\": 6.231884057971014, \"center_x\": -5.507246376811595, \"center_y\": 6.08695652173913, \"value_uncond\": 8.105103636811636e-05}, {\"x\": -5.36231884057971, \"y\": 5.942028985507246, \"x2\": -5.072463768115942, \"y2\": 6.231884057971014, \"center_x\": -5.217391304347826, \"center_y\": 6.08695652173913, \"value_uncond\": 0.00011008695401838697}, {\"x\": -5.0724637681159415, \"y\": 5.942028985507246, \"x2\": -4.782608695652174, \"y2\": 6.231884057971014, \"center_x\": -4.927536231884058, \"center_y\": 6.08695652173913, \"value_uncond\": 0.0001481354336143672}, {\"x\": -4.782608695652174, \"y\": 5.942028985507246, \"x2\": -4.492753623188406, \"y2\": 6.231884057971014, \"center_x\": -4.63768115942029, \"center_y\": 6.08695652173913, \"value_uncond\": 0.00019748215839588857}, {\"x\": -4.492753623188405, \"y\": 5.942028985507246, \"x2\": -4.202898550724638, \"y2\": 6.231884057971014, \"center_x\": -4.3478260869565215, \"center_y\": 6.08695652173913, \"value_uncond\": 0.00026082102176564175}, {\"x\": -4.202898550724638, \"y\": 5.942028985507246, \"x2\": -3.91304347826087, \"y2\": 6.231884057971014, \"center_x\": -4.057971014492754, \"center_y\": 6.08695652173913, \"value_uncond\": 0.0003412739453083699}, {\"x\": -3.913043478260869, \"y\": 5.942028985507246, \"x2\": -3.6231884057971016, \"y2\": 6.231884057971014, \"center_x\": -3.7681159420289854, \"center_y\": 6.08695652173913, \"value_uncond\": 0.00044239426561870794}, {\"x\": -3.6231884057971016, \"y\": 5.942028985507246, \"x2\": -3.333333333333334, \"y2\": 6.231884057971014, \"center_x\": -3.4782608695652177, \"center_y\": 6.08695652173913, \"value_uncond\": 0.0005681482316218242}, {\"x\": -3.333333333333333, \"y\": 5.942028985507246, \"x2\": -3.0434782608695654, \"y2\": 6.231884057971014, \"center_x\": -3.1884057971014492, \"center_y\": 6.08695652173913, \"value_uncond\": 0.0007228690724893748}, {\"x\": -3.0434782608695645, \"y\": 5.942028985507246, \"x2\": -2.753623188405797, \"y2\": 6.231884057971014, \"center_x\": -2.8985507246376807, \"center_y\": 6.08695652173913, \"value_uncond\": 0.0009111784577478195}, {\"x\": -2.753623188405797, \"y\": 5.942028985507246, \"x2\": -2.4637681159420293, \"y2\": 6.231884057971014, \"center_x\": -2.608695652173913, \"center_y\": 6.08695652173913, \"value_uncond\": 0.0011378710744363743}, {\"x\": -2.4637681159420284, \"y\": 5.942028985507246, \"x2\": -2.1739130434782608, \"y2\": 6.231884057971014, \"center_x\": -2.3188405797101446, \"center_y\": 6.08695652173913, \"value_uncond\": 0.0014077595621190266}, {\"x\": -2.1739130434782608, \"y\": 5.942028985507246, \"x2\": -1.8840579710144931, \"y2\": 6.231884057971014, \"center_x\": -2.028985507246377, \"center_y\": 6.08695652173913, \"value_uncond\": 0.0017254792022204579}, {\"x\": -1.8840579710144922, \"y\": 5.942028985507246, \"x2\": -1.5942028985507246, \"y2\": 6.231884057971014, \"center_x\": -1.7391304347826084, \"center_y\": 6.08695652173913, \"value_uncond\": 0.0020952545214967607}, {\"x\": -1.5942028985507246, \"y\": 5.942028985507246, \"x2\": -1.304347826086957, \"y2\": 6.231884057971014, \"center_x\": -1.4492753623188408, \"center_y\": 6.08695652173913, \"value_uncond\": 0.002520633237406963}, {\"x\": -1.304347826086957, \"y\": 5.942028985507246, \"x2\": -1.0144927536231894, \"y2\": 6.231884057971014, \"center_x\": -1.1594202898550732, \"center_y\": 6.08695652173913, \"value_uncond\": 0.003004196565387202}, {\"x\": -1.0144927536231876, \"y\": 5.942028985507246, \"x2\": -0.72463768115942, \"y2\": 6.231884057971014, \"center_x\": -0.8695652173913038, \"center_y\": 6.08695652173913, \"value_uncond\": 0.003547258568643672}, {\"x\": -0.72463768115942, \"y\": 5.942028985507246, \"x2\": -0.43478260869565233, \"y2\": 6.231884057971014, \"center_x\": -0.5797101449275361, \"center_y\": 6.08695652173913, \"value_uncond\": 0.004149570639951542}, {\"x\": -0.43478260869565233, \"y\": 5.942028985507246, \"x2\": -0.1449275362318847, \"y2\": 6.231884057971014, \"center_x\": -0.2898550724637685, \"center_y\": 6.08695652173913, \"value_uncond\": 0.004809049999432688}, {\"x\": -0.14492753623188293, \"y\": 5.942028985507246, \"x2\": 0.1449275362318847, \"y2\": 6.231884057971014, \"center_x\": 8.881784197001252e-16, \"center_y\": 6.08695652173913, \"value_uncond\": 0.005521552898678568}, {\"x\": 0.1449275362318847, \"y\": 5.942028985507246, \"x2\": 0.43478260869565233, \"y2\": 6.231884057971014, \"center_x\": 0.2898550724637685, \"center_y\": 6.08695652173913, \"value_uncond\": 0.006280713694225636}, {\"x\": 0.43478260869565233, \"y\": 5.942028985507246, \"x2\": 0.72463768115942, \"y2\": 6.231884057971014, \"center_x\": 0.5797101449275361, \"center_y\": 6.08695652173913, \"value_uncond\": 0.00707786981783574}, {\"x\": 0.72463768115942, \"y\": 5.942028985507246, \"x2\": 1.0144927536231876, \"y2\": 6.231884057971014, \"center_x\": 0.8695652173913038, \"center_y\": 6.08695652173913, \"value_uncond\": 0.007902089766449183}, {\"x\": 1.0144927536231894, \"y\": 5.942028985507246, \"x2\": 1.304347826086957, \"y2\": 6.231884057971014, \"center_x\": 1.1594202898550732, \"center_y\": 6.08695652173913, \"value_uncond\": 0.008740316549850866}, {\"x\": 1.304347826086957, \"y\": 5.942028985507246, \"x2\": 1.5942028985507246, \"y2\": 6.231884057971014, \"center_x\": 1.4492753623188408, \"center_y\": 6.08695652173913, \"value_uncond\": 0.009577632731404702}, {\"x\": 1.5942028985507246, \"y\": 5.942028985507246, \"x2\": 1.8840579710144922, \"y2\": 6.231884057971014, \"center_x\": 1.7391304347826084, \"center_y\": 6.08695652173913, \"value_uncond\": 0.010397645619704042}, {\"x\": 1.884057971014494, \"y\": 5.942028985507246, \"x2\": 2.1739130434782616, \"y2\": 6.231884057971014, \"center_x\": 2.028985507246378, \"center_y\": 6.08695652173913, \"value_uncond\": 0.011182982827182043}, {\"x\": 2.1739130434782616, \"y\": 5.942028985507246, \"x2\": 2.4637681159420293, \"y2\": 6.231884057971014, \"center_x\": 2.3188405797101455, \"center_y\": 6.08695652173913, \"value_uncond\": 0.011915879949294914}, {\"x\": 2.4637681159420293, \"y\": 5.942028985507246, \"x2\": 2.753623188405797, \"y2\": 6.231884057971014, \"center_x\": 2.608695652173913, \"center_y\": 6.08695652173913, \"value_uncond\": 0.012578834257875109}, {\"x\": 2.753623188405797, \"y\": 5.942028985507246, \"x2\": 3.0434782608695645, \"y2\": 6.231884057971014, \"center_x\": 2.8985507246376807, \"center_y\": 6.08695652173913, \"value_uncond\": 0.013155291778481145}, {\"x\": 3.0434782608695663, \"y\": 5.942028985507246, \"x2\": 3.333333333333334, \"y2\": 6.231884057971014, \"center_x\": 3.18840579710145, \"center_y\": 6.08695652173913, \"value_uncond\": 0.013630330602330078}, {\"x\": 3.333333333333334, \"y\": 5.942028985507246, \"x2\": 3.6231884057971016, \"y2\": 6.231884057971014, \"center_x\": 3.4782608695652177, \"center_y\": 6.08695652173913, \"value_uncond\": 0.01399130129612019}, {\"x\": 3.6231884057971016, \"y\": 5.942028985507246, \"x2\": 3.913043478260869, \"y2\": 6.231884057971014, \"center_x\": 3.7681159420289854, \"center_y\": 6.08695652173913, \"value_uncond\": 0.014228386139430086}, {\"x\": 3.913043478260871, \"y\": 5.942028985507246, \"x2\": 4.202898550724639, \"y2\": 6.231884057971014, \"center_x\": 4.057971014492755, \"center_y\": 6.08695652173913, \"value_uncond\": 0.014335042709602576}, {\"x\": 4.202898550724639, \"y\": 5.942028985507246, \"x2\": 4.492753623188406, \"y2\": 6.231884057971014, \"center_x\": 4.347826086956522, \"center_y\": 6.08695652173913, \"value_uncond\": 0.014308303846864935}, {\"x\": 4.492753623188406, \"y\": 5.942028985507246, \"x2\": 4.782608695652174, \"y2\": 6.231884057971014, \"center_x\": 4.63768115942029, \"center_y\": 6.08695652173913, \"value_uncond\": 0.014148914804956699}, {\"x\": 4.782608695652174, \"y\": 5.942028985507246, \"x2\": 5.0724637681159415, \"y2\": 6.231884057971014, \"center_x\": 4.927536231884058, \"center_y\": 6.08695652173913, \"value_uncond\": 0.013861298739369025}, {\"x\": 5.072463768115943, \"y\": 5.942028985507246, \"x2\": 5.362318840579711, \"y2\": 6.231884057971014, \"center_x\": 5.217391304347827, \"center_y\": 6.08695652173913, \"value_uncond\": 0.013453352763753925}, {\"x\": 5.362318840579711, \"y\": 5.942028985507246, \"x2\": 5.6521739130434785, \"y2\": 6.231884057971014, \"center_x\": 5.507246376811595, \"center_y\": 6.08695652173913, \"value_uncond\": 0.01293608769873285}, {\"x\": 5.6521739130434785, \"y\": 5.942028985507246, \"x2\": 5.942028985507246, \"y2\": 6.231884057971014, \"center_x\": 5.797101449275362, \"center_y\": 6.08695652173913, \"value_uncond\": 0.012323134448469086}, {\"x\": 5.942028985507246, \"y\": 5.942028985507246, \"x2\": 6.231884057971014, \"y2\": 6.231884057971014, \"center_x\": 6.08695652173913, \"center_y\": 6.08695652173913, \"value_uncond\": 0.01163014788001316}, {\"x\": 6.2318840579710155, \"y\": 5.942028985507246, \"x2\": 6.521739130434783, \"y2\": 6.231884057971014, \"center_x\": 6.376811594202899, \"center_y\": 6.08695652173913, \"value_uncond\": 0.010874144545693331}, {\"x\": 6.521739130434785, \"y\": 5.942028985507246, \"x2\": 6.8115942028985526, \"y2\": 6.231884057971014, \"center_x\": 6.666666666666669, \"center_y\": 6.08695652173913, \"value_uncond\": 0.010072813218345815}, {\"x\": 6.811594202898551, \"y\": 5.942028985507246, \"x2\": 7.101449275362318, \"y2\": 6.231884057971014, \"center_x\": 6.956521739130435, \"center_y\": 6.08695652173913, \"value_uncond\": 0.009243836910839224}, {\"x\": 7.10144927536232, \"y\": 5.942028985507246, \"x2\": 7.391304347826088, \"y2\": 6.231884057971014, \"center_x\": 7.246376811594204, \"center_y\": 6.08695652173913, \"value_uncond\": 0.008404261999891829}, {\"x\": 7.391304347826086, \"y\": 5.942028985507246, \"x2\": 7.681159420289854, \"y2\": 6.231884057971014, \"center_x\": 7.53623188405797, \"center_y\": 6.08695652173913, \"value_uncond\": 0.007569944680339263}, {\"x\": 7.681159420289855, \"y\": 5.942028985507246, \"x2\": 7.971014492753623, \"y2\": 6.231884057971014, \"center_x\": 7.826086956521739, \"center_y\": 6.08695652173913, \"value_uncond\": 0.00675509783213515}, {\"x\": 7.971014492753625, \"y\": 5.942028985507246, \"x2\": 8.260869565217392, \"y2\": 6.231884057971014, \"center_x\": 8.115942028985508, \"center_y\": 6.08695652173913, \"value_uncond\": 0.005971953192265764}, {\"x\": 8.26086956521739, \"y\": 5.942028985507246, \"x2\": 8.550724637681158, \"y2\": 6.231884057971014, \"center_x\": 8.405797101449274, \"center_y\": 6.08695652173913, \"value_uncond\": 0.00523054522585382}, {\"x\": 8.55072463768116, \"y\": 5.942028985507246, \"x2\": 8.840579710144928, \"y2\": 6.231884057971014, \"center_x\": 8.695652173913043, \"center_y\": 6.08695652173913, \"value_uncond\": 0.004538614983846707}, {\"x\": 8.84057971014493, \"y\": 5.942028985507246, \"x2\": 9.130434782608697, \"y2\": 6.231884057971014, \"center_x\": 8.985507246376812, \"center_y\": 6.08695652173913, \"value_uncond\": 0.003901625114678845}, {\"x\": 9.130434782608695, \"y\": 5.942028985507246, \"x2\": 9.420289855072463, \"y2\": 6.231884057971014, \"center_x\": 9.275362318840578, \"center_y\": 6.08695652173913, \"value_uncond\": 0.003322871510640635}, {\"x\": 9.420289855072465, \"y\": 5.942028985507246, \"x2\": 9.710144927536232, \"y2\": 6.231884057971014, \"center_x\": 9.565217391304348, \"center_y\": 6.08695652173913, \"value_uncond\": 0.0028036730875515285}, {\"x\": 9.710144927536234, \"y\": 5.942028985507246, \"x2\": 10.000000000000002, \"y2\": 6.231884057971014, \"center_x\": 9.855072463768117, \"center_y\": 6.08695652173913, \"value_uncond\": 0.002343619009778012}, {\"x\": 10.0, \"y\": 5.942028985507246, \"x2\": 10.289855072463768, \"y2\": 6.231884057971014, \"center_x\": 10.144927536231883, \"center_y\": 6.08695652173913, \"value_uncond\": 0.0019408522069250963}, {\"x\": -10.0, \"y\": 6.2318840579710155, \"x2\": -9.710144927536232, \"y2\": 6.521739130434783, \"center_x\": -9.855072463768117, \"center_y\": 6.376811594202899, \"value_uncond\": 2.502689293738903e-07}, {\"x\": -9.710144927536232, \"y\": 6.2318840579710155, \"x2\": -9.420289855072465, \"y2\": 6.521739130434783, \"center_x\": -9.565217391304348, \"center_y\": 6.376811594202899, \"value_uncond\": 3.9101822570820645e-07}, {\"x\": -9.420289855072463, \"y\": 6.2318840579710155, \"x2\": -9.130434782608695, \"y2\": 6.521739130434783, \"center_x\": -9.275362318840578, \"center_y\": 6.376811594202899, \"value_uncond\": 6.052473271715371e-07}, {\"x\": -9.130434782608695, \"y\": 6.2318840579710155, \"x2\": -8.840579710144928, \"y2\": 6.521739130434783, \"center_x\": -8.985507246376812, \"center_y\": 6.376811594202899, \"value_uncond\": 9.281423175927344e-07}, {\"x\": -8.840579710144928, \"y\": 6.2318840579710155, \"x2\": -8.55072463768116, \"y2\": 6.521739130434783, \"center_x\": -8.695652173913043, \"center_y\": 6.376811594202899, \"value_uncond\": 1.4100745781337623e-06}, {\"x\": -8.55072463768116, \"y\": 6.2318840579710155, \"x2\": -8.260869565217392, \"y2\": 6.521739130434783, \"center_x\": -8.405797101449277, \"center_y\": 6.376811594202899, \"value_uncond\": 2.1223421827994186e-06}, {\"x\": -8.26086956521739, \"y\": 6.2318840579710155, \"x2\": -7.971014492753623, \"y2\": 6.521739130434783, \"center_x\": -8.115942028985508, \"center_y\": 6.376811594202899, \"value_uncond\": 3.1647145495149364e-06}, {\"x\": -7.971014492753623, \"y\": 6.2318840579710155, \"x2\": -7.681159420289855, \"y2\": 6.521739130434783, \"center_x\": -7.826086956521739, \"center_y\": 6.376811594202899, \"value_uncond\": 4.675192482195596e-06}, {\"x\": -7.681159420289855, \"y\": 6.2318840579710155, \"x2\": -7.391304347826088, \"y2\": 6.521739130434783, \"center_x\": -7.536231884057972, \"center_y\": 6.376811594202899, \"value_uncond\": 6.842428416685089e-06}, {\"x\": -7.391304347826087, \"y\": 6.2318840579710155, \"x2\": -7.101449275362319, \"y2\": 6.521739130434783, \"center_x\": -7.246376811594203, \"center_y\": 6.376811594202899, \"value_uncond\": 9.921260294568306e-06}, {\"x\": -7.101449275362318, \"y\": 6.2318840579710155, \"x2\": -6.811594202898551, \"y2\": 6.521739130434783, \"center_x\": -6.956521739130435, \"center_y\": 6.376811594202899, \"value_uncond\": 1.4251784269809043e-05}, {\"x\": -6.811594202898551, \"y\": 6.2318840579710155, \"x2\": -6.521739130434783, \"y2\": 6.521739130434783, \"center_x\": -6.666666666666667, \"center_y\": 6.376811594202899, \"value_uncond\": 2.0282311581402006e-05}, {\"x\": -6.521739130434782, \"y\": 6.2318840579710155, \"x2\": -6.231884057971015, \"y2\": 6.521739130434783, \"center_x\": -6.3768115942028984, \"center_y\": 6.376811594202899, \"value_uncond\": 2.8596407363257766e-05}, {\"x\": -6.231884057971014, \"y\": 6.2318840579710155, \"x2\": -5.942028985507246, \"y2\": 6.521739130434783, \"center_x\": -6.08695652173913, \"center_y\": 6.376811594202899, \"value_uncond\": 3.9943978062718354e-05}, {\"x\": -5.942028985507246, \"y\": 6.2318840579710155, \"x2\": -5.6521739130434785, \"y2\": 6.521739130434783, \"center_x\": -5.797101449275362, \"center_y\": 6.376811594202899, \"value_uncond\": 5.5276045867132e-05}, {\"x\": -5.6521739130434785, \"y\": 6.2318840579710155, \"x2\": -5.362318840579711, \"y2\": 6.521739130434783, \"center_x\": -5.507246376811595, \"center_y\": 6.376811594202899, \"value_uncond\": 7.578241430272746e-05}, {\"x\": -5.36231884057971, \"y\": 6.2318840579710155, \"x2\": -5.072463768115942, \"y2\": 6.521739130434783, \"center_x\": -5.217391304347826, \"center_y\": 6.376811594202899, \"value_uncond\": 0.00010293088814874822}, {\"x\": -5.0724637681159415, \"y\": 6.2318840579710155, \"x2\": -4.782608695652174, \"y2\": 6.521739130434783, \"center_x\": -4.927536231884058, \"center_y\": 6.376811594202899, \"value_uncond\": 0.00013850607353238278}, {\"x\": -4.782608695652174, \"y\": 6.2318840579710155, \"x2\": -4.492753623188406, \"y2\": 6.521739130434783, \"center_x\": -4.63768115942029, \"center_y\": 6.376811594202899, \"value_uncond\": 0.00018464507569012695}, {\"x\": -4.492753623188405, \"y\": 6.2318840579710155, \"x2\": -4.202898550724638, \"y2\": 6.521739130434783, \"center_x\": -4.3478260869565215, \"center_y\": 6.376811594202899, \"value_uncond\": 0.00024386667482613364}, {\"x\": -4.202898550724638, \"y\": 6.2318840579710155, \"x2\": -3.91304347826087, \"y2\": 6.521739130434783, \"center_x\": -4.057971014492754, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0003190898558856549}, {\"x\": -3.913043478260869, \"y\": 6.2318840579710155, \"x2\": -3.6231884057971016, \"y2\": 6.521739130434783, \"center_x\": -3.7681159420289854, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0004136369752263406}, {\"x\": -3.6231884057971016, \"y\": 6.2318840579710155, \"x2\": -3.333333333333334, \"y2\": 6.521739130434783, \"center_x\": -3.4782608695652177, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0005312164606825947}, {\"x\": -3.333333333333333, \"y\": 6.2318840579710155, \"x2\": -3.0434782608695654, \"y2\": 6.521739130434783, \"center_x\": -3.1884057971014492, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0006758798652396703}, {\"x\": -3.0434782608695645, \"y\": 6.2318840579710155, \"x2\": -2.753623188405797, \"y2\": 6.521739130434783, \"center_x\": -2.8985507246376807, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0008519484325302061}, {\"x\": -2.753623188405797, \"y\": 6.2318840579710155, \"x2\": -2.4637681159420293, \"y2\": 6.521739130434783, \"center_x\": -2.608695652173913, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0010639051769108295}, {\"x\": -2.4637681159420284, \"y\": 6.2318840579710155, \"x2\": -2.1739130434782608, \"y2\": 6.521739130434783, \"center_x\": -2.3188405797101446, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0013162498982813384}, {\"x\": -2.1739130434782608, \"y\": 6.2318840579710155, \"x2\": -1.8840579710144931, \"y2\": 6.521739130434783, \"center_x\": -2.028985507246377, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0016133165673480364}, {\"x\": -1.8840579710144922, \"y\": 6.2318840579710155, \"x2\": -1.5942028985507246, \"y2\": 6.521739130434783, \"center_x\": -1.7391304347826084, \"center_y\": 6.376811594202899, \"value_uncond\": 0.001959055100746278}, {\"x\": -1.5942028985507246, \"y\": 6.2318840579710155, \"x2\": -1.304347826086957, \"y2\": 6.521739130434783, \"center_x\": -1.4492753623188408, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0023567826009630436}, {\"x\": -1.304347826086957, \"y\": 6.2318840579710155, \"x2\": -1.0144927536231894, \"y2\": 6.521739130434783, \"center_x\": -1.1594202898550732, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0028089124947273613}, {\"x\": -1.0144927536231876, \"y\": 6.2318840579710155, \"x2\": -0.72463768115942, \"y2\": 6.521739130434783, \"center_x\": -0.8695652173913038, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0033166734261969566}, {\"x\": -0.72463768115942, \"y\": 6.2318840579710155, \"x2\": -0.43478260869565233, \"y2\": 6.521739130434783, \"center_x\": -0.5797101449275361, \"center_y\": 6.376811594202899, \"value_uncond\": 0.003879832948551227}, {\"x\": -0.43478260869565233, \"y\": 6.2318840579710155, \"x2\": -0.1449275362318847, \"y2\": 6.521739130434783, \"center_x\": -0.2898550724637685, \"center_y\": 6.376811594202899, \"value_uncond\": 0.004496443670434078}, {\"x\": -0.14492753623188293, \"y\": 6.2318840579710155, \"x2\": 0.1449275362318847, \"y2\": 6.521739130434783, \"center_x\": 8.881784197001252e-16, \"center_y\": 6.376811594202899, \"value_uncond\": 0.005162631202661442}, {\"x\": 0.1449275362318847, \"y\": 6.2318840579710155, \"x2\": 0.43478260869565233, \"y2\": 6.521739130434783, \"center_x\": 0.2898550724637685, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0058724436925257605}, {\"x\": 0.43478260869565233, \"y\": 6.2318840579710155, \"x2\": 0.72463768115942, \"y2\": 6.521739130434783, \"center_x\": 0.5797101449275361, \"center_y\": 6.376811594202899, \"value_uncond\": 0.006617781671290226}, {\"x\": 0.72463768115942, \"y\": 6.2318840579710155, \"x2\": 1.0144927536231876, \"y2\": 6.521739130434783, \"center_x\": 0.8695652173913038, \"center_y\": 6.376811594202899, \"value_uncond\": 0.007388424224689674}, {\"x\": 1.0144927536231894, \"y\": 6.2318840579710155, \"x2\": 1.304347826086957, \"y2\": 6.521739130434783, \"center_x\": 1.1594202898550732, \"center_y\": 6.376811594202899, \"value_uncond\": 0.008172163115959143}, {\"x\": 1.304347826086957, \"y\": 6.2318840579710155, \"x2\": 1.5942028985507246, \"y2\": 6.521739130434783, \"center_x\": 1.4492753623188408, \"center_y\": 6.376811594202899, \"value_uncond\": 0.008955050597924173}, {\"x\": 1.5942028985507246, \"y\": 6.2318840579710155, \"x2\": 1.8840579710144922, \"y2\": 6.521739130434783, \"center_x\": 1.7391304347826084, \"center_y\": 6.376811594202899, \"value_uncond\": 0.00972175956574586}, {\"x\": 1.884057971014494, \"y\": 6.2318840579710155, \"x2\": 2.1739130434782616, \"y2\": 6.521739130434783, \"center_x\": 2.028985507246378, \"center_y\": 6.376811594202899, \"value_uncond\": 0.010456046902358579}, {\"x\": 2.1739130434782616, \"y\": 6.2318840579710155, \"x2\": 2.4637681159420293, \"y2\": 6.521739130434783, \"center_x\": 2.3188405797101455, \"center_y\": 6.376811594202899, \"value_uncond\": 0.011141302956296993}, {\"x\": 2.4637681159420293, \"y\": 6.2318840579710155, \"x2\": 2.753623188405797, \"y2\": 6.521739130434783, \"center_x\": 2.608695652173913, \"center_y\": 6.376811594202899, \"value_uncond\": 0.011761162742523812}, {\"x\": 2.753623188405797, \"y\": 6.2318840579710155, \"x2\": 3.0434782608695645, \"y2\": 6.521739130434783, \"center_x\": 2.8985507246376807, \"center_y\": 6.376811594202899, \"value_uncond\": 0.012300148357168889}, {\"x\": 3.0434782608695663, \"y\": 6.2318840579710155, \"x2\": 3.333333333333334, \"y2\": 6.521739130434783, \"center_x\": 3.18840579710145, \"center_y\": 6.376811594202899, \"value_uncond\": 0.012744307871617264}, {\"x\": 3.333333333333334, \"y\": 6.2318840579710155, \"x2\": 3.6231884057971016, \"y2\": 6.521739130434783, \"center_x\": 3.4782608695652177, \"center_y\": 6.376811594202899, \"value_uncond\": 0.01308181411328583}, {\"x\": 3.6231884057971016, \"y\": 6.2318840579710155, \"x2\": 3.913043478260869, \"y2\": 6.521739130434783, \"center_x\": 3.7681159420289854, \"center_y\": 6.376811594202899, \"value_uncond\": 0.013303487550489101}, {\"x\": 3.913043478260871, \"y\": 6.2318840579710155, \"x2\": 4.202898550724639, \"y2\": 6.521739130434783, \"center_x\": 4.057971014492755, \"center_y\": 6.376811594202899, \"value_uncond\": 0.013403211042638046}, {\"x\": 4.202898550724639, \"y\": 6.2318840579710155, \"x2\": 4.492753623188406, \"y2\": 6.521739130434783, \"center_x\": 4.347826086956522, \"center_y\": 6.376811594202899, \"value_uncond\": 0.013378210306499836}, {\"x\": 4.492753623188406, \"y\": 6.2318840579710155, \"x2\": 4.782608695652174, \"y2\": 6.521739130434783, \"center_x\": 4.63768115942029, \"center_y\": 6.376811594202899, \"value_uncond\": 0.01322918215151925}, {\"x\": 4.782608695652174, \"y\": 6.2318840579710155, \"x2\": 5.0724637681159415, \"y2\": 6.521739130434783, \"center_x\": 4.927536231884058, \"center_y\": 6.376811594202899, \"value_uncond\": 0.012960262211452207}, {\"x\": 5.072463768115943, \"y\": 6.2318840579710155, \"x2\": 5.362318840579711, \"y2\": 6.521739130434783, \"center_x\": 5.217391304347827, \"center_y\": 6.376811594202899, \"value_uncond\": 0.012578834257875104}, {\"x\": 5.362318840579711, \"y\": 6.2318840579710155, \"x2\": 5.6521739130434785, \"y2\": 6.521739130434783, \"center_x\": 5.507246376811595, \"center_y\": 6.376811594202899, \"value_uncond\": 0.012095193366675168}, {\"x\": 5.6521739130434785, \"y\": 6.2318840579710155, \"x2\": 5.942028985507246, \"y2\": 6.521739130434783, \"center_x\": 5.797101449275362, \"center_y\": 6.376811594202899, \"value_uncond\": 0.011522084382001349}, {\"x\": 5.942028985507246, \"y\": 6.2318840579710155, \"x2\": 6.231884057971014, \"y2\": 6.521739130434783, \"center_x\": 6.08695652173913, \"center_y\": 6.376811594202899, \"value_uncond\": 0.010874144545693331}, {\"x\": 6.2318840579710155, \"y\": 6.2318840579710155, \"x2\": 6.521739130434783, \"y2\": 6.521739130434783, \"center_x\": 6.376811594202899, \"center_y\": 6.376811594202899, \"value_uncond\": 0.010167284270206396}, {\"x\": 6.521739130434785, \"y\": 6.2318840579710155, \"x2\": 6.8115942028985526, \"y2\": 6.521739130434783, \"center_x\": 6.666666666666669, \"center_y\": 6.376811594202899, \"value_uncond\": 0.009418042491643618}, {\"x\": 6.811594202898551, \"y\": 6.2318840579710155, \"x2\": 7.101449275362318, \"y2\": 6.521739130434783, \"center_x\": 6.956521739130435, \"center_y\": 6.376811594202899, \"value_uncond\": 0.008642952760560024}, {\"x\": 7.10144927536232, \"y\": 6.2318840579710155, \"x2\": 7.391304347826088, \"y2\": 6.521739130434783, \"center_x\": 7.246376811594204, \"center_y\": 6.376811594202899, \"value_uncond\": 0.007857953375103437}, {\"x\": 7.391304347826086, \"y\": 6.2318840579710155, \"x2\": 7.681159420289854, \"y2\": 6.521739130434783, \"center_x\": 7.53623188405797, \"center_y\": 6.376811594202899, \"value_uncond\": 0.00707786981783574}, {\"x\": 7.681159420289855, \"y\": 6.2318840579710155, \"x2\": 7.971014492753623, \"y2\": 6.521739130434783, \"center_x\": 7.826086956521739, \"center_y\": 6.376811594202899, \"value_uncond\": 0.00631599107808199}, {\"x\": 7.971014492753625, \"y\": 6.2318840579710155, \"x2\": 8.260869565217392, \"y2\": 6.521739130434783, \"center_x\": 8.115942028985508, \"center_y\": 6.376811594202899, \"value_uncond\": 0.005583753783940637}, {\"x\": 8.26086956521739, \"y\": 6.2318840579710155, \"x2\": 8.550724637681158, \"y2\": 6.521739130434783, \"center_x\": 8.405797101449274, \"center_y\": 6.376811594202899, \"value_uncond\": 0.004890540122578068}, {\"x\": 8.55072463768116, \"y\": 6.2318840579710155, \"x2\": 8.840579710144928, \"y2\": 6.521739130434783, \"center_x\": 8.695652173913043, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0042435879475285635}, {\"x\": 8.84057971014493, \"y\": 6.2318840579710155, \"x2\": 9.130434782608697, \"y2\": 6.521739130434783, \"center_x\": 8.985507246376812, \"center_y\": 6.376811594202899, \"value_uncond\": 0.003648004814542142}, {\"x\": 9.130434782608695, \"y\": 6.2318840579710155, \"x2\": 9.420289855072463, \"y2\": 6.521739130434783, \"center_x\": 9.275362318840578, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0031068723705198263}, {\"x\": 9.420289855072465, \"y\": 6.2318840579710155, \"x2\": 9.710144927536232, \"y2\": 6.521739130434783, \"center_x\": 9.565217391304348, \"center_y\": 6.376811594202899, \"value_uncond\": 0.002621423796794503}, {\"x\": 9.710144927536234, \"y\": 6.2318840579710155, \"x2\": 10.000000000000002, \"y2\": 6.521739130434783, \"center_x\": 9.855072463768117, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0021912749635933215}, {\"x\": 10.0, \"y\": 6.2318840579710155, \"x2\": 10.289855072463768, \"y2\": 6.521739130434783, \"center_x\": 10.144927536231883, \"center_y\": 6.376811594202899, \"value_uncond\": 0.0018146895170783953}, {\"x\": -10.0, \"y\": 6.521739130434785, \"x2\": -9.710144927536232, \"y2\": 6.8115942028985526, \"center_x\": -9.855072463768117, \"center_y\": 6.666666666666669, \"value_uncond\": 2.318262525705508e-07}, {\"x\": -9.710144927536232, \"y\": 6.521739130434785, \"x2\": -9.420289855072465, \"y2\": 6.8115942028985526, \"center_x\": -9.565217391304348, \"center_y\": 6.666666666666669, \"value_uncond\": 3.6220353113548075e-07}, {\"x\": -9.420289855072463, \"y\": 6.521739130434785, \"x2\": -9.130434782608695, \"y2\": 6.8115942028985526, \"center_x\": -9.275362318840578, \"center_y\": 6.666666666666669, \"value_uncond\": 5.606457824690636e-07}, {\"x\": -9.130434782608695, \"y\": 6.521739130434785, \"x2\": -8.840579710144928, \"y2\": 6.8115942028985526, \"center_x\": -8.985507246376812, \"center_y\": 6.666666666666669, \"value_uncond\": 8.59746177353957e-07}, {\"x\": -8.840579710144928, \"y\": 6.521739130434785, \"x2\": -8.55072463768116, \"y2\": 6.8115942028985526, \"center_x\": -8.695652173913043, \"center_y\": 6.666666666666669, \"value_uncond\": 1.3061641575386623e-06}, {\"x\": -8.55072463768116, \"y\": 6.521739130434785, \"x2\": -8.260869565217392, \"y2\": 6.8115942028985526, \"center_x\": -8.405797101449277, \"center_y\": 6.666666666666669, \"value_uncond\": 1.965943739567227e-06}, {\"x\": -8.26086956521739, \"y\": 6.521739130434785, \"x2\": -7.971014492753623, \"y2\": 6.8115942028985526, \"center_x\": -8.115942028985508, \"center_y\": 6.666666666666669, \"value_uncond\": 2.931502189684466e-06}, {\"x\": -7.971014492753623, \"y\": 6.521739130434785, \"x2\": -7.681159420289855, \"y2\": 6.8115942028985526, \"center_x\": -7.826086956521739, \"center_y\": 6.666666666666669, \"value_uncond\": 4.330670834389596e-06}, {\"x\": -7.681159420289855, \"y\": 6.521739130434785, \"x2\": -7.391304347826088, \"y2\": 6.8115942028985526, \"center_x\": -7.536231884057972, \"center_y\": 6.666666666666669, \"value_uncond\": 6.338200040615343e-06}, {\"x\": -7.391304347826087, \"y\": 6.521739130434785, \"x2\": -7.101449275362319, \"y2\": 6.8115942028985526, \"center_x\": -7.246376811594203, \"center_y\": 6.666666666666669, \"value_uncond\": 9.190148376072125e-06}, {\"x\": -7.101449275362318, \"y\": 6.521739130434785, \"x2\": -6.811594202898551, \"y2\": 6.8115942028985526, \"center_x\": -6.956521739130435, \"center_y\": 6.666666666666669, \"value_uncond\": 1.3201549820744305e-05}, {\"x\": -6.811594202898551, \"y\": 6.521739130434785, \"x2\": -6.521739130434783, \"y2\": 6.8115942028985526, \"center_x\": -6.666666666666667, \"center_y\": 6.666666666666669, \"value_uncond\": 1.8787678914629364e-05}, {\"x\": -6.521739130434782, \"y\": 6.521739130434785, \"x2\": -6.231884057971015, \"y2\": 6.8115942028985526, \"center_x\": -6.3768115942028984, \"center_y\": 6.666666666666669, \"value_uncond\": 2.6489097038893434e-05}, {\"x\": -6.231884057971014, \"y\": 6.521739130434785, \"x2\": -5.942028985507246, \"y2\": 6.8115942028985526, \"center_x\": -6.08695652173913, \"center_y\": 6.666666666666669, \"value_uncond\": 3.70004489578735e-05}, {\"x\": -5.942028985507246, \"y\": 6.521739130434785, \"x2\": -5.6521739130434785, \"y2\": 6.8115942028985526, \"center_x\": -5.797101449275362, \"center_y\": 6.666666666666669, \"value_uncond\": 5.12026746682202e-05}, {\"x\": -5.6521739130434785, \"y\": 6.521739130434785, \"x2\": -5.362318840579711, \"y2\": 6.8115942028985526, \"center_x\": -5.507246376811595, \"center_y\": 6.666666666666669, \"value_uncond\": 7.019789936570147e-05}, {\"x\": -5.36231884057971, \"y\": 6.521739130434785, \"x2\": -5.072463768115942, \"y2\": 6.8115942028985526, \"center_x\": -5.217391304347826, \"center_y\": 6.666666666666669, \"value_uncond\": 9.534576318754272e-05}, {\"x\": -5.0724637681159415, \"y\": 6.521739130434785, \"x2\": -4.782608695652174, \"y2\": 6.8115942028985526, \"center_x\": -4.927536231884058, \"center_y\": 6.666666666666669, \"value_uncond\": 0.00012829936207264282}, {\"x\": -4.782608695652174, \"y\": 6.521739130434785, \"x2\": -4.492753623188406, \"y2\": 6.8115942028985526, \"center_x\": -4.63768115942029, \"center_y\": 6.666666666666669, \"value_uncond\": 0.00017103831490363806}, {\"x\": -4.492753623188405, \"y\": 6.521739130434785, \"x2\": -4.202898550724638, \"y2\": 6.8115942028985526, \"center_x\": -4.3478260869565215, \"center_y\": 6.666666666666669, \"value_uncond\": 0.00022589578935435225}, {\"x\": -4.202898550724638, \"y\": 6.521739130434785, \"x2\": -3.91304347826087, \"y2\": 6.8115942028985526, \"center_x\": -4.057971014492754, \"center_y\": 6.666666666666669, \"value_uncond\": 0.00029557566617762447}, {\"x\": -3.913043478260869, \"y\": 6.521739130434785, \"x2\": -3.6231884057971016, \"y2\": 6.8115942028985526, \"center_x\": -3.7681159420289854, \"center_y\": 6.666666666666669, \"value_uncond\": 0.00038315547252005096}, {\"x\": -3.6231884057971016, \"y\": 6.521739130434785, \"x2\": -3.333333333333334, \"y2\": 6.8115942028985526, \"center_x\": -3.4782608695652177, \"center_y\": 6.666666666666669, \"value_uncond\": 0.000492070356843445}, {\"x\": -3.333333333333333, \"y\": 6.521739130434785, \"x2\": -3.0434782608695654, \"y2\": 6.8115942028985526, \"center_x\": -3.1884057971014492, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0006260733073753584}, {\"x\": -3.0434782608695645, \"y\": 6.521739130434785, \"x2\": -2.753623188405797, \"y2\": 6.8115942028985526, \"center_x\": -2.8985507246376807, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0007891671290996348}, {\"x\": -2.753623188405797, \"y\": 6.521739130434785, \"x2\": -2.4637681159420293, \"y2\": 6.8115942028985526, \"center_x\": -2.608695652173913, \"center_y\": 6.666666666666669, \"value_uncond\": 0.000985504476607145}, {\"x\": -2.4637681159420284, \"y\": 6.521739130434785, \"x2\": -2.1739130434782608, \"y2\": 6.8115942028985526, \"center_x\": -2.3188405797101446, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0012192535530811497}, {\"x\": -2.1739130434782608, \"y\": 6.521739130434785, \"x2\": -1.8840579710144931, \"y2\": 6.8115942028985526, \"center_x\": -2.028985507246377, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0014944289527028226}, {\"x\": -1.8840579710144922, \"y\": 6.521739130434785, \"x2\": -1.5942028985507246, \"y2\": 6.8115942028985526, \"center_x\": -1.7391304347826084, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0018146895170783953}, {\"x\": -1.5942028985507246, \"y\": 6.521739130434785, \"x2\": -1.304347826086957, \"y2\": 6.8115942028985526, \"center_x\": -1.4492753623188408, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0021831079066490715}, {\"x\": -1.304347826086957, \"y\": 6.521739130434785, \"x2\": -1.0144927536231894, \"y2\": 6.8115942028985526, \"center_x\": -1.1594202898550732, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0026019196992624204}, {\"x\": -1.0144927536231876, \"y\": 6.521739130434785, \"x2\": -0.72463768115942, \"y2\": 6.8115942028985526, \"center_x\": -0.8695652173913038, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0030722629985238}, {\"x\": -0.72463768115942, \"y\": 6.521739130434785, \"x2\": -0.43478260869565233, \"y2\": 6.8115942028985526, \"center_x\": -0.5797101449275361, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0035939224869526182}, {\"x\": -0.43478260869565233, \"y\": 6.521739130434785, \"x2\": -0.1449275362318847, \"y2\": 6.8115942028985526, \"center_x\": -0.2898550724637685, \"center_y\": 6.666666666666669, \"value_uncond\": 0.004165094279258357}, {\"x\": -0.14492753623188293, \"y\": 6.521739130434785, \"x2\": 0.1449275362318847, \"y2\": 6.8115942028985526, \"center_x\": 8.881784197001252e-16, \"center_y\": 6.666666666666669, \"value_uncond\": 0.004782189495559725}, {\"x\": 0.1449275362318847, \"y\": 6.521739130434785, \"x2\": 0.43478260869565233, \"y2\": 6.8115942028985526, \"center_x\": 0.2898550724637685, \"center_y\": 6.666666666666669, \"value_uncond\": 0.005439694883722319}, {\"x\": 0.43478260869565233, \"y\": 6.521739130434785, \"x2\": 0.72463768115942, \"y2\": 6.8115942028985526, \"center_x\": 0.5797101449275361, \"center_y\": 6.666666666666669, \"value_uncond\": 0.006130107836491764}, {\"x\": 0.72463768115942, \"y\": 6.521739130434785, \"x2\": 1.0144927536231876, \"y2\": 6.8115942028985526, \"center_x\": 0.8695652173913038, \"center_y\": 6.666666666666669, \"value_uncond\": 0.006843960633452795}, {\"x\": 1.0144927536231894, \"y\": 6.521739130434785, \"x2\": 1.304347826086957, \"y2\": 6.8115942028985526, \"center_x\": 1.1594202898550732, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0075699446803392575}, {\"x\": 1.304347826086957, \"y\": 6.521739130434785, \"x2\": 1.5942028985507246, \"y2\": 6.8115942028985526, \"center_x\": 1.4492753623188408, \"center_y\": 6.666666666666669, \"value_uncond\": 0.008295140059495587}, {\"x\": 1.5942028985507246, \"y\": 6.521739130434785, \"x2\": 1.8840579710144922, \"y2\": 6.8115942028985526, \"center_x\": 1.7391304347826084, \"center_y\": 6.666666666666669, \"value_uncond\": 0.009005349142448897}, {\"x\": 1.884057971014494, \"y\": 6.521739130434785, \"x2\": 2.1739130434782616, \"y2\": 6.8115942028985526, \"center_x\": 2.028985507246378, \"center_y\": 6.666666666666669, \"value_uncond\": 0.009685525790755987}, {\"x\": 2.1739130434782616, \"y\": 6.521739130434785, \"x2\": 2.4637681159420293, \"y2\": 6.8115942028985526, \"center_x\": 2.3188405797101455, \"center_y\": 6.666666666666669, \"value_uncond\": 0.01032028434202024}, {\"x\": 2.4637681159420293, \"y\": 6.521739130434785, \"x2\": 2.753623188405797, \"y2\": 6.8115942028985526, \"center_x\": 2.608695652173913, \"center_y\": 6.666666666666669, \"value_uncond\": 0.010894465770452633}, {\"x\": 2.753623188405797, \"y\": 6.521739130434785, \"x2\": 3.0434782608695645, \"y2\": 6.8115942028985526, \"center_x\": 2.8985507246376807, \"center_y\": 6.666666666666669, \"value_uncond\": 0.011393732761146198}, {\"x\": 3.0434782608695663, \"y\": 6.521739130434785, \"x2\": 3.333333333333334, \"y2\": 6.8115942028985526, \"center_x\": 3.18840579710145, \"center_y\": 6.666666666666669, \"value_uncond\": 0.011805161523141232}, {\"x\": 3.333333333333334, \"y\": 6.521739130434785, \"x2\": 3.6231884057971016, \"y2\": 6.8115942028985526, \"center_x\": 3.4782608695652177, \"center_y\": 6.666666666666669, \"value_uncond\": 0.012117796445186641}, {\"x\": 3.6231884057971016, \"y\": 6.521739130434785, \"x2\": 3.913043478260869, \"y2\": 6.8115942028985526, \"center_x\": 3.7681159420289854, \"center_y\": 6.666666666666669, \"value_uncond\": 0.012323134448469077}, {\"x\": 3.913043478260871, \"y\": 6.521739130434785, \"x2\": 4.202898550724639, \"y2\": 6.8115942028985526, \"center_x\": 4.057971014492755, \"center_y\": 6.666666666666669, \"value_uncond\": 0.012415509173274013}, {\"x\": 4.202898550724639, \"y\": 6.521739130434785, \"x2\": 4.492753623188406, \"y2\": 6.8115942028985526, \"center_x\": 4.347826086956522, \"center_y\": 6.666666666666669, \"value_uncond\": 0.01239235077728404}, {\"x\": 4.492753623188406, \"y\": 6.521739130434785, \"x2\": 4.782608695652174, \"y2\": 6.8115942028985526, \"center_x\": 4.63768115942029, \"center_y\": 6.666666666666669, \"value_uncond\": 0.01225430472105531}, {\"x\": 4.782608695652174, \"y\": 6.521739130434785, \"x2\": 5.0724637681159415, \"y2\": 6.8115942028985526, \"center_x\": 4.927536231884058, \"center_y\": 6.666666666666669, \"value_uncond\": 0.012005201877553301}, {\"x\": 5.072463768115943, \"y\": 6.521739130434785, \"x2\": 5.362318840579711, \"y2\": 6.8115942028985526, \"center_x\": 5.217391304347827, \"center_y\": 6.666666666666669, \"value_uncond\": 0.011651881897623508}, {\"x\": 5.362318840579711, \"y\": 6.521739130434785, \"x2\": 5.6521739130434785, \"y2\": 6.8115942028985526, \"center_x\": 5.507246376811595, \"center_y\": 6.666666666666669, \"value_uncond\": 0.011203881198226821}, {\"x\": 5.6521739130434785, \"y\": 6.521739130434785, \"x2\": 5.942028985507246, \"y2\": 6.8115942028985526, \"center_x\": 5.797101449275362, \"center_y\": 6.666666666666669, \"value_uncond\": 0.010673005437644672}, {\"x\": 5.942028985507246, \"y\": 6.521739130434785, \"x2\": 6.231884057971014, \"y2\": 6.8115942028985526, \"center_x\": 6.08695652173913, \"center_y\": 6.666666666666669, \"value_uncond\": 0.010072813218345815}, {\"x\": 6.2318840579710155, \"y\": 6.521739130434785, \"x2\": 6.521739130434783, \"y2\": 6.8115942028985526, \"center_x\": 6.376811594202899, \"center_y\": 6.666666666666669, \"value_uncond\": 0.009418042491643618}, {\"x\": 6.521739130434785, \"y\": 6.521739130434785, \"x2\": 6.8115942028985526, \"y2\": 6.8115942028985526, \"center_x\": 6.666666666666669, \"center_y\": 6.666666666666669, \"value_uncond\": 0.008724013415689036}, {\"x\": 6.811594202898551, \"y\": 6.521739130434785, \"x2\": 7.101449275362318, \"y2\": 6.8115942028985526, \"center_x\": 6.956521739130435, \"center_y\": 6.666666666666669, \"value_uncond\": 0.008006041159953757}, {\"x\": 7.10144927536232, \"y\": 6.521739130434785, \"x2\": 7.391304347826088, \"y2\": 6.8115942028985526, \"center_x\": 7.246376811594204, \"center_y\": 6.666666666666669, \"value_uncond\": 0.007278889506506953}, {\"x\": 7.391304347826086, \"y\": 6.521739130434785, \"x2\": 7.681159420289854, \"y2\": 6.8115942028985526, \"center_x\": 7.53623188405797, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0065562914268104434}, {\"x\": 7.681159420289855, \"y\": 6.521739130434785, \"x2\": 7.971014492753623, \"y2\": 6.8115942028985526, \"center_x\": 7.826086956521739, \"center_y\": 6.666666666666669, \"value_uncond\": 0.005850556625482317}, {\"x\": 7.971014492753625, \"y\": 6.521739130434785, \"x2\": 8.260869565217392, \"y2\": 6.8115942028985526, \"center_x\": 8.115942028985508, \"center_y\": 6.666666666666669, \"value_uncond\": 0.005172278949072917}, {\"x\": 8.26086956521739, \"y\": 6.521739130434785, \"x2\": 8.550724637681158, \"y2\": 6.8115942028985526, \"center_x\": 8.405797101449274, \"center_y\": 6.666666666666669, \"value_uncond\": 0.004530149197903092}, {\"x\": 8.55072463768116, \"y\": 6.521739130434785, \"x2\": 8.840579710144928, \"y2\": 6.8115942028985526, \"center_x\": 8.695652173913043, \"center_y\": 6.666666666666669, \"value_uncond\": 0.003930871857686281}, {\"x\": 8.84057971014493, \"y\": 6.521739130434785, \"x2\": 9.130434782608697, \"y2\": 6.8115942028985526, \"center_x\": 8.985507246376812, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0033791781010546027}, {\"x\": 9.130434782608695, \"y\": 6.521739130434785, \"x2\": 9.420289855072463, \"y2\": 6.8115942028985526, \"center_x\": 9.275362318840578, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0028779224839235533}, {\"x\": 9.420289855072465, \"y\": 6.521739130434785, \"x2\": 9.710144927536232, \"y2\": 6.8115942028985526, \"center_x\": 9.565217391304348, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0024282473127226916}, {\"x\": 9.710144927536234, \"y\": 6.521739130434785, \"x2\": 10.000000000000002, \"y2\": 6.8115942028985526, \"center_x\": 9.855072463768117, \"center_y\": 6.666666666666669, \"value_uncond\": 0.002029796764753759}, {\"x\": 10.0, \"y\": 6.521739130434785, \"x2\": 10.289855072463768, \"y2\": 6.8115942028985526, \"center_x\": 10.144927536231883, \"center_y\": 6.666666666666669, \"value_uncond\": 0.0016809624405866655}, {\"x\": -10.0, \"y\": 6.811594202898551, \"x2\": -9.710144927536232, \"y2\": 7.101449275362318, \"center_x\": -9.855072463768117, \"center_y\": 6.956521739130435, \"value_uncond\": 2.1274732529638975e-07}, {\"x\": -9.710144927536232, \"y\": 6.811594202898551, \"x2\": -9.420289855072465, \"y2\": 7.101449275362318, \"center_x\": -9.565217391304348, \"center_y\": 6.956521739130435, \"value_uncond\": 3.32394763783409e-07}, {\"x\": -9.420289855072463, \"y\": 6.811594202898551, \"x2\": -9.130434782608695, \"y2\": 7.101449275362318, \"center_x\": -9.275362318840578, \"center_y\": 6.956521739130435, \"value_uncond\": 5.145055373860044e-07}, {\"x\": -9.130434782608695, \"y\": 6.811594202898551, \"x2\": -8.840579710144928, \"y2\": 7.101449275362318, \"center_x\": -8.985507246376812, \"center_y\": 6.956521739130435, \"value_uncond\": 7.889904514165666e-07}, {\"x\": -8.840579710144928, \"y\": 6.811594202898551, \"x2\": -8.55072463768116, \"y2\": 7.101449275362318, \"center_x\": -8.695652173913043, \"center_y\": 6.956521739130435, \"value_uncond\": 1.198668950703914e-06}, {\"x\": -8.55072463768116, \"y\": 6.811594202898551, \"x2\": -8.260869565217392, \"y2\": 7.101449275362318, \"center_x\": -8.405797101449277, \"center_y\": 6.956521739130435, \"value_uncond\": 1.8041497355819331e-06}, {\"x\": -8.26086956521739, \"y\": 6.811594202898551, \"x2\": -7.971014492753623, \"y2\": 7.101449275362318, \"center_x\": -8.115942028985508, \"center_y\": 6.956521739130435, \"value_uncond\": 2.6902442801040447e-06}, {\"x\": -7.971014492753623, \"y\": 6.811594202898551, \"x2\": -7.681159420289855, \"y2\": 7.101449275362318, \"center_x\": -7.826086956521739, \"center_y\": 6.956521739130435, \"value_uncond\": 3.974263598446794e-06}, {\"x\": -7.681159420289855, \"y\": 6.811594202898551, \"x2\": -7.391304347826088, \"y2\": 7.101449275362318, \"center_x\": -7.536231884057972, \"center_y\": 6.956521739130435, \"value_uncond\": 5.816576383746788e-06}, {\"x\": -7.391304347826087, \"y\": 6.811594202898551, \"x2\": -7.101449275362319, \"y2\": 7.101449275362318, \"center_x\": -7.246376811594203, \"center_y\": 6.956521739130435, \"value_uncond\": 8.433813963719633e-06}, {\"x\": -7.101449275362318, \"y\": 6.811594202898551, \"x2\": -6.811594202898551, \"y2\": 7.101449275362318, \"center_x\": -6.956521739130435, \"center_y\": 6.956521739130435, \"value_uncond\": 1.2115083529099698e-05}, {\"x\": -6.811594202898551, \"y\": 6.811594202898551, \"x2\": -6.521739130434783, \"y2\": 7.101449275362318, \"center_x\": -6.666666666666667, \"center_y\": 6.956521739130435, \"value_uncond\": 1.7241483193963888e-05}, {\"x\": -6.521739130434782, \"y\": 6.811594202898551, \"x2\": -6.231884057971015, \"y2\": 7.101449275362318, \"center_x\": -6.3768115942028984, \"center_y\": 6.956521739130435, \"value_uncond\": 2.4309087008280366e-05}, {\"x\": -6.231884057971014, \"y\": 6.811594202898551, \"x2\": -5.942028985507246, \"y2\": 7.101449275362318, \"center_x\": -6.08695652173913, \"center_y\": 6.956521739130435, \"value_uncond\": 3.3955371590875396e-05}, {\"x\": -5.942028985507246, \"y\": 6.811594202898551, \"x2\": -5.6521739130434785, \"y2\": 7.101449275362318, \"center_x\": -5.797101449275362, \"center_y\": 6.956521739130435, \"value_uncond\": 4.698877699526274e-05}, {\"x\": -5.6521739130434785, \"y\": 6.811594202898551, \"x2\": -5.362318840579711, \"y2\": 7.101449275362318, \"center_x\": -5.507246376811595, \"center_y\": 6.956521739130435, \"value_uncond\": 6.44207252883631e-05}, {\"x\": -5.36231884057971, \"y\": 6.811594202898551, \"x2\": -5.072463768115942, \"y2\": 7.101449275362318, \"center_x\": -5.217391304347826, \"center_y\": 6.956521739130435, \"value_uncond\": 8.74989604135519e-05}, {\"x\": -5.0724637681159415, \"y\": 6.811594202898551, \"x2\": -4.782608695652174, \"y2\": 7.101449275362318, \"center_x\": -4.927536231884058, \"center_y\": 6.956521739130435, \"value_uncond\": 0.00011774053117595541}, {\"x\": -4.782608695652174, \"y\": 6.811594202898551, \"x2\": -4.492753623188406, \"y2\": 7.101449275362318, \"center_x\": -4.63768115942029, \"center_y\": 6.956521739130435, \"value_uncond\": 0.00015696213701197131}, {\"x\": -4.492753623188405, \"y\": 6.811594202898551, \"x2\": -4.202898550724638, \"y2\": 7.101449275362318, \"center_x\": -4.3478260869565215, \"center_y\": 6.956521739130435, \"value_uncond\": 0.00020730492965299356}, {\"x\": -4.202898550724638, \"y\": 6.811594202898551, \"x2\": -3.91304347826087, \"y2\": 7.101449275362318, \"center_x\": -4.057971014492754, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0002712502648199919}, {\"x\": -3.913043478260869, \"y\": 6.811594202898551, \"x2\": -3.6231884057971016, \"y2\": 7.101449275362318, \"center_x\": -3.7681159420289854, \"center_y\": 6.956521739130435, \"value_uncond\": 0.000351622394131174}, {\"x\": -3.6231884057971016, \"y\": 6.811594202898551, \"x2\": -3.333333333333334, \"y2\": 7.101449275362318, \"center_x\": -3.4782608695652177, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0004515737588616033}, {\"x\": -3.333333333333333, \"y\": 6.811594202898551, \"x2\": -3.0434782608695654, \"y2\": 7.101449275362318, \"center_x\": -3.1884057971014492, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0005745484823511837}, {\"x\": -3.0434782608695645, \"y\": 6.811594202898551, \"x2\": -2.753623188405797, \"y2\": 7.101449275362318, \"center_x\": -2.8985507246376807, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0007242199451793485}, {\"x\": -2.753623188405797, \"y\": 6.811594202898551, \"x2\": -2.4637681159420293, \"y2\": 7.101449275362318, \"center_x\": -2.608695652173913, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0009043990451512076}, {\"x\": -2.4637681159420284, \"y\": 6.811594202898551, \"x2\": -2.1739130434782608, \"y2\": 7.101449275362318, \"center_x\": -2.3188405797101446, \"center_y\": 6.956521739130435, \"value_uncond\": 0.001118910949040142}, {\"x\": -2.1739130434782608, \"y\": 6.811594202898551, \"x2\": -1.8840579710144931, \"y2\": 7.101449275362318, \"center_x\": -2.028985507246377, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0013714398563909602}, {\"x\": -1.8840579710144922, \"y\": 6.811594202898551, \"x2\": -1.5942028985507246, \"y2\": 7.101449275362318, \"center_x\": -1.7391304347826084, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0016653434920375757}, {\"x\": -1.5942028985507246, \"y\": 6.811594202898551, \"x2\": -1.304347826086957, \"y2\": 7.101449275362318, \"center_x\": -1.4492753623188408, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0020034416414148196}, {\"x\": -1.304347826086957, \"y\": 6.811594202898551, \"x2\": -1.0144927536231894, \"y2\": 7.101449275362318, \"center_x\": -1.1594202898550732, \"center_y\": 6.956521739130435, \"value_uncond\": 0.002387785897913383}, {\"x\": -1.0144927536231876, \"y\": 6.811594202898551, \"x2\": -0.72463768115942, \"y2\": 7.101449275362318, \"center_x\": -0.8695652173913038, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0028194207010446017}, {\"x\": -0.72463768115942, \"y\": 6.811594202898551, \"x2\": -0.43478260869565233, \"y2\": 7.101449275362318, \"center_x\": -0.5797101449275361, \"center_y\": 6.956521739130435, \"value_uncond\": 0.00329814845360981}, {\"x\": -0.43478260869565233, \"y\": 6.811594202898551, \"x2\": -0.1449275362318847, \"y2\": 7.101449275362318, \"center_x\": -0.2898550724637685, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0038223137271730825}, {\"x\": -0.14492753623188293, \"y\": 6.811594202898551, \"x2\": 0.1449275362318847, \"y2\": 7.101449275362318, \"center_x\": 8.881784197001252e-16, \"center_y\": 6.956521739130435, \"value_uncond\": 0.004388623000888145}, {\"x\": 0.1449275362318847, \"y\": 6.811594202898551, \"x2\": 0.43478260869565233, \"y2\": 7.101449275362318, \"center_x\": 0.2898550724637685, \"center_y\": 6.956521739130435, \"value_uncond\": 0.004992016754393205}, {\"x\": 0.43478260869565233, \"y\": 6.811594202898551, \"x2\": 0.72463768115942, \"y2\": 7.101449275362318, \"center_x\": 0.5797101449275361, \"center_y\": 6.956521739130435, \"value_uncond\": 0.005625609832929387}, {\"x\": 0.72463768115942, \"y\": 6.811594202898551, \"x2\": 1.0144927536231876, \"y2\": 7.101449275362318, \"center_x\": 0.8695652173913038, \"center_y\": 6.956521739130435, \"value_uncond\": 0.006280713694225632}, {\"x\": 1.0144927536231894, \"y\": 6.811594202898551, \"x2\": 1.304347826086957, \"y2\": 7.101449275362318, \"center_x\": 1.1594202898550732, \"center_y\": 6.956521739130435, \"value_uncond\": 0.006946950423113533}, {\"x\": 1.304347826086957, \"y\": 6.811594202898551, \"x2\": 1.5942028985507246, \"y2\": 7.101449275362318, \"center_x\": 1.4492753623188408, \"center_y\": 6.956521739130435, \"value_uncond\": 0.007612463390355489}, {\"x\": 1.5942028985507246, \"y\": 6.811594202898551, \"x2\": 1.8840579710144922, \"y2\": 7.101449275362318, \"center_x\": 1.7391304347826084, \"center_y\": 6.956521739130435, \"value_uncond\": 0.008264223409439334}, {\"x\": 1.884057971014494, \"y\": 6.811594202898551, \"x2\": 2.1739130434782616, \"y2\": 7.101449275362318, \"center_x\": 2.028985507246378, \"center_y\": 6.956521739130435, \"value_uncond\": 0.00888842261488678}, {\"x\": 2.1739130434782616, \"y\": 6.811594202898551, \"x2\": 2.4637681159420293, \"y2\": 7.101449275362318, \"center_x\": 2.3188405797101455, \"center_y\": 6.956521739130435, \"value_uncond\": 0.009470941559540745}, {\"x\": 2.4637681159420293, \"y\": 6.811594202898551, \"x2\": 2.753623188405797, \"y2\": 7.101449275362318, \"center_x\": 2.608695652173913, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0099978687810239}, {\"x\": 2.753623188405797, \"y\": 6.811594202898551, \"x2\": 3.0434782608695645, \"y2\": 7.101449275362318, \"center_x\": 2.8985507246376807, \"center_y\": 6.956521739130435, \"value_uncond\": 0.010456046902358577}, {\"x\": 3.0434782608695663, \"y\": 6.811594202898551, \"x2\": 3.333333333333334, \"y2\": 7.101449275362318, \"center_x\": 3.18840579710145, \"center_y\": 6.956521739130435, \"value_uncond\": 0.010833615739769736}, {\"x\": 3.333333333333334, \"y\": 6.811594202898551, \"x2\": 3.6231884057971016, \"y2\": 7.101449275362318, \"center_x\": 3.4782608695652177, \"center_y\": 6.956521739130435, \"value_uncond\": 0.011120521311170306}, {\"x\": 3.6231884057971016, \"y\": 6.811594202898551, \"x2\": 3.913043478260869, \"y2\": 7.101449275362318, \"center_x\": 3.7681159420289854, \"center_y\": 6.956521739130435, \"value_uncond\": 0.011308960327440668}, {\"x\": 3.913043478260871, \"y\": 6.811594202898551, \"x2\": 4.202898550724639, \"y2\": 7.101449275362318, \"center_x\": 4.057971014492755, \"center_y\": 6.956521739130435, \"value_uncond\": 0.011393732761146204}, {\"x\": 4.202898550724639, \"y\": 6.811594202898551, \"x2\": 4.492753623188406, \"y2\": 7.101449275362318, \"center_x\": 4.347826086956522, \"center_y\": 6.956521739130435, \"value_uncond\": 0.011372480263853986}, {\"x\": 4.492753623188406, \"y\": 6.811594202898551, \"x2\": 4.782608695652174, \"y2\": 7.101449275362318, \"center_x\": 4.63768115942029, \"center_y\": 6.956521739130435, \"value_uncond\": 0.011245795175755779}, {\"x\": 4.782608695652174, \"y\": 6.811594202898551, \"x2\": 5.0724637681159415, \"y2\": 7.101449275362318, \"center_x\": 4.927536231884058, \"center_y\": 6.956521739130435, \"value_uncond\": 0.011017193095140902}, {\"x\": 5.072463768115943, \"y\": 6.811594202898551, \"x2\": 5.362318840579711, \"y2\": 7.101449275362318, \"center_x\": 5.217391304347827, \"center_y\": 6.956521739130435, \"value_uncond\": 0.010692950780604234}, {\"x\": 5.362318840579711, \"y\": 6.811594202898551, \"x2\": 5.6521739130434785, \"y2\": 7.101449275362318, \"center_x\": 5.507246376811595, \"center_y\": 6.956521739130435, \"value_uncond\": 0.010281819817347382}, {\"x\": 5.6521739130434785, \"y\": 6.811594202898551, \"x2\": 5.942028985507246, \"y2\": 7.101449275362318, \"center_x\": 5.797101449275362, \"center_y\": 6.956521739130435, \"value_uncond\": 0.009794634276985995}, {\"x\": 5.942028985507246, \"y\": 6.811594202898551, \"x2\": 6.231884057971014, \"y2\": 7.101449275362318, \"center_x\": 6.08695652173913, \"center_y\": 6.956521739130435, \"value_uncond\": 0.009243836910839224}, {\"x\": 6.2318840579710155, \"y\": 6.811594202898551, \"x2\": 6.521739130434783, \"y2\": 7.101449275362318, \"center_x\": 6.376811594202899, \"center_y\": 6.956521739130435, \"value_uncond\": 0.008642952760560024}, {\"x\": 6.521739130434785, \"y\": 6.811594202898551, \"x2\": 6.8115942028985526, \"y2\": 7.101449275362318, \"center_x\": 6.666666666666669, \"center_y\": 6.956521739130435, \"value_uncond\": 0.008006041159953757}, {\"x\": 6.811594202898551, \"y\": 6.811594202898551, \"x2\": 7.101449275362318, \"y2\": 7.101449275362318, \"center_x\": 6.956521739130435, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0073471568647067755}, {\"x\": 7.10144927536232, \"y\": 6.811594202898551, \"x2\": 7.391304347826088, \"y2\": 7.101449275362318, \"center_x\": 7.246376811594204, \"center_y\": 6.956521739130435, \"value_uncond\": 0.00667984862139824}, {\"x\": 7.391304347826086, \"y\": 6.811594202898551, \"x2\": 7.681159420289854, \"y2\": 7.101449275362318, \"center_x\": 7.53623188405797, \"center_y\": 6.956521739130435, \"value_uncond\": 0.00601671920005302}, {\"x\": 7.681159420289855, \"y\": 6.811594202898551, \"x2\": 7.971014492753623, \"y2\": 7.101449275362318, \"center_x\": 7.826086956521739, \"center_y\": 6.956521739130435, \"value_uncond\": 0.00536906523642159}, {\"x\": 7.971014492753625, \"y\": 6.811594202898551, \"x2\": 8.260869565217392, \"y2\": 7.101449275362318, \"center_x\": 8.115942028985508, \"center_y\": 6.956521739130435, \"value_uncond\": 0.004746608720542592}, {\"x\": 8.26086956521739, \"y\": 6.811594202898551, \"x2\": 8.550724637681158, \"y2\": 7.101449275362318, \"center_x\": 8.405797101449274, \"center_y\": 6.956521739130435, \"value_uncond\": 0.004157325213865356}, {\"x\": 8.55072463768116, \"y\": 6.811594202898551, \"x2\": 8.840579710144928, \"y2\": 7.101449275362318, \"center_x\": 8.695652173913043, \"center_y\": 6.956521739130435, \"value_uncond\": 0.003607367433725416}, {\"x\": 8.84057971014493, \"y\": 6.811594202898551, \"x2\": 9.130434782608697, \"y2\": 7.101449275362318, \"center_x\": 8.985507246376812, \"center_y\": 6.956521739130435, \"value_uncond\": 0.003101077184865926}, {\"x\": 9.130434782608695, \"y\": 6.811594202898551, \"x2\": 9.420289855072463, \"y2\": 7.101449275362318, \"center_x\": 9.275362318840578, \"center_y\": 6.956521739130435, \"value_uncond\": 0.002641074097847261}, {\"x\": 9.420289855072465, \"y\": 6.811594202898551, \"x2\": 9.710144927536232, \"y2\": 7.101449275362318, \"center_x\": 9.565217391304348, \"center_y\": 6.956521739130435, \"value_uncond\": 0.002228406469119295}, {\"x\": 9.710144927536234, \"y\": 6.811594202898551, \"x2\": 10.000000000000002, \"y2\": 7.101449275362318, \"center_x\": 9.855072463768117, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0018627477596188527}, {\"x\": 10.0, \"y\": 6.811594202898551, \"x2\": 10.289855072463768, \"y2\": 7.101449275362318, \"center_x\": 10.144927536231883, \"center_y\": 6.956521739130435, \"value_uncond\": 0.0015426219385989153}, {\"x\": -10.0, \"y\": 7.10144927536232, \"x2\": -9.710144927536232, \"y2\": 7.391304347826088, \"center_x\": -9.855072463768117, \"center_y\": 7.246376811594204, \"value_uncond\": 1.9342447068386744e-07}, {\"x\": -9.710144927536232, \"y\": 7.10144927536232, \"x2\": -9.420289855072465, \"y2\": 7.391304347826088, \"center_x\": -9.565217391304348, \"center_y\": 7.246376811594204, \"value_uncond\": 3.022048862580275e-07}, {\"x\": -9.420289855072463, \"y\": 7.10144927536232, \"x2\": -9.130434782608695, \"y2\": 7.391304347826088, \"center_x\": -9.275362318840578, \"center_y\": 7.246376811594204, \"value_uncond\": 4.677753814021533e-07}, {\"x\": -9.130434782608695, \"y\": 7.10144927536232, \"x2\": -8.840579710144928, \"y2\": 7.391304347826088, \"center_x\": -8.985507246376812, \"center_y\": 7.246376811594204, \"value_uncond\": 7.17330101458459e-07}, {\"x\": -8.840579710144928, \"y\": 7.10144927536232, \"x2\": -8.55072463768116, \"y2\": 7.391304347826088, \"center_x\": -8.695652173913043, \"center_y\": 7.246376811594204, \"value_uncond\": 1.089799399320701e-06}, {\"x\": -8.55072463768116, \"y\": 7.10144927536232, \"x2\": -8.260869565217392, \"y2\": 7.391304347826088, \"center_x\": -8.405797101449277, \"center_y\": 7.246376811594204, \"value_uncond\": 1.6402871676680804e-06}, {\"x\": -8.26086956521739, \"y\": 7.10144927536232, \"x2\": -7.971014492753623, \"y2\": 7.391304347826088, \"center_x\": -8.115942028985508, \"center_y\": 7.246376811594204, \"value_uncond\": 2.445901847012585e-06}, {\"x\": -7.971014492753623, \"y\": 7.10144927536232, \"x2\": -7.681159420289855, \"y2\": 7.391304347826088, \"center_x\": -7.826086956521739, \"center_y\": 7.246376811594204, \"value_uncond\": 3.613299635221212e-06}, {\"x\": -7.681159420289855, \"y\": 7.10144927536232, \"x2\": -7.391304347826088, \"y2\": 7.391304347826088, \"center_x\": -7.536231884057972, \"center_y\": 7.246376811594204, \"value_uncond\": 5.288283679482755e-06}, {\"x\": -7.391304347826087, \"y\": 7.10144927536232, \"x2\": -7.101449275362319, \"y2\": 7.391304347826088, \"center_x\": -7.246376811594203, \"center_y\": 7.246376811594204, \"value_uncond\": 7.66780968694211e-06}, {\"x\": -7.101449275362318, \"y\": 7.10144927536232, \"x2\": -6.811594202898551, \"y2\": 7.391304347826088, \"center_x\": -6.956521739130435, \"center_y\": 7.246376811594204, \"value_uncond\": 1.1014726580662296e-05}, {\"x\": -6.811594202898551, \"y\": 7.10144927536232, \"x2\": -6.521739130434783, \"y2\": 7.391304347826088, \"center_x\": -6.666666666666667, \"center_y\": 7.246376811594204, \"value_uncond\": 1.56755190973668e-05}, {\"x\": -6.521739130434782, \"y\": 7.10144927536232, \"x2\": -6.231884057971015, \"y2\": 7.391304347826088, \"center_x\": -6.3768115942028984, \"center_y\": 7.246376811594204, \"value_uncond\": 2.21012051777109e-05}, {\"x\": -6.231884057971014, \"y\": 7.10144927536232, \"x2\": -5.942028985507246, \"y2\": 7.391304347826088, \"center_x\": -6.08695652173913, \"center_y\": 7.246376811594204, \"value_uncond\": 3.0871362390521965e-05}, {\"x\": -5.942028985507246, \"y\": 7.10144927536232, \"x2\": -5.6521739130434785, \"y2\": 7.391304347826088, \"center_x\": -5.797101449275362, \"center_y\": 7.246376811594204, \"value_uncond\": 4.27210039220419e-05}, {\"x\": -5.6521739130434785, \"y\": 7.10144927536232, \"x2\": -5.362318840579711, \"y2\": 7.391304347826088, \"center_x\": -5.507246376811595, \"center_y\": 7.246376811594204, \"value_uncond\": 5.856968905537602e-05}, {\"x\": -5.36231884057971, \"y\": 7.10144927536232, \"x2\": -5.072463768115942, \"y2\": 7.391304347826088, \"center_x\": -5.217391304347826, \"center_y\": 7.246376811594204, \"value_uncond\": 7.955183492813184e-05}, {\"x\": -5.0724637681159415, \"y\": 7.10144927536232, \"x2\": -4.782608695652174, \"y2\": 7.391304347826088, \"center_x\": -4.927536231884058, \"center_y\": 7.246376811594204, \"value_uncond\": 0.00010704670382586031}, {\"x\": -4.782608695652174, \"y\": 7.10144927536232, \"x2\": -4.492753623188406, \"y2\": 7.391304347826088, \"center_x\": -4.63768115942029, \"center_y\": 7.246376811594204, \"value_uncond\": 0.00014270599278582075}, {\"x\": -4.492753623188405, \"y\": 7.10144927536232, \"x2\": -4.202898550724638, \"y2\": 7.391304347826088, \"center_x\": -4.3478260869565215, \"center_y\": 7.246376811594204, \"value_uncond\": 0.00018847638264041263}, {\"x\": -4.202898550724638, \"y\": 7.10144927536232, \"x2\": -3.91304347826087, \"y2\": 7.391304347826088, \"center_x\": -4.057971014492754, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0002466138590582607}, {\"x\": -3.913043478260869, \"y\": 7.10144927536232, \"x2\": -3.6231884057971016, \"y2\": 7.391304347826088, \"center_x\": -3.7681159420289854, \"center_y\": 7.246376811594204, \"value_uncond\": 0.00031968615995836775}, {\"x\": -3.6231884057971016, \"y\": 7.10144927536232, \"x2\": -3.333333333333334, \"y2\": 7.391304347826088, \"center_x\": -3.4782608695652177, \"center_y\": 7.246376811594204, \"value_uncond\": 0.00041055940496946086}, {\"x\": -3.333333333333333, \"y\": 7.10144927536232, \"x2\": -3.0434782608695654, \"y2\": 7.391304347826088, \"center_x\": -3.1884057971014492, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0005223649036535408}, {\"x\": -3.0434782608695645, \"y\": 7.10144927536232, \"x2\": -2.753623188405797, \"y2\": 7.391304347826088, \"center_x\": -2.8985507246376807, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0006584424004384523}, {\"x\": -2.753623188405797, \"y\": 7.10144927536232, \"x2\": -2.4637681159420293, \"y2\": 7.391304347826088, \"center_x\": -2.608695652173913, \"center_y\": 7.246376811594204, \"value_uncond\": 0.000822256666924762}, {\"x\": -2.4637681159420284, \"y\": 7.10144927536232, \"x2\": -2.1739130434782608, \"y2\": 7.391304347826088, \"center_x\": -2.3188405797101446, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0010172854476969823}, {\"x\": -2.1739130434782608, \"y\": 7.10144927536232, \"x2\": -1.8840579710144931, \"y2\": 7.391304347826088, \"center_x\": -2.028985507246377, \"center_y\": 7.246376811594204, \"value_uncond\": 0.001246878323511795}, {\"x\": -1.8840579710144922, \"y\": 7.10144927536232, \"x2\": -1.5942028985507246, \"y2\": 7.391304347826088, \"center_x\": -1.7391304347826084, \"center_y\": 7.246376811594204, \"value_uncond\": 0.001514088052601515}, {\"x\": -1.5942028985507246, \"y\": 7.10144927536232, \"x2\": -1.304347826086957, \"y2\": 7.391304347826088, \"center_x\": -1.4492753623188408, \"center_y\": 7.246376811594204, \"value_uncond\": 0.001821478312344528}, {\"x\": -1.304347826086957, \"y\": 7.10144927536232, \"x2\": -1.0144927536231894, \"y2\": 7.391304347826088, \"center_x\": -1.1594202898550732, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0021709143594019938}, {\"x\": -1.0144927536231876, \"y\": 7.10144927536232, \"x2\": -0.72463768115942, \"y2\": 7.391304347826088, \"center_x\": -0.8695652173913038, \"center_y\": 7.246376811594204, \"value_uncond\": 0.002563345771679815}, {\"x\": -0.72463768115942, \"y\": 7.10144927536232, \"x2\": -0.43478260869565233, \"y2\": 7.391304347826088, \"center_x\": -0.5797101449275361, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0029985928988180773}, {\"x\": -0.43478260869565233, \"y\": 7.10144927536232, \"x2\": -0.1449275362318847, \"y2\": 7.391304347826088, \"center_x\": -0.2898550724637685, \"center_y\": 7.246376811594204, \"value_uncond\": 0.003475150667281647}, {\"x\": -0.14492753623188293, \"y\": 7.10144927536232, \"x2\": 0.1449275362318847, \"y2\": 7.391304347826088, \"center_x\": 8.881784197001252e-16, \"center_y\": 7.246376811594204, \"value_uncond\": 0.003990024691474892}, {\"x\": 0.1449275362318847, \"y\": 7.10144927536232, \"x2\": 0.43478260869565233, \"y2\": 7.391304347826088, \"center_x\": 0.2898550724637685, \"center_y\": 7.246376811594204, \"value_uncond\": 0.004538614983846708}, {\"x\": 0.43478260869565233, \"y\": 7.10144927536232, \"x2\": 0.72463768115942, \"y2\": 7.391304347826088, \"center_x\": 0.5797101449275361, \"center_y\": 7.246376811594204, \"value_uncond\": 0.005114661736369161}, {\"x\": 0.72463768115942, \"y\": 7.10144927536232, \"x2\": 1.0144927536231876, \"y2\": 7.391304347826088, \"center_x\": 0.8695652173913038, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0057102655468408235}, {\"x\": 1.0144927536231894, \"y\": 7.10144927536232, \"x2\": 1.304347826086957, \"y2\": 7.391304347826088, \"center_x\": 1.1594202898550732, \"center_y\": 7.246376811594204, \"value_uncond\": 0.006315991078081992}, {\"x\": 1.304347826086957, \"y\": 7.10144927536232, \"x2\": 1.5942028985507246, \"y2\": 7.391304347826088, \"center_x\": 1.4492753623188408, \"center_y\": 7.246376811594204, \"value_uncond\": 0.00692105858359676}, {\"x\": 1.5942028985507246, \"y\": 7.10144927536232, \"x2\": 1.8840579710144922, \"y2\": 7.391304347826088, \"center_x\": 1.7391304347826084, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0075136222575633805}, {\"x\": 1.884057971014494, \"y\": 7.10144927536232, \"x2\": 2.1739130434782616, \"y2\": 7.391304347826088, \"center_x\": 2.028985507246378, \"center_y\": 7.246376811594204, \"value_uncond\": 0.008081128338999469}, {\"x\": 2.1739130434782616, \"y\": 7.10144927536232, \"x2\": 2.4637681159420293, \"y2\": 7.391304347826088, \"center_x\": 2.3188405797101455, \"center_y\": 7.246376811594204, \"value_uncond\": 0.008610739784765224}, {\"x\": 2.4637681159420293, \"y\": 7.10144927536232, \"x2\": 2.753623188405797, \"y2\": 7.391304347826088, \"center_x\": 2.608695652173913, \"center_y\": 7.246376811594204, \"value_uncond\": 0.009089808646205944}, {\"x\": 2.753623188405797, \"y\": 7.10144927536232, \"x2\": 3.0434782608695645, \"y2\": 7.391304347826088, \"center_x\": 2.8985507246376807, \"center_y\": 7.246376811594204, \"value_uncond\": 0.00950637256998089}, {\"x\": 3.0434782608695663, \"y\": 7.10144927536232, \"x2\": 3.333333333333334, \"y2\": 7.391304347826088, \"center_x\": 3.18840579710145, \"center_y\": 7.246376811594204, \"value_uncond\": 0.00984964857789889}, {\"x\": 3.333333333333334, \"y\": 7.10144927536232, \"x2\": 3.6231884057971016, \"y2\": 7.391304347826088, \"center_x\": 3.4782608695652177, \"center_y\": 7.246376811594204, \"value_uncond\": 0.010110495844519491}, {\"x\": 3.6231884057971016, \"y\": 7.10144927536232, \"x2\": 3.913043478260869, \"y2\": 7.391304347826088, \"center_x\": 3.7681159420289854, \"center_y\": 7.246376811594204, \"value_uncond\": 0.010281819817347378}, {\"x\": 3.913043478260871, \"y\": 7.10144927536232, \"x2\": 4.202898550724639, \"y2\": 7.391304347826088, \"center_x\": 4.057971014492755, \"center_y\": 7.246376811594204, \"value_uncond\": 0.010358892763365537}, {\"x\": 4.202898550724639, \"y\": 7.10144927536232, \"x2\": 4.492753623188406, \"y2\": 7.391304347826088, \"center_x\": 4.347826086956522, \"center_y\": 7.246376811594204, \"value_uncond\": 0.010339570532010896}, {\"x\": 4.492753623188406, \"y\": 7.10144927536232, \"x2\": 4.782608695652174, \"y2\": 7.391304347826088, \"center_x\": 4.63768115942029, \"center_y\": 7.246376811594204, \"value_uncond\": 0.01022439166395793}, {\"x\": 4.782608695652174, \"y\": 7.10144927536232, \"x2\": 5.0724637681159415, \"y2\": 7.391304347826088, \"center_x\": 4.927536231884058, \"center_y\": 7.246376811594204, \"value_uncond\": 0.010016552451979297}, {\"x\": 5.072463768115943, \"y\": 7.10144927536232, \"x2\": 5.362318840579711, \"y2\": 7.391304347826088, \"center_x\": 5.217391304347827, \"center_y\": 7.246376811594204, \"value_uncond\": 0.009721759565745856}, {\"x\": 5.362318840579711, \"y\": 7.10144927536232, \"x2\": 5.6521739130434785, \"y2\": 7.391304347826088, \"center_x\": 5.507246376811595, \"center_y\": 7.246376811594204, \"value_uncond\": 0.00934796972449207}, {\"x\": 5.6521739130434785, \"y\": 7.10144927536232, \"x2\": 5.942028985507246, \"y2\": 7.391304347826088, \"center_x\": 5.797101449275362, \"center_y\": 7.246376811594204, \"value_uncond\": 0.00890503299126662}, {\"x\": 5.942028985507246, \"y\": 7.10144927536232, \"x2\": 6.231884057971014, \"y2\": 7.391304347826088, \"center_x\": 6.08695652173913, \"center_y\": 7.246376811594204, \"value_uncond\": 0.008404261999891829}, {\"x\": 6.2318840579710155, \"y\": 7.10144927536232, \"x2\": 6.521739130434783, \"y2\": 7.391304347826088, \"center_x\": 6.376811594202899, \"center_y\": 7.246376811594204, \"value_uncond\": 0.007857953375103437}, {\"x\": 6.521739130434785, \"y\": 7.10144927536232, \"x2\": 6.8115942028985526, \"y2\": 7.391304347826088, \"center_x\": 6.666666666666669, \"center_y\": 7.246376811594204, \"value_uncond\": 0.007278889506506953}, {\"x\": 6.811594202898551, \"y\": 7.10144927536232, \"x2\": 7.101449275362318, \"y2\": 7.391304347826088, \"center_x\": 6.956521739130435, \"center_y\": 7.246376811594204, \"value_uncond\": 0.00667984862139824}, {\"x\": 7.10144927536232, \"y\": 7.10144927536232, \"x2\": 7.391304347826088, \"y2\": 7.391304347826088, \"center_x\": 7.246376811594204, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0060731488964305335}, {\"x\": 7.391304347826086, \"y\": 7.10144927536232, \"x2\": 7.681159420289854, \"y2\": 7.391304347826088, \"center_x\": 7.53623188405797, \"center_y\": 7.246376811594204, \"value_uncond\": 0.005470248450373667}, {\"x\": 7.681159420289855, \"y\": 7.10144927536232, \"x2\": 7.971014492753623, \"y2\": 7.391304347826088, \"center_x\": 7.826086956521739, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0048814178978522915}, {\"x\": 7.971014492753625, \"y\": 7.10144927536232, \"x2\": 8.260869565217392, \"y2\": 7.391304347826088, \"center_x\": 8.115942028985508, \"center_y\": 7.246376811594204, \"value_uncond\": 0.004315496225559179}, {\"x\": 8.26086956521739, \"y\": 7.10144927536232, \"x2\": 8.550724637681158, \"y2\": 7.391304347826088, \"center_x\": 8.405797101449274, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0037797346116212206}, {\"x\": 8.55072463768116, \"y\": 7.10144927536232, \"x2\": 8.840579710144928, \"y2\": 7.391304347826088, \"center_x\": 8.695652173913043, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0032797269505432467}, {\"x\": 8.84057971014493, \"y\": 7.10144927536232, \"x2\": 9.130434782608697, \"y2\": 7.391304347826088, \"center_x\": 8.985507246376812, \"center_y\": 7.246376811594204, \"value_uncond\": 0.002819420701044596}, {\"x\": 9.130434782608695, \"y\": 7.10144927536232, \"x2\": 9.420289855072463, \"y2\": 7.391304347826088, \"center_x\": 9.275362318840578, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0024011975647698}, {\"x\": 9.420289855072465, \"y\": 7.10144927536232, \"x2\": 9.710144927536232, \"y2\": 7.391304347826088, \"center_x\": 9.565217391304348, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0020260106262554294}, {\"x\": 9.710144927536234, \"y\": 7.10144927536232, \"x2\": 10.000000000000002, \"y2\": 7.391304347826088, \"center_x\": 9.855072463768117, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0016935630044696544}, {\"x\": 10.0, \"y\": 7.10144927536232, \"x2\": 10.289855072463768, \"y2\": 7.391304347826088, \"center_x\": 10.144927536231883, \"center_y\": 7.246376811594204, \"value_uncond\": 0.0014025127297047169}, {\"x\": -10.0, \"y\": 7.391304347826086, \"x2\": -9.710144927536232, \"y2\": 7.681159420289854, \"center_x\": -9.855072463768117, \"center_y\": 7.53623188405797, \"value_uncond\": 1.7422261977549334e-07}, {\"x\": -9.710144927536232, \"y\": 7.391304347826086, \"x2\": -9.420289855072465, \"y2\": 7.681159420289854, \"center_x\": -9.565217391304348, \"center_y\": 7.53623188405797, \"value_uncond\": 2.7220406397741216e-07}, {\"x\": -9.420289855072463, \"y\": 7.391304347826086, \"x2\": -9.130434782608695, \"y2\": 7.681159420289854, \"center_x\": -9.275362318840578, \"center_y\": 7.53623188405797, \"value_uncond\": 4.213378593009689e-07}, {\"x\": -9.130434782608695, \"y\": 7.391304347826086, \"x2\": -8.840579710144928, \"y2\": 7.681159420289854, \"center_x\": -8.985507246376812, \"center_y\": 7.53623188405797, \"value_uncond\": 6.461185034036994e-07}, {\"x\": -8.840579710144928, \"y\": 7.391304347826086, \"x2\": -8.55072463768116, \"y2\": 7.681159420289854, \"center_x\": -8.695652173913043, \"center_y\": 7.53623188405797, \"value_uncond\": 9.8161161154077e-07}, {\"x\": -8.55072463768116, \"y\": 7.391304347826086, \"x2\": -8.260869565217392, \"y2\": 7.681159420289854, \"center_x\": -8.405797101449277, \"center_y\": 7.53623188405797, \"value_uncond\": 1.4774507409785143e-06}, {\"x\": -8.26086956521739, \"y\": 7.391304347826086, \"x2\": -7.971014492753623, \"y2\": 7.681159420289854, \"center_x\": -8.115942028985508, \"center_y\": 7.53623188405797, \"value_uncond\": 2.2030895366735617e-06}, {\"x\": -7.971014492753623, \"y\": 7.391304347826086, \"x2\": -7.681159420289855, \"y2\": 7.681159420289854, \"center_x\": -7.826086956521739, \"center_y\": 7.53623188405797, \"value_uncond\": 3.2545961028424198e-06}, {\"x\": -7.681159420289855, \"y\": 7.391304347826086, \"x2\": -7.391304347826088, \"y2\": 7.681159420289854, \"center_x\": -7.536231884057972, \"center_y\": 7.53623188405797, \"value_uncond\": 4.763299253181387e-06}, {\"x\": -7.391304347826087, \"y\": 7.391304347826086, \"x2\": -7.101449275362319, \"y2\": 7.681159420289854, \"center_x\": -7.246376811594203, \"center_y\": 7.53623188405797, \"value_uncond\": 6.906602287062016e-06}, {\"x\": -7.101449275362318, \"y\": 7.391304347826086, \"x2\": -6.811594202898551, \"y2\": 7.681159420289854, \"center_x\": -6.956521739130435, \"center_y\": 7.53623188405797, \"value_uncond\": 9.921260294568306e-06}, {\"x\": -6.811594202898551, \"y\": 7.391304347826086, \"x2\": -6.521739130434783, \"y2\": 7.681159420289854, \"center_x\": -6.666666666666667, \"center_y\": 7.53623188405797, \"value_uncond\": 1.4119361391184097e-05}, {\"x\": -6.521739130434782, \"y\": 7.391304347826086, \"x2\": -6.231884057971015, \"y2\": 7.681159420289854, \"center_x\": -6.3768115942028984, \"center_y\": 7.53623188405797, \"value_uncond\": 1.9907149558908627e-05}, {\"x\": -6.231884057971014, \"y\": 7.391304347826086, \"x2\": -5.942028985507246, \"y2\": 7.681159420289854, \"center_x\": -6.08695652173913, \"center_y\": 7.53623188405797, \"value_uncond\": 2.780666589237285e-05}, {\"x\": -5.942028985507246, \"y\": 7.391304347826086, \"x2\": -5.6521739130434785, \"y2\": 7.681159420289854, \"center_x\": -5.797101449275362, \"center_y\": 7.53623188405797, \"value_uncond\": 3.8479956524746164e-05}, {\"x\": -5.6521739130434785, \"y\": 7.391304347826086, \"x2\": -5.362318840579711, \"y2\": 7.681159420289854, \"center_x\": -5.507246376811595, \"center_y\": 7.53623188405797, \"value_uncond\": 5.275529321903279e-05}, {\"x\": -5.36231884057971, \"y\": 7.391304347826086, \"x2\": -5.072463768115942, \"y2\": 7.681159420289854, \"center_x\": -5.217391304347826, \"center_y\": 7.53623188405797, \"value_uncond\": 7.165447598292267e-05}, {\"x\": -5.0724637681159415, \"y\": 7.391304347826086, \"x2\": -4.782608695652174, \"y2\": 7.681159420289854, \"center_x\": -4.927536231884058, \"center_y\": 7.53623188405797, \"value_uncond\": 9.641984343001844e-05}, {\"x\": -4.782608695652174, \"y\": 7.391304347826086, \"x2\": -4.492753623188406, \"y2\": 7.681159420289854, \"center_x\": -4.63768115942029, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0001285391234775238}, {\"x\": -4.492753623188405, \"y\": 7.391304347826086, \"x2\": -4.202898550724638, \"y2\": 7.681159420289854, \"center_x\": -4.3478260869565215, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0001697657438757553}, {\"x\": -4.202898550724638, \"y\": 7.391304347826086, \"x2\": -3.91304347826087, \"y2\": 7.681159420289854, \"center_x\": -4.057971014492754, \"center_y\": 7.53623188405797, \"value_uncond\": 0.00022213173155478084}, {\"x\": -3.913043478260869, \"y\": 7.391304347826086, \"x2\": -3.6231884057971016, \"y2\": 7.681159420289854, \"center_x\": -3.7681159420289854, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0002879499170761312}, {\"x\": -3.6231884057971016, \"y\": 7.391304347826086, \"x2\": -3.333333333333334, \"y2\": 7.681159420289854, \"center_x\": -3.4782608695652177, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0003698018914274478}, {\"x\": -3.333333333333333, \"y\": 7.391304347826086, \"x2\": -3.0434782608695654, \"y2\": 7.681159420289854, \"center_x\": -3.1884057971014492, \"center_y\": 7.53623188405797, \"value_uncond\": 0.00047050810929727627}, {\"x\": -3.0434782608695645, \"y\": 7.391304347826086, \"x2\": -2.753623188405797, \"y2\": 7.681159420289854, \"center_x\": -2.8985507246376807, \"center_y\": 7.53623188405797, \"value_uncond\": 0.000593076768260322}, {\"x\": -2.753623188405797, \"y\": 7.391304347826086, \"x2\": -2.4637681159420293, \"y2\": 7.681159420289854, \"center_x\": -2.608695652173913, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0007406286812263477}, {\"x\": -2.4637681159420284, \"y\": 7.391304347826086, \"x2\": -2.1739130434782608, \"y2\": 7.681159420289854, \"center_x\": -2.3188405797101446, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0009162963462204569}, {\"x\": -2.1739130434782608, \"y\": 7.391304347826086, \"x2\": -1.8840579710144931, \"y2\": 7.681159420289854, \"center_x\": -2.028985507246377, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0011230968206631274}, {\"x\": -1.8840579710144922, \"y\": 7.391304347826086, \"x2\": -1.5942028985507246, \"y2\": 7.681159420289854, \"center_x\": -1.7391304347826084, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0013637798059488858}, {\"x\": -1.5942028985507246, \"y\": 7.391304347826086, \"x2\": -1.304347826086957, \"y2\": 7.681159420289854, \"center_x\": -1.4492753623188408, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0016406544752011858}, {\"x\": -1.304347826086957, \"y\": 7.391304347826086, \"x2\": -1.0144927536231894, \"y2\": 7.681159420289854, \"center_x\": -1.1594202898550732, \"center_y\": 7.53623188405797, \"value_uncond\": 0.001955400915230719}, {\"x\": -1.0144927536231876, \"y\": 7.391304347826086, \"x2\": -0.72463768115942, \"y2\": 7.681159420289854, \"center_x\": -0.8695652173913038, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0023088744363809113}, {\"x\": -0.72463768115942, \"y\": 7.391304347826086, \"x2\": -0.43478260869565233, \"y2\": 7.681159420289854, \"center_x\": -0.5797101449275361, \"center_y\": 7.53623188405797, \"value_uncond\": 0.002700913222743788}, {\"x\": -0.43478260869565233, \"y\": 7.391304347826086, \"x2\": -0.1449275362318847, \"y2\": 7.681159420289854, \"center_x\": -0.2898550724637685, \"center_y\": 7.53623188405797, \"value_uncond\": 0.003130161614131584}, {\"x\": -0.14492753623188293, \"y\": 7.391304347826086, \"x2\": 0.1449275362318847, \"y2\": 7.681159420289854, \"center_x\": 8.881784197001252e-16, \"center_y\": 7.53623188405797, \"value_uncond\": 0.003593922486952622}, {\"x\": 0.1449275362318847, \"y\": 7.391304347826086, \"x2\": 0.43478260869565233, \"y2\": 7.681159420289854, \"center_x\": 0.2898550724637685, \"center_y\": 7.53623188405797, \"value_uncond\": 0.004088052508777173}, {\"x\": 0.43478260869565233, \"y\": 7.391304347826086, \"x2\": 0.72463768115942, \"y2\": 7.681159420289854, \"center_x\": 0.5797101449275361, \"center_y\": 7.53623188405797, \"value_uncond\": 0.004606913302257929}, {\"x\": 0.72463768115942, \"y\": 7.391304347826086, \"x2\": 1.0144927536231876, \"y2\": 7.681159420289854, \"center_x\": 0.8695652173913038, \"center_y\": 7.53623188405797, \"value_uncond\": 0.00514338966350509}, {\"x\": 1.0144927536231894, \"y\": 7.391304347826086, \"x2\": 1.304347826086957, \"y2\": 7.681159420289854, \"center_x\": 1.1594202898550732, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0056889829307097284}, {\"x\": 1.304347826086957, \"y\": 7.391304347826086, \"x2\": 1.5942028985507246, \"y2\": 7.681159420289854, \"center_x\": 1.4492753623188408, \"center_y\": 7.53623188405797, \"value_uncond\": 0.00623398349645561}, {\"x\": 1.5942028985507246, \"y\": 7.391304347826086, \"x2\": 1.8840579710144922, \"y2\": 7.681159420289854, \"center_x\": 1.7391304347826084, \"center_y\": 7.53623188405797, \"value_uncond\": 0.006767721525037255}, {\"x\": 1.884057971014494, \"y\": 7.391304347826086, \"x2\": 2.1739130434782616, \"y2\": 7.681159420289854, \"center_x\": 2.028985507246378, \"center_y\": 7.53623188405797, \"value_uncond\": 0.007278889506506966}, {\"x\": 2.1739130434782616, \"y\": 7.391304347826086, \"x2\": 2.4637681159420293, \"y2\": 7.681159420289854, \"center_x\": 2.3188405797101455, \"center_y\": 7.53623188405797, \"value_uncond\": 0.007755924771063552}, {\"x\": 2.4637681159420293, \"y\": 7.391304347826086, \"x2\": 2.753623188405797, \"y2\": 7.681159420289854, \"center_x\": 2.608695652173913, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0081874349713912}, {\"x\": 2.753623188405797, \"y\": 7.391304347826086, \"x2\": 3.0434782608695645, \"y2\": 7.681159420289854, \"center_x\": 2.8985507246376807, \"center_y\": 7.53623188405797, \"value_uncond\": 0.008562645294301409}, {\"x\": 3.0434782608695663, \"y\": 7.391304347826086, \"x2\": 3.333333333333334, \"y2\": 7.681159420289854, \"center_x\": 3.18840579710145, \"center_y\": 7.53623188405797, \"value_uncond\": 0.008871843221503157}, {\"x\": 3.333333333333334, \"y\": 7.391304347826086, \"x2\": 3.6231884057971016, \"y2\": 7.681159420289854, \"center_x\": 3.4782608695652177, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0091067953658272}, {\"x\": 3.6231884057971016, \"y\": 7.391304347826086, \"x2\": 3.913043478260869, \"y2\": 7.681159420289854, \"center_x\": 3.7681159420289854, \"center_y\": 7.53623188405797, \"value_uncond\": 0.009261111473147477}, {\"x\": 3.913043478260871, \"y\": 7.391304347826086, \"x2\": 4.202898550724639, \"y2\": 7.681159420289854, \"center_x\": 4.057971014492755, \"center_y\": 7.53623188405797, \"value_uncond\": 0.009330533147259464}, {\"x\": 4.202898550724639, \"y\": 7.391304347826086, \"x2\": 4.492753623188406, \"y2\": 7.681159420289854, \"center_x\": 4.347826086956522, \"center_y\": 7.53623188405797, \"value_uncond\": 0.009313129094118662}, {\"x\": 4.492753623188406, \"y\": 7.391304347826086, \"x2\": 4.782608695652174, \"y2\": 7.681159420289854, \"center_x\": 4.63768115942029, \"center_y\": 7.53623188405797, \"value_uncond\": 0.009209384391785931}, {\"x\": 4.782608695652174, \"y\": 7.391304347826086, \"x2\": 5.0724637681159415, \"y2\": 7.681159420289854, \"center_x\": 4.927536231884058, \"center_y\": 7.53623188405797, \"value_uncond\": 0.009022178027074335}, {\"x\": 5.072463768115943, \"y\": 7.391304347826086, \"x2\": 5.362318840579711, \"y2\": 7.681159420289854, \"center_x\": 5.217391304347827, \"center_y\": 7.53623188405797, \"value_uncond\": 0.00875665015074523}, {\"x\": 5.362318840579711, \"y\": 7.391304347826086, \"x2\": 5.6521739130434785, \"y2\": 7.681159420289854, \"center_x\": 5.507246376811595, \"center_y\": 7.53623188405797, \"value_uncond\": 0.008419967593680685}, {\"x\": 5.6521739130434785, \"y\": 7.391304347826086, \"x2\": 5.942028985507246, \"y2\": 7.681159420289854, \"center_x\": 5.797101449275362, \"center_y\": 7.53623188405797, \"value_uncond\": 0.008021002572427181}, {\"x\": 5.942028985507246, \"y\": 7.391304347826086, \"x2\": 6.231884057971014, \"y2\": 7.681159420289854, \"center_x\": 6.08695652173913, \"center_y\": 7.53623188405797, \"value_uncond\": 0.007569944680339263}, {\"x\": 6.2318840579710155, \"y\": 7.391304347826086, \"x2\": 6.521739130434783, \"y2\": 7.681159420289854, \"center_x\": 6.376811594202899, \"center_y\": 7.53623188405797, \"value_uncond\": 0.00707786981783574}, {\"x\": 6.521739130434785, \"y\": 7.391304347826086, \"x2\": 6.8115942028985526, \"y2\": 7.681159420289854, \"center_x\": 6.666666666666669, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0065562914268104434}, {\"x\": 6.811594202898551, \"y\": 7.391304347826086, \"x2\": 7.101449275362318, \"y2\": 7.681159420289854, \"center_x\": 6.956521739130435, \"center_y\": 7.53623188405797, \"value_uncond\": 0.00601671920005302}, {\"x\": 7.10144927536232, \"y\": 7.391304347826086, \"x2\": 7.391304347826088, \"y2\": 7.681159420289854, \"center_x\": 7.246376811594204, \"center_y\": 7.53623188405797, \"value_uncond\": 0.005470248450373667}, {\"x\": 7.391304347826086, \"y\": 7.391304347826086, \"x2\": 7.681159420289854, \"y2\": 7.681159420289854, \"center_x\": 7.53623188405797, \"center_y\": 7.53623188405797, \"value_uncond\": 0.00492719981332962}, {\"x\": 7.681159420289855, \"y\": 7.391304347826086, \"x2\": 7.971014492753623, \"y2\": 7.681159420289854, \"center_x\": 7.826086956521739, \"center_y\": 7.53623188405797, \"value_uncond\": 0.004396824307575778}, {\"x\": 7.971014492753625, \"y\": 7.391304347826086, \"x2\": 8.260869565217392, \"y2\": 7.681159420289854, \"center_x\": 8.115942028985508, \"center_y\": 7.53623188405797, \"value_uncond\": 0.003887083446008268}, {\"x\": 8.26086956521739, \"y\": 7.391304347826086, \"x2\": 8.550724637681158, \"y2\": 7.681159420289854, \"center_x\": 8.405797101449274, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0034045085596694285}, {\"x\": 8.55072463768116, \"y\": 7.391304347826086, \"x2\": 8.840579710144928, \"y2\": 7.681159420289854, \"center_x\": 8.695652173913043, \"center_y\": 7.53623188405797, \"value_uncond\": 0.002954138219697305}, {\"x\": 8.84057971014493, \"y\": 7.391304347826086, \"x2\": 9.130434782608697, \"y2\": 7.681159420289854, \"center_x\": 8.985507246376812, \"center_y\": 7.53623188405797, \"value_uncond\": 0.002539528008263621}, {\"x\": 9.130434782608695, \"y\": 7.391304347826086, \"x2\": 9.420289855072463, \"y2\": 7.681159420289854, \"center_x\": 9.275362318840578, \"center_y\": 7.53623188405797, \"value_uncond\": 0.002162823188057047}, {\"x\": 9.420289855072465, \"y\": 7.391304347826086, \"x2\": 9.710144927536232, \"y2\": 7.681159420289854, \"center_x\": 9.565217391304348, \"center_y\": 7.53623188405797, \"value_uncond\": 0.0018248822279375043}, {\"x\": 9.710144927536234, \"y\": 7.391304347826086, \"x2\": 10.000000000000002, \"y2\": 7.681159420289854, \"center_x\": 9.855072463768117, \"center_y\": 7.53623188405797, \"value_uncond\": 0.001525437719179798}, {\"x\": 10.0, \"y\": 7.391304347826086, \"x2\": 10.289855072463768, \"y2\": 7.681159420289854, \"center_x\": 10.144927536231883, \"center_y\": 7.53623188405797, \"value_uncond\": 0.001263280913597526}, {\"x\": -10.0, \"y\": 7.681159420289855, \"x2\": -9.710144927536232, \"y2\": 7.971014492753623, \"center_x\": -9.855072463768117, \"center_y\": 7.826086956521739, \"value_uncond\": 1.5546888264731634e-07}, {\"x\": -9.710144927536232, \"y\": 7.681159420289855, \"x2\": -9.420289855072465, \"y2\": 7.971014492753623, \"center_x\": -9.565217391304348, \"center_y\": 7.826086956521739, \"value_uncond\": 2.4290337117625886e-07}, {\"x\": -9.420289855072463, \"y\": 7.681159420289855, \"x2\": -9.130434782608695, \"y2\": 7.971014492753623, \"center_x\": -9.275362318840578, \"center_y\": 7.826086956521739, \"value_uncond\": 3.7598405010178783e-07}, {\"x\": -9.130434782608695, \"y\": 7.681159420289855, \"x2\": -8.840579710144928, \"y2\": 7.971014492753623, \"center_x\": -8.985507246376812, \"center_y\": 7.826086956521739, \"value_uncond\": 5.765687711008647e-07}, {\"x\": -8.840579710144928, \"y\": 7.681159420289855, \"x2\": -8.55072463768116, \"y2\": 7.971014492753623, \"center_x\": -8.695652173913043, \"center_y\": 7.826086956521739, \"value_uncond\": 8.759486032096825e-07}, {\"x\": -8.55072463768116, \"y\": 7.681159420289855, \"x2\": -8.260869565217392, \"y2\": 7.971014492753623, \"center_x\": -8.405797101449277, \"center_y\": 7.826086956521739, \"value_uncond\": 1.3184144295520983e-06}, {\"x\": -8.26086956521739, \"y\": 7.681159420289855, \"x2\": -7.971014492753623, \"y2\": 7.971014492753623, \"center_x\": -8.115942028985508, \"center_y\": 7.826086956521739, \"value_uncond\": 1.965943739567227e-06}, {\"x\": -7.971014492753623, \"y\": 7.681159420289855, \"x2\": -7.681159420289855, \"y2\": 7.971014492753623, \"center_x\": -7.826086956521739, \"center_y\": 7.826086956521739, \"value_uncond\": 2.9042636382649264e-06}, {\"x\": -7.681159420289855, \"y\": 7.681159420289855, \"x2\": -7.391304347826088, \"y2\": 7.971014492753623, \"center_x\": -7.536231884057972, \"center_y\": 7.826086956521739, \"value_uncond\": 4.250566393509563e-06}, {\"x\": -7.391304347826087, \"y\": 7.681159420289855, \"x2\": -7.101449275362319, \"y2\": 7.971014492753623, \"center_x\": -7.246376811594203, \"center_y\": 7.826086956521739, \"value_uncond\": 6.163159191628511e-06}, {\"x\": -7.101449275362318, \"y\": 7.681159420289855, \"x2\": -6.811594202898551, \"y2\": 7.971014492753623, \"center_x\": -6.956521739130435, \"center_y\": 7.826086956521739, \"value_uncond\": 8.853312241759115e-06}, {\"x\": -6.811594202898551, \"y\": 7.681159420289855, \"x2\": -6.521739130434783, \"y2\": 7.971014492753623, \"center_x\": -6.666666666666667, \"center_y\": 7.826086956521739, \"value_uncond\": 1.2599519752427816e-05}, {\"x\": -6.521739130434782, \"y\": 7.681159420289855, \"x2\": -6.231884057971015, \"y2\": 7.971014492753623, \"center_x\": -6.3768115942028984, \"center_y\": 7.826086956521739, \"value_uncond\": 1.7764296637283633e-05}, {\"x\": -6.231884057971014, \"y\": 7.681159420289855, \"x2\": -5.942028985507246, \"y2\": 7.971014492753623, \"center_x\": -6.08695652173913, \"center_y\": 7.826086956521739, \"value_uncond\": 2.4813490246015368e-05}, {\"x\": -5.942028985507246, \"y\": 7.681159420289855, \"x2\": -5.6521739130434785, \"y2\": 7.971014492753623, \"center_x\": -5.797101449275362, \"center_y\": 7.826086956521739, \"value_uncond\": 3.43378824915426e-05}, {\"x\": -5.6521739130434785, \"y\": 7.681159420289855, \"x2\": -5.362318840579711, \"y2\": 7.971014492753623, \"center_x\": -5.507246376811595, \"center_y\": 7.826086956521739, \"value_uncond\": 4.707658799450714e-05}, {\"x\": -5.36231884057971, \"y\": 7.681159420289855, \"x2\": -5.072463768115942, \"y2\": 7.971014492753623, \"center_x\": -5.217391304347826, \"center_y\": 7.826086956521739, \"value_uncond\": 6.394141777973048e-05}, {\"x\": -5.0724637681159415, \"y\": 7.681159420289855, \"x2\": -4.782608695652174, \"y2\": 7.971014492753623, \"center_x\": -4.927536231884058, \"center_y\": 7.826086956521739, \"value_uncond\": 8.604098217792227e-05}, {\"x\": -4.782608695652174, \"y\": 7.681159420289855, \"x2\": -4.492753623188406, \"y2\": 7.971014492753623, \"center_x\": -4.63768115942029, \"center_y\": 7.826086956521739, \"value_uncond\": 0.00011470286653516983}, {\"x\": -4.492753623188405, \"y\": 7.681159420289855, \"x2\": -4.202898550724638, \"y2\": 7.971014492753623, \"center_x\": -4.3478260869565215, \"center_y\": 7.826086956521739, \"value_uncond\": 0.00015149175546875064}, {\"x\": -4.202898550724638, \"y\": 7.681159420289855, \"x2\": -3.91304347826087, \"y2\": 7.971014492753623, \"center_x\": -4.057971014492754, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0001982209436974218}, {\"x\": -3.913043478260869, \"y\": 7.681159420289855, \"x2\": -3.6231884057971016, \"y2\": 7.971014492753623, \"center_x\": -3.7681159420289854, \"center_y\": 7.826086956521739, \"value_uncond\": 0.00025695430320070645}, {\"x\": -3.6231884057971016, \"y\": 7.681159420289855, \"x2\": -3.333333333333334, \"y2\": 7.971014492753623, \"center_x\": -3.4782608695652177, \"center_y\": 7.826086956521739, \"value_uncond\": 0.00032999553637280677}, {\"x\": -3.333333333333333, \"y\": 7.681159420289855, \"x2\": -3.0434782608695654, \"y2\": 7.971014492753623, \"center_x\": -3.1884057971014492, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0004198614974519994}, {\"x\": -3.0434782608695645, \"y\": 7.681159420289855, \"x2\": -2.753623188405797, \"y2\": 7.971014492753623, \"center_x\": -2.8985507246376807, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0005292365744719645}, {\"x\": -2.753623188405797, \"y\": 7.681159420289855, \"x2\": -2.4637681159420293, \"y2\": 7.971014492753623, \"center_x\": -2.608695652173913, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0006609056486189536}, {\"x\": -2.4637681159420284, \"y\": 7.681159420289855, \"x2\": -2.1739130434782608, \"y2\": 7.971014492753623, \"center_x\": -2.3188405797101446, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0008176640283809533}, {\"x\": -2.1739130434782608, \"y\": 7.681159420289855, \"x2\": -1.8840579710144931, \"y2\": 7.971014492753623, \"center_x\": -2.028985507246377, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0010022040079425468}, {\"x\": -1.8840579710144922, \"y\": 7.681159420289855, \"x2\": -1.5942028985507246, \"y2\": 7.971014492753623, \"center_x\": -1.7391304347826084, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0012169793043008256}, {\"x\": -1.5942028985507246, \"y\": 7.681159420289855, \"x2\": -1.304347826086957, \"y2\": 7.971014492753623, \"center_x\": -1.4492753623188408, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0014640505256925686}, {\"x\": -1.304347826086957, \"y\": 7.681159420289855, \"x2\": -1.0144927536231894, \"y2\": 7.971014492753623, \"center_x\": -1.1594202898550732, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0017449169103885887}, {\"x\": -1.0144927536231876, \"y\": 7.681159420289855, \"x2\": -0.72463768115942, \"y2\": 7.971014492753623, \"center_x\": -0.8695652173913038, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0020603417010928485}, {\"x\": -0.72463768115942, \"y\": 7.681159420289855, \"x2\": -0.43478260869565233, \"y2\": 7.971014492753623, \"center_x\": -0.5797101449275361, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0024101805001465392}, {\"x\": -0.43478260869565233, \"y\": 7.681159420289855, \"x2\": -0.1449275362318847, \"y2\": 7.971014492753623, \"center_x\": -0.2898550724637685, \"center_y\": 7.826086956521739, \"value_uncond\": 0.002793223573848532}, {\"x\": -0.14492753623188293, \"y\": 7.681159420289855, \"x2\": 0.1449275362318847, \"y2\": 7.971014492753623, \"center_x\": 8.881784197001252e-16, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0032070641234048475}, {\"x\": 0.1449275362318847, \"y\": 7.681159420289855, \"x2\": 0.43478260869565233, \"y2\": 7.971014492753623, \"center_x\": 0.2898550724637685, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0036480048145421467}, {\"x\": 0.43478260869565233, \"y\": 7.681159420289855, \"x2\": 0.72463768115942, \"y2\": 7.971014492753623, \"center_x\": 0.5797101449275361, \"center_y\": 7.826086956521739, \"value_uncond\": 0.004111014198259955}, {\"x\": 0.72463768115942, \"y\": 7.681159420289855, \"x2\": 1.0144927536231876, \"y2\": 7.971014492753623, \"center_x\": 0.8695652173913038, \"center_y\": 7.826086956521739, \"value_uncond\": 0.004589742968136519}, {\"x\": 1.0144927536231894, \"y\": 7.681159420289855, \"x2\": 1.304347826086957, \"y2\": 7.971014492753623, \"center_x\": 1.1594202898550732, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0050766072785315055}, {\"x\": 1.304347826086957, \"y\": 7.681159420289855, \"x2\": 1.5942028985507246, \"y2\": 7.971014492753623, \"center_x\": 1.4492753623188408, \"center_y\": 7.826086956521739, \"value_uncond\": 0.005562942687262318}, {\"x\": 1.5942028985507246, \"y\": 7.681159420289855, \"x2\": 1.8840579710144922, \"y2\": 7.971014492753623, \"center_x\": 1.7391304347826084, \"center_y\": 7.826086956521739, \"value_uncond\": 0.006039227885113773}, {\"x\": 1.884057971014494, \"y\": 7.681159420289855, \"x2\": 2.1739130434782616, \"y2\": 7.971014492753623, \"center_x\": 2.028985507246378, \"center_y\": 7.826086956521739, \"value_uncond\": 0.006495372529400421}, {\"x\": 2.1739130434782616, \"y\": 7.681159420289855, \"x2\": 2.4637681159420293, \"y2\": 7.971014492753623, \"center_x\": 2.3188405797101455, \"center_y\": 7.826086956521739, \"value_uncond\": 0.006921058583596764}, {\"x\": 2.4637681159420293, \"y\": 7.681159420289855, \"x2\": 2.753623188405797, \"y2\": 7.971014492753623, \"center_x\": 2.608695652173913, \"center_y\": 7.826086956521739, \"value_uncond\": 0.007306119999745298}, {\"x\": 2.753623188405797, \"y\": 7.681159420289855, \"x2\": 3.0434782608695645, \"y2\": 7.971014492753623, \"center_x\": 2.8985507246376807, \"center_y\": 7.826086956521739, \"value_uncond\": 0.00764094179117375}, {\"x\": 3.0434782608695663, \"y\": 7.681159420289855, \"x2\": 3.333333333333334, \"y2\": 7.971014492753623, \"center_x\": 3.18840579710145, \"center_y\": 7.826086956521739, \"value_uncond\": 0.007916856918158218}, {\"x\": 3.333333333333334, \"y\": 7.681159420289855, \"x2\": 3.6231884057971016, \"y2\": 7.971014492753623, \"center_x\": 3.4782608695652177, \"center_y\": 7.826086956521739, \"value_uncond\": 0.008126518254904964}, {\"x\": 3.6231884057971016, \"y\": 7.681159420289855, \"x2\": 3.913043478260869, \"y2\": 7.971014492753623, \"center_x\": 3.7681159420289854, \"center_y\": 7.826086956521739, \"value_uncond\": 0.008264223409439334}, {\"x\": 3.913043478260871, \"y\": 7.681159420289855, \"x2\": 4.202898550724639, \"y2\": 7.971014492753623, \"center_x\": 4.057971014492755, \"center_y\": 7.826086956521739, \"value_uncond\": 0.008326172369451556}, {\"x\": 4.202898550724639, \"y\": 7.681159420289855, \"x2\": 4.492753623188406, \"y2\": 7.971014492753623, \"center_x\": 4.347826086956522, \"center_y\": 7.826086956521739, \"value_uncond\": 0.00831064172998108}, {\"x\": 4.492753623188406, \"y\": 7.681159420289855, \"x2\": 4.782608695652174, \"y2\": 7.971014492753623, \"center_x\": 4.63768115942029, \"center_y\": 7.826086956521739, \"value_uncond\": 0.008218064354132682}, {\"x\": 4.782608695652174, \"y\": 7.681159420289855, \"x2\": 5.0724637681159415, \"y2\": 7.971014492753623, \"center_x\": 4.927536231884058, \"center_y\": 7.826086956521739, \"value_uncond\": 0.008051009327732077}, {\"x\": 5.072463768115943, \"y\": 7.681159420289855, \"x2\": 5.362318840579711, \"y2\": 7.971014492753623, \"center_x\": 5.217391304347827, \"center_y\": 7.826086956521739, \"value_uncond\": 0.007814063503488377}, {\"x\": 5.362318840579711, \"y\": 7.681159420289855, \"x2\": 5.6521739130434785, \"y2\": 7.971014492753623, \"center_x\": 5.507246376811595, \"center_y\": 7.826086956521739, \"value_uncond\": 0.007513622257563381}, {\"x\": 5.6521739130434785, \"y\": 7.681159420289855, \"x2\": 5.942028985507246, \"y2\": 7.971014492753623, \"center_x\": 5.797101449275362, \"center_y\": 7.826086956521739, \"value_uncond\": 0.007157602780014635}, {\"x\": 5.942028985507246, \"y\": 7.681159420289855, \"x2\": 6.231884057971014, \"y2\": 7.971014492753623, \"center_x\": 6.08695652173913, \"center_y\": 7.826086956521739, \"value_uncond\": 0.00675509783213515}, {\"x\": 6.2318840579710155, \"y\": 7.681159420289855, \"x2\": 6.521739130434783, \"y2\": 7.971014492753623, \"center_x\": 6.376811594202899, \"center_y\": 7.826086956521739, \"value_uncond\": 0.00631599107808199}, {\"x\": 6.521739130434785, \"y\": 7.681159420289855, \"x2\": 6.8115942028985526, \"y2\": 7.971014492753623, \"center_x\": 6.666666666666669, \"center_y\": 7.826086956521739, \"value_uncond\": 0.005850556625482317}, {\"x\": 6.811594202898551, \"y\": 7.681159420289855, \"x2\": 7.101449275362318, \"y2\": 7.971014492753623, \"center_x\": 6.956521739130435, \"center_y\": 7.826086956521739, \"value_uncond\": 0.00536906523642159}, {\"x\": 7.10144927536232, \"y\": 7.681159420289855, \"x2\": 7.391304347826088, \"y2\": 7.971014492753623, \"center_x\": 7.246376811594204, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0048814178978522915}, {\"x\": 7.391304347826086, \"y\": 7.681159420289855, \"x2\": 7.681159420289854, \"y2\": 7.971014492753623, \"center_x\": 7.53623188405797, \"center_y\": 7.826086956521739, \"value_uncond\": 0.004396824307575778}, {\"x\": 7.681159420289855, \"y\": 7.681159420289855, \"x2\": 7.971014492753623, \"y2\": 7.971014492753623, \"center_x\": 7.826086956521739, \"center_y\": 7.826086956521739, \"value_uncond\": 0.003923539682598204}, {\"x\": 7.971014492753625, \"y\": 7.681159420289855, \"x2\": 8.260869565217392, \"y2\": 7.971014492753623, \"center_x\": 8.115942028985508, \"center_y\": 7.826086956521739, \"value_uncond\": 0.003468668539633514}, {\"x\": 8.26086956521739, \"y\": 7.681159420289855, \"x2\": 8.550724637681158, \"y2\": 7.971014492753623, \"center_x\": 8.405797101449274, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0030380391617178667}, {\"x\": 8.55072463768116, \"y\": 7.681159420289855, \"x2\": 8.840579710144928, \"y2\": 7.971014492753623, \"center_x\": 8.695652173913043, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0026361477562092976}, {\"x\": 8.84057971014493, \"y\": 7.681159420289855, \"x2\": 9.130434782608697, \"y2\": 7.971014492753623, \"center_x\": 8.985507246376812, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0022661671739586946}, {\"x\": 9.130434782608695, \"y\": 7.681159420289855, \"x2\": 9.420289855072463, \"y2\": 7.971014492753623, \"center_x\": 9.275362318840578, \"center_y\": 7.826086956521739, \"value_uncond\": 0.001930011756477064}, {\"x\": 9.420289855072465, \"y\": 7.681159420289855, \"x2\": 9.710144927536232, \"y2\": 7.971014492753623, \"center_x\": 9.565217391304348, \"center_y\": 7.826086956521739, \"value_uncond\": 0.0016284475649946393}, {\"x\": 9.710144927536234, \"y\": 7.681159420289855, \"x2\": 10.000000000000002, \"y2\": 7.971014492753623, \"center_x\": 9.855072463768117, \"center_y\": 7.826086956521739, \"value_uncond\": 0.001361235975297355}, {\"x\": 10.0, \"y\": 7.681159420289855, \"x2\": 10.289855072463768, \"y2\": 7.971014492753623, \"center_x\": 10.144927536231883, \"center_y\": 7.826086956521739, \"value_uncond\": 0.001127298351728233}, {\"x\": -10.0, \"y\": 7.971014492753625, \"x2\": -9.710144927536232, \"y2\": 8.260869565217392, \"center_x\": -9.855072463768117, \"center_y\": 8.115942028985508, \"value_uncond\": 1.3744477328023635e-07}, {\"x\": -9.710144927536232, \"y\": 7.971014492753625, \"x2\": -9.420289855072465, \"y2\": 8.260869565217392, \"center_x\": -9.565217391304348, \"center_y\": 8.115942028985508, \"value_uncond\": 2.1474264310538734e-07}, {\"x\": -9.420289855072463, \"y\": 7.971014492753625, \"x2\": -9.130434782608695, \"y2\": 8.260869565217392, \"center_x\": -9.275362318840578, \"center_y\": 8.115942028985508, \"value_uncond\": 3.32394763783409e-07}, {\"x\": -9.130434782608695, \"y\": 7.971014492753625, \"x2\": -8.840579710144928, \"y2\": 8.260869565217392, \"center_x\": -8.985507246376812, \"center_y\": 8.115942028985508, \"value_uncond\": 5.097249216371772e-07}, {\"x\": -8.840579710144928, \"y\": 7.971014492753625, \"x2\": -8.55072463768116, \"y2\": 8.260869565217392, \"center_x\": -8.695652173913043, \"center_y\": 8.115942028985508, \"value_uncond\": 7.74396490945468e-07}, {\"x\": -8.55072463768116, \"y\": 7.971014492753625, \"x2\": -8.260869565217392, \"y2\": 8.260869565217392, \"center_x\": -8.405797101449277, \"center_y\": 8.115942028985508, \"value_uncond\": 1.165565541306785e-06}, {\"x\": -8.26086956521739, \"y\": 7.971014492753625, \"x2\": -7.971014492753623, \"y2\": 8.260869565217392, \"center_x\": -8.115942028985508, \"center_y\": 8.115942028985508, \"value_uncond\": 1.7380242719019876e-06}, {\"x\": -7.971014492753623, \"y\": 7.971014492753625, \"x2\": -7.681159420289855, \"y2\": 8.260869565217392, \"center_x\": -7.826086956521739, \"center_y\": 8.115942028985508, \"value_uncond\": 2.567561112617595e-06}, {\"x\": -7.681159420289855, \"y\": 7.971014492753625, \"x2\": -7.391304347826088, \"y2\": 8.260869565217392, \"center_x\": -7.536231884057972, \"center_y\": 8.115942028985508, \"value_uncond\": 3.7577817780669465e-06}, {\"x\": -7.391304347826087, \"y\": 7.971014492753625, \"x2\": -7.101449275362319, \"y2\": 8.260869565217392, \"center_x\": -7.246376811594203, \"center_y\": 8.115942028985508, \"value_uncond\": 5.448640289677979e-06}, {\"x\": -7.101449275362318, \"y\": 7.971014492753625, \"x2\": -6.811594202898551, \"y2\": 8.260869565217392, \"center_x\": -6.956521739130435, \"center_y\": 8.115942028985508, \"value_uncond\": 7.826913483440587e-06}, {\"x\": -6.811594202898551, \"y\": 7.971014492753625, \"x2\": -6.521739130434783, \"y2\": 8.260869565217392, \"center_x\": -6.666666666666667, \"center_y\": 8.115942028985508, \"value_uncond\": 1.1138808656268394e-05}, {\"x\": -6.521739130434782, \"y\": 7.971014492753625, \"x2\": -6.231884057971015, \"y2\": 8.260869565217392, \"center_x\": -6.3768115942028984, \"center_y\": 8.115942028985508, \"value_uncond\": 1.5704812964618436e-05}, {\"x\": -6.231884057971014, \"y\": 7.971014492753625, \"x2\": -5.942028985507246, \"y2\": 8.260869565217392, \"center_x\": -6.08695652173913, \"center_y\": 8.115942028985508, \"value_uncond\": 2.1936766271689755e-05}, {\"x\": -5.942028985507246, \"y\": 7.971014492753625, \"x2\": -5.6521739130434785, \"y2\": 8.260869565217392, \"center_x\": -5.797101449275362, \"center_y\": 8.115942028985508, \"value_uncond\": 3.035695885638976e-05}, {\"x\": -5.6521739130434785, \"y\": 7.971014492753625, \"x2\": -5.362318840579711, \"y2\": 8.260869565217392, \"center_x\": -5.507246376811595, \"center_y\": 8.115942028985508, \"value_uncond\": 4.161881692036346e-05}, {\"x\": -5.36231884057971, \"y\": 7.971014492753625, \"x2\": -5.072463768115942, \"y2\": 8.260869565217392, \"center_x\": -5.217391304347826, \"center_y\": 8.115942028985508, \"value_uncond\": 5.652844170681143e-05}, {\"x\": -5.0724637681159415, \"y\": 7.971014492753625, \"x2\": -4.782608695652174, \"y2\": 8.260869565217392, \"center_x\": -4.927536231884058, \"center_y\": 8.115942028985508, \"value_uncond\": 7.606591805950384e-05}, {\"x\": -4.782608695652174, \"y\": 7.971014492753625, \"x2\": -4.492753623188406, \"y2\": 8.260869565217392, \"center_x\": -4.63768115942029, \"center_y\": 8.115942028985508, \"value_uncond\": 0.00010140491921642922}, {\"x\": -4.492753623188405, \"y\": 7.971014492753625, \"x2\": -4.202898550724638, \"y2\": 8.260869565217392, \"center_x\": -4.3478260869565215, \"center_y\": 8.115942028985508, \"value_uncond\": 0.00013392872985047388}, {\"x\": -4.202898550724638, \"y\": 7.971014492753625, \"x2\": -3.91304347826087, \"y2\": 8.260869565217392, \"center_x\": -4.057971014492754, \"center_y\": 8.115942028985508, \"value_uncond\": 0.00017524042240459845}, {\"x\": -3.913043478260869, \"y\": 7.971014492753625, \"x2\": -3.6231884057971016, \"y2\": 8.260869565217392, \"center_x\": -3.7681159420289854, \"center_y\": 8.115942028985508, \"value_uncond\": 0.00022716459619073407}, {\"x\": -3.6231884057971016, \"y\": 7.971014492753625, \"x2\": -3.333333333333334, \"y2\": 8.260869565217392, \"center_x\": -3.4782608695652177, \"center_y\": 8.115942028985508, \"value_uncond\": 0.00029173787646716157}, {\"x\": -3.333333333333333, \"y\": 7.971014492753625, \"x2\": -3.0434782608695654, \"y2\": 8.260869565217392, \"center_x\": -3.1884057971014492, \"center_y\": 8.115942028985508, \"value_uncond\": 0.00037118532881786785}, {\"x\": -3.0434782608695645, \"y\": 7.971014492753625, \"x2\": -2.753623188405797, \"y2\": 8.260869565217392, \"center_x\": -2.8985507246376807, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0004678801297808371}, {\"x\": -2.753623188405797, \"y\": 7.971014492753625, \"x2\": -2.4637681159420293, \"y2\": 8.260869565217392, \"center_x\": -2.608695652173913, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0005842842984864515}, {\"x\": -2.4637681159420284, \"y\": 7.971014492753625, \"x2\": -2.1739130434782608, \"y2\": 8.260869565217392, \"center_x\": -2.3188405797101446, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0007228690724893741}, {\"x\": -2.1739130434782608, \"y\": 7.971014492753625, \"x2\": -1.8840579710144931, \"y2\": 8.260869565217392, \"center_x\": -2.028985507246377, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0008860146178878153}, {\"x\": -1.8840579710144922, \"y\": 7.971014492753625, \"x2\": -1.5942028985507246, \"y2\": 8.260869565217392, \"center_x\": -1.7391304347826084, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0010758901827693436}, {\"x\": -1.5942028985507246, \"y\": 7.971014492753625, \"x2\": -1.304347826086957, \"y2\": 8.260869565217392, \"center_x\": -1.4492753623188408, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0012943174810814762}, {\"x\": -1.304347826086957, \"y\": 7.971014492753625, \"x2\": -1.0144927536231894, \"y2\": 8.260869565217392, \"center_x\": -1.1594202898550732, \"center_y\": 8.115942028985508, \"value_uncond\": 0.001542621938598914}, {\"x\": -1.0144927536231876, \"y\": 7.971014492753625, \"x2\": -0.72463768115942, \"y2\": 8.260869565217392, \"center_x\": -0.8695652173913038, \"center_y\": 8.115942028985508, \"value_uncond\": 0.001821478312344528}, {\"x\": -0.72463768115942, \"y\": 7.971014492753625, \"x2\": -0.43478260869565233, \"y2\": 8.260869565217392, \"center_x\": -0.5797101449275361, \"center_y\": 8.115942028985508, \"value_uncond\": 0.00213075894523904}, {\"x\": -0.43478260869565233, \"y\": 7.971014492753625, \"x2\": -0.1449275362318847, \"y2\": 8.260869565217392, \"center_x\": -0.2898550724637685, \"center_y\": 8.115942028985508, \"value_uncond\": 0.002469394352692033}, {\"x\": -0.14492753623188293, \"y\": 7.971014492753625, \"x2\": 0.1449275362318847, \"y2\": 8.260869565217392, \"center_x\": 8.881784197001252e-16, \"center_y\": 8.115942028985508, \"value_uncond\": 0.002835256765410144}, {\"x\": 0.1449275362318847, \"y\": 7.971014492753625, \"x2\": 0.43478260869565233, \"y2\": 8.260869565217392, \"center_x\": 0.2898550724637685, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0032250774953942927}, {\"x\": 0.43478260869565233, \"y\": 7.971014492753625, \"x2\": 0.72463768115942, \"y2\": 8.260869565217392, \"center_x\": 0.5797101449275361, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0036344084090027774}, {\"x\": 0.72463768115942, \"y\": 7.971014492753625, \"x2\": 1.0144927536231876, \"y2\": 8.260869565217392, \"center_x\": 0.8695652173913038, \"center_y\": 8.115942028985508, \"value_uncond\": 0.004057636299484735}, {\"x\": 1.0144927536231894, \"y\": 7.971014492753625, \"x2\": 1.304347826086957, \"y2\": 8.260869565217392, \"center_x\": 1.1594202898550732, \"center_y\": 8.115942028985508, \"value_uncond\": 0.004488056545781094}, {\"x\": 1.304347826086957, \"y\": 7.971014492753625, \"x2\": 1.5942028985507246, \"y2\": 8.260869565217392, \"center_x\": 1.4492753623188408, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0049180092080305235}, {\"x\": 1.5942028985507246, \"y\": 7.971014492753625, \"x2\": 1.8840579710144922, \"y2\": 8.260869565217392, \"center_x\": 1.7391304347826084, \"center_y\": 8.115942028985508, \"value_uncond\": 0.005339076819251023}, {\"x\": 1.884057971014494, \"y\": 7.971014492753625, \"x2\": 2.1739130434782616, \"y2\": 8.260869565217392, \"center_x\": 2.028985507246378, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0057423388492432005}, {\"x\": 2.1739130434782616, \"y\": 7.971014492753625, \"x2\": 2.4637681159420293, \"y2\": 8.260869565217392, \"center_x\": 2.3188405797101455, \"center_y\": 8.115942028985508, \"value_uncond\": 0.006118673471395866}, {\"x\": 2.4637681159420293, \"y\": 7.971014492753625, \"x2\": 2.753623188405797, \"y2\": 8.260869565217392, \"center_x\": 2.608695652173913, \"center_y\": 8.115942028985508, \"value_uncond\": 0.006459093227042803}, {\"x\": 2.753623188405797, \"y\": 7.971014492753625, \"x2\": 3.0434782608695645, \"y2\": 8.260869565217392, \"center_x\": 2.8985507246376807, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0067550978321351445}, {\"x\": 3.0434782608695663, \"y\": 7.971014492753625, \"x2\": 3.333333333333334, \"y2\": 8.260869565217392, \"center_x\": 3.18840579710145, \"center_y\": 8.115942028985508, \"value_uncond\": 0.006999025050413267}, {\"x\": 3.333333333333334, \"y\": 7.971014492753625, \"x2\": 3.6231884057971016, \"y2\": 8.260869565217392, \"center_x\": 3.4782608695652177, \"center_y\": 8.115942028985508, \"value_uncond\": 0.007184379536816565}, {\"x\": 3.6231884057971016, \"y\": 7.971014492753625, \"x2\": 3.913043478260869, \"y2\": 8.260869565217392, \"center_x\": 3.7681159420289854, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0073061199997452924}, {\"x\": 3.913043478260871, \"y\": 7.971014492753625, \"x2\": 4.202898550724639, \"y2\": 8.260869565217392, \"center_x\": 4.057971014492755, \"center_y\": 8.115942028985508, \"value_uncond\": 0.007360886977026152}, {\"x\": 4.202898550724639, \"y\": 7.971014492753625, \"x2\": 4.492753623188406, \"y2\": 8.260869565217392, \"center_x\": 4.347826086956522, \"center_y\": 8.115942028985508, \"value_uncond\": 0.007347156864706769}, {\"x\": 4.492753623188406, \"y\": 7.971014492753625, \"x2\": 4.782608695652174, \"y2\": 8.260869565217392, \"center_x\": 4.63768115942029, \"center_y\": 8.115942028985508, \"value_uncond\": 0.00726531234239662}, {\"x\": 4.782608695652174, \"y\": 7.971014492753625, \"x2\": 5.0724637681159415, \"y2\": 8.260869565217392, \"center_x\": 4.927536231884058, \"center_y\": 8.115942028985508, \"value_uncond\": 0.007117624651857015}, {\"x\": 5.072463768115943, \"y\": 7.971014492753625, \"x2\": 5.362318840579711, \"y2\": 8.260869565217392, \"center_x\": 5.217391304347827, \"center_y\": 8.115942028985508, \"value_uncond\": 0.006908148874207331}, {\"x\": 5.362318840579711, \"y\": 7.971014492753625, \"x2\": 5.6521739130434785, \"y2\": 8.260869565217392, \"center_x\": 5.507246376811595, \"center_y\": 8.115942028985508, \"value_uncond\": 0.00664253894489518}, {\"x\": 5.6521739130434785, \"y\": 7.971014492753625, \"x2\": 5.942028985507246, \"y2\": 8.260869565217392, \"center_x\": 5.797101449275362, \"center_y\": 8.115942028985508, \"value_uncond\": 0.006327794183488224}, {\"x\": 5.942028985507246, \"y\": 7.971014492753625, \"x2\": 6.231884057971014, \"y2\": 8.260869565217392, \"center_x\": 6.08695652173913, \"center_y\": 8.115942028985508, \"value_uncond\": 0.005971953192265764}, {\"x\": 6.2318840579710155, \"y\": 7.971014492753625, \"x2\": 6.521739130434783, \"y2\": 8.260869565217392, \"center_x\": 6.376811594202899, \"center_y\": 8.115942028985508, \"value_uncond\": 0.005583753783940637}, {\"x\": 6.521739130434785, \"y\": 7.971014492753625, \"x2\": 6.8115942028985526, \"y2\": 8.260869565217392, \"center_x\": 6.666666666666669, \"center_y\": 8.115942028985508, \"value_uncond\": 0.005172278949072917}, {\"x\": 6.811594202898551, \"y\": 7.971014492753625, \"x2\": 7.101449275362318, \"y2\": 8.260869565217392, \"center_x\": 6.956521739130435, \"center_y\": 8.115942028985508, \"value_uncond\": 0.004746608720542592}, {\"x\": 7.10144927536232, \"y\": 7.971014492753625, \"x2\": 7.391304347826088, \"y2\": 8.260869565217392, \"center_x\": 7.246376811594204, \"center_y\": 8.115942028985508, \"value_uncond\": 0.004315496225559179}, {\"x\": 7.391304347826086, \"y\": 7.971014492753625, \"x2\": 7.681159420289854, \"y2\": 8.260869565217392, \"center_x\": 7.53623188405797, \"center_y\": 8.115942028985508, \"value_uncond\": 0.003887083446008268}, {\"x\": 7.681159420289855, \"y\": 7.971014492753625, \"x2\": 7.971014492753623, \"y2\": 8.260869565217392, \"center_x\": 7.826086956521739, \"center_y\": 8.115942028985508, \"value_uncond\": 0.003468668539633514}, {\"x\": 7.971014492753625, \"y\": 7.971014492753625, \"x2\": 8.260869565217392, \"y2\": 8.260869565217392, \"center_x\": 8.115942028985508, \"center_y\": 8.115942028985508, \"value_uncond\": 0.003066532369025466}, {\"x\": 8.26086956521739, \"y\": 7.971014492753625, \"x2\": 8.550724637681158, \"y2\": 8.260869565217392, \"center_x\": 8.405797101449274, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0026858275218073005}, {\"x\": 8.55072463768116, \"y\": 7.971014492753625, \"x2\": 8.840579710144928, \"y2\": 8.260869565217392, \"center_x\": 8.695652173913043, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0023305289426137467}, {\"x\": 8.84057971014493, \"y\": 7.971014492753625, \"x2\": 9.130434782608697, \"y2\": 8.260869565217392, \"center_x\": 8.985507246376812, \"center_y\": 8.115942028985508, \"value_uncond\": 0.002003441641414816}, {\"x\": 9.130434782608695, \"y\": 7.971014492753625, \"x2\": 9.420289855072463, \"y2\": 8.260869565217392, \"center_x\": 9.275362318840578, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0017062580226999524}, {\"x\": 9.420289855072465, \"y\": 7.971014492753625, \"x2\": 9.710144927536232, \"y2\": 8.260869565217392, \"center_x\": 9.565217391304348, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0014396553352556355}, {\"x\": 9.710144927536234, \"y\": 7.971014492753625, \"x2\": 10.000000000000002, \"y2\": 8.260869565217392, \"center_x\": 9.855072463768117, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0012034226194966226}, {\"x\": 10.0, \"y\": 7.971014492753625, \"x2\": 10.289855072463768, \"y2\": 8.260869565217392, \"center_x\": 10.144927536231883, \"center_y\": 8.115942028985508, \"value_uncond\": 0.0009966062901729214}, {\"x\": -10.0, \"y\": 8.26086956521739, \"x2\": -9.710144927536232, \"y2\": 8.550724637681158, \"center_x\": -9.855072463768117, \"center_y\": 8.405797101449274, \"value_uncond\": 1.203812353436658e-07}, {\"x\": -9.710144927536232, \"y\": 8.26086956521739, \"x2\": -9.420289855072465, \"y2\": 8.550724637681158, \"center_x\": -9.565217391304348, \"center_y\": 8.405797101449274, \"value_uncond\": 1.880827043548819e-07}, {\"x\": -9.420289855072463, \"y\": 8.26086956521739, \"x2\": -9.130434782608695, \"y2\": 8.550724637681158, \"center_x\": -9.275362318840578, \"center_y\": 8.405797101449274, \"value_uncond\": 2.911285116999536e-07}, {\"x\": -9.130434782608695, \"y\": 8.26086956521739, \"x2\": -8.840579710144928, \"y2\": 8.550724637681158, \"center_x\": -8.985507246376812, \"center_y\": 8.405797101449274, \"value_uncond\": 4.4644342805984316e-07}, {\"x\": -8.840579710144928, \"y\": 8.26086956521739, \"x2\": -8.55072463768116, \"y2\": 8.550724637681158, \"center_x\": -8.695652173913043, \"center_y\": 8.405797101449274, \"value_uncond\": 6.782564662225695e-07}, {\"x\": -8.55072463768116, \"y\": 8.26086956521739, \"x2\": -8.260869565217392, \"y2\": 8.550724637681158, \"center_x\": -8.405797101449277, \"center_y\": 8.405797101449274, \"value_uncond\": 1.020862535459508e-06}, {\"x\": -8.26086956521739, \"y\": 8.26086956521739, \"x2\": -7.971014492753623, \"y2\": 8.550724637681158, \"center_x\": -8.115942028985508, \"center_y\": 8.405797101449274, \"value_uncond\": 1.5222514753780152e-06}, {\"x\": -7.971014492753623, \"y\": 8.26086956521739, \"x2\": -7.681159420289855, \"y2\": 8.550724637681158, \"center_x\": -7.826086956521739, \"center_y\": 8.405797101449274, \"value_uncond\": 2.248802709485845e-06}, {\"x\": -7.681159420289855, \"y\": 8.26086956521739, \"x2\": -7.391304347826088, \"y2\": 8.550724637681158, \"center_x\": -7.536231884057972, \"center_y\": 8.405797101449274, \"value_uncond\": 3.291259476802988e-06}, {\"x\": -7.391304347826087, \"y\": 8.26086956521739, \"x2\": -7.101449275362319, \"y2\": 8.550724637681158, \"center_x\": -7.246376811594203, \"center_y\": 8.405797101449274, \"value_uncond\": 4.772200741874412e-06}, {\"x\": -7.101449275362318, \"y\": 8.26086956521739, \"x2\": -6.811594202898551, \"y2\": 8.550724637681158, \"center_x\": -6.956521739130435, \"center_y\": 8.405797101449274, \"value_uncond\": 6.855215309959383e-06}, {\"x\": -6.811594202898551, \"y\": 8.26086956521739, \"x2\": -6.521739130434783, \"y2\": 8.550724637681158, \"center_x\": -6.666666666666667, \"center_y\": 8.405797101449274, \"value_uncond\": 9.755944255256153e-06}, {\"x\": -6.521739130434782, \"y\": 8.26086956521739, \"x2\": -6.231884057971015, \"y2\": 8.550724637681158, \"center_x\": -6.3768115942028984, \"center_y\": 8.405797101449274, \"value_uncond\": 1.375508679160399e-05}, {\"x\": -6.231884057971014, \"y\": 8.26086956521739, \"x2\": -5.942028985507246, \"y2\": 8.550724637681158, \"center_x\": -6.08695652173913, \"center_y\": 8.405797101449274, \"value_uncond\": 1.921335355435446e-05}, {\"x\": -5.942028985507246, \"y\": 8.26086956521739, \"x2\": -5.6521739130434785, \"y2\": 8.550724637681158, \"center_x\": -5.797101449275362, \"center_y\": 8.405797101449274, \"value_uncond\": 2.658819336082033e-05}, {\"x\": -5.6521739130434785, \"y\": 8.26086956521739, \"x2\": -5.362318840579711, \"y2\": 8.550724637681158, \"center_x\": -5.507246376811595, \"center_y\": 8.405797101449274, \"value_uncond\": 3.645191064632239e-05}, {\"x\": -5.36231884057971, \"y\": 8.26086956521739, \"x2\": -5.072463768115942, \"y2\": 8.550724637681158, \"center_x\": -5.217391304347826, \"center_y\": 8.405797101449274, \"value_uncond\": 4.9510530537554236e-05}, {\"x\": -5.0724637681159415, \"y\": 8.26086956521739, \"x2\": -4.782608695652174, \"y2\": 8.550724637681158, \"center_x\": -4.927536231884058, \"center_y\": 8.405797101449274, \"value_uncond\": 6.662246198975567e-05}, {\"x\": -4.782608695652174, \"y\": 8.26086956521739, \"x2\": -4.492753623188406, \"y2\": 8.550724637681158, \"center_x\": -4.63768115942029, \"center_y\": 8.405797101449274, \"value_uncond\": 8.881566867813159e-05}, {\"x\": -4.492753623188405, \"y\": 8.26086956521739, \"x2\": -4.202898550724638, \"y2\": 8.550724637681158, \"center_x\": -4.3478260869565215, \"center_y\": 8.405797101449274, \"value_uncond\": 0.00011730170280492166}, {\"x\": -4.202898550724638, \"y\": 8.26086956521739, \"x2\": -3.91304347826087, \"y2\": 8.550724637681158, \"center_x\": -4.057971014492754, \"center_y\": 8.405797101449274, \"value_uncond\": 0.00015348461805964338}, {\"x\": -3.913043478260869, \"y\": 8.26086956521739, \"x2\": -3.6231884057971016, \"y2\": 8.550724637681158, \"center_x\": -3.7681159420289854, \"center_y\": 8.405797101449274, \"value_uncond\": 0.00019896249281177862}, {\"x\": -3.6231884057971016, \"y\": 8.26086956521739, \"x2\": -3.333333333333334, \"y2\": 8.550724637681158, \"center_x\": -3.4782608695652177, \"center_y\": 8.405797101449274, \"value_uncond\": 0.000255519108711751}, {\"x\": -3.333333333333333, \"y\": 8.26086956521739, \"x2\": -3.0434782608695654, \"y2\": 8.550724637681158, \"center_x\": -3.1884057971014492, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0003251032931855033}, {\"x\": -3.0434782608695645, \"y\": 8.26086956521739, \"x2\": -2.753623188405797, \"y2\": 8.550724637681158, \"center_x\": -2.8985507246376807, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0004097935968866038}, {\"x\": -2.753623188405797, \"y\": 8.26086956521739, \"x2\": -2.4637681159420293, \"y2\": 8.550724637681158, \"center_x\": -2.608695652173913, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0005117463834022718}, {\"x\": -2.4637681159420284, \"y\": 8.26086956521739, \"x2\": -2.1739130434782608, \"y2\": 8.550724637681158, \"center_x\": -2.3188405797101446, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0006331260902921042}, {\"x\": -2.1739130434782608, \"y\": 8.26086956521739, \"x2\": -1.8840579710144931, \"y2\": 8.550724637681158, \"center_x\": -2.028985507246377, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0007760173900277234}, {\"x\": -1.8840579710144922, \"y\": 8.26086956521739, \"x2\": -1.5942028985507246, \"y2\": 8.550724637681158, \"center_x\": -1.7391304347826084, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0009423202221871583}, {\"x\": -1.5942028985507246, \"y\": 8.26086956521739, \"x2\": -1.304347826086957, \"y2\": 8.550724637681158, \"center_x\": -1.4492753623188408, \"center_y\": 8.405797101449274, \"value_uncond\": 0.001133630137988626}, {\"x\": -1.304347826086957, \"y\": 8.26086956521739, \"x2\": -1.0144927536231894, \"y2\": 8.550724637681158, \"center_x\": -1.1594202898550732, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0013511080138212909}, {\"x\": -1.0144927536231876, \"y\": 8.26086956521739, \"x2\": -0.72463768115942, \"y2\": 8.550724637681158, \"center_x\": -0.8695652173913038, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0015953448367560417}, {\"x\": -0.72463768115942, \"y\": 8.26086956521739, \"x2\": -0.43478260869565233, \"y2\": 8.550724637681158, \"center_x\": -0.5797101449275361, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0018662287981257527}, {\"x\": -0.43478260869565233, \"y\": 8.26086956521739, \"x2\": -0.1449275362318847, \"y2\": 8.550724637681158, \"center_x\": -0.2898550724637685, \"center_y\": 8.405797101449274, \"value_uncond\": 0.002162823188057046}, {\"x\": -0.14492753623188293, \"y\": 8.26086956521739, \"x2\": 0.1449275362318847, \"y2\": 8.550724637681158, \"center_x\": 8.881784197001252e-16, \"center_y\": 8.405797101449274, \"value_uncond\": 0.002483264396243414}, {\"x\": 0.1449275362318847, \"y\": 8.26086956521739, \"x2\": 0.43478260869565233, \"y2\": 8.550724637681158, \"center_x\": 0.2898550724637685, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0028246895368151965}, {\"x\": 0.43478260869565233, \"y\": 8.26086956521739, \"x2\": 0.72463768115942, \"y2\": 8.550724637681158, \"center_x\": 0.5797101449275361, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0031832027044572447}, {\"x\": 0.72463768115942, \"y\": 8.26086956521739, \"x2\": 1.0144927536231876, \"y2\": 8.550724637681158, \"center_x\": 0.8695652173913038, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0035538875626164724}, {\"x\": 1.0144927536231894, \"y\": 8.26086956521739, \"x2\": 1.304347826086957, \"y2\": 8.550724637681158, \"center_x\": 1.1594202898550732, \"center_y\": 8.405797101449274, \"value_uncond\": 0.003930871857686288}, {\"x\": 1.304347826086957, \"y\": 8.26086956521739, \"x2\": 1.5942028985507246, \"y2\": 8.550724637681158, \"center_x\": 1.4492753623188408, \"center_y\": 8.405797101449274, \"value_uncond\": 0.004307446618483881}, {\"x\": 1.5942028985507246, \"y\": 8.26086956521739, \"x2\": 1.8840579710144922, \"y2\": 8.550724637681158, \"center_x\": 1.7391304347826084, \"center_y\": 8.405797101449274, \"value_uncond\": 0.004676239392426481}, {\"x\": 1.884057971014494, \"y\": 8.26086956521739, \"x2\": 2.1739130434782616, \"y2\": 8.550724637681158, \"center_x\": 2.028985507246378, \"center_y\": 8.405797101449274, \"value_uncond\": 0.005029437118168106}, {\"x\": 2.1739130434782616, \"y\": 8.26086956521739, \"x2\": 2.4637681159420293, \"y2\": 8.550724637681158, \"center_x\": 2.3188405797101455, \"center_y\": 8.405797101449274, \"value_uncond\": 0.005359050428562672}, {\"x\": 2.4637681159420293, \"y\": 8.26086956521739, \"x2\": 2.753623188405797, \"y2\": 8.550724637681158, \"center_x\": 2.608695652173913, \"center_y\": 8.405797101449274, \"value_uncond\": 0.005657207642854211}, {\"x\": 2.753623188405797, \"y\": 8.26086956521739, \"x2\": 3.0434782608695645, \"y2\": 8.550724637681158, \"center_x\": 2.8985507246376807, \"center_y\": 8.405797101449274, \"value_uncond\": 0.005916463772992945}, {\"x\": 3.0434782608695663, \"y\": 8.26086956521739, \"x2\": 3.333333333333334, \"y2\": 8.550724637681158, \"center_x\": 3.18840579710145, \"center_y\": 8.405797101449274, \"value_uncond\": 0.00613010783649177}, {\"x\": 3.333333333333334, \"y\": 8.26086956521739, \"x2\": 3.6231884057971016, \"y2\": 8.550724637681158, \"center_x\": 3.4782608695652177, \"center_y\": 8.405797101449274, \"value_uncond\": 0.006292450874478565}, {\"x\": 3.6231884057971016, \"y\": 8.26086956521739, \"x2\": 3.913043478260869, \"y2\": 8.550724637681158, \"center_x\": 3.7681159420289854, \"center_y\": 8.405797101449274, \"value_uncond\": 0.006399077463245162}, {\"x\": 3.913043478260871, \"y\": 8.26086956521739, \"x2\": 4.202898550724639, \"y2\": 8.550724637681158, \"center_x\": 4.057971014492755, \"center_y\": 8.405797101449274, \"value_uncond\": 0.006447045212209076}, {\"x\": 4.202898550724639, \"y\": 8.26086956521739, \"x2\": 4.492753623188406, \"y2\": 8.550724637681158, \"center_x\": 4.347826086956522, \"center_y\": 8.405797101449274, \"value_uncond\": 0.006435019670291634}, {\"x\": 4.492753623188406, \"y\": 8.26086956521739, \"x2\": 4.782608695652174, \"y2\": 8.550724637681158, \"center_x\": 4.63768115942029, \"center_y\": 8.405797101449274, \"value_uncond\": 0.00636333600807103}, {\"x\": 4.782608695652174, \"y\": 8.26086956521739, \"x2\": 5.0724637681159415, \"y2\": 8.550724637681158, \"center_x\": 4.927536231884058, \"center_y\": 8.405797101449274, \"value_uncond\": 0.00623398349645561}, {\"x\": 5.072463768115943, \"y\": 8.26086956521739, \"x2\": 5.362318840579711, \"y2\": 8.550724637681158, \"center_x\": 5.217391304347827, \"center_y\": 8.405797101449274, \"value_uncond\": 0.006050513785049202}, {\"x\": 5.362318840579711, \"y\": 8.26086956521739, \"x2\": 5.6521739130434785, \"y2\": 8.550724637681158, \"center_x\": 5.507246376811595, \"center_y\": 8.405797101449274, \"value_uncond\": 0.005817878882702297}, {\"x\": 5.6521739130434785, \"y\": 8.26086956521739, \"x2\": 5.942028985507246, \"y2\": 8.550724637681158, \"center_x\": 5.797101449275362, \"center_y\": 8.405797101449274, \"value_uncond\": 0.005542209155204808}, {\"x\": 5.942028985507246, \"y\": 8.26086956521739, \"x2\": 6.231884057971014, \"y2\": 8.550724637681158, \"center_x\": 6.08695652173913, \"center_y\": 8.405797101449274, \"value_uncond\": 0.00523054522585382}, {\"x\": 6.2318840579710155, \"y\": 8.26086956521739, \"x2\": 6.521739130434783, \"y2\": 8.550724637681158, \"center_x\": 6.376811594202899, \"center_y\": 8.405797101449274, \"value_uncond\": 0.004890540122578068}, {\"x\": 6.521739130434785, \"y\": 8.26086956521739, \"x2\": 6.8115942028985526, \"y2\": 8.550724637681158, \"center_x\": 6.666666666666669, \"center_y\": 8.405797101449274, \"value_uncond\": 0.004530149197903092}, {\"x\": 6.811594202898551, \"y\": 8.26086956521739, \"x2\": 7.101449275362318, \"y2\": 8.550724637681158, \"center_x\": 6.956521739130435, \"center_y\": 8.405797101449274, \"value_uncond\": 0.004157325213865356}, {\"x\": 7.10144927536232, \"y\": 8.26086956521739, \"x2\": 7.391304347826088, \"y2\": 8.550724637681158, \"center_x\": 7.246376811594204, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0037797346116212206}, {\"x\": 7.391304347826086, \"y\": 8.26086956521739, \"x2\": 7.681159420289854, \"y2\": 8.550724637681158, \"center_x\": 7.53623188405797, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0034045085596694285}, {\"x\": 7.681159420289855, \"y\": 8.26086956521739, \"x2\": 7.971014492753623, \"y2\": 8.550724637681158, \"center_x\": 7.826086956521739, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0030380391617178667}, {\"x\": 7.971014492753625, \"y\": 8.26086956521739, \"x2\": 8.260869565217392, \"y2\": 8.550724637681158, \"center_x\": 8.115942028985508, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0026858275218073005}, {\"x\": 8.26086956521739, \"y\": 8.26086956521739, \"x2\": 8.550724637681158, \"y2\": 8.550724637681158, \"center_x\": 8.405797101449274, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0023523865424548013}, {\"x\": 8.55072463768116, \"y\": 8.26086956521739, \"x2\": 8.840579710144928, \"y2\": 8.550724637681158, \"center_x\": 8.695652173913043, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0020411976855896304}, {\"x\": 8.84057971014493, \"y\": 8.26086956521739, \"x2\": 9.130434782608697, \"y2\": 8.550724637681158, \"center_x\": 8.985507246376812, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0017547177239015214}, {\"x\": 9.130434782608695, \"y\": 8.26086956521739, \"x2\": 9.420289855072463, \"y2\": 8.550724637681158, \"center_x\": 9.275362318840578, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0014944289527028252}, {\"x\": 9.420289855072465, \"y\": 8.26086956521739, \"x2\": 9.710144927536232, \"y2\": 8.550724637681158, \"center_x\": 9.565217391304348, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0012609245414797678}, {\"x\": 9.710144927536234, \"y\": 8.26086956521739, \"x2\": 10.000000000000002, \"y2\": 8.550724637681158, \"center_x\": 9.855072463768117, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0010540197209255755}, {\"x\": 10.0, \"y\": 8.26086956521739, \"x2\": 10.289855072463768, \"y2\": 8.550724637681158, \"center_x\": 10.144927536231883, \"center_y\": 8.405797101449274, \"value_uncond\": 0.0008728792917986891}, {\"x\": -10.0, \"y\": 8.55072463768116, \"x2\": -9.710144927536232, \"y2\": 8.840579710144928, \"center_x\": -9.855072463768117, \"center_y\": 8.695652173913043, \"value_uncond\": 1.0445642947586815e-07}, {\"x\": -9.710144927536232, \"y\": 8.55072463768116, \"x2\": -9.420289855072465, \"y2\": 8.840579710144928, \"center_x\": -9.565217391304348, \"center_y\": 8.695652173913043, \"value_uncond\": 1.6320191171812923e-07}, {\"x\": -9.420289855072463, \"y\": 8.55072463768116, \"x2\": -9.130434782608695, \"y2\": 8.840579710144928, \"center_x\": -9.275362318840578, \"center_y\": 8.695652173913043, \"value_uncond\": 2.5261615536661616e-07}, {\"x\": -9.130434782608695, \"y\": 8.55072463768116, \"x2\": -8.840579710144928, \"y2\": 8.840579710144928, \"center_x\": -8.985507246376812, \"center_y\": 8.695652173913043, \"value_uncond\": 3.873850133284215e-07}, {\"x\": -8.840579710144928, \"y\": 8.55072463768116, \"x2\": -8.55072463768116, \"y2\": 8.840579710144928, \"center_x\": -8.695652173913043, \"center_y\": 8.695652173913043, \"value_uncond\": 5.885323283838296e-07}, {\"x\": -8.55072463768116, \"y\": 8.55072463768116, \"x2\": -8.260869565217392, \"y2\": 8.840579710144928, \"center_x\": -8.405797101449277, \"center_y\": 8.695652173913043, \"value_uncond\": 8.858162581182798e-07}, {\"x\": -8.26086956521739, \"y\": 8.55072463768116, \"x2\": -7.971014492753623, \"y2\": 8.840579710144928, \"center_x\": -8.115942028985508, \"center_y\": 8.695652173913043, \"value_uncond\": 1.3208782367818309e-06}, {\"x\": -7.971014492753623, \"y\": 8.55072463768116, \"x2\": -7.681159420289855, \"y2\": 8.840579710144928, \"center_x\": -7.826086956521739, \"center_y\": 8.695652173913043, \"value_uncond\": 1.9513165898152533e-06}, {\"x\": -7.681159420289855, \"y\": 8.55072463768116, \"x2\": -7.391304347826088, \"y2\": 8.840579710144928, \"center_x\": -7.536231884057972, \"center_y\": 8.695652173913043, \"value_uncond\": 2.8558704555904338e-06}, {\"x\": -7.391304347826087, \"y\": 8.55072463768116, \"x2\": -7.101449275362319, \"y2\": 8.840579710144928, \"center_x\": -7.246376811594203, \"center_y\": 8.695652173913043, \"value_uncond\": 4.140903262997788e-06}, {\"x\": -7.101449275362318, \"y\": 8.55072463768116, \"x2\": -6.811594202898551, \"y2\": 8.840579710144928, \"center_x\": -6.956521739130435, \"center_y\": 8.695652173913043, \"value_uncond\": 5.948363235535961e-06}, {\"x\": -6.811594202898551, \"y\": 8.55072463768116, \"x2\": -6.521739130434783, \"y2\": 8.840579710144928, \"center_x\": -6.666666666666667, \"center_y\": 8.695652173913043, \"value_uncond\": 8.465365055944217e-06}, {\"x\": -6.521739130434782, \"y\": 8.55072463768116, \"x2\": -6.231884057971015, \"y2\": 8.840579710144928, \"center_x\": -6.3768115942028984, \"center_y\": 8.695652173913043, \"value_uncond\": 1.1935475236483604e-05}, {\"x\": -6.231884057971014, \"y\": 8.55072463768116, \"x2\": -5.942028985507246, \"y2\": 8.840579710144928, \"center_x\": -6.08695652173913, \"center_y\": 8.695652173913043, \"value_uncond\": 1.6671687284283626e-05}, {\"x\": -5.942028985507246, \"y\": 8.55072463768116, \"x2\": -5.6521739130434785, \"y2\": 8.840579710144928, \"center_x\": -5.797101449275362, \"center_y\": 8.695652173913043, \"value_uncond\": 2.3070935738087277e-05}, {\"x\": -5.6521739130434785, \"y\": 8.55072463768116, \"x2\": -5.362318840579711, \"y2\": 8.840579710144928, \"center_x\": -5.507246376811595, \"center_y\": 8.695652173913043, \"value_uncond\": 3.1629816913060714e-05}, {\"x\": -5.36231884057971, \"y\": 8.55072463768116, \"x2\": -5.072463768115942, \"y2\": 8.840579710144928, \"center_x\": -5.217391304347826, \"center_y\": 8.695652173913043, \"value_uncond\": 4.296095838063664e-05}, {\"x\": -5.0724637681159415, \"y\": 8.55072463768116, \"x2\": -4.782608695652174, \"y2\": 8.840579710144928, \"center_x\": -4.927536231884058, \"center_y\": 8.695652173913043, \"value_uncond\": 5.780921322558761e-05}, {\"x\": -4.782608695652174, \"y\": 8.55072463768116, \"x2\": -4.492753623188406, \"y2\": 8.840579710144928, \"center_x\": -4.63768115942029, \"center_y\": 8.695652173913043, \"value_uncond\": 7.706655946123317e-05}, {\"x\": -4.492753623188405, \"y\": 8.55072463768116, \"x2\": -4.202898550724638, \"y2\": 8.840579710144928, \"center_x\": -4.3478260869565215, \"center_y\": 8.695652173913043, \"value_uncond\": 0.00010178427735403919}, {\"x\": -4.202898550724638, \"y\": 8.55072463768116, \"x2\": -3.91304347826087, \"y2\": 8.840579710144928, \"center_x\": -4.057971014492754, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0001331806833200212}, {\"x\": -3.913043478260869, \"y\": 8.55072463768116, \"x2\": -3.6231884057971016, \"y2\": 8.840579710144928, \"center_x\": -3.7681159420289854, \"center_y\": 8.695652173913043, \"value_uncond\": 0.00017264245161968284}, {\"x\": -3.6231884057971016, \"y\": 8.55072463768116, \"x2\": -3.333333333333334, \"y2\": 8.840579710144928, \"center_x\": -3.4782608695652177, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0002217173937673012}, {\"x\": -3.333333333333333, \"y\": 8.55072463768116, \"x2\": -3.0434782608695654, \"y2\": 8.840579710144928, \"center_x\": -3.1884057971014492, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0002820965337334934}, {\"x\": -3.0434782608695645, \"y\": 8.55072463768116, \"x2\": -2.753623188405797, \"y2\": 8.840579710144928, \"center_x\": -2.8985507246376807, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0003555834580916702}, {\"x\": -2.753623188405797, \"y\": 8.55072463768116, \"x2\": -2.4637681159420293, \"y2\": 8.840579710144928, \"center_x\": -2.608695652173913, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0004440492727523974}, {\"x\": -2.4637681159420284, \"y\": 8.55072463768116, \"x2\": -2.1739130434782608, \"y2\": 8.840579710144928, \"center_x\": -2.3188405797101446, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0005493720895215017}, {\"x\": -2.1739130434782608, \"y\": 8.55072463768116, \"x2\": -1.8840579710144931, \"y2\": 8.840579710144928, \"center_x\": -2.028985507246377, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0006733608069568906}, {\"x\": -1.8840579710144922, \"y\": 8.55072463768116, \"x2\": -1.5942028985507246, \"y2\": 8.840579710144928, \"center_x\": -1.7391304347826084, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0008176640283809529}, {\"x\": -1.5942028985507246, \"y\": 8.55072463768116, \"x2\": -1.304347826086957, \"y2\": 8.840579710144928, \"center_x\": -1.4492753623188408, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0009836662352107881}, {\"x\": -1.304347826086957, \"y\": 8.55072463768116, \"x2\": -1.0144927536231894, \"y2\": 8.840579710144928, \"center_x\": -1.1594202898550732, \"center_y\": 8.695652173913043, \"value_uncond\": 0.00117237473562303}, {\"x\": -1.0144927536231876, \"y\": 8.55072463768116, \"x2\": -0.72463768115942, \"y2\": 8.840579710144928, \"center_x\": -0.8695652173913038, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0013843023371089397}, {\"x\": -0.72463768115942, \"y\": 8.55072463768116, \"x2\": -0.43478260869565233, \"y2\": 8.840579710144928, \"center_x\": -0.5797101449275361, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0016193520217726706}, {\"x\": -0.43478260869565233, \"y\": 8.55072463768116, \"x2\": -0.1449275362318847, \"y2\": 8.840579710144928, \"center_x\": -0.2898550724637685, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0018767109937615424}, {\"x\": -0.14492753623188293, \"y\": 8.55072463768116, \"x2\": 0.1449275362318847, \"y2\": 8.840579710144928, \"center_x\": 8.881784197001252e-16, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0021547621731544497}, {\"x\": 0.1449275362318847, \"y\": 8.55072463768116, \"x2\": 0.43478260869565233, \"y2\": 8.840579710144928, \"center_x\": 0.2898550724637685, \"center_y\": 8.695652173913043, \"value_uncond\": 0.002451021395080612}, {\"x\": 0.43478260869565233, \"y\": 8.55072463768116, \"x2\": 0.72463768115942, \"y2\": 8.840579710144928, \"center_x\": 0.5797101449275361, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0027621081296955365}, {\"x\": 0.72463768115942, \"y\": 8.55072463768116, \"x2\": 1.0144927536231876, \"y2\": 8.840579710144928, \"center_x\": 0.8695652173913038, \"center_y\": 8.695652173913043, \"value_uncond\": 0.003083756405139314}, {\"x\": 1.0144927536231894, \"y\": 8.55072463768116, \"x2\": 1.304347826086957, \"y2\": 8.840579710144928, \"center_x\": 1.1594202898550732, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0034108707873688375}, {\"x\": 1.304347826086957, \"y\": 8.55072463768116, \"x2\": 1.5942028985507246, \"y2\": 8.840579710144928, \"center_x\": 1.4492753623188408, \"center_y\": 8.695652173913043, \"value_uncond\": 0.003737629811159793}, {\"x\": 1.5942028985507246, \"y\": 8.55072463768116, \"x2\": 1.8840579710144922, \"y2\": 8.840579710144928, \"center_x\": 1.7391304347826084, \"center_y\": 8.695652173913043, \"value_uncond\": 0.004057636299484736}, {\"x\": 1.884057971014494, \"y\": 8.55072463768116, \"x2\": 2.1739130434782616, \"y2\": 8.840579710144928, \"center_x\": 2.028985507246378, \"center_y\": 8.695652173913043, \"value_uncond\": 0.004364110753120656}, {\"x\": 2.1739130434782616, \"y\": 8.55072463768116, \"x2\": 2.4637681159420293, \"y2\": 8.840579710144928, \"center_x\": 2.3188405797101455, \"center_y\": 8.695652173913043, \"value_uncond\": 0.004650120689912263}, {\"x\": 2.4637681159420293, \"y\": 8.55072463768116, \"x2\": 2.753623188405797, \"y2\": 8.840579710144928, \"center_x\": 2.608695652173913, \"center_y\": 8.695652173913043, \"value_uncond\": 0.004908835745780014}, {\"x\": 2.753623188405797, \"y\": 8.55072463768116, \"x2\": 3.0434782608695645, \"y2\": 8.840579710144928, \"center_x\": 2.8985507246376807, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0051337958036886434}, {\"x\": 3.0434782608695663, \"y\": 8.55072463768116, \"x2\": 3.333333333333334, \"y2\": 8.840579710144928, \"center_x\": 3.18840579710145, \"center_y\": 8.695652173913043, \"value_uncond\": 0.005319177653177839}, {\"x\": 3.333333333333334, \"y\": 8.55072463768116, \"x2\": 3.6231884057971016, \"y2\": 8.840579710144928, \"center_x\": 3.4782608695652177, \"center_y\": 8.695652173913043, \"value_uncond\": 0.005460044907529852}, {\"x\": 3.6231884057971016, \"y\": 8.55072463768116, \"x2\": 3.913043478260869, \"y2\": 8.840579710144928, \"center_x\": 3.7681159420289854, \"center_y\": 8.695652173913043, \"value_uncond\": 0.005552566243749356}, {\"x\": 3.913043478260871, \"y\": 8.55072463768116, \"x2\": 4.202898550724639, \"y2\": 8.840579710144928, \"center_x\": 4.057971014492755, \"center_y\": 8.695652173913043, \"value_uncond\": 0.005594188509648697}, {\"x\": 4.202898550724639, \"y\": 8.55072463768116, \"x2\": 4.492753623188406, \"y2\": 8.840579710144928, \"center_x\": 4.347826086956522, \"center_y\": 8.695652173913043, \"value_uncond\": 0.005583753783940638}, {\"x\": 4.492753623188406, \"y\": 8.55072463768116, \"x2\": 4.782608695652174, \"y2\": 8.840579710144928, \"center_x\": 4.63768115942029, \"center_y\": 8.695652173913043, \"value_uncond\": 0.005521552898678561}, {\"x\": 4.782608695652174, \"y\": 8.55072463768116, \"x2\": 5.0724637681159415, \"y2\": 8.840579710144928, \"center_x\": 4.927536231884058, \"center_y\": 8.695652173913043, \"value_uncond\": 0.005409311971190908}, {\"x\": 5.072463768115943, \"y\": 8.55072463768116, \"x2\": 5.362318840579711, \"y2\": 8.840579710144928, \"center_x\": 5.217391304347827, \"center_y\": 8.695652173913043, \"value_uncond\": 0.005250112815975646}, {\"x\": 5.362318840579711, \"y\": 8.55072463768116, \"x2\": 5.6521739130434785, \"y2\": 8.840579710144928, \"center_x\": 5.507246376811595, \"center_y\": 8.695652173913043, \"value_uncond\": 0.005048252358228618}, {\"x\": 5.6521739130434785, \"y\": 8.55072463768116, \"x2\": 5.942028985507246, \"y2\": 8.840579710144928, \"center_x\": 5.797101449275362, \"center_y\": 8.695652173913043, \"value_uncond\": 0.004809049999432685}, {\"x\": 5.942028985507246, \"y\": 8.55072463768116, \"x2\": 6.231884057971014, \"y2\": 8.840579710144928, \"center_x\": 6.08695652173913, \"center_y\": 8.695652173913043, \"value_uncond\": 0.004538614983846707}, {\"x\": 6.2318840579710155, \"y\": 8.55072463768116, \"x2\": 6.521739130434783, \"y2\": 8.840579710144928, \"center_x\": 6.376811594202899, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0042435879475285635}, {\"x\": 6.521739130434785, \"y\": 8.55072463768116, \"x2\": 6.8115942028985526, \"y2\": 8.840579710144928, \"center_x\": 6.666666666666669, \"center_y\": 8.695652173913043, \"value_uncond\": 0.003930871857686281}, {\"x\": 6.811594202898551, \"y\": 8.55072463768116, \"x2\": 7.101449275362318, \"y2\": 8.840579710144928, \"center_x\": 6.956521739130435, \"center_y\": 8.695652173913043, \"value_uncond\": 0.003607367433725416}, {\"x\": 7.10144927536232, \"y\": 8.55072463768116, \"x2\": 7.391304347826088, \"y2\": 8.840579710144928, \"center_x\": 7.246376811594204, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0032797269505432467}, {\"x\": 7.391304347826086, \"y\": 8.55072463768116, \"x2\": 7.681159420289854, \"y2\": 8.840579710144928, \"center_x\": 7.53623188405797, \"center_y\": 8.695652173913043, \"value_uncond\": 0.002954138219697305}, {\"x\": 7.681159420289855, \"y\": 8.55072463768116, \"x2\": 7.971014492753623, \"y2\": 8.840579710144928, \"center_x\": 7.826086956521739, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0026361477562092976}, {\"x\": 7.971014492753625, \"y\": 8.55072463768116, \"x2\": 8.260869565217392, \"y2\": 8.840579710144928, \"center_x\": 8.115942028985508, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0023305289426137467}, {\"x\": 8.26086956521739, \"y\": 8.55072463768116, \"x2\": 8.550724637681158, \"y2\": 8.840579710144928, \"center_x\": 8.405797101449274, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0020411976855896304}, {\"x\": 8.55072463768116, \"y\": 8.55072463768116, \"x2\": 8.840579710144928, \"y2\": 8.840579710144928, \"center_x\": 8.695652173913043, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0017711748968384177}, {\"x\": 8.84057971014493, \"y\": 8.55072463768116, \"x2\": 9.130434782608697, \"y2\": 8.840579710144928, \"center_x\": 8.985507246376812, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0015225923513204718}, {\"x\": 9.130434782608695, \"y\": 8.55072463768116, \"x2\": 9.420289855072463, \"y2\": 8.840579710144928, \"center_x\": 9.275362318840578, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0012967362567683765}, {\"x\": 9.420289855072465, \"y\": 8.55072463768116, \"x2\": 9.710144927536232, \"y2\": 8.840579710144928, \"center_x\": 9.565217391304348, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0010941213143847602}, {\"x\": 9.710144927536234, \"y\": 8.55072463768116, \"x2\": 10.000000000000002, \"y2\": 8.840579710144928, \"center_x\": 9.855072463768117, \"center_y\": 8.695652173913043, \"value_uncond\": 0.000914587197337893}, {\"x\": 10.0, \"y\": 8.55072463768116, \"x2\": 10.289855072463768, \"y2\": 8.840579710144928, \"center_x\": 10.144927536231883, \"center_y\": 8.695652173913043, \"value_uncond\": 0.0007574091919261327}, {\"x\": -10.0, \"y\": 8.84057971014493, \"x2\": -9.710144927536232, \"y2\": 9.130434782608697, \"center_x\": -9.855072463768117, \"center_y\": 8.985507246376812, \"value_uncond\": 8.979607877804766e-08}, {\"x\": -9.710144927536232, \"y\": 8.84057971014493, \"x2\": -9.420289855072465, \"y2\": 9.130434782608697, \"center_x\": -9.565217391304348, \"center_y\": 8.985507246376812, \"value_uncond\": 1.402966939890929e-07}, {\"x\": -9.420289855072463, \"y\": 8.84057971014493, \"x2\": -9.130434782608695, \"y2\": 9.130434782608697, \"center_x\": -9.275362318840578, \"center_y\": 8.985507246376812, \"value_uncond\": 2.1716174199835867e-07}, {\"x\": -9.130434782608695, \"y\": 8.84057971014493, \"x2\": -8.840579710144928, \"y2\": 9.130434782608697, \"center_x\": -8.985507246376812, \"center_y\": 8.985507246376812, \"value_uncond\": 3.330159316072577e-07}, {\"x\": -8.840579710144928, \"y\": 8.84057971014493, \"x2\": -8.55072463768116, \"y2\": 9.130434782608697, \"center_x\": -8.695652173913043, \"center_y\": 8.985507246376812, \"value_uncond\": 5.059324312362338e-07}, {\"x\": -8.55072463768116, \"y\": 8.84057971014493, \"x2\": -8.260869565217392, \"y2\": 9.130434782608697, \"center_x\": -8.405797101449277, \"center_y\": 8.985507246376812, \"value_uncond\": 7.614928721571976e-07}, {\"x\": -8.26086956521739, \"y\": 8.84057971014493, \"x2\": -7.971014492753623, \"y2\": 9.130434782608697, \"center_x\": -8.115942028985508, \"center_y\": 8.985507246376812, \"value_uncond\": 1.1354943568473354e-06}, {\"x\": -7.971014492753623, \"y\": 8.84057971014493, \"x2\": -7.681159420289855, \"y2\": 9.130434782608697, \"center_x\": -7.826086956521739, \"center_y\": 8.985507246376812, \"value_uncond\": 1.6774513459742732e-06}, {\"x\": -7.681159420289855, \"y\": 8.84057971014493, \"x2\": -7.391304347826088, \"y2\": 9.130434782608697, \"center_x\": -7.536231884057972, \"center_y\": 8.985507246376812, \"value_uncond\": 2.455052022138501e-06}, {\"x\": -7.391304347826087, \"y\": 8.84057971014493, \"x2\": -7.101449275362319, \"y2\": 9.130434782608697, \"center_x\": -7.246376811594203, \"center_y\": 8.985507246376812, \"value_uncond\": 3.559731818157989e-06}, {\"x\": -7.101449275362318, \"y\": 8.84057971014493, \"x2\": -6.811594202898551, \"y2\": 9.130434782608697, \"center_x\": -6.956521739130435, \"center_y\": 8.985507246376812, \"value_uncond\": 5.113516672729353e-06}, {\"x\": -6.811594202898551, \"y\": 8.84057971014493, \"x2\": -6.521739130434783, \"y2\": 9.130434782608697, \"center_x\": -6.666666666666667, \"center_y\": 8.985507246376812, \"value_uncond\": 7.277259918443921e-06}, {\"x\": -6.521739130434782, \"y\": 8.84057971014493, \"x2\": -6.231884057971015, \"y2\": 9.130434782608697, \"center_x\": -6.3768115942028984, \"center_y\": 8.985507246376812, \"value_uncond\": 1.0260343762145541e-05}, {\"x\": -6.231884057971014, \"y\": 8.84057971014493, \"x2\": -5.942028985507246, \"y2\": 9.130434782608697, \"center_x\": -6.08695652173913, \"center_y\": 8.985507246376812, \"value_uncond\": 1.4331833399382685e-05}, {\"x\": -5.942028985507246, \"y\": 8.84057971014493, \"x2\": -5.6521739130434785, \"y2\": 9.130434782608697, \"center_x\": -5.797101449275362, \"center_y\": 8.985507246376812, \"value_uncond\": 1.9832954021266523e-05}, {\"x\": -5.6521739130434785, \"y\": 8.84057971014493, \"x2\": -5.362318840579711, \"y2\": 9.130434782608697, \"center_x\": -5.507246376811595, \"center_y\": 8.985507246376812, \"value_uncond\": 2.719060516917808e-05}, {\"x\": -5.36231884057971, \"y\": 8.84057971014493, \"x2\": -5.072463768115942, \"y2\": 9.130434782608697, \"center_x\": -5.217391304347826, \"center_y\": 8.985507246376812, \"value_uncond\": 3.6931432775225205e-05}, {\"x\": -5.0724637681159415, \"y\": 8.84057971014493, \"x2\": -4.782608695652174, \"y2\": 9.130434782608697, \"center_x\": -4.927536231884058, \"center_y\": 8.985507246376812, \"value_uncond\": 4.9695750572262035e-05}, {\"x\": -4.782608695652174, \"y\": 8.84057971014493, \"x2\": -4.492753623188406, \"y2\": 9.130434782608697, \"center_x\": -4.63768115942029, \"center_y\": 8.985507246376812, \"value_uncond\": 6.625034839174487e-05}, {\"x\": -4.492753623188405, \"y\": 8.84057971014493, \"x2\": -4.202898550724638, \"y2\": 9.130434782608697, \"center_x\": -4.3478260869565215, \"center_y\": 8.985507246376812, \"value_uncond\": 8.74989604135519e-05}, {\"x\": -4.202898550724638, \"y\": 8.84057971014493, \"x2\": -3.91304347826087, \"y2\": 9.130434782608697, \"center_x\": -4.057971014492754, \"center_y\": 8.985507246376812, \"value_uncond\": 0.00011448891361810995}, {\"x\": -3.913043478260869, \"y\": 8.84057971014493, \"x2\": -3.6231884057971016, \"y2\": 9.130434782608697, \"center_x\": -3.7681159420289854, \"center_y\": 8.985507246376812, \"value_uncond\": 0.00014841226398282917}, {\"x\": -3.6231884057971016, \"y\": 8.84057971014493, \"x2\": -3.333333333333334, \"y2\": 9.130434782608697, \"center_x\": -3.4782608695652177, \"center_y\": 8.985507246376812, \"value_uncond\": 0.00019059958929374977}, {\"x\": -3.333333333333333, \"y\": 8.84057971014493, \"x2\": -3.0434782608695654, \"y2\": 9.130434782608697, \"center_x\": -3.1884057971014492, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0002425045800746907}, {\"x\": -3.0434782608695645, \"y\": 8.84057971014493, \"x2\": -2.753623188405797, \"y2\": 9.130434782608697, \"center_x\": -2.8985507246376807, \"center_y\": 8.985507246376812, \"value_uncond\": 0.00030567769140861566}, {\"x\": -2.753623188405797, \"y\": 8.84057971014493, \"x2\": -2.4637681159420293, \"y2\": 9.130434782608697, \"center_x\": -2.608695652173913, \"center_y\": 8.985507246376812, \"value_uncond\": 0.00038172742144724434}, {\"x\": -2.4637681159420284, \"y\": 8.84057971014493, \"x2\": -2.1739130434782608, \"y2\": 9.130434782608697, \"center_x\": -2.3188405797101446, \"center_y\": 8.985507246376812, \"value_uncond\": 0.000472268290967481}, {\"x\": -2.1739130434782608, \"y\": 8.84057971014493, \"x2\": -1.8840579710144931, \"y2\": 9.130434782608697, \"center_x\": -2.028985507246377, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0005788553215053133}, {\"x\": -1.8840579710144922, \"y\": 8.84057971014493, \"x2\": -1.5942028985507246, \"y2\": 9.130434782608697, \"center_x\": -1.7391304347826084, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0007029057366299728}, {\"x\": -1.5942028985507246, \"y\": 8.84057971014493, \"x2\": -1.304347826086957, \"y2\": 9.130434782608697, \"center_x\": -1.4492753623188408, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0008456097072387457}, {\"x\": -1.304347826086957, \"y\": 8.84057971014493, \"x2\": -1.0144927536231894, \"y2\": 9.130434782608697, \"center_x\": -1.1594202898550732, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0010078331668585262}, {\"x\": -1.0144927536231876, \"y\": 8.84057971014493, \"x2\": -0.72463768115942, \"y2\": 9.130434782608697, \"center_x\": -0.8695652173913038, \"center_y\": 8.985507246376812, \"value_uncond\": 0.001190016950985169}, {\"x\": -0.72463768115942, \"y\": 8.84057971014493, \"x2\": -0.43478260869565233, \"y2\": 9.130434782608697, \"center_x\": -0.5797101449275361, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0013920776580831054}, {\"x\": -0.43478260869565233, \"y\": 8.84057971014493, \"x2\": -0.1449275362318847, \"y2\": 9.130434782608697, \"center_x\": -0.2898550724637685, \"center_y\": 8.985507246376812, \"value_uncond\": 0.001613316567348035}, {\"x\": -0.14492753623188293, \"y\": 8.84057971014493, \"x2\": 0.1449275362318847, \"y2\": 9.130434782608697, \"center_x\": 8.881784197001252e-16, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0018523435543355879}, {\"x\": 0.1449275362318847, \"y\": 8.84057971014493, \"x2\": 0.43478260869565233, \"y2\": 9.130434782608697, \"center_x\": 0.2898550724637685, \"center_y\": 8.985507246376812, \"value_uncond\": 0.002107023104118119}, {\"x\": 0.43478260869565233, \"y\": 8.84057971014493, \"x2\": 0.72463768115942, \"y2\": 9.130434782608697, \"center_x\": 0.5797101449275361, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0023744491406814394}, {\"x\": 0.72463768115942, \"y\": 8.84057971014493, \"x2\": 1.0144927536231876, \"y2\": 9.130434782608697, \"center_x\": 0.8695652173913038, \"center_y\": 8.985507246376812, \"value_uncond\": 0.002650954416857332}, {\"x\": 1.0144927536231894, \"y\": 8.84057971014493, \"x2\": 1.304347826086957, \"y2\": 9.130434782608697, \"center_x\": 1.1594202898550732, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0029321586374448324}, {\"x\": 1.304347826086957, \"y\": 8.84057971014493, \"x2\": 1.5942028985507246, \"y2\": 9.130434782608697, \"center_x\": 1.4492753623188408, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0032130573737791934}, {\"x\": 1.5942028985507246, \"y\": 8.84057971014493, \"x2\": 1.8840579710144922, \"y2\": 9.130434782608697, \"center_x\": 1.7391304347826084, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0034881512859423654}, {\"x\": 1.884057971014494, \"y\": 8.84057971014493, \"x2\": 2.1739130434782616, \"y2\": 9.130434782608697, \"center_x\": 2.028985507246378, \"center_y\": 8.985507246376812, \"value_uncond\": 0.003751612370341272}, {\"x\": 2.1739130434782616, \"y\": 8.84057971014493, \"x2\": 2.4637681159420293, \"y2\": 9.130434782608697, \"center_x\": 2.3188405797101455, \"center_y\": 8.985507246376812, \"value_uncond\": 0.003997481111445207}, {\"x\": 2.4637681159420293, \"y\": 8.84057971014493, \"x2\": 2.753623188405797, \"y2\": 9.130434782608697, \"center_x\": 2.608695652173913, \"center_y\": 8.985507246376812, \"value_uncond\": 0.004219885779634011}, {\"x\": 2.753623188405797, \"y\": 8.84057971014493, \"x2\": 3.0434782608695645, \"y2\": 9.130434782608697, \"center_x\": 2.8985507246376807, \"center_y\": 8.985507246376812, \"value_uncond\": 0.004413272928546124}, {\"x\": 3.0434782608695663, \"y\": 8.84057971014493, \"x2\": 3.333333333333334, \"y2\": 9.130434782608697, \"center_x\": 3.18840579710145, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0045726366292228515}, {\"x\": 3.333333333333334, \"y\": 8.84057971014493, \"x2\": 3.6231884057971016, \"y2\": 9.130434782608697, \"center_x\": 3.4782608695652177, \"center_y\": 8.985507246376812, \"value_uncond\": 0.00469373331166271}, {\"x\": 3.6231884057971016, \"y\": 8.84057971014493, \"x2\": 3.913043478260869, \"y2\": 9.130434782608697, \"center_x\": 3.7681159420289854, \"center_y\": 8.985507246376812, \"value_uncond\": 0.004773269375048221}, {\"x\": 3.913043478260871, \"y\": 8.84057971014493, \"x2\": 4.202898550724639, \"y2\": 9.130434782608697, \"center_x\": 4.057971014492755, \"center_y\": 8.985507246376812, \"value_uncond\": 0.004809049999432683}, {\"x\": 4.202898550724639, \"y\": 8.84057971014493, \"x2\": 4.492753623188406, \"y2\": 9.130434782608697, \"center_x\": 4.347826086956522, \"center_y\": 8.985507246376812, \"value_uncond\": 0.00480007977657125}, {\"x\": 4.492753623188406, \"y\": 8.84057971014493, \"x2\": 4.782608695652174, \"y2\": 9.130434782608697, \"center_x\": 4.63768115942029, \"center_y\": 8.985507246376812, \"value_uncond\": 0.004746608720542591}, {\"x\": 4.782608695652174, \"y\": 8.84057971014493, \"x2\": 5.0724637681159415, \"y2\": 9.130434782608697, \"center_x\": 4.927536231884058, \"center_y\": 8.985507246376812, \"value_uncond\": 0.004650120689912261}, {\"x\": 5.072463768115943, \"y\": 8.84057971014493, \"x2\": 5.362318840579711, \"y2\": 9.130434782608697, \"center_x\": 5.217391304347827, \"center_y\": 8.985507246376812, \"value_uncond\": 0.004513264969734587}, {\"x\": 5.362318840579711, \"y\": 8.84057971014493, \"x2\": 5.6521739130434785, \"y2\": 9.130434782608697, \"center_x\": 5.507246376811595, \"center_y\": 8.985507246376812, \"value_uncond\": 0.004339735416245373}, {\"x\": 5.6521739130434785, \"y\": 8.84057971014493, \"x2\": 5.942028985507246, \"y2\": 9.130434782608697, \"center_x\": 5.797101449275362, \"center_y\": 8.985507246376812, \"value_uncond\": 0.004134104858489265}, {\"x\": 5.942028985507246, \"y\": 8.84057971014493, \"x2\": 6.231884057971014, \"y2\": 9.130434782608697, \"center_x\": 6.08695652173913, \"center_y\": 8.985507246376812, \"value_uncond\": 0.003901625114678845}, {\"x\": 6.2318840579710155, \"y\": 8.84057971014493, \"x2\": 6.521739130434783, \"y2\": 9.130434782608697, \"center_x\": 6.376811594202899, \"center_y\": 8.985507246376812, \"value_uncond\": 0.003648004814542142}, {\"x\": 6.521739130434785, \"y\": 8.84057971014493, \"x2\": 6.8115942028985526, \"y2\": 9.130434782608697, \"center_x\": 6.666666666666669, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0033791781010546027}, {\"x\": 6.811594202898551, \"y\": 8.84057971014493, \"x2\": 7.101449275362318, \"y2\": 9.130434782608697, \"center_x\": 6.956521739130435, \"center_y\": 8.985507246376812, \"value_uncond\": 0.003101077184865926}, {\"x\": 7.10144927536232, \"y\": 8.84057971014493, \"x2\": 7.391304347826088, \"y2\": 9.130434782608697, \"center_x\": 7.246376811594204, \"center_y\": 8.985507246376812, \"value_uncond\": 0.002819420701044596}, {\"x\": 7.391304347826086, \"y\": 8.84057971014493, \"x2\": 7.681159420289854, \"y2\": 9.130434782608697, \"center_x\": 7.53623188405797, \"center_y\": 8.985507246376812, \"value_uncond\": 0.002539528008263621}, {\"x\": 7.681159420289855, \"y\": 8.84057971014493, \"x2\": 7.971014492753623, \"y2\": 9.130434782608697, \"center_x\": 7.826086956521739, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0022661671739586946}, {\"x\": 7.971014492753625, \"y\": 8.84057971014493, \"x2\": 8.260869565217392, \"y2\": 9.130434782608697, \"center_x\": 8.115942028985508, \"center_y\": 8.985507246376812, \"value_uncond\": 0.002003441641414816}, {\"x\": 8.26086956521739, \"y\": 8.84057971014493, \"x2\": 8.550724637681158, \"y2\": 9.130434782608697, \"center_x\": 8.405797101449274, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0017547177239015214}, {\"x\": 8.55072463768116, \"y\": 8.84057971014493, \"x2\": 8.840579710144928, \"y2\": 9.130434782608697, \"center_x\": 8.695652173913043, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0015225923513204718}, {\"x\": 8.84057971014493, \"y\": 8.84057971014493, \"x2\": 9.130434782608697, \"y2\": 9.130434782608697, \"center_x\": 8.985507246376812, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0013088981062445}, {\"x\": 9.130434782608695, \"y\": 8.84057971014493, \"x2\": 9.420289855072463, \"y2\": 9.130434782608697, \"center_x\": 9.275362318840578, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0011147406784952822}, {\"x\": 9.420289855072465, \"y\": 8.84057971014493, \"x2\": 9.710144927536232, \"y2\": 9.130434782608697, \"center_x\": 9.565217391304348, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0009405625314996294}, {\"x\": 9.710144927536234, \"y\": 8.84057971014493, \"x2\": 10.000000000000002, \"y2\": 9.130434782608697, \"center_x\": 9.855072463768117, \"center_y\": 8.985507246376812, \"value_uncond\": 0.0007862258401290695}, {\"x\": 10.0, \"y\": 8.84057971014493, \"x2\": 10.289855072463768, \"y2\": 9.130434782608697, \"center_x\": 10.144927536231883, \"center_y\": 8.985507246376812, \"value_uncond\": 0.000651107603492506}, {\"x\": -10.0, \"y\": 9.130434782608695, \"x2\": -9.710144927536232, \"y2\": 9.420289855072463, \"center_x\": -9.855072463768117, \"center_y\": 9.275362318840578, \"value_uncond\": 7.647603836058899e-08}, {\"x\": -9.710144927536232, \"y\": 9.130434782608695, \"x2\": -9.420289855072465, \"y2\": 9.420289855072463, \"center_x\": -9.565217391304348, \"center_y\": 9.275362318840578, \"value_uncond\": 1.1948556660134085e-07}, {\"x\": -9.420289855072463, \"y\": 9.130434782608695, \"x2\": -9.130434782608695, \"y2\": 9.420289855072463, \"center_x\": -9.275362318840578, \"center_y\": 9.275362318840578, \"value_uncond\": 1.8494871866920357e-07}, {\"x\": -9.130434782608695, \"y\": 9.130434782608695, \"x2\": -8.840579710144928, \"y2\": 9.420289855072463, \"center_x\": -8.985507246376812, \"center_y\": 9.275362318840578, \"value_uncond\": 2.836174976329806e-07}, {\"x\": -8.840579710144928, \"y\": 9.130434782608695, \"x2\": -8.55072463768116, \"y2\": 9.420289855072463, \"center_x\": -8.695652173913043, \"center_y\": 9.275362318840578, \"value_uncond\": 4.308841604846021e-07}, {\"x\": -8.55072463768116, \"y\": 9.130434782608695, \"x2\": -8.260869565217392, \"y2\": 9.420289855072463, \"center_x\": -8.405797101449277, \"center_y\": 9.275362318840578, \"value_uncond\": 6.485356476016378e-07}, {\"x\": -8.26086956521739, \"y\": 9.130434782608695, \"x2\": -7.971014492753623, \"y2\": 9.420289855072463, \"center_x\": -8.115942028985508, \"center_y\": 9.275362318840578, \"value_uncond\": 9.670590428244664e-07}, {\"x\": -7.971014492753623, \"y\": 9.130434782608695, \"x2\": -7.681159420289855, \"y2\": 9.420289855072463, \"center_x\": -7.826086956521739, \"center_y\": 9.275362318840578, \"value_uncond\": 1.4286240026119246e-06}, {\"x\": -7.681159420289855, \"y\": 9.130434782608695, \"x2\": -7.391304347826088, \"y2\": 9.420289855072463, \"center_x\": -7.536231884057972, \"center_y\": 9.275362318840578, \"value_uncond\": 2.0908780781662027e-06}, {\"x\": -7.391304347826087, \"y\": 9.130434782608695, \"x2\": -7.101449275362319, \"y2\": 9.420289855072463, \"center_x\": -7.246376811594203, \"center_y\": 9.275362318840578, \"value_uncond\": 3.0316934857673573e-06}, {\"x\": -7.101449275362318, \"y\": 9.130434782608695, \"x2\": -6.811594202898551, \"y2\": 9.420289855072463, \"center_x\": -6.956521739130435, \"center_y\": 9.275362318840578, \"value_uncond\": 4.354995257507432e-06}, {\"x\": -6.811594202898551, \"y\": 9.130434782608695, \"x2\": -6.521739130434783, \"y2\": 9.420289855072463, \"center_x\": -6.666666666666667, \"center_y\": 9.275362318840578, \"value_uncond\": 6.197776297765796e-06}, {\"x\": -6.521739130434782, \"y\": 9.130434782608695, \"x2\": -6.231884057971015, \"y2\": 9.420289855072463, \"center_x\": -6.3768115942028984, \"center_y\": 9.275362318840578, \"value_uncond\": 8.738359779452863e-06}, {\"x\": -6.231884057971014, \"y\": 9.130434782608695, \"x2\": -5.942028985507246, \"y2\": 9.420289855072463, \"center_x\": -6.08695652173913, \"center_y\": 9.275362318840578, \"value_uncond\": 1.2205898695619978e-05}, {\"x\": -5.942028985507246, \"y\": 9.130434782608695, \"x2\": -5.6521739130434785, \"y2\": 9.420289855072463, \"center_x\": -5.797101449275362, \"center_y\": 9.275362318840578, \"value_uncond\": 1.6891002070181413e-05}, {\"x\": -5.6521739130434785, \"y\": 9.130434782608695, \"x2\": -5.362318840579711, \"y2\": 9.420289855072463, \"center_x\": -5.507246376811595, \"center_y\": 9.275362318840578, \"value_uncond\": 2.315724463988563e-05}, {\"x\": -5.36231884057971, \"y\": 9.130434782608695, \"x2\": -5.072463768115942, \"y2\": 9.420289855072463, \"center_x\": -5.217391304347826, \"center_y\": 9.275362318840578, \"value_uncond\": 3.1453151496856975e-05}, {\"x\": -5.0724637681159415, \"y\": 9.130434782608695, \"x2\": -4.782608695652174, \"y2\": 9.420289855072463, \"center_x\": -4.927536231884058, \"center_y\": 9.275362318840578, \"value_uncond\": 4.2324054444699044e-05}, {\"x\": -4.782608695652174, \"y\": 9.130434782608695, \"x2\": -4.492753623188406, \"y2\": 9.420289855072463, \"center_x\": -4.63768115942029, \"center_y\": 9.275362318840578, \"value_uncond\": 5.642300035765128e-05}, {\"x\": -4.492753623188405, \"y\": 9.130434782608695, \"x2\": -4.202898550724638, \"y2\": 9.420289855072463, \"center_x\": -4.3478260869565215, \"center_y\": 9.275362318840578, \"value_uncond\": 7.451966660635891e-05}, {\"x\": -4.202898550724638, \"y\": 9.130434782608695, \"x2\": -3.91304347826087, \"y2\": 9.420289855072463, \"center_x\": -4.057971014492754, \"center_y\": 9.275362318840578, \"value_uncond\": 9.750602330155659e-05}, {\"x\": -3.913043478260869, \"y\": 9.130434782608695, \"x2\": -3.6231884057971016, \"y2\": 9.420289855072463, \"center_x\": -3.7681159420289854, \"center_y\": 9.275362318840578, \"value_uncond\": 0.00012639730095104576}, {\"x\": -3.6231884057971016, \"y\": 9.130434782608695, \"x2\": -3.333333333333334, \"y2\": 9.420289855072463, \"center_x\": -3.4782608695652177, \"center_y\": 9.275362318840578, \"value_uncond\": 0.00016232670402423812}, {\"x\": -3.333333333333333, \"y\": 9.130434782608695, \"x2\": -3.0434782608695654, \"y2\": 9.420289855072463, \"center_x\": -3.1884057971014492, \"center_y\": 9.275362318840578, \"value_uncond\": 0.000206532287609695}, {\"x\": -3.0434782608695645, \"y\": 9.130434782608695, \"x2\": -2.753623188405797, \"y2\": 9.420289855072463, \"center_x\": -2.8985507246376807, \"center_y\": 9.275362318840578, \"value_uncond\": 0.00026033451763437723}, {\"x\": -2.753623188405797, \"y\": 9.130434782608695, \"x2\": -2.4637681159420293, \"y2\": 9.420289855072463, \"center_x\": -2.608695652173913, \"center_y\": 9.275362318840578, \"value_uncond\": 0.00032510329318550315}, {\"x\": -2.4637681159420284, \"y\": 9.130434782608695, \"x2\": -2.1739130434782608, \"y2\": 9.420289855072463, \"center_x\": -2.3188405797101446, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0004022136426000418}, {\"x\": -2.1739130434782608, \"y\": 9.130434782608695, \"x2\": -1.8840579710144931, \"y2\": 9.420289855072463, \"center_x\": -2.028985507246377, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0004929899208860965}, {\"x\": -1.8840579710144922, \"y\": 9.130434782608695, \"x2\": -1.5942028985507246, \"y2\": 9.420289855072463, \"center_x\": -1.7391304347826084, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0005986391255598276}, {\"x\": -1.5942028985507246, \"y\": 9.130434782608695, \"x2\": -1.304347826086957, \"y2\": 9.420289855072463, \"center_x\": -1.4492753623188408, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0007201748816751926}, {\"x\": -1.304347826086957, \"y\": 9.130434782608695, \"x2\": -1.0144927536231894, \"y2\": 9.420289855072463, \"center_x\": -1.1594202898550732, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0008583346731682558}, {\"x\": -1.0144927536231876, \"y\": 9.130434782608695, \"x2\": -0.72463768115942, \"y2\": 9.420289855072463, \"center_x\": -0.8695652173913038, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0010134939435188506}, {\"x\": -0.72463768115942, \"y\": 9.130434782608695, \"x2\": -0.43478260869565233, \"y2\": 9.420289855072463, \"center_x\": -0.5797101449275361, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0011855816626873544}, {\"x\": -0.43478260869565233, \"y\": 9.130434782608695, \"x2\": -0.1449275362318847, \"y2\": 9.420289855072463, \"center_x\": -0.2898550724637685, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0013740027557021192}, {\"x\": -0.14492753623188293, \"y\": 9.130434782608695, \"x2\": 0.1449275362318847, \"y2\": 9.420289855072463, \"center_x\": 8.881784197001252e-16, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0015775733043811879}, {\"x\": 0.1449275362318847, \"y\": 9.130434782608695, \"x2\": 0.43478260869565233, \"y2\": 9.420289855072463, \"center_x\": 0.2898550724637685, \"center_y\": 9.275362318840578, \"value_uncond\": 0.001794474568711094}, {\"x\": 0.43478260869565233, \"y\": 9.130434782608695, \"x2\": 0.72463768115942, \"y2\": 9.420289855072463, \"center_x\": 0.5797101449275361, \"center_y\": 9.275362318840578, \"value_uncond\": 0.002022231549964005}, {\"x\": 0.72463768115942, \"y\": 9.130434782608695, \"x2\": 1.0144927536231876, \"y2\": 9.420289855072463, \"center_x\": 0.8695652173913038, \"center_y\": 9.275362318840578, \"value_uncond\": 0.002257720987760062}, {\"x\": 1.0144927536231894, \"y\": 9.130434782608695, \"x2\": 1.304347826086957, \"y2\": 9.420289855072463, \"center_x\": 1.1594202898550732, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0024972123447709275}, {\"x\": 1.304347826086957, \"y\": 9.130434782608695, \"x2\": 1.5942028985507246, \"y2\": 9.420289855072463, \"center_x\": 1.4492753623188408, \"center_y\": 9.275362318840578, \"value_uncond\": 0.002736443532008462}, {\"x\": 1.5942028985507246, \"y\": 9.130434782608695, \"x2\": 1.8840579710144922, \"y2\": 9.420289855072463, \"center_x\": 1.7391304347826084, \"center_y\": 9.275362318840578, \"value_uncond\": 0.002970730962658479}, {\"x\": 1.884057971014494, \"y\": 9.130434782608695, \"x2\": 2.1739130434782616, \"y2\": 9.420289855072463, \"center_x\": 2.028985507246378, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0031951111390670145}, {\"x\": 2.1739130434782616, \"y\": 9.130434782608695, \"x2\": 2.4637681159420293, \"y2\": 9.420289855072463, \"center_x\": 2.3188405797101455, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0034045085596694277}, {\"x\": 2.4637681159420293, \"y\": 9.130434782608695, \"x2\": 2.753623188405797, \"y2\": 9.420289855072463, \"center_x\": 2.608695652173913, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0035939224869526204}, {\"x\": 2.753623188405797, \"y\": 9.130434782608695, \"x2\": 3.0434782608695645, \"y2\": 9.420289855072463, \"center_x\": 2.8985507246376807, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0037586232536219915}, {\"x\": 3.0434782608695663, \"y\": 9.130434782608695, \"x2\": 3.333333333333334, \"y2\": 9.420289855072463, \"center_x\": 3.18840579710145, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0038943474929438796}, {\"x\": 3.333333333333334, \"y\": 9.130434782608695, \"x2\": 3.6231884057971016, \"y2\": 9.420289855072463, \"center_x\": 3.4782608695652177, \"center_y\": 9.275362318840578, \"value_uncond\": 0.003997481111445211}, {\"x\": 3.6231884057971016, \"y\": 9.130434782608695, \"x2\": 3.913043478260869, \"y2\": 9.420289855072463, \"center_x\": 3.7681159420289854, \"center_y\": 9.275362318840578, \"value_uncond\": 0.004065219069686742}, {\"x\": 3.913043478260871, \"y\": 9.130434782608695, \"x2\": 4.202898550724639, \"y2\": 9.420289855072463, \"center_x\": 4.057971014492755, \"center_y\": 9.275362318840578, \"value_uncond\": 0.004095692119737797}, {\"x\": 4.202898550724639, \"y\": 9.130434782608695, \"x2\": 4.492753623188406, \"y2\": 9.420289855072463, \"center_x\": 4.347826086956522, \"center_y\": 9.275362318840578, \"value_uncond\": 0.004088052508777171}, {\"x\": 4.492753623188406, \"y\": 9.130434782608695, \"x2\": 4.782608695652174, \"y2\": 9.420289855072463, \"center_x\": 4.63768115942029, \"center_y\": 9.275362318840578, \"value_uncond\": 0.004042513164657964}, {\"x\": 4.782608695652174, \"y\": 9.130434782608695, \"x2\": 5.0724637681159415, \"y2\": 9.420289855072463, \"center_x\": 4.927536231884058, \"center_y\": 9.275362318840578, \"value_uncond\": 0.003960337835487279}, {\"x\": 5.072463768115943, \"y\": 9.130434782608695, \"x2\": 5.362318840579711, \"y2\": 9.420289855072463, \"center_x\": 5.217391304347827, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0038437828205178234}, {\"x\": 5.362318840579711, \"y\": 9.130434782608695, \"x2\": 5.6521739130434785, \"y2\": 9.420289855072463, \"center_x\": 5.507246376811595, \"center_y\": 9.275362318840578, \"value_uncond\": 0.003695994042099792}, {\"x\": 5.6521739130434785, \"y\": 9.130434782608695, \"x2\": 5.942028985507246, \"y2\": 9.420289855072463, \"center_x\": 5.797101449275362, \"center_y\": 9.275362318840578, \"value_uncond\": 0.003520866011599312}, {\"x\": 5.942028985507246, \"y\": 9.130434782608695, \"x2\": 6.231884057971014, \"y2\": 9.420289855072463, \"center_x\": 6.08695652173913, \"center_y\": 9.275362318840578, \"value_uncond\": 0.003322871510640635}, {\"x\": 6.2318840579710155, \"y\": 9.130434782608695, \"x2\": 6.521739130434783, \"y2\": 9.420289855072463, \"center_x\": 6.376811594202899, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0031068723705198263}, {\"x\": 6.521739130434785, \"y\": 9.130434782608695, \"x2\": 6.8115942028985526, \"y2\": 9.420289855072463, \"center_x\": 6.666666666666669, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0028779224839235533}, {\"x\": 6.811594202898551, \"y\": 9.130434782608695, \"x2\": 7.101449275362318, \"y2\": 9.420289855072463, \"center_x\": 6.956521739130435, \"center_y\": 9.275362318840578, \"value_uncond\": 0.002641074097847261}, {\"x\": 7.10144927536232, \"y\": 9.130434782608695, \"x2\": 7.391304347826088, \"y2\": 9.420289855072463, \"center_x\": 7.246376811594204, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0024011975647698}, {\"x\": 7.391304347826086, \"y\": 9.130434782608695, \"x2\": 7.681159420289854, \"y2\": 9.420289855072463, \"center_x\": 7.53623188405797, \"center_y\": 9.275362318840578, \"value_uncond\": 0.002162823188057047}, {\"x\": 7.681159420289855, \"y\": 9.130434782608695, \"x2\": 7.971014492753623, \"y2\": 9.420289855072463, \"center_x\": 7.826086956521739, \"center_y\": 9.275362318840578, \"value_uncond\": 0.001930011756477064}, {\"x\": 7.971014492753625, \"y\": 9.130434782608695, \"x2\": 8.260869565217392, \"y2\": 9.420289855072463, \"center_x\": 8.115942028985508, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0017062580226999524}, {\"x\": 8.26086956521739, \"y\": 9.130434782608695, \"x2\": 8.550724637681158, \"y2\": 9.420289855072463, \"center_x\": 8.405797101449274, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0014944289527028252}, {\"x\": 8.55072463768116, \"y\": 9.130434782608695, \"x2\": 8.840579710144928, \"y2\": 9.420289855072463, \"center_x\": 8.695652173913043, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0012967362567683765}, {\"x\": 8.84057971014493, \"y\": 9.130434782608695, \"x2\": 9.130434782608697, \"y2\": 9.420289855072463, \"center_x\": 8.985507246376812, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0011147406784952822}, {\"x\": 9.130434782608695, \"y\": 9.130434782608695, \"x2\": 9.420289855072463, \"y2\": 9.420289855072463, \"center_x\": 9.275362318840578, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0009493838934930793}, {\"x\": 9.420289855072465, \"y\": 9.130434782608695, \"x2\": 9.710144927536232, \"y2\": 9.420289855072463, \"center_x\": 9.565217391304348, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0008010427316908976}, {\"x\": 9.710144927536234, \"y\": 9.130434782608695, \"x2\": 10.000000000000002, \"y2\": 9.420289855072463, \"center_x\": 9.855072463768117, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0006695998124641526}, {\"x\": 10.0, \"y\": 9.130434782608695, \"x2\": 10.289855072463768, \"y2\": 9.420289855072463, \"center_x\": 10.144927536231883, \"center_y\": 9.275362318840578, \"value_uncond\": 0.0005545245487238043}, {\"x\": -10.0, \"y\": 9.420289855072465, \"x2\": -9.710144927536232, \"y2\": 9.710144927536232, \"center_x\": -9.855072463768117, \"center_y\": 9.565217391304348, \"value_uncond\": 6.452666313083046e-08}, {\"x\": -9.710144927536232, \"y\": 9.420289855072465, \"x2\": -9.420289855072465, \"y2\": 9.710144927536232, \"center_x\": -9.565217391304348, \"center_y\": 9.565217391304348, \"value_uncond\": 1.0081595582564033e-07}, {\"x\": -9.420289855072463, \"y\": 9.420289855072465, \"x2\": -9.130434782608695, \"y2\": 9.710144927536232, \"center_x\": -9.275362318840578, \"center_y\": 9.565217391304348, \"value_uncond\": 1.5605049531692952e-07}, {\"x\": -9.130434782608695, \"y\": 9.420289855072465, \"x2\": -8.840579710144928, \"y2\": 9.710144927536232, \"center_x\": -8.985507246376812, \"center_y\": 9.565217391304348, \"value_uncond\": 2.3930228500439113e-07}, {\"x\": -8.840579710144928, \"y\": 9.420289855072465, \"x2\": -8.55072463768116, \"y2\": 9.710144927536232, \"center_x\": -8.695652173913043, \"center_y\": 9.565217391304348, \"value_uncond\": 3.6355854288509836e-07}, {\"x\": -8.55072463768116, \"y\": 9.420289855072465, \"x2\": -8.260869565217392, \"y2\": 9.710144927536232, \"center_x\": -8.405797101449277, \"center_y\": 9.565217391304348, \"value_uncond\": 5.472020015447292e-07}, {\"x\": -8.26086956521739, \"y\": 9.420289855072465, \"x2\": -7.971014492753623, \"y2\": 9.710144927536232, \"center_x\": -8.115942028985508, \"center_y\": 9.565217391304348, \"value_uncond\": 8.15956140271452e-07}, {\"x\": -7.971014492753623, \"y\": 9.420289855072465, \"x2\": -7.681159420289855, \"y2\": 9.710144927536232, \"center_x\": -7.826086956521739, \"center_y\": 9.565217391304348, \"value_uncond\": 1.2054016098807787e-06}, {\"x\": -7.681159420289855, \"y\": 9.420289855072465, \"x2\": -7.391304347826088, \"y2\": 9.710144927536232, \"center_x\": -7.536231884057972, \"center_y\": 9.565217391304348, \"value_uncond\": 1.7641785360445216e-06}, {\"x\": -7.391304347826087, \"y\": 9.420289855072465, \"x2\": -7.101449275362319, \"y2\": 9.710144927536232, \"center_x\": -7.246376811594203, \"center_y\": 9.565217391304348, \"value_uncond\": 2.5579916071182954e-06}, {\"x\": -7.101449275362318, \"y\": 9.420289855072465, \"x2\": -6.811594202898551, \"y2\": 9.710144927536232, \"center_x\": -6.956521739130435, \"center_y\": 9.565217391304348, \"value_uncond\": 3.674527576762701e-06}, {\"x\": -6.811594202898551, \"y\": 9.420289855072465, \"x2\": -6.521739130434783, \"y2\": 9.710144927536232, \"center_x\": -6.666666666666667, \"center_y\": 9.565217391304348, \"value_uncond\": 5.229374218373128e-06}, {\"x\": -6.521739130434782, \"y\": 9.420289855072465, \"x2\": -6.231884057971015, \"y2\": 9.710144927536232, \"center_x\": -6.3768115942028984, \"center_y\": 9.565217391304348, \"value_uncond\": 7.372991722533171e-06}, {\"x\": -6.231884057971014, \"y\": 9.420289855072465, \"x2\": -5.942028985507246, \"y2\": 9.710144927536232, \"center_x\": -6.08695652173913, \"center_y\": 9.565217391304348, \"value_uncond\": 1.0298727944401408e-05}, {\"x\": -5.942028985507246, \"y\": 9.420289855072465, \"x2\": -5.6521739130434785, \"y2\": 9.710144927536232, \"center_x\": -5.797101449275362, \"center_y\": 9.565217391304348, \"value_uncond\": 1.425178426980903e-05}, {\"x\": -5.6521739130434785, \"y\": 9.420289855072465, \"x2\": -5.362318840579711, \"y2\": 9.710144927536232, \"center_x\": -5.507246376811595, \"center_y\": 9.565217391304348, \"value_uncond\": 1.9538926910290582e-05}, {\"x\": -5.36231884057971, \"y\": 9.420289855072465, \"x2\": -5.072463768115942, \"y2\": 9.710144927536232, \"center_x\": -5.217391304347826, \"center_y\": 9.565217391304348, \"value_uncond\": 2.6538598946131802e-05}, {\"x\": -5.0724637681159415, \"y\": 9.420289855072465, \"x2\": -4.782608695652174, \"y2\": 9.710144927536232, \"center_x\": -4.927536231884058, \"center_y\": 9.565217391304348, \"value_uncond\": 3.5710924127725504e-05}, {\"x\": -4.782608695652174, \"y\": 9.420289855072465, \"x2\": -4.492753623188406, \"y2\": 9.710144927536232, \"center_x\": -4.63768115942029, \"center_y\": 9.565217391304348, \"value_uncond\": 4.760691080443206e-05}, {\"x\": -4.492753623188405, \"y\": 9.420289855072465, \"x2\": -4.202898550724638, \"y2\": 9.710144927536232, \"center_x\": -4.3478260869565215, \"center_y\": 9.565217391304348, \"value_uncond\": 6.287597431574483e-05}, {\"x\": -4.202898550724638, \"y\": 9.420289855072465, \"x2\": -3.91304347826087, \"y2\": 9.710144927536232, \"center_x\": -4.057971014492754, \"center_y\": 9.565217391304348, \"value_uncond\": 8.227071450982501e-05}, {\"x\": -3.913043478260869, \"y\": 9.420289855072465, \"x2\": -3.6231884057971016, \"y2\": 9.710144927536232, \"center_x\": -3.7681159420289854, \"center_y\": 9.565217391304348, \"value_uncond\": 0.00010664773220414889}, {\"x\": -3.6231884057971016, \"y\": 9.420289855072465, \"x2\": -3.333333333333334, \"y2\": 9.710144927536232, \"center_x\": -3.4782608695652177, \"center_y\": 9.565217391304348, \"value_uncond\": 0.00013696316875519372}, {\"x\": -3.333333333333333, \"y\": 9.420289855072465, \"x2\": -3.0434782608695654, \"y2\": 9.710144927536232, \"center_x\": -3.1884057971014492, \"center_y\": 9.565217391304348, \"value_uncond\": 0.00017426163323724657}, {\"x\": -3.0434782608695645, \"y\": 9.420289855072465, \"x2\": -2.753623188405797, \"y2\": 9.710144927536232, \"center_x\": -2.8985507246376807, \"center_y\": 9.565217391304348, \"value_uncond\": 0.00021965726887570564}, {\"x\": -2.753623188405797, \"y\": 9.420289855072465, \"x2\": -2.4637681159420293, \"y2\": 9.710144927536232, \"center_x\": -2.608695652173913, \"center_y\": 9.565217391304348, \"value_uncond\": 0.00027430592812866244}, {\"x\": -2.4637681159420284, \"y\": 9.420289855072465, \"x2\": -2.1739130434782608, \"y2\": 9.710144927536232, \"center_x\": -2.3188405797101446, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0003393677912590714}, {\"x\": -2.1739130434782608, \"y\": 9.420289855072465, \"x2\": -1.8840579710144931, \"y2\": 9.710144927536232, \"center_x\": -2.028985507246377, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0004159602829048383}, {\"x\": -1.8840579710144922, \"y\": 9.420289855072465, \"x2\": -1.5942028985507246, \"y2\": 9.710144927536232, \"center_x\": -1.7391304347826084, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0005051018073111961}, {\"x\": -1.5942028985507246, \"y\": 9.420289855072465, \"x2\": -1.304347826086957, \"y2\": 9.710144927536232, \"center_x\": -1.4492753623188408, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0006076476106938192}, {\"x\": -1.304347826086957, \"y\": 9.420289855072465, \"x2\": -1.0144927536231894, \"y2\": 9.710144927536232, \"center_x\": -1.1594202898550732, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0007242199451793476}, {\"x\": -1.0144927536231876, \"y\": 9.420289855072465, \"x2\": -0.72463768115942, \"y2\": 9.710144927536232, \"center_x\": -0.8695652173913038, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0008551355912321872}, {\"x\": -0.72463768115942, \"y\": 9.420289855072465, \"x2\": -0.43478260869565233, \"y2\": 9.710144927536232, \"center_x\": -0.5797101449275361, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0010003346172510537}, {\"x\": -0.43478260869565233, \"y\": 9.420289855072465, \"x2\": -0.1449275362318847, \"y2\": 9.710144927536232, \"center_x\": -0.2898550724637685, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0011593149286837669}, {\"x\": -0.14492753623188293, \"y\": 9.420289855072465, \"x2\": 0.1449275362318847, \"y2\": 9.710144927536232, \"center_x\": 8.881784197001252e-16, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0013310775944750685}, {\"x\": 0.1449275362318847, \"y\": 9.420289855072465, \"x2\": 0.43478260869565233, \"y2\": 9.710144927536232, \"center_x\": 0.2898550724637685, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0015140880526015143}, {\"x\": 0.43478260869565233, \"y\": 9.420289855072465, \"x2\": 0.72463768115942, \"y2\": 9.710144927536232, \"center_x\": 0.5797101449275361, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0017062580226999535}, {\"x\": 0.72463768115942, \"y\": 9.420289855072465, \"x2\": 1.0144927536231876, \"y2\": 9.710144927536232, \"center_x\": 0.8695652173913038, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0019049522535894748}, {\"x\": 1.0144927536231894, \"y\": 9.420289855072465, \"x2\": 1.304347826086957, \"y2\": 9.710144927536232, \"center_x\": 1.1594202898550732, \"center_y\": 9.565217391304348, \"value_uncond\": 0.00210702310411812}, {\"x\": 1.304347826086957, \"y\": 9.420289855072465, \"x2\": 1.5942028985507246, \"y2\": 9.710144927536232, \"center_x\": 1.4492753623188408, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0023088744363809082}, {\"x\": 1.5942028985507246, \"y\": 9.420289855072465, \"x2\": 1.8840579710144922, \"y2\": 9.710144927536232, \"center_x\": 1.7391304347826084, \"center_y\": 9.565217391304348, \"value_uncond\": 0.002506554473650362}, {\"x\": 1.884057971014494, \"y\": 9.420289855072465, \"x2\": 2.1739130434782616, \"y2\": 9.710144927536232, \"center_x\": 2.028985507246378, \"center_y\": 9.565217391304348, \"value_uncond\": 0.002695875264406846}, {\"x\": 2.1739130434782616, \"y\": 9.420289855072465, \"x2\": 2.4637681159420293, \"y2\": 9.710144927536232, \"center_x\": 2.3188405797101455, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0028725543538226468}, {\"x\": 2.4637681159420293, \"y\": 9.420289855072465, \"x2\": 2.753623188405797, \"y2\": 9.710144927536232, \"center_x\": 2.608695652173913, \"center_y\": 9.565217391304348, \"value_uncond\": 0.003032372369244177}, {\"x\": 2.753623188405797, \"y\": 9.420289855072465, \"x2\": 3.0434782608695645, \"y2\": 9.710144927536232, \"center_x\": 2.8985507246376807, \"center_y\": 9.565217391304348, \"value_uncond\": 0.003171338653535138}, {\"x\": 3.0434782608695663, \"y\": 9.420289855072465, \"x2\": 3.333333333333334, \"y2\": 9.710144927536232, \"center_x\": 3.18840579710145, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0032858559906926666}, {\"x\": 3.333333333333334, \"y\": 9.420289855072465, \"x2\": 3.6231884057971016, \"y2\": 9.710144927536232, \"center_x\": 3.4782608695652177, \"center_y\": 9.565217391304348, \"value_uncond\": 0.00337287498907646}, {\"x\": 3.6231884057971016, \"y\": 9.420289855072465, \"x2\": 3.913043478260869, \"y2\": 9.710144927536232, \"center_x\": 3.7681159420289854, \"center_y\": 9.565217391304348, \"value_uncond\": 0.003430028896448236}, {\"x\": 3.913043478260871, \"y\": 9.420289855072465, \"x2\": 4.202898550724639, \"y2\": 9.710144927536232, \"center_x\": 4.057971014492755, \"center_y\": 9.565217391304348, \"value_uncond\": 0.003455740534725601}, {\"x\": 4.202898550724639, \"y\": 9.420289855072465, \"x2\": 4.492753623188406, \"y2\": 9.710144927536232, \"center_x\": 4.347826086956522, \"center_y\": 9.565217391304348, \"value_uncond\": 0.003449294612401767}, {\"x\": 4.492753623188406, \"y\": 9.420289855072465, \"x2\": 4.782608695652174, \"y2\": 9.710144927536232, \"center_x\": 4.63768115942029, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0034108707873688354}, {\"x\": 4.782608695652174, \"y\": 9.420289855072465, \"x2\": 5.0724637681159415, \"y2\": 9.710144927536232, \"center_x\": 4.927536231884058, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0033415353471874256}, {\"x\": 5.072463768115943, \"y\": 9.420289855072465, \"x2\": 5.362318840579711, \"y2\": 9.710144927536232, \"center_x\": 5.217391304347827, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0032431920445220664}, {\"x\": 5.362318840579711, \"y\": 9.420289855072465, \"x2\": 5.6521739130434785, \"y2\": 9.710144927536232, \"center_x\": 5.507246376811595, \"center_y\": 9.565217391304348, \"value_uncond\": 0.003118495251592849}, {\"x\": 5.6521739130434785, \"y\": 9.420289855072465, \"x2\": 5.942028985507246, \"y2\": 9.710144927536232, \"center_x\": 5.797101449275362, \"center_y\": 9.565217391304348, \"value_uncond\": 0.002970730962658476}, {\"x\": 5.942028985507246, \"y\": 9.420289855072465, \"x2\": 6.231884057971014, \"y2\": 9.710144927536232, \"center_x\": 6.08695652173913, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0028036730875515285}, {\"x\": 6.2318840579710155, \"y\": 9.420289855072465, \"x2\": 6.521739130434783, \"y2\": 9.710144927536232, \"center_x\": 6.376811594202899, \"center_y\": 9.565217391304348, \"value_uncond\": 0.002621423796794503}, {\"x\": 6.521739130434785, \"y\": 9.420289855072465, \"x2\": 6.8115942028985526, \"y2\": 9.710144927536232, \"center_x\": 6.666666666666669, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0024282473127226916}, {\"x\": 6.811594202898551, \"y\": 9.420289855072465, \"x2\": 7.101449275362318, \"y2\": 9.710144927536232, \"center_x\": 6.956521739130435, \"center_y\": 9.565217391304348, \"value_uncond\": 0.002228406469119295}, {\"x\": 7.10144927536232, \"y\": 9.420289855072465, \"x2\": 7.391304347826088, \"y2\": 9.710144927536232, \"center_x\": 7.246376811594204, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0020260106262554294}, {\"x\": 7.391304347826086, \"y\": 9.420289855072465, \"x2\": 7.681159420289854, \"y2\": 9.710144927536232, \"center_x\": 7.53623188405797, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0018248822279375043}, {\"x\": 7.681159420289855, \"y\": 9.420289855072465, \"x2\": 7.971014492753623, \"y2\": 9.710144927536232, \"center_x\": 7.826086956521739, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0016284475649946393}, {\"x\": 7.971014492753625, \"y\": 9.420289855072465, \"x2\": 8.260869565217392, \"y2\": 9.710144927536232, \"center_x\": 8.115942028985508, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0014396553352556355}, {\"x\": 8.26086956521739, \"y\": 9.420289855072465, \"x2\": 8.550724637681158, \"y2\": 9.710144927536232, \"center_x\": 8.405797101449274, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0012609245414797678}, {\"x\": 8.55072463768116, \"y\": 9.420289855072465, \"x2\": 8.840579710144928, \"y2\": 9.710144927536232, \"center_x\": 8.695652173913043, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0010941213143847602}, {\"x\": 8.84057971014493, \"y\": 9.420289855072465, \"x2\": 9.130434782608697, \"y2\": 9.710144927536232, \"center_x\": 8.985507246376812, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0009405625314996294}, {\"x\": 9.130434782608695, \"y\": 9.420289855072465, \"x2\": 9.420289855072463, \"y2\": 9.710144927536232, \"center_x\": 9.275362318840578, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0008010427316908976}, {\"x\": 9.420289855072465, \"y\": 9.420289855072465, \"x2\": 9.710144927536232, \"y2\": 9.710144927536232, \"center_x\": 9.565217391304348, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0006758798652396694}, {\"x\": 9.710144927536234, \"y\": 9.420289855072465, \"x2\": 10.000000000000002, \"y2\": 9.710144927536232, \"center_x\": 9.855072463768117, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0005649748922351057}, {\"x\": 10.0, \"y\": 9.420289855072465, \"x2\": 10.289855072463768, \"y2\": 9.710144927536232, \"center_x\": 10.144927536231883, \"center_y\": 9.565217391304348, \"value_uncond\": 0.0004678801297808369}, {\"x\": -10.0, \"y\": 9.710144927536234, \"x2\": -9.710144927536232, \"y2\": 10.000000000000002, \"center_x\": -9.855072463768117, \"center_y\": 9.855072463768117, \"value_uncond\": 5.3938497688053584e-08}, {\"x\": -9.710144927536232, \"y\": 9.710144927536234, \"x2\": -9.420289855072465, \"y2\": 10.000000000000002, \"center_x\": -9.565217391304348, \"center_y\": 9.855072463768117, \"value_uncond\": 8.427308861756474e-08}, {\"x\": -9.420289855072463, \"y\": 9.710144927536234, \"x2\": -9.130434782608695, \"y2\": 10.000000000000002, \"center_x\": -9.275362318840578, \"center_y\": 9.855072463768117, \"value_uncond\": 1.3044420511573268e-07}, {\"x\": -9.130434782608695, \"y\": 9.710144927536234, \"x2\": -8.840579710144928, \"y2\": 10.000000000000002, \"center_x\": -8.985507246376812, \"center_y\": 9.855072463768117, \"value_uncond\": 2.0003522761257018e-07}, {\"x\": -8.840579710144928, \"y\": 9.710144927536234, \"x2\": -8.55072463768116, \"y2\": 10.000000000000002, \"center_x\": -8.695652173913043, \"center_y\": 9.855072463768117, \"value_uncond\": 3.039023044647501e-07}, {\"x\": -8.55072463768116, \"y\": 9.710144927536234, \"x2\": -8.260869565217392, \"y2\": 10.000000000000002, \"center_x\": -8.405797101449277, \"center_y\": 9.855072463768117, \"value_uncond\": 4.5741174985874186e-07}, {\"x\": -8.26086956521739, \"y\": 9.710144927536234, \"x2\": -7.971014492753623, \"y2\": 10.000000000000002, \"center_x\": -8.115942028985508, \"center_y\": 9.855072463768117, \"value_uncond\": 6.820660832305835e-07}, {\"x\": -7.971014492753623, \"y\": 9.710144927536234, \"x2\": -7.681159420289855, \"y2\": 10.000000000000002, \"center_x\": -7.826086956521739, \"center_y\": 9.855072463768117, \"value_uncond\": 1.0076075345149136e-06}, {\"x\": -7.681159420289855, \"y\": 9.710144927536234, \"x2\": -7.391304347826088, \"y2\": 10.000000000000002, \"center_x\": -7.536231884057972, \"center_y\": 9.855072463768117, \"value_uncond\": 1.4746948822507115e-06}, {\"x\": -7.391304347826087, \"y\": 9.710144927536234, \"x2\": -7.101449275362319, \"y2\": 10.000000000000002, \"center_x\": -7.246376811594203, \"center_y\": 9.855072463768117, \"value_uncond\": 2.138251347460231e-06}, {\"x\": -7.101449275362318, \"y\": 9.710144927536234, \"x2\": -6.811594202898551, \"y2\": 10.000000000000002, \"center_x\": -6.956521739130435, \"center_y\": 9.855072463768117, \"value_uncond\": 3.071575184386158e-06}, {\"x\": -6.811594202898551, \"y\": 9.710144927536234, \"x2\": -6.521739130434783, \"y2\": 10.000000000000002, \"center_x\": -6.666666666666667, \"center_y\": 9.855072463768117, \"value_uncond\": 4.371287395038365e-06}, {\"x\": -6.521739130434782, \"y\": 9.710144927536234, \"x2\": -6.231884057971015, \"y2\": 10.000000000000002, \"center_x\": -6.3768115942028984, \"center_y\": 9.855072463768117, \"value_uncond\": 6.1631591916285065e-06}, {\"x\": -6.231884057971014, \"y\": 9.710144927536234, \"x2\": -5.942028985507246, \"y2\": 10.000000000000002, \"center_x\": -6.08695652173913, \"center_y\": 9.855072463768117, \"value_uncond\": 8.608812023840343e-06}, {\"x\": -5.942028985507246, \"y\": 9.710144927536234, \"x2\": -5.6521739130434785, \"y2\": 10.000000000000002, \"center_x\": -5.797101449275362, \"center_y\": 9.855072463768117, \"value_uncond\": 1.191321223800342e-05}, {\"x\": -5.6521739130434785, \"y\": 9.710144927536234, \"x2\": -5.362318840579711, \"y2\": 10.000000000000002, \"center_x\": -5.507246376811595, \"center_y\": 9.855072463768117, \"value_uncond\": 1.6332788847936102e-05}, {\"x\": -5.36231884057971, \"y\": 9.710144927536234, \"x2\": -5.072463768115942, \"y2\": 10.000000000000002, \"center_x\": -5.217391304347826, \"center_y\": 9.855072463768117, \"value_uncond\": 2.2183886295154995e-05}, {\"x\": -5.0724637681159415, \"y\": 9.710144927536234, \"x2\": -4.782608695652174, \"y2\": 10.000000000000002, \"center_x\": -4.927536231884058, \"center_y\": 9.855072463768117, \"value_uncond\": 2.9851126728746904e-05}, {\"x\": -4.782608695652174, \"y\": 9.710144927536234, \"x2\": -4.492753623188406, \"y2\": 10.000000000000002, \"center_x\": -4.63768115942029, \"center_y\": 9.855072463768117, \"value_uncond\": 3.979510366364091e-05}, {\"x\": -4.492753623188405, \"y\": 9.710144927536234, \"x2\": -4.202898550724638, \"y2\": 10.000000000000002, \"center_x\": -4.3478260869565215, \"center_y\": 9.855072463768117, \"value_uncond\": 5.25586700243223e-05}, {\"x\": -4.202898550724638, \"y\": 9.710144927536234, \"x2\": -3.91304347826087, \"y2\": 10.000000000000002, \"center_x\": -4.057971014492754, \"center_y\": 9.855072463768117, \"value_uncond\": 6.877093172144017e-05}, {\"x\": -3.913043478260869, \"y\": 9.710144927536234, \"x2\": -3.6231884057971016, \"y2\": 10.000000000000002, \"center_x\": -3.7681159420289854, \"center_y\": 9.855072463768117, \"value_uncond\": 8.914793013961349e-05}, {\"x\": -3.6231884057971016, \"y\": 9.710144927536234, \"x2\": -3.333333333333334, \"y2\": 10.000000000000002, \"center_x\": -3.4782608695652177, \"center_y\": 9.855072463768117, \"value_uncond\": 0.00011448891361810975}, {\"x\": -3.333333333333333, \"y\": 9.710144927536234, \"x2\": -3.0434782608695654, \"y2\": 10.000000000000002, \"center_x\": -3.1884057971014492, \"center_y\": 9.855072463768117, \"value_uncond\": 0.00014566708156635937}, {\"x\": -3.0434782608695645, \"y\": 9.710144927536234, \"x2\": -2.753623188405797, \"y2\": 10.000000000000002, \"center_x\": -2.8985507246376807, \"center_y\": 9.855072463768117, \"value_uncond\": 0.00018361375770189993}, {\"x\": -2.753623188405797, \"y\": 9.710144927536234, \"x2\": -2.4637681159420293, \"y2\": 10.000000000000002, \"center_x\": -2.608695652173913, \"center_y\": 9.855072463768117, \"value_uncond\": 0.00022929513091647812}, {\"x\": -2.4637681159420284, \"y\": 9.710144927536234, \"x2\": -2.1739130434782608, \"y2\": 10.000000000000002, \"center_x\": -2.3188405797101446, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0002836810077581909}, {\"x\": -2.1739130434782608, \"y\": 9.710144927536234, \"x2\": -1.8840579710144931, \"y2\": 10.000000000000002, \"center_x\": -2.028985507246377, \"center_y\": 9.855072463768117, \"value_uncond\": 0.00034770545491085266}, {\"x\": -1.8840579710144922, \"y\": 9.710144927536234, \"x2\": -1.5942028985507246, \"y2\": 10.000000000000002, \"center_x\": -1.7391304347826084, \"center_y\": 9.855072463768117, \"value_uncond\": 0.00042221976689926533}, {\"x\": -1.5942028985507246, \"y\": 9.710144927536234, \"x2\": -1.304347826086957, \"y2\": 10.000000000000002, \"center_x\": -1.4492753623188408, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0005079388527825467}, {\"x\": -1.304347826086957, \"y\": 9.710144927536234, \"x2\": -1.0144927536231894, \"y2\": 10.000000000000002, \"center_x\": -1.1594202898550732, \"center_y\": 9.855072463768117, \"value_uncond\": 0.000605382859477733}, {\"x\": -1.0144927536231876, \"y\": 9.710144927536234, \"x2\": -0.72463768115942, \"y2\": 10.000000000000002, \"center_x\": -0.8695652173913038, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0007148165870150437}, {\"x\": -0.72463768115942, \"y\": 9.710144927536234, \"x2\": -0.43478260869565233, \"y2\": 10.000000000000002, \"center_x\": -0.5797101449275361, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0008361899379559863}, {\"x\": -0.43478260869565233, \"y\": 9.710144927536234, \"x2\": -0.1449275362318847, \"y2\": 10.000000000000002, \"center_x\": -0.2898550724637685, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0009690832063289839}, {\"x\": -0.14492753623188293, \"y\": 9.710144927536234, \"x2\": 0.1449275362318847, \"y2\": 10.000000000000002, \"center_x\": 8.881784197001252e-16, \"center_y\": 9.855072463768117, \"value_uncond\": 0.001112661375447905}, {\"x\": 0.1449275362318847, \"y\": 9.710144927536234, \"x2\": 0.43478260869565233, \"y2\": 10.000000000000002, \"center_x\": 0.2898550724637685, \"center_y\": 9.855072463768117, \"value_uncond\": 0.001265641689221894}, {\"x\": 0.43478260869565233, \"y\": 9.710144927536234, \"x2\": 0.72463768115942, \"y2\": 10.000000000000002, \"center_x\": 0.5797101449275361, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0014262785327365166}, {\"x\": 0.72463768115942, \"y\": 9.710144927536234, \"x2\": 1.0144927536231876, \"y2\": 10.000000000000002, \"center_x\": 0.8695652173913038, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0015923690725763713}, {\"x\": 1.0144927536231894, \"y\": 9.710144927536234, \"x2\": 1.304347826086957, \"y2\": 10.000000000000002, \"center_x\": 1.1594202898550732, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0017612821633085447}, {\"x\": 1.304347826086957, \"y\": 9.710144927536234, \"x2\": 1.5942028985507246, \"y2\": 10.000000000000002, \"center_x\": 1.4492753623188408, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0019300117564770617}, {\"x\": 1.5942028985507246, \"y\": 9.710144927536234, \"x2\": 1.8840579710144922, \"y2\": 10.000000000000002, \"center_x\": 1.7391304347826084, \"center_y\": 9.855072463768117, \"value_uncond\": 0.002095254521496756}, {\"x\": 1.884057971014494, \"y\": 9.710144927536234, \"x2\": 2.1739130434782616, \"y2\": 10.000000000000002, \"center_x\": 2.028985507246378, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0022535097068581075}, {\"x\": 2.1739130434782616, \"y\": 9.710144927536234, \"x2\": 2.4637681159420293, \"y2\": 10.000000000000002, \"center_x\": 2.3188405797101455, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0024011975647697976}, {\"x\": 2.4637681159420293, \"y\": 9.710144927536234, \"x2\": 2.753623188405797, \"y2\": 10.000000000000002, \"center_x\": 2.608695652173913, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0025347910784750617}, {\"x\": 2.753623188405797, \"y\": 9.710144927536234, \"x2\": 3.0434782608695645, \"y2\": 10.000000000000002, \"center_x\": 2.8985507246376807, \"center_y\": 9.855072463768117, \"value_uncond\": 0.002650954416857331}, {\"x\": 3.0434782608695663, \"y\": 9.710144927536234, \"x2\": 3.333333333333334, \"y2\": 10.000000000000002, \"center_x\": 3.18840579710145, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0027466806302675847}, {\"x\": 3.333333333333334, \"y\": 9.710144927536234, \"x2\": 3.6231884057971016, \"y2\": 10.000000000000002, \"center_x\": 3.4782608695652177, \"center_y\": 9.855072463768117, \"value_uncond\": 0.002819420701044596}, {\"x\": 3.6231884057971016, \"y\": 9.710144927536234, \"x2\": 3.913043478260869, \"y2\": 10.000000000000002, \"center_x\": 3.7681159420289854, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0028671962367853064}, {\"x\": 3.913043478260871, \"y\": 9.710144927536234, \"x2\": 4.202898550724639, \"y2\": 10.000000000000002, \"center_x\": 4.057971014492755, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0028886888581993076}, {\"x\": 4.202898550724639, \"y\": 9.710144927536234, \"x2\": 4.492753623188406, \"y2\": 10.000000000000002, \"center_x\": 4.347826086956522, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0028833006458000928}, {\"x\": 4.492753623188406, \"y\": 9.710144927536234, \"x2\": 4.782608695652174, \"y2\": 10.000000000000002, \"center_x\": 4.63768115942029, \"center_y\": 9.855072463768117, \"value_uncond\": 0.002851181777457206}, {\"x\": 4.782608695652174, \"y\": 9.710144927536234, \"x2\": 5.0724637681159415, \"y2\": 10.000000000000002, \"center_x\": 4.927536231884058, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0027932235738485287}, {\"x\": 5.072463768115943, \"y\": 9.710144927536234, \"x2\": 5.362318840579711, \"y2\": 10.000000000000002, \"center_x\": 5.217391304347827, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0027110174012978747}, {\"x\": 5.362318840579711, \"y\": 9.710144927536234, \"x2\": 5.6521739130434785, \"y2\": 10.000000000000002, \"center_x\": 5.507246376811595, \"center_y\": 9.855072463768117, \"value_uncond\": 0.002606782076692864}, {\"x\": 5.6521739130434785, \"y\": 9.710144927536234, \"x2\": 5.942028985507246, \"y2\": 10.000000000000002, \"center_x\": 5.797101449275362, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0024832643962434085}, {\"x\": 5.942028985507246, \"y\": 9.710144927536234, \"x2\": 6.231884057971014, \"y2\": 10.000000000000002, \"center_x\": 6.08695652173913, \"center_y\": 9.855072463768117, \"value_uncond\": 0.002343619009778012}, {\"x\": 6.2318840579710155, \"y\": 9.710144927536234, \"x2\": 6.521739130434783, \"y2\": 10.000000000000002, \"center_x\": 6.376811594202899, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0021912749635933215}, {\"x\": 6.521739130434785, \"y\": 9.710144927536234, \"x2\": 6.8115942028985526, \"y2\": 10.000000000000002, \"center_x\": 6.666666666666669, \"center_y\": 9.855072463768117, \"value_uncond\": 0.002029796764753759}, {\"x\": 6.811594202898551, \"y\": 9.710144927536234, \"x2\": 7.101449275362318, \"y2\": 10.000000000000002, \"center_x\": 6.956521739130435, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0018627477596188527}, {\"x\": 7.10144927536232, \"y\": 9.710144927536234, \"x2\": 7.391304347826088, \"y2\": 10.000000000000002, \"center_x\": 7.246376811594204, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0016935630044696544}, {\"x\": 7.391304347826086, \"y\": 9.710144927536234, \"x2\": 7.681159420289854, \"y2\": 10.000000000000002, \"center_x\": 7.53623188405797, \"center_y\": 9.855072463768117, \"value_uncond\": 0.001525437719179798}, {\"x\": 7.681159420289855, \"y\": 9.710144927536234, \"x2\": 7.971014492753623, \"y2\": 10.000000000000002, \"center_x\": 7.826086956521739, \"center_y\": 9.855072463768117, \"value_uncond\": 0.001361235975297355}, {\"x\": 7.971014492753625, \"y\": 9.710144927536234, \"x2\": 8.260869565217392, \"y2\": 10.000000000000002, \"center_x\": 8.115942028985508, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0012034226194966226}, {\"x\": 8.26086956521739, \"y\": 9.710144927536234, \"x2\": 8.550724637681158, \"y2\": 10.000000000000002, \"center_x\": 8.405797101449274, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0010540197209255755}, {\"x\": 8.55072463768116, \"y\": 9.710144927536234, \"x2\": 8.840579710144928, \"y2\": 10.000000000000002, \"center_x\": 8.695652173913043, \"center_y\": 9.855072463768117, \"value_uncond\": 0.000914587197337893}, {\"x\": 8.84057971014493, \"y\": 9.710144927536234, \"x2\": 9.130434782608697, \"y2\": 10.000000000000002, \"center_x\": 8.985507246376812, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0007862258401290695}, {\"x\": 9.130434782608695, \"y\": 9.710144927536234, \"x2\": 9.420289855072463, \"y2\": 10.000000000000002, \"center_x\": 9.275362318840578, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0006695998124641526}, {\"x\": 9.420289855072465, \"y\": 9.710144927536234, \"x2\": 9.710144927536232, \"y2\": 10.000000000000002, \"center_x\": 9.565217391304348, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0005649748922351057}, {\"x\": 9.710144927536234, \"y\": 9.710144927536234, \"x2\": 10.000000000000002, \"y2\": 10.000000000000002, \"center_x\": 9.855072463768117, \"center_y\": 9.855072463768117, \"value_uncond\": 0.0004722682909674797}, {\"x\": 10.0, \"y\": 9.710144927536234, \"x2\": 10.289855072463768, \"y2\": 10.000000000000002, \"center_x\": 10.144927536231883, \"center_y\": 9.855072463768117, \"value_uncond\": 0.00039110578594931143}, {\"x\": -10.0, \"y\": 10.0, \"x2\": -9.710144927536232, \"y2\": 10.289855072463768, \"center_x\": -9.855072463768117, \"center_y\": 10.144927536231883, \"value_uncond\": 4.466880147298297e-08}, {\"x\": -9.710144927536232, \"y\": 10.0, \"x2\": -9.420289855072465, \"y2\": 10.289855072463768, \"center_x\": -9.565217391304348, \"center_y\": 10.144927536231883, \"value_uncond\": 6.979018746024219e-08}, {\"x\": -9.420289855072463, \"y\": 10.0, \"x2\": -9.130434782608695, \"y2\": 10.289855072463768, \"center_x\": -9.275362318840578, \"center_y\": 10.144927536231883, \"value_uncond\": 1.080264848182129e-07}, {\"x\": -9.130434782608695, \"y\": 10.0, \"x2\": -8.840579710144928, \"y2\": 10.289855072463768, \"center_x\": -8.985507246376812, \"center_y\": 10.144927536231883, \"value_uncond\": 1.6565781867906704e-07}, {\"x\": -8.840579710144928, \"y\": 10.0, \"x2\": -8.55072463768116, \"y2\": 10.289855072463768, \"center_x\": -8.695652173913043, \"center_y\": 10.144927536231883, \"value_uncond\": 2.5167463476322513e-07}, {\"x\": -8.55072463768116, \"y\": 10.0, \"x2\": -8.260869565217392, \"y2\": 10.289855072463768, \"center_x\": -8.405797101449277, \"center_y\": 10.144927536231883, \"value_uncond\": 3.7880244207052163e-07}, {\"x\": -8.26086956521739, \"y\": 10.0, \"x2\": -7.971014492753623, \"y2\": 10.289855072463768, \"center_x\": -8.115942028985508, \"center_y\": 10.144927536231883, \"value_uncond\": 5.648484064106578e-07}, {\"x\": -7.971014492753623, \"y\": 10.0, \"x2\": -7.681159420289855, \"y2\": 10.289855072463768, \"center_x\": -7.826086956521739, \"center_y\": 10.144927536231883, \"value_uncond\": 8.344433540257313e-07}, {\"x\": -7.681159420289855, \"y\": 10.0, \"x2\": -7.391304347826088, \"y2\": 10.289855072463768, \"center_x\": -7.536231884057972, \"center_y\": 10.144927536231883, \"value_uncond\": 1.221258576934201e-06}, {\"x\": -7.391304347826087, \"y\": 10.0, \"x2\": -7.101449275362319, \"y2\": 10.289855072463768, \"center_x\": -7.246376811594203, \"center_y\": 10.144927536231883, \"value_uncond\": 1.770778368567611e-06}, {\"x\": -7.101449275362318, \"y\": 10.0, \"x2\": -6.811594202898551, \"y2\": 10.289855072463768, \"center_x\": -6.956521739130435, \"center_y\": 10.144927536231883, \"value_uncond\": 2.5437041816438e-06}, {\"x\": -6.811594202898551, \"y\": 10.0, \"x2\": -6.521739130434783, \"y2\": 10.289855072463768, \"center_x\": -6.666666666666667, \"center_y\": 10.144927536231883, \"value_uncond\": 3.6200520444522546e-06}, {\"x\": -6.521739130434782, \"y\": 10.0, \"x2\": -6.231884057971015, \"y2\": 10.289855072463768, \"center_x\": -6.3768115942028984, \"center_y\": 10.144927536231883, \"value_uncond\": 5.103978534393217e-06}, {\"x\": -6.231884057971014, \"y\": 10.0, \"x2\": -5.942028985507246, \"y2\": 10.289855072463768, \"center_x\": -6.08695652173913, \"center_y\": 10.144927536231883, \"value_uncond\": 7.1293293601746525e-06}, {\"x\": -5.942028985507246, \"y\": 10.0, \"x2\": -5.6521739130434785, \"y2\": 10.289855072463768, \"center_x\": -5.797101449275362, \"center_y\": 10.144927536231883, \"value_uncond\": 9.865846013036942e-06}, {\"x\": -5.6521739130434785, \"y\": 10.0, \"x2\": -5.362318840579711, \"y2\": 10.289855072463768, \"center_x\": -5.507246376811595, \"center_y\": 10.144927536231883, \"value_uncond\": 1.3525888443685628e-05}, {\"x\": -5.36231884057971, \"y\": 10.0, \"x2\": -5.072463768115942, \"y2\": 10.289855072463768, \"center_x\": -5.217391304347826, \"center_y\": 10.144927536231883, \"value_uncond\": 1.837143515839854e-05}, {\"x\": -5.0724637681159415, \"y\": 10.0, \"x2\": -4.782608695652174, \"y2\": 10.289855072463768, \"center_x\": -4.927536231884058, \"center_y\": 10.144927536231883, \"value_uncond\": 2.4721008384454473e-05}, {\"x\": -4.782608695652174, \"y\": 10.0, \"x2\": -4.492753623188406, \"y2\": 10.289855072463768, \"center_x\": -4.63768115942029, \"center_y\": 10.144927536231883, \"value_uncond\": 3.29560455211132e-05}, {\"x\": -4.492753623188405, \"y\": 10.0, \"x2\": -4.202898550724638, \"y2\": 10.289855072463768, \"center_x\": -4.3478260869565215, \"center_y\": 10.144927536231883, \"value_uncond\": 4.3526106540421027e-05}, {\"x\": -4.202898550724638, \"y\": 10.0, \"x2\": -3.91304347826087, \"y2\": 10.289855072463768, \"center_x\": -4.057971014492754, \"center_y\": 10.144927536231883, \"value_uncond\": 5.695218124062533e-05}, {\"x\": -3.913043478260869, \"y\": 10.0, \"x2\": -3.6231884057971016, \"y2\": 10.289855072463768, \"center_x\": -3.7681159420289854, \"center_y\": 10.144927536231883, \"value_uncond\": 7.382725444382787e-05}, {\"x\": -3.6231884057971016, \"y\": 10.0, \"x2\": -3.333333333333334, \"y2\": 10.289855072463768, \"center_x\": -3.4782608695652177, \"center_y\": 10.144927536231883, \"value_uncond\": 9.48132182479661e-05}, {\"x\": -3.333333333333333, \"y\": 10.0, \"x2\": -3.0434782608695654, \"y2\": 10.289855072463768, \"center_x\": -3.1884057971014492, \"center_y\": 10.144927536231883, \"value_uncond\": 0.00012063320682877794}, {\"x\": -3.0434782608695645, \"y\": 10.0, \"x2\": -2.753623188405797, \"y2\": 10.289855072463768, \"center_x\": -2.8985507246376807, \"center_y\": 10.144927536231883, \"value_uncond\": 0.00015205848961401678}, {\"x\": -2.753623188405797, \"y\": 10.0, \"x2\": -2.4637681159420293, \"y2\": 10.289855072463768, \"center_x\": -2.608695652173913, \"center_y\": 10.144927536231883, \"value_uncond\": 0.00018988920938927623}, {\"x\": -2.4637681159420284, \"y\": 10.0, \"x2\": -2.1739130434782608, \"y2\": 10.289855072463768, \"center_x\": -2.3188405797101446, \"center_y\": 10.144927536231883, \"value_uncond\": 0.00023492850487774955}, {\"x\": -2.1739130434782608, \"y\": 10.0, \"x2\": -1.8840579710144931, \"y2\": 10.289855072463768, \"center_x\": -2.028985507246377, \"center_y\": 10.144927536231883, \"value_uncond\": 0.00028794991707613093}, {\"x\": -1.8840579710144922, \"y\": 10.0, \"x2\": -1.5942028985507246, \"y2\": 10.289855072463768, \"center_x\": -1.7391304347826084, \"center_y\": 10.144927536231883, \"value_uncond\": 0.00034965843977834024}, {\"x\": -1.5942028985507246, \"y\": 10.0, \"x2\": -1.304347826086957, \"y2\": 10.289855072463768, \"center_x\": -1.4492753623188408, \"center_y\": 10.144927536231883, \"value_uncond\": 0.00042064612007878583}, {\"x\": -1.304347826086957, \"y\": 10.0, \"x2\": -1.0144927536231894, \"y2\": 10.289855072463768, \"center_x\": -1.1594202898550732, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0005013437141232592}, {\"x\": -1.0144927536231876, \"y\": 10.0, \"x2\": -0.72463768115942, \"y2\": 10.289855072463768, \"center_x\": -0.8695652173913038, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0005919705142629914}, {\"x\": -0.72463768115942, \"y\": 10.0, \"x2\": -0.43478260869565233, \"y2\": 10.289855072463768, \"center_x\": -0.5797101449275361, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0006924850326436628}, {\"x\": -0.43478260869565233, \"y\": 10.0, \"x2\": -0.1449275362318847, \"y2\": 10.289855072463768, \"center_x\": -0.2898550724637685, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0008025396926080617}, {\"x\": -0.14492753623188293, \"y\": 10.0, \"x2\": 0.1449275362318847, \"y2\": 10.289855072463768, \"center_x\": 8.881784197001252e-16, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0009214429807440965}, {\"x\": 0.1449275362318847, \"y\": 10.0, \"x2\": 0.43478260869565233, \"y2\": 10.289855072463768, \"center_x\": 0.2898550724637685, \"center_y\": 10.144927536231883, \"value_uncond\": 0.001048132591284704}, {\"x\": 0.43478260869565233, \"y\": 10.0, \"x2\": 0.72463768115942, \"y2\": 10.289855072463768, \"center_x\": 0.5797101449275361, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0011811629050635496}, {\"x\": 0.72463768115942, \"y\": 10.0, \"x2\": 1.0144927536231876, \"y2\": 10.289855072463768, \"center_x\": 0.8695652173913038, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0013187096605099884}, {\"x\": 1.0144927536231894, \"y\": 10.0, \"x2\": 1.304347826086957, \"y2\": 10.289855072463768, \"center_x\": 1.1594202898550732, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0014585938923575234}, {\"x\": 1.304347826086957, \"y\": 10.0, \"x2\": 1.5942028985507246, \"y2\": 10.289855072463768, \"center_x\": 1.4492753623188408, \"center_y\": 10.144927536231883, \"value_uncond\": 0.001598326161940756}, {\"x\": 1.5942028985507246, \"y\": 10.0, \"x2\": 1.8840579710144922, \"y2\": 10.289855072463768, \"center_x\": 1.7391304347826084, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0017351708384128314}, {\"x\": 1.884057971014494, \"y\": 10.0, \"x2\": 2.1739130434782616, \"y2\": 10.289855072463768, \"center_x\": 2.028985507246378, \"center_y\": 10.144927536231883, \"value_uncond\": 0.001866228798125752}, {\"x\": 2.1739130434782616, \"y\": 10.0, \"x2\": 2.4637681159420293, \"y2\": 10.289855072463768, \"center_x\": 2.3188405797101455, \"center_y\": 10.144927536231883, \"value_uncond\": 0.001988535497195876}, {\"x\": 2.4637681159420293, \"y\": 10.0, \"x2\": 2.753623188405797, \"y2\": 10.289855072463768, \"center_x\": 2.608695652173913, \"center_y\": 10.144927536231883, \"value_uncond\": 0.002099170060588627}, {\"x\": 2.753623188405797, \"y\": 10.0, \"x2\": 3.0434782608695645, \"y2\": 10.289855072463768, \"center_x\": 2.8985507246376807, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0021953699423622308}, {\"x\": 3.0434782608695663, \"y\": 10.0, \"x2\": 3.333333333333334, \"y2\": 10.289855072463768, \"center_x\": 3.18840579710145, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0022746449575343722}, {\"x\": 3.333333333333334, \"y\": 10.0, \"x2\": 3.6231884057971016, \"y2\": 10.289855072463768, \"center_x\": 3.4782608695652177, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0023348841543963327}, {\"x\": 3.6231884057971016, \"y\": 10.0, \"x2\": 3.913043478260869, \"y2\": 10.289855072463768, \"center_x\": 3.7681159420289854, \"center_y\": 10.144927536231883, \"value_uncond\": 0.002374449140681441}, {\"x\": 3.913043478260871, \"y\": 10.0, \"x2\": 4.202898550724639, \"y2\": 10.289855072463768, \"center_x\": 4.057971014492755, \"center_y\": 10.144927536231883, \"value_uncond\": 0.002392248109511243}, {\"x\": 4.202898550724639, \"y\": 10.0, \"x2\": 4.492753623188406, \"y2\": 10.289855072463768, \"center_x\": 4.347826086956522, \"center_y\": 10.144927536231883, \"value_uncond\": 0.002387785897913383}, {\"x\": 4.492753623188406, \"y\": 10.0, \"x2\": 4.782608695652174, \"y2\": 10.289855072463768, \"center_x\": 4.63768115942029, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0023611868746731966}, {\"x\": 4.782608695652174, \"y\": 10.0, \"x2\": 5.0724637681159415, \"y2\": 10.289855072463768, \"center_x\": 4.927536231884058, \"center_y\": 10.144927536231883, \"value_uncond\": 0.002313189180972133}, {\"x\": 5.072463768115943, \"y\": 10.0, \"x2\": 5.362318840579711, \"y2\": 10.289855072463768, \"center_x\": 5.217391304347827, \"center_y\": 10.144927536231883, \"value_uncond\": 0.002245110696051106}, {\"x\": 5.362318840579711, \"y\": 10.0, \"x2\": 5.6521739130434785, \"y2\": 10.289855072463768, \"center_x\": 5.507246376811595, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0021587889180850065}, {\"x\": 5.6521739130434785, \"y\": 10.0, \"x2\": 5.942028985507246, \"y2\": 10.289855072463768, \"center_x\": 5.797101449275362, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0020564985877478664}, {\"x\": 5.942028985507246, \"y\": 10.0, \"x2\": 6.231884057971014, \"y2\": 10.289855072463768, \"center_x\": 6.08695652173913, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0019408522069250963}, {\"x\": 6.2318840579710155, \"y\": 10.0, \"x2\": 6.521739130434783, \"y2\": 10.289855072463768, \"center_x\": 6.376811594202899, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0018146895170783953}, {\"x\": 6.521739130434785, \"y\": 10.0, \"x2\": 6.8115942028985526, \"y2\": 10.289855072463768, \"center_x\": 6.666666666666669, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0016809624405866655}, {\"x\": 6.811594202898551, \"y\": 10.0, \"x2\": 7.101449275362318, \"y2\": 10.289855072463768, \"center_x\": 6.956521739130435, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0015426219385989153}, {\"x\": 7.10144927536232, \"y\": 10.0, \"x2\": 7.391304347826088, \"y2\": 10.289855072463768, \"center_x\": 7.246376811594204, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0014025127297047169}, {\"x\": 7.391304347826086, \"y\": 10.0, \"x2\": 7.681159420289854, \"y2\": 10.289855072463768, \"center_x\": 7.53623188405797, \"center_y\": 10.144927536231883, \"value_uncond\": 0.001263280913597526}, {\"x\": 7.681159420289855, \"y\": 10.0, \"x2\": 7.971014492753623, \"y2\": 10.289855072463768, \"center_x\": 7.826086956521739, \"center_y\": 10.144927536231883, \"value_uncond\": 0.001127298351728233}, {\"x\": 7.971014492753625, \"y\": 10.0, \"x2\": 8.260869565217392, \"y2\": 10.289855072463768, \"center_x\": 8.115942028985508, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0009966062901729214}, {\"x\": 8.26086956521739, \"y\": 10.0, \"x2\": 8.550724637681158, \"y2\": 10.289855072463768, \"center_x\": 8.405797101449274, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0008728792917986891}, {\"x\": 8.55072463768116, \"y\": 10.0, \"x2\": 8.840579710144928, \"y2\": 10.289855072463768, \"center_x\": 8.695652173913043, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0007574091919261327}, {\"x\": 8.84057971014493, \"y\": 10.0, \"x2\": 9.130434782608697, \"y2\": 10.289855072463768, \"center_x\": 8.985507246376812, \"center_y\": 10.144927536231883, \"value_uncond\": 0.000651107603492506}, {\"x\": 9.130434782608695, \"y\": 10.0, \"x2\": 9.420289855072463, \"y2\": 10.289855072463768, \"center_x\": 9.275362318840578, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0005545245487238043}, {\"x\": 9.420289855072465, \"y\": 10.0, \"x2\": 9.710144927536232, \"y2\": 10.289855072463768, \"center_x\": 9.565217391304348, \"center_y\": 10.144927536231883, \"value_uncond\": 0.0004678801297808369}, {\"x\": 9.710144927536234, \"y\": 10.0, \"x2\": 10.000000000000002, \"y2\": 10.289855072463768, \"center_x\": 9.855072463768117, \"center_y\": 10.144927536231883, \"value_uncond\": 0.00039110578594931143}, {\"x\": 10.0, \"y\": 10.0, \"x2\": 10.289855072463768, \"y2\": 10.289855072463768, \"center_x\": 10.144927536231883, \"center_y\": 10.144927536231883, \"value_uncond\": 0.00032389160722535483}], \"data-8c80cb8577b8cc407d46734c5f0d66d3\": [{\"theta\": 0.0, \"x\": 1.0, \"y\": 0.0}, {\"theta\": 0.06346651825433926, \"x\": 0.9979866764718844, \"y\": 0.0634239196565645}, {\"theta\": 0.12693303650867852, \"x\": 0.9919548128307953, \"y\": 0.12659245357374926}, {\"theta\": 0.1903995547630178, \"x\": 0.9819286972627067, \"y\": 0.18925124436041021}, {\"theta\": 0.25386607301735703, \"x\": 0.9679487013963562, \"y\": 0.2511479871810792}, {\"theta\": 0.3173325912716963, \"x\": 0.9500711177409454, \"y\": 0.31203344569848707}, {\"theta\": 0.3807991095260356, \"x\": 0.9283679330160726, \"y\": 0.3716624556603276}, {\"theta\": 0.4442656277803748, \"x\": 0.9029265382866212, \"y\": 0.42979491208917164}, {\"theta\": 0.5077321460347141, \"x\": 0.8738493770697849, \"y\": 0.4861967361004687}, {\"theta\": 0.5711986642890533, \"x\": 0.8412535328311812, \"y\": 0.5406408174555976}, {\"theta\": 0.6346651825433925, \"x\": 0.8052702575310586, \"y\": 0.5929079290546404}, {\"theta\": 0.6981317007977318, \"x\": 0.766044443118978, \"y\": 0.6427876096865393}, {\"theta\": 0.7615982190520711, \"x\": 0.7237340381050702, \"y\": 0.690079011482112}, {\"theta\": 0.8250647373064104, \"x\": 0.6785094115571322, \"y\": 0.7345917086575333}, {\"theta\": 0.8885312555607496, \"x\": 0.6305526670845225, \"y\": 0.7761464642917568}, {\"theta\": 0.9519977738150889, \"x\": 0.5800569095711982, \"y\": 0.8145759520503357}, {\"theta\": 1.0154642920694281, \"x\": 0.5272254676105024, \"y\": 0.8497254299495144}, {\"theta\": 1.0789308103237674, \"x\": 0.4722710747726827, \"y\": 0.8814533634475821}, {\"theta\": 1.1423973285781066, \"x\": 0.41541501300188644, \"y\": 0.9096319953545183}, {\"theta\": 1.2058638468324459, \"x\": 0.3568862215918719, \"y\": 0.9341478602651067}, {\"theta\": 1.269330365086785, \"x\": 0.2969203753282749, \"y\": 0.9549022414440739}, {\"theta\": 1.3327968833411243, \"x\": 0.23575893550942728, \"y\": 0.9718115683235417}, {\"theta\": 1.3962634015954636, \"x\": 0.17364817766693041, \"y\": 0.984807753012208}, {\"theta\": 1.4597299198498028, \"x\": 0.1108381999010111, \"y\": 0.9938384644612541}, {\"theta\": 1.5231964381041423, \"x\": 0.04758191582374218, \"y\": 0.998867339183008}, {\"theta\": 1.5866629563584815, \"x\": -0.01586596383480803, \"y\": 0.9998741276738751}, {\"theta\": 1.6501294746128208, \"x\": -0.07924995685678854, \"y\": 0.9968547759519424}, {\"theta\": 1.71359599286716, \"x\": -0.14231483827328523, \"y\": 0.9898214418809327}, {\"theta\": 1.7770625111214993, \"x\": -0.20480666806519074, \"y\": 0.9788024462147787}, {\"theta\": 1.8405290293758385, \"x\": -0.26647381369003503, \"y\": 0.963842158559942}, {\"theta\": 1.9039955476301778, \"x\": -0.32706796331742166, \"y\": 0.9450008187146685}, {\"theta\": 1.967462065884517, \"x\": -0.3863451256931287, \"y\": 0.9223542941045814}, {\"theta\": 2.0309285841388562, \"x\": -0.4440666126057741, \"y\": 0.8959937742913359}, {\"theta\": 2.0943951023931957, \"x\": -0.5000000000000002, \"y\": 0.8660254037844386}, {\"theta\": 2.1578616206475347, \"x\": -0.5539200638661103, \"y\": 0.8325698546347714}, {\"theta\": 2.221328138901874, \"x\": -0.6056096871376668, \"y\": 0.795761840530832}, {\"theta\": 2.284794657156213, \"x\": -0.6548607339452851, \"y\": 0.7557495743542583}, {\"theta\": 2.3482611754105527, \"x\": -0.7014748877063214, \"y\": 0.7126941713788628}, {\"theta\": 2.4117276936648917, \"x\": -0.7452644496757547, \"y\": 0.6667690005162916}, {\"theta\": 2.475194211919231, \"x\": -0.7860530947427875, \"y\": 0.6181589862206052}, {\"theta\": 2.53866073017357, \"x\": -0.8236765814298327, \"y\": 0.5670598638627709}, {\"theta\": 2.6021272484279097, \"x\": -0.8579834132349771, \"y\": 0.5136773915734063}, {\"theta\": 2.6655937666822487, \"x\": -0.8888354486549234, \"y\": 0.4582265217274105}, {\"theta\": 2.729060284936588, \"x\": -0.9161084574320696, \"y\": 0.4009305354066136}, {\"theta\": 2.792526803190927, \"x\": -0.9396926207859083, \"y\": 0.3420201433256689}, {\"theta\": 2.8559933214452666, \"x\": -0.9594929736144974, \"y\": 0.28173255684142967}, {\"theta\": 2.9194598396996057, \"x\": -0.975429786885407, \"y\": 0.2203105327865408}, {\"theta\": 2.982926357953945, \"x\": -0.9874388886763943, \"y\": 0.1580013959733499}, {\"theta\": 3.0463928762082846, \"x\": -0.9954719225730846, \"y\": 0.09505604330418244}, {\"theta\": 3.1098593944626236, \"x\": -0.9994965423831851, \"y\": 0.031727933498067656}, {\"theta\": 3.173325912716963, \"x\": -0.9994965423831851, \"y\": -0.03172793349806786}, {\"theta\": 3.236792430971302, \"x\": -0.9954719225730846, \"y\": -0.09505604330418263}, {\"theta\": 3.3002589492256416, \"x\": -0.9874388886763943, \"y\": -0.15800139597335008}, {\"theta\": 3.3637254674799806, \"x\": -0.975429786885407, \"y\": -0.22031053278654056}, {\"theta\": 3.42719198573432, \"x\": -0.9594929736144974, \"y\": -0.28173255684142984}, {\"theta\": 3.490658503988659, \"x\": -0.9396926207859084, \"y\": -0.34202014332566866}, {\"theta\": 3.5541250222429985, \"x\": -0.9161084574320696, \"y\": -0.4009305354066138}, {\"theta\": 3.6175915404973376, \"x\": -0.8888354486549235, \"y\": -0.4582265217274103}, {\"theta\": 3.681058058751677, \"x\": -0.857983413234977, \"y\": -0.5136773915734064}, {\"theta\": 3.744524577006016, \"x\": -0.8236765814298328, \"y\": -0.5670598638627706}, {\"theta\": 3.8079910952603555, \"x\": -0.7860530947427874, \"y\": -0.6181589862206053}, {\"theta\": 3.8714576135146945, \"x\": -0.7452644496757548, \"y\": -0.6667690005162915}, {\"theta\": 3.934924131769034, \"x\": -0.7014748877063213, \"y\": -0.7126941713788629}, {\"theta\": 3.998390650023373, \"x\": -0.6548607339452852, \"y\": -0.7557495743542582}, {\"theta\": 4.0618571682777125, \"x\": -0.6056096871376666, \"y\": -0.7957618405308321}, {\"theta\": 4.1253236865320515, \"x\": -0.5539200638661105, \"y\": -0.8325698546347713}, {\"theta\": 4.188790204786391, \"x\": -0.4999999999999996, \"y\": -0.8660254037844388}, {\"theta\": 4.25225672304073, \"x\": -0.44406661260577396, \"y\": -0.895993774291336}, {\"theta\": 4.3157232412950695, \"x\": -0.3863451256931287, \"y\": -0.9223542941045814}, {\"theta\": 4.3791897595494085, \"x\": -0.3270679633174219, \"y\": -0.9450008187146683}, {\"theta\": 4.442656277803748, \"x\": -0.26647381369003464, \"y\": -0.9638421585599422}, {\"theta\": 4.506122796058087, \"x\": -0.20480666806519054, \"y\": -0.9788024462147787}, {\"theta\": 4.569589314312426, \"x\": -0.14231483827328523, \"y\": -0.9898214418809327}, {\"theta\": 4.6330558325667655, \"x\": -0.07924995685678879, \"y\": -0.9968547759519423}, {\"theta\": 4.696522350821105, \"x\": -0.01586596383480761, \"y\": -0.9998741276738751}, {\"theta\": 4.759988869075444, \"x\": 0.04758191582374238, \"y\": -0.998867339183008}, {\"theta\": 4.823455387329783, \"x\": 0.11083819990101086, \"y\": -0.9938384644612541}, {\"theta\": 4.886921905584122, \"x\": 0.17364817766692997, \"y\": -0.9848077530122081}, {\"theta\": 4.950388423838462, \"x\": 0.23575893550942748, \"y\": -0.9718115683235417}, {\"theta\": 5.013854942092801, \"x\": 0.29692037532827487, \"y\": -0.9549022414440739}, {\"theta\": 5.07732146034714, \"x\": 0.35688622159187167, \"y\": -0.9341478602651068}, {\"theta\": 5.14078797860148, \"x\": 0.4154150130018868, \"y\": -0.9096319953545182}, {\"theta\": 5.204254496855819, \"x\": 0.4722710747726829, \"y\": -0.881453363447582}, {\"theta\": 5.267721015110158, \"x\": 0.5272254676105024, \"y\": -0.8497254299495144}, {\"theta\": 5.331187533364497, \"x\": 0.5800569095711979, \"y\": -0.8145759520503358}, {\"theta\": 5.394654051618837, \"x\": 0.6305526670845228, \"y\": -0.7761464642917566}, {\"theta\": 5.458120569873176, \"x\": 0.6785094115571323, \"y\": -0.7345917086575332}, {\"theta\": 5.521587088127515, \"x\": 0.7237340381050701, \"y\": -0.690079011482112}, {\"theta\": 5.585053606381854, \"x\": 0.7660444431189778, \"y\": -0.6427876096865396}, {\"theta\": 5.648520124636194, \"x\": 0.8052702575310589, \"y\": -0.5929079290546402}, {\"theta\": 5.711986642890533, \"x\": 0.8412535328311812, \"y\": -0.5406408174555976}, {\"theta\": 5.775453161144872, \"x\": 0.8738493770697849, \"y\": -0.4861967361004688}, {\"theta\": 5.838919679399211, \"x\": 0.9029265382866211, \"y\": -0.4297949120891719}, {\"theta\": 5.902386197653551, \"x\": 0.9283679330160727, \"y\": -0.37166245566032724}, {\"theta\": 5.96585271590789, \"x\": 0.9500711177409454, \"y\": -0.31203344569848707}, {\"theta\": 6.029319234162229, \"x\": 0.9679487013963562, \"y\": -0.2511479871810794}, {\"theta\": 6.092785752416569, \"x\": 0.9819286972627068, \"y\": -0.18925124436040974}, {\"theta\": 6.156252270670908, \"x\": 0.9919548128307953, \"y\": -0.12659245357374904}, {\"theta\": 6.219718788925247, \"x\": 0.9979866764718844, \"y\": -0.06342391965656452}, {\"theta\": 6.283185307179586, \"x\": 1.0, \"y\": -2.4492935982947064e-16}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.LayerChart(...)"
      ]
     },
     "execution_count": 12,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# | label: plot2\n",
    "plot_conditional(components)"
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": ".venv",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.12.8"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 2
}
